!******************************************************************************!
!                                                                              !
!    class_vertices.f90                                                        !
!    is part of RECOLA2 (REcursive Computation of One Loop Amplitudes)2        !
!                                                                              !
!    Copyright (C) 2016-2018 Ansgar Denner, Jean-Nicolas Lang and              !
!                            Sandro Uccirati                                   !
!                                                                              !
!    RECOLA2 is licenced under the GNU GPL version 3,                          !
!    see COPYING for details.                                                  !
!                                                                              !
!******************************************************************************!
!                                                           .---.              !
!                                                          /  .  \             !
!                                                         |\_/|   |            !
!                                                         |   |  /|            !
!          .----------------------------------------------------' |            !
!         /  .-.   class_vertices.f90                             |            !
!        |  /   \  This code was generated with REPT1L.           |            !
!        | |\_.  | Change this file and you get what you deserve. |            !
!        |\|  | /| Author: J.N. Lang                              |            !
!        | `---' | UFO date: 07/2017                              |            !
!        |       | UFO version: 1.0                               |            !
!        |       | Generation date: 2018-11-30 19:53             /             !
!        |       |----------------------------------------------'              !
!        \       |                                                             !
!         \     /                                                              !
!          `---'                                                               !
!******************************************************************************!
module class_vertices
  use fill_couplings
  use class_particles
  use class_ctparameters
  use fill_ctparameters, only: init_CTparameters_mdl
  use particle_keys, only: createParticleConfig
  use dictionary, only: dict,dict_get_value,dict_init
  use constants_mdl, only: Nc
  implicit none
  save

  interface get_vertex_mdl
    module procedure get_vertex3_mdl, get_vertex4_mdl, get_vertexN_mdl
  end interface

  type Branch
    integer :: lorentz_id
    integer :: perm
    integer, allocatable :: couplings(:)
    integer, dimension(n_orders) :: coupling_order
    integer :: color_id
    integer :: colorfac_id
    ! Propagator extension (only supported for massive vectors)
    ! 0: Usual propagator
    ! 1: Rxi-propagator part with pole @ M_V^2
    ! 2: Rxi-propagator part with pole @ \xi*M_V^2
    integer :: pext
  end type

  type Vertex
    type(Branch), allocatable :: branch(:)
    type(Branch), allocatable :: branchCT(:)
    type(Branch), allocatable :: branchR2(:)
  end type

  logical :: vertices_init = .false.
  logical :: vertices_filled = .false.
    interface createCurrent
      module procedure createCurrent2, createCurrent3, createCurrent4,         &
      createCurrent5, createCurrent6, createCurrent7, createCurrent8
    end interface 
  integer, parameter :: n_vertices = 10763
  type(Vertex) :: vertices(0:n_vertices-1)

  ! Defines the maximum allowed number of legs participating at a vertex
  integer, parameter :: max_leg_multiplicity = 4

  integer, parameter :: FFaS0 = 1
  integer, parameter :: FFaS1 = 2
  integer, parameter :: FFaS2 = 3
  integer, parameter :: UaVUV0 = 4
  integer, parameter :: VFaF0 = 5
  integer, parameter :: VFaF1 = 6
  integer, parameter :: SVVS0 = 7
  integer, parameter :: UaSSU0 = 8
  integer, parameter :: VVVV0 = 9
  integer, parameter :: VVVV1 = 10
  integer, parameter :: UUaS0 = 11
  integer, parameter :: UUaV0 = 12
  integer, parameter :: UUaV1 = 13
  integer, parameter :: SUSUa0 = 14
  integer, parameter :: SUUaS0 = 15
  integer, parameter :: SUUa0 = 16
  integer, parameter :: SSUUa0 = 17
  integer, parameter :: VVSS0 = 18
  integer, parameter :: VUaUV0 = 19
  integer, parameter :: UaSU0 = 20
  integer, parameter :: FFaV0 = 21
  integer, parameter :: FFaV1 = 22
  integer, parameter :: SUaSU0 = 23
  integer, parameter :: VVV0 = 24
  integer, parameter :: VVV1 = 25
  integer, parameter :: FSFa0 = 26
  integer, parameter :: FSFa1 = 27
  integer, parameter :: FSFa2 = 28
  integer, parameter :: UaUSS0 = 29
  integer, parameter :: VVUUa0 = 30
  integer, parameter :: FaVF0 = 31
  integer, parameter :: FaVF1 = 32
  integer, parameter :: UUaVV0 = 33
  integer, parameter :: UaVU0 = 34
  integer, parameter :: FaF0 = 35
  integer, parameter :: FaF1 = 36
  integer, parameter :: FaF2 = 37
  integer, parameter :: SUaUS0 = 38
  integer, parameter :: FVFa0 = 39
  integer, parameter :: FVFa1 = 40
  integer, parameter :: UaSUS0 = 41
  integer, parameter :: VUaU0 = 42
  integer, parameter :: VUaU1 = 43
  integer, parameter :: USUa0 = 44
  integer, parameter :: SV0 = 45
  integer, parameter :: SV1 = 46
  integer, parameter :: VUUaV0 = 47
  integer, parameter :: VV0 = 48
  integer, parameter :: VV1 = 49
  integer, parameter :: VV2 = 50
  integer, parameter :: VV3 = 51
  integer, parameter :: UaVVU0 = 52
  integer, parameter :: SVSV0 = 53
  integer, parameter :: VUVUa0 = 54
  integer, parameter :: FaFS0 = 55
  integer, parameter :: FaFS1 = 56
  integer, parameter :: FaFS2 = 57
  integer, parameter :: FFa0 = 58
  integer, parameter :: FFa1 = 59
  integer, parameter :: FFa2 = 60
  integer, parameter :: FaFV0 = 61
  integer, parameter :: FaFV1 = 62
  integer, parameter :: SSSS0 = 63
  integer, parameter :: VSVS0 = 64
  integer, parameter :: UVUaV0 = 65
  integer, parameter :: VS0 = 66
  integer, parameter :: VS1 = 67
  integer, parameter :: SFFa0 = 68
  integer, parameter :: SFFa1 = 69
  integer, parameter :: SFFa2 = 70
  integer, parameter :: VUUa0 = 71
  integer, parameter :: VUUa1 = 72
  integer, parameter :: SFaF0 = 73
  integer, parameter :: SFaF1 = 74
  integer, parameter :: SFaF2 = 75
  integer, parameter :: VVS0 = 76
  integer, parameter :: SVV0 = 77
  integer, parameter :: FaSF0 = 78
  integer, parameter :: FaSF1 = 79
  integer, parameter :: FaSF2 = 80
  integer, parameter :: SVS0 = 81
  integer, parameter :: VVUaU0 = 82
  integer, parameter :: USUaS0 = 83
  integer, parameter :: UaUVV0 = 84
  integer, parameter :: VSS0 = 85
  integer, parameter :: VSS1 = 86
  integer, parameter :: VSV0 = 87
  integer, parameter :: SS0 = 88
  integer, parameter :: SS1 = 89
  integer, parameter :: SS2 = 90
  integer, parameter :: SS3 = 91
  integer, parameter :: SS4 = 92
  integer, parameter :: SS5 = 93
  integer, parameter :: SSVV0 = 94
  integer, parameter :: SSV0 = 95
  integer, parameter :: SSV1 = 96
  integer, parameter :: UVVUa0 = 97
  integer, parameter :: SSS0 = 98
  integer, parameter :: UVUa0 = 99
  integer, parameter :: SSUaU0 = 100
  integer, parameter :: VSSV0 = 101
  integer, parameter :: SUaU0 = 102
  integer, parameter :: USSUa0 = 103
  integer, parameter :: UaUS0 = 104
  integer, parameter :: VFFa0 = 105
  integer, parameter :: VFFa1 = 106
  integer, parameter :: UUaSS0 = 107
  integer, parameter :: VUaVU0 = 108
  integer, parameter :: UaUV0 = 109
  integer, parameter :: UaUV1 = 110
  complex(dp), parameter :: c1 = cmplx(1d0, 0d0, kind=dp)
  character(len=20), parameter :: c1f = "1"
  complex(dp), parameter :: c2 = cmplx(1d0/2d0, 0d0, kind=dp)
  character(len=20), parameter :: c2f = "1/2"
  complex(dp), parameter :: c3 = cmplx(-1d0/2d0, 0d0, kind=dp)
  character(len=20), parameter :: c3f = "-1/2"
  complex(dp), parameter :: c4 = cmplx(sq2/2d0, 0d0, kind=dp)
  character(len=20), parameter :: c4f = "sq2/2"
  complex(dp), parameter :: c5 = cmplx(-sq2/(2d0*Nc), 0d0, kind=dp)
  character(len=20), parameter :: c5f = "-sq2/(2*Nc)"
  complex(dp), parameter :: c6 = cmplx(0d0, sq2/2d0, kind=dp)
  character(len=20), parameter :: c6f = "i_*sq2/2"
  complex(dp), parameter :: c7 = cmplx(0d0, -sq2/2d0, kind=dp)
  character(len=20), parameter :: c7f = "-i_*sq2/2"
  complex(dp), parameter :: c8 = cmplx(-1d0/Nc, 0d0, kind=dp)
  character(len=20), parameter :: c8f = "-1/Nc"
  complex(dp), dimension(1:8) :: colorcoeffs = (/c1, c2, c3, c4, c5, c6, c7, c8&
                                               /)
  character(len=20), dimension(1:8) :: colorcoeffs_form = (/c1f, c2f, c3f, c4f &
                 , c5f, c6f, c7f, c8f/)
  integer, dimension(1:110) :: lorentz_rank = (/0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0&
                                              , 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0&
                                              , 0, 1, 1, 1, 1, 1, 0, 0, 1, 1, 0&
                                              , 1, -1, -1, -1, 0, 1, 1, 0, 1, 1&
                                              , 0, -1, -1, 0, -1, -1, -1, -1, 0&
                                              , 0, 0, 0, 0, 0, -1, -1, -1, 0, 0&
                                              , 0, 0, 0, -1, -1, 1, 1, 1, 1, 1 &
                                              , 1, 1, 1, 0, 0, 1, 1, 1, 1, 0, 0&
                                              , 0, 1, 1, 0, -1, -1, -1, -1, -1 &
                                              , -1, 0, 1, 1, 0, 0, 1, 0, 0, 0, &
                                              0, 0, 1, 1, 0, 0, 1, 1/)
  integer, dimension(1:110) :: recola_base = (/5, 7, 9, -14, 53, 58, -2, -1, - &
                                             11, -111, 1, 0, 161, -1, -1, 1, -1&
                                             , -4, -13, 1, 15, 17, -1, 160, 12 &
                                             , 21, 25, 27, -1, -4, 51, 57, -12 &
                                             , 0, 0, 0, 0, -1, 31, 35, -1, 0,  &
                                             162, 1, 0, 0, -13, 0, 0, 0, 0, -2 &
                                             , -14, -3, 8, 10, 6, 0, 0, 0, 16, &
                                             18, -1, -3, -14, 0, 0, 26, 23, 28 &
                                             , 163, 0, 43, 46, 48, 2, 13, 47,  &
                                             41, 45, 3, -4, -1, -12, 0, 4, 14, &
                                             0, 0, 0, 0, 0, 0, -12, 0, 11, -2, &
                                             1, 0, -1, -13, 1, -1, 1, 33, 36, -&
                                             1, -3, 0, 164/)
  integer, dimension(1:110) :: propagator_extension = (/0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0/)
  character(len=*), parameter :: model_timestamp = "Fri Nov 30 19:48:23 2018"

  contains
    function get_timestamp_mdl() result(ret_timestamp)
      character(len=len(model_timestamp)) :: ret_timestamp
      ret_timestamp = model_timestamp
    end function get_timestamp_mdl

    function get_lorentz_rank_mdl(l_id) result(ret_lorentz_rank)
      integer, intent(in) :: l_id
      integer :: ret_lorentz_rank
      ret_lorentz_rank = lorentz_rank(l_id)
    end function get_lorentz_rank_mdl

    function get_propagator_extension_mdl(l_id) result(ret_pext)
      integer, intent(in) :: l_id
      integer :: ret_pext
      ret_pext = propagator_extension(l_id)
    end function get_propagator_extension_mdl

    function get_max_leg_multiplicity_mdl() result(ret_max_leg_multiplicity)
      integer :: ret_max_leg_multiplicity
      ret_max_leg_multiplicity = max_leg_multiplicity
    end function get_max_leg_multiplicity_mdl

    function is_model_init_mdl() result(ret_init)
      logical :: ret_init
      ret_init = vertices_init
    end function is_model_init_mdl

    function is_model_filled_mdl() result(ret_init)
      logical :: ret_init
      ret_init = vertices_filled
    end function is_model_filled_mdl

    subroutine get_vertex3_mdl(p1, p2, p3, vertex_ret)
      integer, intent(out) :: vertex_ret
      integer, intent(in)  :: p1, p2, p3
      integer(kind=8)      :: config
      integer              :: address
      logical              :: found_vertex

      call createParticleConfig(p1, p2, p3, config)
      call dict(config, 1, address, found_vertex, 0)
      if(found_vertex) then
        vertex_ret = dict_get_value(address)
      else
        vertex_ret = -1
      end if

    end subroutine get_vertex3_mdl

    subroutine get_vertex4_mdl(p1, p2, p3, p4, vertex_ret)
      integer, intent(out) :: vertex_ret
      integer, intent(in)  :: p1, p2, p3, p4
      integer(kind=8)      :: config
      integer              :: address
      logical              :: found_vertex

      call createParticleConfig(p1, p2, p3, p4, config)
      call dict(config, 1, address, found_vertex, 0)
      if(found_vertex) then
        vertex_ret = dict_get_value(address)
      else
        vertex_ret = -1
      end if
    end subroutine get_vertex4_mdl

    subroutine get_vertexN_mdl(particles, particleOut, vertex_ret)
      integer, intent(out)              :: vertex_ret
      integer, dimension(:), intent(in) :: particles
      integer, intent(in)               :: particleOut
      integer(kind=8)                   :: config
      integer                           :: address
      logical                           :: found_vertex

      call createParticleConfig(particles, particleOut, config)
      call dict(config, 1, address, found_vertex, 0)
      if(found_vertex) then
        vertex_ret = dict_get_value(address)
      else
        vertex_ret = -1
      end if

    end subroutine get_vertexN_mdl

    subroutine av(vid,bid,cid,cfid,pext,lid,perm,co,cop)
      integer, intent(in) :: vid,bid,cid,cfid,pext,lid,perm
      integer, dimension(0:), intent(in) :: co, cop
      integer scop,i
      vertices(vid)%branch(bid)%color_id = cid
      vertices(vid)%branch(bid)%colorfac_id = cfid
      vertices(vid)%branch(bid)%pext = pext
      vertices(vid)%branch(bid)%lorentz_id = lid
      vertices(vid)%branch(bid)%perm = perm
      vertices(vid)%branch(bid)%coupling_order = co
      scop = size(cop)
      allocate(vertices(vid)%branch(bid)%couplings(0:scop-1))
      do i = 0, scop-1
        vertices(vid)%branch(bid)%couplings(i) = cop(i)
      end do
    end subroutine av

    subroutine avCT(vid,bid,cid,cfid,pext,lid,perm,co,cop)
      integer, intent(in) :: vid,bid,cid,cfid,pext,lid,perm
      integer, dimension(0:), intent(in) :: co, cop
      integer scop,i
      vertices(vid)%branchCT(bid)%color_id = cid
      vertices(vid)%branchCT(bid)%colorfac_id = cfid
      vertices(vid)%branchCT(bid)%pext = pext
      vertices(vid)%branchCT(bid)%lorentz_id = lid
      vertices(vid)%branchCT(bid)%perm = perm
      vertices(vid)%branchCT(bid)%coupling_order = co
      scop = size(cop)
      allocate(vertices(vid)%branchCT(bid)%couplings(0:scop-1))
      do i = 0, scop-1
        vertices(vid)%branchCT(bid)%couplings(i) = cop(i)
      end do
    end subroutine avCT

    subroutine avR2(vid,bid,cid,cfid,pext,lid,perm,co,cop)
      integer, intent(in) :: vid,bid,cid,cfid,pext,lid,perm
      integer, dimension(0:), intent(in) :: co, cop
      integer scop,i
      vertices(vid)%branchR2(bid)%color_id = cid
      vertices(vid)%branchR2(bid)%colorfac_id = cfid
      vertices(vid)%branchR2(bid)%pext = pext
      vertices(vid)%branchR2(bid)%lorentz_id = lid
      vertices(vid)%branchR2(bid)%perm = perm
      vertices(vid)%branchR2(bid)%coupling_order = co
      scop = size(cop)
      allocate(vertices(vid)%branchR2(bid)%couplings(0:scop-1))
      do i = 0, scop-1
        vertices(vid)%branchR2(bid)%couplings(i) = cop(i)
      end do
    end subroutine avR2

    function get_colourfac_mdl(cfid)
      integer, intent(in) :: cfid
      complex(dp) :: get_colourfac_mdl
      get_colourfac_mdl = colorcoeffs(cfid)
    end function get_colourfac_mdl

    function get_colourfac_form_mdl(cfid)
      integer, intent(in) :: cfid
      character(len=20) :: get_colourfac_form_mdl
      get_colourfac_form_mdl = colorcoeffs_form(cfid)
    end function get_colourfac_form_mdl

  function get_recola_base_mdl(l_id) result(ret_rb)
      integer, intent(in) :: l_id
      integer :: ret_rb
      ret_rb = recola_base(l_id)
    end function get_recola_base_mdl

  subroutine get_vertex_branch_status_mdl(vx,xlp,branch_exists)
    integer, intent(in)  :: vx,xlp
    logical, intent(out) ::branch_exists
    select case (xlp)
    case(TreeBranch:LoopBranch)
      branch_exists = allocated(vertices(vx)%branch)
    case(CTBranch)
      branch_exists = allocated(vertices(vx)%branchCT)
    case(R2Branch)
      branch_exists = allocated(vertices(vx)%branchR2)
    end select
  end subroutine get_vertex_branch_status_mdl

  subroutine get_vertex_colour_branches_mdl(vx,xlp,cfids,nbranches)
    integer, allocatable, intent(out) :: cfids(:)
    integer, intent(out) :: nbranches
    integer, intent(in)  :: vx,xlp
    select case (xlp)
    case (TreeBranch:LoopBranch)
      allocate(cfids(size(vertices(vx)%branch)))
      cfids(:) = vertices(vx)%branch(0:)%color_id
      nbranches = size(vertices(vx)%branch)
    case(CTBranch)
      allocate(cfids(size(vertices(vx)%branchCT)))
      cfids(:) = vertices(vx)%branchCT(0:)%color_id
      nbranches = size(vertices(vx)%branchCT)
    case(R2Branch)
      allocate(cfids(size(vertices(vx)%branchR2)))
      cfids(:) = vertices(vx)%branchR2(0:)%color_id
      nbranches = size(vertices(vx)%branchR2)
    end select
  end subroutine get_vertex_colour_branches_mdl

  subroutine get_vertex_pext_mdl(vx,xlp,br,pext)
    integer, intent(in) :: vx,xlp,br
    integer, intent(out) :: pext
    select case (xlp)
    case (TreeBranch:LoopBranch)
      pext = vertices(vx)%branch(br)%pext
    case(CTBranch)
      pext = vertices(vx)%branchCT(br)%pext
    case(R2Branch)
      pext = vertices(vx)%branchR2(br)%pext
    end select
  end subroutine get_vertex_pext_mdl

  subroutine get_vertex_order_increase_mdl(vx,xlp,br,orderInc)
    integer, intent(in) :: vx,xlp,br
    integer, dimension(:), intent(out) :: orderInc
    select case (xlp)
    case (TreeBranch:LoopBranch)
      orderInc = vertices(vx)%branch(br)%coupling_order
    case(CTBranch)
      orderInc = vertices(vx)%branchCT(br)%coupling_order
    case(R2Branch)
      orderInc = vertices(vx)%branchR2(br)%coupling_order
    end select
  end subroutine get_vertex_order_increase_mdl

  subroutine get_vertex_lorentz_type_mdl(vx,xlp,br,lid)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: lid
    select case (xlp)
    case (TreeBranch:LoopBranch)
      lid = vertices(vx)%branch(br)%lorentz_id
    case(CTBranch)
      lid = vertices(vx)%branchCT(br)%lorentz_id
    case(R2Branch)
      lid = vertices(vx)%branchR2(br)%lorentz_id
    end select
  end subroutine get_vertex_lorentz_type_mdl

  subroutine get_vertex_perm_mdl(vx,xlp,br,perm)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: perm
    select case (xlp)
    case (TreeBranch:LoopBranch)
      perm = vertices(vx)%branch(br)%perm
    case(CTBranch)
      perm = vertices(vx)%branchCT(br)%perm
    case(R2Branch)
      perm = vertices(vx)%branchR2(br)%perm
    end select
  end subroutine get_vertex_perm_mdl

  subroutine get_vertex_colour_id_mdl(vx,xlp,br,cid)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: cid
    select case (xlp)
    case (TreeBranch:LoopBranch)
      cid = vertices(vx)%branch(br)%colorfac_id
    case(CTBranch)
      cid = vertices(vx)%branchCT(br)%colorfac_id
    case(R2Branch)
      cid = vertices(vx)%branchR2(br)%colorfac_id
    end select
  end subroutine get_vertex_colour_id_mdl

  function is_zero_coupling_vertex_mdl(vx,xlp,br) result(zero)
    use class_couplings, only: get_coupling_value_mdl
    use input_mdl, only: zerocut
    integer, intent(in)  :: vx,xlp,br
    logical              :: zero
    real(dp)             :: maxvalue
    integer              :: i

    zero = .false.
    select case (xlp)
    case (TreeBranch:LoopBranch)
      maxvalue = 0d0
      do i = 1,size(vertices(vx)%branch(br)%couplings)
        maxvalue = maxvalue + &
                abs(get_coupling_value_mdl(vertices(vx)%branch(br)%couplings(i-&
                1)))
      end do
      if (maxvalue/zerocut .lt. 100d0) then
        zero = .true.
      end if
    case(CTBranch)
      maxvalue = 0d0
      do i = 1,size(vertices(vx)%branchCT(br)%couplings)
        maxvalue = maxvalue + &
                abs(get_coupling_value_mdl(vertices(vx)%branchCT(br)%couplings(&
                i-1)))
      end do
      if (maxvalue/zerocut .lt. 100d0) then
        zero = .true.
      end if
    case(R2Branch)
      maxvalue = 0d0
      do i = 1,size(vertices(vx)%branchR2(br)%couplings)
        maxvalue = maxvalue + &
                abs(get_coupling_value_mdl(vertices(vx)%branchR2(br)%couplings(&
                i-1)))
      end do
      if (maxvalue/zerocut .lt. 100d0) then
        zero = .true.
      end if
    end select
  end function is_zero_coupling_vertex_mdl

  subroutine get_vertex_ncouplings_mdl(vx,xlp,br,ncouplings)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: ncouplings
    select case(xlp)
    case(TreeBranch, LoopBranch)
      ncouplings = size(vertices(vx)%branch(br)%couplings)
    case (CTBranch)
      ncouplings = size(vertices(vx)%branchCT(br)%couplings)
    case (R2Branch)
      ncouplings = size(vertices(vx)%branchR2(br)%couplings)
    end select
  end subroutine get_vertex_ncouplings_mdl

  subroutine get_vertex_coupling_ids_mdl(vx,xlp,br,cids)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: cids(:)
    select case(xlp)
    case(TreeBranch, LoopBranch)
      cids(:) = vertices(vx)%branch(br)%couplings(:)
    case (CTBranch)
      cids(:) = vertices(vx)%branchCT(br)%couplings(:)
    case (R2Branch)
      cids(:) = vertices(vx)%branchR2(br)%couplings(:)
    end select
  end subroutine get_vertex_coupling_ids_mdl

    subroutine createCurrent2(P1, P2, id, check)
      integer, intent(in) :: P1, P2, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent2

    subroutine createCurrent3(P1, P2, P3, id, check)
      integer, intent(in) :: P1, P2, P3, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent3

    subroutine createCurrent4(P1, P2, P3, P4, id, check)
      integer, intent(in) :: P1, P2, P3, P4, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent4

    subroutine createCurrent5(P1, P2, P3, P4, P5, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent5

    subroutine createCurrent6(P1, P2, P3, P4, P5, P6, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, P6, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, P6, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent6

    subroutine createCurrent7(P1, P2, P3, P4, P5, P6, P7, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, P6, P7, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, P6, P7, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent7

    subroutine createCurrent8(P1, P2, P3, P4, P5, P6, P7, P8, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, P6, P7, P8, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, P6, P7, P8, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent8

    subroutine init_vertices_mdl()
      use constants_mdl
      use input_mdl, only: nx, error_mdl

      ! check if modelfile is compatible to drivers
      if (model_timestamp .ne. driver_timestamp) then
        call error_mdl("Model corrupted. Driver timestamp mismatch.", &
                      where='init_vertices')
      end if

      vertices_init = .true.
      call fill_couplings_mdl
      call init_CTparameters_mdl(.true.)
      call fill_CTcouplings_mdl
      call dict_init(21523)
      call createCurrents(.false.)

    end subroutine init_vertices_mdl

    subroutine createCurrents(check)
      logical, intent(in) :: check
      call createCurrent(P_ghWp, P_Hh, P_ghZAnti, P_HQMinus, 5280, check)
      call createCurrent(P_GMinus, P_G0, P_A, P_WPlus, 4005, check)
      call createCurrent(P_ghAAnti, P_ghZ, P_WMinus, P_WPlus, 6547, check)
      call createCurrent(P_GPlus, P_b, P_tAnti, 4977, check)
      call createCurrent(P_ghZ, P_Ha, P_ghWmAnti, P_HMinus, 6493, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_HMinus, P_G0, 9935, check)
      call createCurrent(P_GQ0, P_Hh, P_G0, P_HhQ, 7946, check)
      call createCurrent(P_WQPlus, P_WPlus, P_ghWpAnti, P_ghWm, 1151, check)
      call createCurrent(P_HQMinus, P_Hh, P_GPlus, P_HlQ, 7136, check)
      call createCurrent(P_Hl, P_Ha, P_A, 9431, check)
      call createCurrent(P_ghWm, P_Hh, P_ghWmAnti, P_Hl, 9212, check)
      call createCurrent(P_GQ0, P_Hh, P_G0, P_HlQ, 8237, check)
      call createCurrent(P_ghZAnti, P_Hh, P_ghZ, P_Hh, 8622, check)
      call createCurrent(P_HPlus, P_A, P_G0, P_WMinus, 9454, check)
      call createCurrent(P_WQMinus, P_Hl, P_Z, P_GQPlus, 1591, check)
      call createCurrent(P_HMinus, P_Ha, P_GPlus, 7472, check)
      call createCurrent(P_ghZAnti, P_G0, P_GPlus, P_ghWm, 5458, check)
      call createCurrent(P_HPlus, P_ghWpAnti, P_ghZ, P_Hh, 3369, check)
      call createCurrent(P_GPlus, P_ghWm, P_Ha, P_ghZAnti, 9758, check)
      call createCurrent(P_GPlus, P_A, P_HMinus, P_Z, 10400, check)
      call createCurrent(P_nu_tau, P_tauPlus, P_GQMinus, 7859, check)
      call createCurrent(P_ghWpAnti, P_Ha, P_ghA, P_HQPlus, 5112, check)
      call createCurrent(P_HMinus, P_ghWpAnti, P_HPlus, P_ghWp, 2058, check)
      call createCurrent(P_b, P_bAnti, P_Ha, 3084, check)
      call createCurrent(P_GQPlus, P_WMinus, P_HhQ, 8607, check)
      call createCurrent(P_HQPlus, P_GMinus, P_Hh, P_HhQ, 2018, check)
      call createCurrent(P_G0, P_G0, P_G0, P_G0, 6907, check)
      call createCurrent(P_HQPlus, P_Hh, P_GMinus, P_HaQ, 7008, check)
      call createCurrent(P_G0, P_uAnti, P_u, 1849, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_GMinus, P_G0, 4472, check)
      call createCurrent(P_HhQ, P_Ha, P_Ha, P_HhQ, 6443, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghWm, P_GPlus, 1338, check)
      call createCurrent(P_GPlus, P_GMinus, P_Ha, P_G0, 1828, check)
      call createCurrent(P_ghA, P_GMinus, P_GPlus, P_ghAAnti, 7840, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghZ, P_GPlus, 8149, check)
      call createCurrent(P_G0, P_ghWpAnti, P_ghWp, P_Ha, 10372, check)
      call createCurrent(P_G0, P_GPlus, P_Ha, P_GMinus, 1040, check)
      call createCurrent(P_A, P_A, P_ghWm, P_ghWmAnti, 6126, check)
      call createCurrent(P_GPlus, P_Hl, P_GMinus, P_Hl, 7304, check)
      call createCurrent(P_g, P_cAnti, P_c, 8145, check)
      call createCurrent(P_Z, P_Ha, P_Z, P_G0, 9562, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghWpAnti, P_WQPlus, 4052, check)
      call createCurrent(P_HMinus, P_ghZ, P_HPlus, P_ghZAnti, 3174, check)
      call createCurrent(P_WQPlus, P_HMinus, P_HaQ, 3612, check)
      call createCurrent(P_Z, P_GPlus, P_GMinus, P_A, 2563, check)
      call createCurrent(P_HlQ, P_GPlus, P_HMinus, P_GQ0, 1140, check)
      call createCurrent(P_Z, P_Hh, P_A, P_Hh, 10464, check)
      call createCurrent(P_WQPlus, P_A, P_WQMinus, 8524, check)
      call createCurrent(P_HMinus, P_ghWp, P_Ha, P_ghZAnti, 7090, check)
      call createCurrent(P_Hh, P_HMinus, P_HPlus, P_Hh, 2181, check)
      call createCurrent(P_WMinus, P_Ha, P_WPlus, P_Ha, 2655, check)
      call createCurrent(P_Hl, P_HMinus, P_ghZAnti, P_ghWp, 1182, check)
      call createCurrent(P_Hh, P_HMinus, P_A, P_WPlus, 3280, check)
      call createCurrent(P_ghA, P_Hh, P_ghWmAnti, P_HQMinus, 4305, check)
      call createCurrent(P_HhQ, P_HPlus, P_A, P_WQMinus, 8406, check)
      call createCurrent(P_WPlus, P_ghZ, P_WMinus, P_ghZAnti, 8148, check)
      call createCurrent(P_WQPlus, P_Hh, P_GMinus, P_AQ, 890, check)
      call createCurrent(P_WPlus, P_Z, P_Hl, P_HMinus, 1324, check)
      call createCurrent(P_Ha, P_GMinus, P_GPlus, P_Hh, 8943, check)
      call createCurrent(P_Ha, P_HMinus, P_HPlus, 9621, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_GMinus, P_GQPlus, 7909, check)
      call createCurrent(P_g, P_Hh, P_g, P_Hl, 10720, check)
      call createCurrent(P_WQPlus, P_Hh, P_WMinus, P_HhQ, 2005, check)
      call createCurrent(P_G0, P_GPlus, P_WMinus, P_A, 5020, check)
      call createCurrent(P_HQMinus, P_HPlus, P_AQ, 7502, check)
      call createCurrent(P_HaQ, P_HPlus, P_G0, P_HQMinus, 7044, check)
      call createCurrent(P_WPlus, P_Ha, P_GMinus, 10259, check)
      call createCurrent(P_HhQ, P_ghWm, P_Ha, P_ghWmAnti, 3485, check)
      call createCurrent(P_GPlus, P_Hl, P_Z, P_WMinus, 5699, check)
      call createCurrent(P_WQPlus, P_Hl, P_HMinus, P_ZQ, 1199, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_Ha, 6776, check)
      call createCurrent(P_ZQ, P_Hh, P_GPlus, P_WQMinus, 2636, check)
      call createCurrent(P_GQ0, P_Hl, P_ghWmAnti, P_ghWm, 909, check)
      call createCurrent(P_Hh, P_Hh, P_ghWpAnti, P_ghWp, 2537, check)
      call createCurrent(P_HMinus, P_Z, P_HPlus, P_Z, 5008, check)
      call createCurrent(P_Hl, P_ghWp, P_ghWpAnti, P_Hl, 5030, check)
      call createCurrent(P_ghZAnti, P_Hh, P_ghZ, P_HhQ, 597, check)
      call createCurrent(P_GPlus, P_HMinus, P_Hl, P_Ha, 5158, check)
      call createCurrent(P_Hh, P_HMinus, P_Hh, P_GPlus, 1982, check)
      call createCurrent(P_ghWmAnti, P_HMinus, P_ghZ, P_HlQ, 7062, check)
      call createCurrent(P_G0, P_Hh, P_GMinus, P_GPlus, 9354, check)
      call createCurrent(P_ghWmAnti, P_Hh, P_HMinus, P_ghZ, 3747, check)
      call createCurrent(P_GPlus, P_HMinus, P_ghAAnti, P_ghZ, 9541, check)
      call createCurrent(P_Hh, P_HPlus, P_ghZAnti, P_ghWm, 3648, check)
      call createCurrent(P_Ha, P_ghZ, P_Ha, P_ghZAnti, 4737, check)
      call createCurrent(P_ghWmAnti, P_Ha, P_ghA, P_HMinus, 3202, check)
      call createCurrent(P_HaQ, P_HMinus, P_G0, P_HQPlus, 3757, check)
      call createCurrent(P_GQ0, P_ghWmAnti, P_GMinus, P_ghZ, 1455, check)
      call createCurrent(P_A, P_Hl, P_A, P_Hl, 10554, check)
      call createCurrent(P_Hh, P_G0, P_Hl, P_Ha, 747, check)
      call createCurrent(P_HMinus, P_muPlus, P_nu_mu, 1348, check)
      call createCurrent(P_WPlus, P_GMinus, P_Z, P_Ha, 9147, check)
      call createCurrent(P_HQMinus, P_ghWp, P_Ha, P_ghZAnti, 1709, check)
      call createCurrent(P_GMinus, P_GPlus, P_Hl, P_Hl, 4426, check)
      call createCurrent(P_HQMinus, P_ghWp, P_HPlus, P_ghWpAnti, 3079, check)
      call createCurrent(P_A, P_ghWm, P_ghWmAnti, 3148, check)
      call createCurrent(P_Hl, P_ghZ, P_HPlus, P_ghWpAnti, 8228, check)
      call createCurrent(P_Hh, P_HPlus, P_Hl, P_HMinus, 2212, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghA, P_G0, 4709, check)
      call createCurrent(P_HQPlus, P_ghZ, P_Hl, P_ghWpAnti, 4681, check)
      call createCurrent(P_HMinus, P_ghA, P_GPlus, P_ghAAnti, 9874, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_HQPlus, 2711, check)
      call createCurrent(P_ghZAnti, P_G0, P_ghWp, P_GMinus, 5914, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_ghWp, P_AQ, 860, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_GMinus, P_Hl, 2723, check)
      call createCurrent(P_Z, P_ePlus, P_eMinus, 4056, check)
      call createCurrent(P_HQPlus, P_HMinus, P_AQ, 943, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Z, P_AQ, 5605, check)
      call createCurrent(P_G0, P_Hl, P_Ha, P_Hh, 7031, check)
      call createCurrent(P_G0, P_HMinus, P_Hl, P_GPlus, 8384, check)
      call createCurrent(P_ghWmAnti, P_HMinus, P_ghZ, P_Hl, 4457, check)
      call createCurrent(P_GQMinus, P_G0, P_Z, P_WQPlus, 6004, check)
      call createCurrent(P_ZQ, P_WMinus, P_ghZAnti, P_ghWp, 3520, check)
      call createCurrent(P_A, P_ghWmAnti, P_WMinus, P_ghA, 8160, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_Hl, P_GPlus, 397, check)
      call createCurrent(P_HhQ, P_ghWp, P_HMinus, P_ghZAnti, 8729, check)
      call createCurrent(P_ghWm, P_Ha, P_ghZAnti, P_HQPlus, 3352, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_GMinus, P_GQPlus, 4555, check)
      call createCurrent(P_HQPlus, P_HMinus, P_HlQ, 7829, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_A, P_WQPlus, 6427, check)
      call createCurrent(P_Hl, P_GPlus, P_A, P_WMinus, 8387, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_WMinus, P_WQPlus, 6405, check)
      call createCurrent(P_Hl, P_ghZ, P_GMinus, P_ghWmAnti, 4827, check)
      call createCurrent(P_GPlus, P_GMinus, P_Ha, P_Ha, 6569, check)
      call createCurrent(P_GPlus, P_HPlus, P_GMinus, P_HMinus, 7979, check)
      call createCurrent(P_Hh, P_Hh, P_GMinus, P_GPlus, 5408, check)
      call createCurrent(P_ghZAnti, P_Hl, P_ghZ, P_Hh, 9829, check)
      call createCurrent(P_GQ0, P_GMinus, P_ghWp, P_ghAAnti, 3690, check)
      call createCurrent(P_Ha, P_Hh, P_G0, P_Hl, 4311, check)
      call createCurrent(P_HhQ, P_GMinus, P_Hh, P_HQPlus, 5364, check)
      call createCurrent(P_A, P_Z, P_A, P_Z, 10737, check)
      call createCurrent(P_GQ0, P_ghWpAnti, P_ghWp, 2255, check)
      call createCurrent(P_ghA, P_WMinus, P_ghWmAnti, P_A, 8371, check)
      call createCurrent(P_HQPlus, P_Hh, P_GMinus, P_HlQ, 7456, check)
      call createCurrent(P_Z, P_ghZAnti, P_WMinus, P_ghWp, 3807, check)
      call createCurrent(P_WQMinus, P_WPlus, P_HaQ, 4246, check)
      call createCurrent(P_A, P_Hl, P_WMinus, P_HPlus, 2525, check)
      call createCurrent(P_GQ0, P_G0, P_ghWm, P_ghWmAnti, 7910, check)
      call createCurrent(P_HhQ, P_GMinus, P_HQPlus, 5225, check)
      call createCurrent(P_nu_mu, P_nu_muAnti, P_Z, 396, check)
      call createCurrent(P_ZQ, P_WPlus, P_Ha, P_HQMinus, 2364, check)
      call createCurrent(P_ghA, P_Ha, P_ghWmAnti, P_GMinus, 8858, check)
      call createCurrent(P_AQ, P_A, P_ghWp, P_ghWpAnti, 5048, check)
      call createCurrent(P_WPlus, P_ghZ, P_Z, P_ghWpAnti, 7564, check)
      call createCurrent(P_GMinus, P_GPlus, P_ghWm, P_ghWmAnti, 2779, check)
      call createCurrent(P_G0, P_HPlus, P_HMinus, P_G0, 6153, check)
      call createCurrent(P_AQ, P_WPlus, P_ghAAnti, P_ghWm, 6801, check)
      call createCurrent(P_HhQ, P_GMinus, P_WQPlus, 8452, check)
      call createCurrent(P_HQMinus, P_HPlus, P_HlQ, 4216, check)
      call createCurrent(P_GMinus, P_WPlus, P_Z, P_Hh, 7948, check)
      call createCurrent(P_g, P_WPlus, P_WMinus, P_g, 10740, check)
      call createCurrent(P_g, P_A, P_g, P_Z, 10677, check)
      call createCurrent(P_u, P_uAnti, P_Hh, 2787, check)
      call createCurrent(P_Hl, P_G0, P_Ha, P_Hh, 7253, check)
      call createCurrent(P_Hh, P_ghWp, P_ghWpAnti, 5485, check)
      call createCurrent(P_GQMinus, P_HPlus, P_G0, P_HhQ, 5833, check)
      call createCurrent(P_WMinus, P_GMinus, P_HPlus, P_WPlus, 9466, check)
      call createCurrent(P_GMinus, P_GPlus, P_Hl, P_Ha, 10193, check)
      call createCurrent(P_HhQ, P_u, P_uAnti, 8323, check)
      call createCurrent(P_GQMinus, P_Z, P_Z, P_GQPlus, 1474, check)
      call createCurrent(P_HQPlus, P_Hl, P_ghWpAnti, P_ghA, 4383, check)
      call createCurrent(P_GQPlus, P_Hh, P_GMinus, P_HhQ, 3972, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_GPlus, P_G0, 4568, check)
      call createCurrent(P_ghG, P_g, P_ghGAnti, P_g, 3463, check)
      call createCurrent(P_GPlus, P_ghA, P_G0, P_ghWpAnti, 5940, check)
      call createCurrent(P_Z, P_HMinus, P_Z, P_GPlus, 9018, check)
      call createCurrent(P_Ha, P_WPlus, P_HMinus, 1788, check)
      call createCurrent(P_WMinus, P_HPlus, P_Ha, P_Z, 2851, check)
      call createCurrent(P_GMinus, P_ghZ, P_HPlus, P_ghZAnti, 9910, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_Hh, 4651, check)
      call createCurrent(P_GQPlus, P_Ha, P_HMinus, P_HaQ, 2574, check)
      call createCurrent(P_ghZ, P_Ha, P_ghWmAnti, P_GMinus, 9351, check)
      call createCurrent(P_HQMinus, P_HPlus, P_GMinus, P_HQPlus, 8252, check)
      call createCurrent(P_Ha, P_G0, P_ghWp, P_ghWpAnti, 9276, check)
      call createCurrent(P_GPlus, P_nu_muAnti, P_muMinus, 3089, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghWpAnti, P_Ha, 9085, check)
      call createCurrent(P_HPlus, P_A, P_WMinus, P_G0, 9235, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_HMinus, P_ghZ, 9427, check)
      call createCurrent(P_HPlus, P_Hh, P_Ha, P_GMinus, 5711, check)
      call createCurrent(P_G0, P_Ha, P_WMinus, P_WPlus, 9201, check)
      call createCurrent(P_HQMinus, P_ghWmAnti, P_Hh, P_ghZ, 7865, check)
      call createCurrent(P_ghZ, P_ghAAnti, P_GPlus, P_GQMinus, 365, check)
      call createCurrent(P_AQ, P_ghZAnti, P_WMinus, P_ghWp, 5192, check)
      call createCurrent(P_Hh, P_ghWp, P_HMinus, P_ghZAnti, 2322, check)
      call createCurrent(P_WMinus, P_ghWp, P_A, P_ghAAnti, 251, check)
      call createCurrent(P_nu_e, P_HMinus, P_ePlus, 1879, check)
      call createCurrent(P_HQMinus, P_HPlus, P_GPlus, P_HQMinus, 8565, check)
      call createCurrent(P_ZQ, P_Z, P_HlQ, 4871, check)
      call createCurrent(P_ghWp, P_GPlus, P_ghWpAnti, P_GQMinus, 5200, check)
      call createCurrent(P_HhQ, P_HMinus, P_WQPlus, 6295, check)
      call createCurrent(P_GQPlus, P_ghWm, P_ghZAnti, 247, check)
      call createCurrent(P_ghZ, P_HPlus, P_ghWpAnti, P_Ha, 942, check)
      call createCurrent(P_tAnti, P_t, P_A, 2440, check)
      call createCurrent(P_HaQ, P_HPlus, P_GQMinus, 938, check)
      call createCurrent(P_HQMinus, P_HPlus, P_Ha, P_HhQ, 7040, check)
      call createCurrent(P_HMinus, P_ghZ, P_ghAAnti, P_HPlus, 2087, check)
      call createCurrent(P_ghWm, P_HPlus, P_ghZAnti, P_Ha, 2741, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghWpAnti, P_GPlus, 6439, check)
      call createCurrent(P_Z, P_WMinus, P_Ha, P_GPlus, 9997, check)
      call createCurrent(P_HMinus, P_dAnti, P_u, 1891, check)
      call createCurrent(P_Hl, P_Z, P_Hh, P_Z, 10341, check)
      call createCurrent(P_G0, P_GPlus, P_ghWm, P_ghZAnti, 2949, check)
      call createCurrent(P_HlQ, P_tauMinus, P_tauPlus, 3462, check)
      call createCurrent(P_c, P_sAnti, P_WMinus, 7240, check)
      call createCurrent(P_GMinus, P_GPlus, P_ghAAnti, P_ghZ, 7027, check)
      call createCurrent(P_A, P_G0, P_A, P_Ha, 10542, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_WQPlus, 1845, check)
      call createCurrent(P_WPlus, P_ghZ, P_ghWpAnti, 1390, check)
      call createCurrent(P_GQ0, P_GPlus, P_G0, P_HQMinus, 6616, check)
      call createCurrent(P_HPlus, P_ghWm, P_GMinus, P_ghWmAnti, 10070, check)
      call createCurrent(P_HhQ, P_G0, P_ghWm, P_ghWmAnti, 6781, check)
      call createCurrent(P_GQPlus, P_Hl, P_ghWpAnti, P_ghA, 5014, check)
      call createCurrent(P_ghWmAnti, P_G0, P_ghWm, P_GQ0, 3453, check)
      call createCurrent(P_HPlus, P_GMinus, P_GMinus, P_GPlus, 3049, check)
      call createCurrent(P_GPlus, P_Hh, P_G0, P_GMinus, 9496, check)
      call createCurrent(P_G0, P_GMinus, P_ghA, P_ghWmAnti, 3343, check)
      call createCurrent(P_HlQ, P_Hl, P_GMinus, P_GQPlus, 6131, check)
      call createCurrent(P_ghZ, P_Ha, P_ghWpAnti, P_HQPlus, 8701, check)
      call createCurrent(P_WMinus, P_ghWp, P_ghZAnti, P_A, 7193, check)
      call createCurrent(P_HPlus, P_GPlus, P_HMinus, P_GMinus, 4846, check)
      call createCurrent(P_WQPlus, P_G0, P_GQMinus, 74, check)
      call createCurrent(P_WPlus, P_Z, P_ghZAnti, P_ghWm, 6502, check)
      call createCurrent(P_ZQ, P_WMinus, P_A, P_WQPlus, 4850, check)
      call createCurrent(P_cAnti, P_c, P_gQ, 4090, check)
      call createCurrent(P_bAnti, P_t, P_GQMinus, 8114, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_Ha, P_Ha, 3918, check)
      call createCurrent(P_WPlus, P_WMinus, P_G0, P_Ha, 9266, check)
      call createCurrent(P_HhQ, P_ghWp, P_GMinus, P_ghZAnti, 6764, check)
      call createCurrent(P_HPlus, P_HMinus, P_GPlus, P_HMinus, 7725, check)
      call createCurrent(P_Hh, P_Ha, P_Hl, P_Ha, 1139, check)
      call createCurrent(P_Hh, P_A, P_A, P_Hh, 10679, check)
      call createCurrent(P_HlQ, P_Hl, P_Hh, P_HhQ, 3588, check)
      call createCurrent(P_AQ, P_c, P_cAnti, 3402, check)
      call createCurrent(P_GMinus, P_ghAAnti, P_HPlus, P_ghZ, 8862, check)
      call createCurrent(P_HMinus, P_GPlus, P_ghZAnti, P_ghZ, 9793, check)
      call createCurrent(P_HlQ, P_HMinus, P_ghWmAnti, P_ghZ, 1293, check)
      call createCurrent(P_HMinus, P_HPlus, P_Ha, P_Hh, 8849, check)
      call createCurrent(P_HhQ, P_HPlus, P_Hl, P_GQMinus, 6057, check)
      call createCurrent(P_GQ0, P_Hl, P_G0, P_HlQ, 5996, check)
      call createCurrent(P_HaQ, P_Hh, P_GMinus, P_GQPlus, 2903, check)
      call createCurrent(P_HMinus, P_G0, P_ghWmAnti, P_ghZ, 10288, check)
      call createCurrent(P_WMinus, P_A, P_GPlus, P_G0, 2934, check)
      call createCurrent(P_Z, P_G0, P_Ha, P_A, 10641, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_WMinus, P_A, 2732, check)
      call createCurrent(P_Z, P_A, P_Hl, 10390, check)
      call createCurrent(P_AQ, P_GPlus, P_A, P_GQMinus, 1612, check)
      call createCurrent(P_Hh, P_Ha, P_GMinus, P_HPlus, 3333, check)
      call createCurrent(P_u, P_uAnti, P_HhQ, 4621, check)
      call createCurrent(P_ghA, P_ghZAnti, P_WMinus, P_WPlus, 4461, check)
      call createCurrent(P_WQMinus, P_HPlus, P_Z, P_HlQ, 2530, check)
      call createCurrent(P_WQPlus, P_Hl, P_GMinus, P_AQ, 2523, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_GMinus, P_Ha, 9414, check)
      call createCurrent(P_HhQ, P_Hh, P_ghWmAnti, P_ghWm, 8642, check)
      call createCurrent(P_u, P_uAnti, P_Ha, 6574, check)
      call createCurrent(P_Z, P_HMinus, P_A, P_GPlus, 9538, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_G0, P_HMinus, 9301, check)
      call createCurrent(P_ghA, P_Hl, P_GPlus, P_ghWpAnti, 5344, check)
      call createCurrent(P_HMinus, P_WPlus, P_Hl, P_Z, 4282, check)
      call createCurrent(P_ghWp, P_G0, P_HMinus, P_ghAAnti, 9364, check)
      call createCurrent(P_HlQ, P_Ha, P_HPlus, P_GQMinus, 5379, check)
      call createCurrent(P_HQMinus, P_ghWp, P_Hh, P_ghZAnti, 8034, check)
      call createCurrent(P_ghZ, P_Hl, P_ghZAnti, 163, check)
      call createCurrent(P_GPlus, P_Hl, P_Hl, P_GMinus, 4060, check)
      call createCurrent(P_HhQ, P_G0, P_Hh, P_GQ0, 6482, check)
      call createCurrent(P_WMinus, P_Z, P_HPlus, P_Hl, 3788, check)
      call createCurrent(P_tAnti, P_t, P_Z, 3950, check)
      call createCurrent(P_A, P_HMinus, P_A, P_HPlus, 2585, check)
      call createCurrent(P_GMinus, P_A, P_Hl, P_WPlus, 8650, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_GPlus, P_HMinus, 9922, check)
      call createCurrent(P_Hl, P_Ha, P_Ha, 707, check)
      call createCurrent(P_WPlus, P_A, P_ghZ, P_ghWpAnti, 975, check)
      call createCurrent(P_HMinus, P_WPlus, P_A, P_Hl, 683, check)
      call createCurrent(P_WQMinus, P_ghAAnti, P_ghWp, 6039, check)
      call createCurrent(P_ghGAnti, P_g, P_ghG, P_gQ, 5545, check)
      call createCurrent(P_WQPlus, P_Hh, P_Z, P_GQMinus, 6239, check)
      call createCurrent(P_HPlus, P_Hl, P_Ha, P_HMinus, 10183, check)
      call createCurrent(P_HaQ, P_G0, P_HMinus, P_HQPlus, 6241, check)
      call createCurrent(P_Z, P_Ha, P_Z, P_Ha, 7617, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_A, P_ghZ, 997, check)
      call createCurrent(P_WQPlus, P_ghZ, P_ghWpAnti, 7209, check)
      call createCurrent(P_GQPlus, P_G0, P_Z, P_WQMinus, 7329, check)
      call createCurrent(P_Hl, P_HPlus, P_WMinus, P_Z, 3966, check)
      call createCurrent(P_ghZ, P_GPlus, P_HMinus, P_ghAAnti, 9652, check)
      call createCurrent(P_WQPlus, P_GMinus, P_Hl, P_ZQ, 589, check)
      call createCurrent(P_HPlus, P_HMinus, P_ghA, P_ghAAnti, 754, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_Hl, P_GQPlus, 5528, check)
      call createCurrent(P_Hh, P_Ha, P_GPlus, P_HMinus, 2184, check)
      call createCurrent(P_c, P_cAnti, P_G0, 4377, check)
      call createCurrent(P_HlQ, P_HPlus, P_Z, P_WQMinus, 5453, check)
      call createCurrent(P_Ha, P_ghWpAnti, P_G0, P_ghWp, 9043, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghZAnti, P_GMinus, 6618, check)
      call createCurrent(P_HhQ, P_GPlus, P_ghZ, P_ghWpAnti, 6589, check)
      call createCurrent(P_WPlus, P_A, P_G0, P_HMinus, 9672, check)
      call createCurrent(P_ghAAnti, P_HPlus, P_GMinus, P_ghZ, 9359, check)
      call createCurrent(P_HaQ, P_ghWp, P_HMinus, P_ghAAnti, 6966, check)
      call createCurrent(P_Ha, P_Ha, P_HPlus, P_GMinus, 4467, check)
      call createCurrent(P_GMinus, P_ghWm, P_HPlus, P_ghWmAnti, 10412, check)
      call createCurrent(P_HaQ, P_ghAAnti, P_HPlus, P_ghWm, 1083, check)
      call createCurrent(P_HQPlus, P_WMinus, P_WPlus, P_HQMinus, 4100, check)
      call createCurrent(P_WPlus, P_GMinus, P_G0, 6923, check)
      call createCurrent(P_GMinus, P_ghZ, P_ghWmAnti, P_Hh, 4968, check)
      call createCurrent(P_ghAAnti, P_ghA, P_HMinus, P_HPlus, 6027, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_G0, P_GQPlus, 118, check)
      call createCurrent(P_HPlus, P_GMinus, P_ghA, P_ghZAnti, 9808, check)
      call createCurrent(P_A, P_ghWp, P_Z, P_ghWpAnti, 3621, check)
      call createCurrent(P_GMinus, P_HPlus, P_Hh, P_Hl, 1124, check)
      call createCurrent(P_ghWm, P_GPlus, P_Hh, P_ghAAnti, 6472, check)
      call createCurrent(P_Z, P_ghWpAnti, P_WPlus, P_ghZ, 2357, check)
      call createCurrent(P_Z, P_Hl, P_Z, 6573, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_GQ0, 919, check)
      call createCurrent(P_Hl, P_A, P_A, P_Hh, 10719, check)
      call createCurrent(P_Hh, P_GPlus, P_WMinus, P_A, 353, check)
      call createCurrent(P_GMinus, P_A, P_A, P_GPlus, 5469, check)
      call createCurrent(P_HMinus, P_Ha, P_HPlus, 8980, check)
      call createCurrent(P_WQMinus, P_ghWmAnti, P_WMinus, P_ghWp, 3484, check)
      call createCurrent(P_muPlus, P_muMinus, P_A, 1201, check)
      call createCurrent(P_GQPlus, P_GMinus, P_GPlus, P_HQMinus, 1906, check)
      call createCurrent(P_HaQ, P_Hh, P_WMinus, P_WQPlus, 1902, check)
      call createCurrent(P_HMinus, P_ghWp, P_Hh, P_ghZAnti, 5702, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_ZQ, 7577, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_ghWm, P_Hl, 7800, check)
      call createCurrent(P_Hh, P_GMinus, P_HPlus, P_Ha, 1091, check)
      call createCurrent(P_HhQ, P_HMinus, P_ghWp, P_ghAAnti, 249, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghZ, P_Z, 3919, check)
      call createCurrent(P_Hh, P_tAnti, P_t, 2333, check)
      call createCurrent(P_A, P_Hh, P_A, P_Hh, 10654, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_G0, P_ghZ, 1220, check)
      call createCurrent(P_HaQ, P_muPlus, P_muMinus, 4868, check)
      call createCurrent(P_GQPlus, P_G0, P_G0, P_HQMinus, 7446, check)
      call createCurrent(P_d, P_dAnti, 8944, check)
      call createCurrent(P_u, P_dAnti, P_GMinus, 2520, check)
      call createCurrent(P_Z, P_WMinus, P_ghWp, P_ghAAnti, 7977, check)
      call createCurrent(P_HaQ, P_GPlus, P_Hl, P_HQMinus, 6683, check)
      call createCurrent(P_t, P_Hh, P_tAnti, 4280, check)
      call createCurrent(P_G0, P_ghWmAnti, P_ghA, P_HMinus, 9031, check)
      call createCurrent(P_nu_e, P_ePlus, P_WMinus, 3330, check)
      call createCurrent(P_GPlus, P_Z, P_Ha, P_WMinus, 9103, check)
      call createCurrent(P_WQMinus, P_A, P_A, P_WQPlus, 207, check)
      call createCurrent(P_sAnti, P_s, P_Hl, 8425, check)
      call createCurrent(P_ghA, P_HMinus, P_ghZAnti, P_HQPlus, 5437, check)
      call createCurrent(P_GQPlus, P_HMinus, P_GMinus, P_GQPlus, 1590, check)
      call createCurrent(P_G0, P_HMinus, P_Z, P_WPlus, 10408, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghWpAnti, P_GQ0, 6099, check)
      call createCurrent(P_G0, P_HPlus, P_GMinus, P_Ha, 2135, check)
      call createCurrent(P_AQ, P_GPlus, P_WQMinus, 533, check)
      call createCurrent(P_HlQ, P_ghAAnti, P_GPlus, P_ghWm, 1280, check)
      call createCurrent(P_WMinus, P_ghWm, P_ghWmAnti, P_WPlus, 8717, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghAAnti, P_Ha, 8991, check)
      call createCurrent(P_HaQ, P_G0, P_Ha, P_GQ0, 663, check)
      call createCurrent(P_G0, P_Hl, P_HMinus, P_HPlus, 10383, check)
      call createCurrent(P_ghWmAnti, P_Hl, P_HMinus, P_ghA, 6879, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_Ha, P_HPlus, 6095, check)
      call createCurrent(P_HlQ, P_WPlus, P_G0, P_WQMinus, 7386, check)
      call createCurrent(P_HaQ, P_Hh, P_GMinus, P_HQPlus, 6505, check)
      call createCurrent(P_GQPlus, P_HMinus, P_Hl, P_HaQ, 8615, check)
      call createCurrent(P_HQPlus, P_ghA, P_HMinus, P_ghAAnti, 5245, check)
      call createCurrent(P_bAnti, P_G0, P_b, 2374, check)
      call createCurrent(P_WMinus, P_ghZAnti, P_A, P_ghWp, 5504, check)
      call createCurrent(P_GPlus, P_Hl, P_Hh, P_GMinus, 44, check)
      call createCurrent(P_Hh, P_Hl, P_Ha, P_G0, 2081, check)
      call createCurrent(P_HhQ, P_ghZ, P_HMinus, P_ghWmAnti, 8792, check)
      call createCurrent(P_GMinus, P_Z, P_HPlus, 9832, check)
      call createCurrent(P_HQPlus, P_Hh, P_G0, P_GQMinus, 5467, check)
      call createCurrent(P_Hl, P_Ha, P_GMinus, P_GPlus, 10449, check)
      call createCurrent(P_dAnti, P_u, P_GQMinus, 971, check)
      call createCurrent(P_A, P_HPlus, P_HMinus, P_Z, 2965, check)
      call createCurrent(P_GQPlus, P_nu_tauAnti, P_tauMinus, 1693, check)
      call createCurrent(P_HhQ, P_Hh, P_GPlus, P_GQMinus, 3740, check)
      call createCurrent(P_HlQ, P_cAnti, P_c, 2493, check)
      call createCurrent(P_AQ, P_WMinus, P_HQPlus, 878, check)
      call createCurrent(P_HMinus, P_WPlus, P_HPlus, P_WMinus, 4860, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_Ha, P_HQPlus, 1356, check)
      call createCurrent(P_GPlus, P_Ha, P_Hl, P_GMinus, 10032, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_HPlus, P_G0, 10429, check)
      call createCurrent(P_ZQ, P_WPlus, P_Hh, P_HQMinus, 215, check)
      call createCurrent(P_WQPlus, P_Z, P_Z, P_WQMinus, 8391, check)
      call createCurrent(P_G0, P_tauPlus, P_tauMinus, 6919, check)
      call createCurrent(P_G0, P_g, P_G0, P_g, 10678, check)
      call createCurrent(P_ghWmAnti, P_Hh, P_ghWm, P_Hh, 8362, check)
      call createCurrent(P_HPlus, P_GMinus, P_GPlus, P_GMinus, 976, check)
      call createCurrent(P_tAnti, P_Ha, P_t, 4498, check)
      call createCurrent(P_WQPlus, P_HMinus, P_A, P_HhQ, 4805, check)
      call createCurrent(P_HQPlus, P_G0, P_Ha, P_GQMinus, 8818, check)
      call createCurrent(P_WPlus, P_ghAAnti, P_ghWm, P_A, 2679, check)
      call createCurrent(P_HPlus, P_GMinus, P_ghWmAnti, P_ghWm, 9692, check)
      call createCurrent(P_GQMinus, P_GPlus, P_Z, P_AQ, 1955, check)
      call createCurrent(P_ghWm, P_G0, P_ghWmAnti, P_HhQ, 2292, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_Ha, P_GMinus, 8982, check)
      call createCurrent(P_Hl, P_A, P_G0, 9325, check)
      call createCurrent(P_GQMinus, P_G0, P_GPlus, P_GQ0, 3468, check)
      call createCurrent(P_ghA, P_Hh, P_ghWpAnti, P_GPlus, 7140, check)
      call createCurrent(P_HhQ, P_GPlus, P_Hl, P_HQMinus, 4677, check)
      call createCurrent(P_Ha, P_GPlus, P_GMinus, P_Ha, 8824, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Hh, P_GQ0, 5230, check)
      call createCurrent(P_Hh, P_GPlus, P_Hh, P_HMinus, 1494, check)
      call createCurrent(P_HaQ, P_ghZ, P_HMinus, P_ghWmAnti, 8057, check)
      call createCurrent(P_HQPlus, P_Hl, P_WQMinus, 2886, check)
      call createCurrent(P_Ha, P_ghA, P_HMinus, P_ghWmAnti, 6865, check)
      call createCurrent(P_Z, P_ghWp, P_A, P_ghWpAnti, 1598, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_GMinus, P_Ha, 9456, check)
      call createCurrent(P_Z, P_HPlus, P_HMinus, P_A, 2613, check)
      call createCurrent(P_HhQ, P_Hl, P_HhQ, 1616, check)
      call createCurrent(P_muPlus, P_muMinus, P_Hl, 293, check)
      call createCurrent(P_GQ0, P_HPlus, P_HQMinus, 6356, check)
      call createCurrent(P_HPlus, P_G0, P_Hl, P_HMinus, 9574, check)
      call createCurrent(P_HaQ, P_Z, P_Ha, P_ZQ, 1445, check)
      call createCurrent(P_WMinus, P_A, P_G0, P_GPlus, 4607, check)
      call createCurrent(P_GPlus, P_A, P_A, P_GMinus, 5615, check)
      call createCurrent(P_G0, P_ghWm, P_ghZAnti, P_HPlus, 9838, check)
      call createCurrent(P_ghWm, P_G0, P_G0, P_ghWmAnti, 7528, check)
      call createCurrent(P_HhQ, P_HPlus, P_Hl, P_HQMinus, 272, check)
      call createCurrent(P_Hl, P_WPlus, P_Z, P_HMinus, 2460, check)
      call createCurrent(P_Ha, P_WPlus, P_Ha, P_WMinus, 4372, check)
      call createCurrent(P_GPlus, P_HMinus, P_G0, P_Hl, 5703, check)
      call createCurrent(P_HPlus, P_ghZAnti, P_ghA, P_GMinus, 8880, check)
      call createCurrent(P_HMinus, P_GPlus, P_Hl, P_Hh, 378, check)
      call createCurrent(P_Hh, P_Z, P_A, P_Hl, 10664, check)
      call createCurrent(P_GMinus, P_ghWp, P_ghAAnti, 6606, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_Hl, P_GMinus, 213, check)
      call createCurrent(P_ghWm, P_A, P_Z, P_ghWmAnti, 3063, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_ghWp, P_Hl, 5669, check)
      call createCurrent(P_HPlus, P_WMinus, P_WPlus, P_GMinus, 9757, check)
      call createCurrent(P_GQMinus, P_GPlus, P_Ha, P_HlQ, 1692, check)
      call createCurrent(P_HlQ, P_WMinus, P_GPlus, P_ZQ, 7213, check)
      call createCurrent(P_GQMinus, P_GPlus, P_ghWp, P_ghWpAnti, 7622, check)
      call createCurrent(P_ghWmAnti, P_Ha, P_Ha, P_ghWm, 2575, check)
      call createCurrent(P_HaQ, P_G0, P_HMinus, P_GQPlus, 1990, check)
      call createCurrent(P_GQMinus, P_GPlus, P_GPlus, P_GQMinus, 7692, check)
      call createCurrent(P_HQPlus, P_HMinus, P_GQ0, 3938, check)
      call createCurrent(P_Z, P_Hh, P_Z, 7189, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghWpAnti, P_HPlus, 10480, check)
      call createCurrent(P_Z, P_Z, P_Z, P_A, 10686, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_GPlus, P_GMinus, 8530, check)
      call createCurrent(P_GQPlus, P_HMinus, P_HMinus, P_GQPlus, 2805, check)
      call createCurrent(P_WMinus, P_ghWp, P_A, P_ghZAnti, 4475, check)
      call createCurrent(P_ghA, P_ghZAnti, P_GMinus, P_GPlus, 1664, check)
      call createCurrent(P_HQMinus, P_Ha, P_ghZAnti, P_ghWp, 6600, check)
      call createCurrent(P_GPlus, P_ghWp, P_ghWpAnti, P_HMinus, 9545, check)
      call createCurrent(P_ZQ, P_Z, P_ghWpAnti, P_ghWp, 2430, check)
      call createCurrent(P_GQ0, P_Hl, P_GMinus, P_GQPlus, 2668, check)
      call createCurrent(P_ghWpAnti, P_A, P_A, P_ghWp, 7305, check)
      call createCurrent(P_HaQ, P_c, P_cAnti, 2167, check)
      call createCurrent(P_ghWm, P_HPlus, P_HMinus, P_ghWmAnti, 3077, check)
      call createCurrent(P_ghZ, P_Hl, P_ghZAnti, P_HlQ, 3811, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghZ, P_GQ0, 7925, check)
      call createCurrent(P_Hl, P_HMinus, P_HPlus, 4613, check)
      call createCurrent(P_G0, P_Hl, P_G0, P_Hl, 8283, check)
      call createCurrent(P_A, P_s, P_sAnti, 3566, check)
      call createCurrent(P_GQMinus, P_G0, P_HPlus, P_HhQ, 8484, check)
      call createCurrent(P_Hl, P_ghWm, P_GPlus, P_ghAAnti, 1222, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_WPlus, P_Z, 2341, check)
      call createCurrent(P_GQMinus, P_GPlus, P_HlQ, 1343, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_HPlus, P_G0, 10232, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_GPlus, P_GQMinus, 240, check)
      call createCurrent(P_Z, P_GPlus, P_WMinus, P_Hh, 8189, check)
      call createCurrent(P_g, P_t, P_tAnti, 2175, check)
      call createCurrent(P_HPlus, P_Ha, P_WMinus, P_A, 8627, check)
      call createCurrent(P_HQMinus, P_HPlus, P_Z, P_AQ, 4122, check)
      call createCurrent(P_ghWm, P_Ha, P_ghZAnti, P_HPlus, 7237, check)
      call createCurrent(P_Ha, P_ghWm, P_G0, P_ghWmAnti, 9654, check)
      call createCurrent(P_HlQ, P_ghWpAnti, P_Ha, P_ghWp, 6346, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_GMinus, P_HlQ, 1255, check)
      call createCurrent(P_Hh, P_ghA, P_ghWmAnti, P_GMinus, 8683, check)
      call createCurrent(P_A, P_Z, P_Z, P_A, 10538, check)
      call createCurrent(P_GMinus, P_Hl, P_WPlus, 7069, check)
      call createCurrent(P_GMinus, P_Hh, P_Hh, P_GPlus, 5841, check)
      call createCurrent(P_WQPlus, P_GMinus, P_A, P_GQ0, 5201, check)
      call createCurrent(P_HaQ, P_Hl, P_GQ0, 5848, check)
      call createCurrent(P_HPlus, P_ghA, P_GMinus, P_ghZAnti, 10160, check)
      call createCurrent(P_WMinus, P_Z, P_ghAAnti, P_ghWp, 1422, check)
      call createCurrent(P_HMinus, P_WPlus, P_Z, 4127, check)
      call createCurrent(P_GQPlus, P_G0, P_ghZAnti, P_ghWm, 231, check)
      call createCurrent(P_Ha, P_Ha, P_HMinus, P_GPlus, 2069, check)
      call createCurrent(P_HhQ, P_Hl, P_Hl, P_HhQ, 5239, check)
      call createCurrent(P_s, P_Ha, P_sAnti, 2769, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghWp, P_GMinus, 3920, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Z, P_A, 7243, check)
      call createCurrent(P_G0, P_GMinus, P_HPlus, P_Hh, 7974, check)
      call createCurrent(P_GQPlus, P_G0, P_HMinus, P_HhQ, 375, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_Hh, P_Hh, 4430, check)
      call createCurrent(P_HPlus, P_Ha, P_GMinus, P_Hh, 6508, check)
      call createCurrent(P_GQMinus, P_ghWmAnti, P_ghA, 6171, check)
      call createCurrent(P_GQMinus, P_Hl, P_HPlus, P_HaQ, 4474, check)
      call createCurrent(P_GQ0, P_ghWm, P_Hh, P_ghWmAnti, 2300, check)
      call createCurrent(P_HMinus, P_HPlus, P_ghA, P_ghZAnti, 3710, check)
      call createCurrent(P_ghZ, P_WMinus, P_ghWmAnti, P_A, 3813, check)
      call createCurrent(P_WQPlus, P_WMinus, P_ghWm, P_ghWmAnti, 3457, check)
      call createCurrent(P_ePlus, P_eMinus, P_G0, 2478, check)
      call createCurrent(P_Hh, P_Hl, P_Hh, 1661, check)
      call createCurrent(P_G0, P_G0, P_Z, P_A, 9715, check)
      call createCurrent(P_ghZ, P_WPlus, P_ghWpAnti, P_Z, 2981, check)
      call createCurrent(P_HhQ, P_GMinus, P_ghWp, P_ghAAnti, 3822, check)
      call createCurrent(P_Hh, P_GPlus, P_Ha, P_HMinus, 1132, check)
      call createCurrent(P_A, P_Z, P_WPlus, P_WMinus, 8677, check)
      call createCurrent(P_GMinus, P_nu_tau, P_tauPlus, 111, check)
      call createCurrent(P_Ha, P_Ha, P_Z, P_Z, 3228, check)
      call createCurrent(P_HQMinus, P_ghWmAnti, P_ghZ, 1883, check)
      call createCurrent(P_HPlus, P_HMinus, P_A, 7641, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_Hh, P_GPlus, 7690, check)
      call createCurrent(P_HaQ, P_ghAAnti, P_HMinus, P_ghWp, 670, check)
      call createCurrent(P_HhQ, P_G0, P_Hh, P_HaQ, 7679, check)
      call createCurrent(P_HQMinus, P_WPlus, P_Z, P_HhQ, 1815, check)
      call createCurrent(P_HQPlus, P_Hh, P_ghWpAnti, P_ghZ, 8269, check)
      call createCurrent(P_Hh, P_ghAAnti, P_ghWp, P_GMinus, 7039, check)
      call createCurrent(P_ghA, P_WPlus, P_ghWpAnti, P_Z, 3640, check)
      call createCurrent(P_Z, P_Hh, P_Ha, 1015, check)
      call createCurrent(P_A, P_Ha, P_Hh, 8869, check)
      call createCurrent(P_HPlus, P_ghWm, P_Hl, P_ghAAnti, 891, check)
      call createCurrent(P_GPlus, P_HMinus, P_Hh, P_Ha, 8168, check)
      call createCurrent(P_WQMinus, P_WPlus, P_ghA, P_ghZAnti, 3326, check)
      call createCurrent(P_WMinus, P_ghAAnti, P_ghWp, P_A, 6823, check)
      call createCurrent(P_WQMinus, P_GPlus, P_Hl, P_ZQ, 1683, check)
      call createCurrent(P_ghWp, P_HMinus, P_Hh, P_ghZAnti, 1213, check)
      call createCurrent(P_Hl, P_GPlus, P_Hh, P_GMinus, 7893, check)
      call createCurrent(P_G0, P_WPlus, P_Z, P_HMinus, 8859, check)
      call createCurrent(P_ghWm, P_Hl, P_ghWmAnti, P_GQ0, 3767, check)
      call createCurrent(P_HhQ, P_G0, P_G0, P_HlQ, 2642, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_A, P_WMinus, 3118, check)
      call createCurrent(P_HPlus, P_HMinus, P_HPlus, P_HMinus, 2538, check)
      call createCurrent(P_HhQ, P_G0, P_Ha, P_HhQ, 3062, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_GMinus, P_Hh, 6373, check)
      call createCurrent(P_sAnti, P_s, P_G0, 6491, check)
      call createCurrent(P_Z, P_Z, P_HPlus, P_HMinus, 5525, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_ghA, P_GQMinus, 1821, check)
      call createCurrent(P_ghWp, P_Ha, P_ghAAnti, P_HMinus, 1100, check)
      call createCurrent(P_Z, P_ghZAnti, P_ghWp, P_WMinus, 7540, check)
      call createCurrent(P_WQPlus, P_G0, P_G0, P_WQMinus, 301, check)
      call createCurrent(P_b, P_Hl, P_bAnti, 5968, check)
      call createCurrent(P_GPlus, P_Ha, P_G0, P_GMinus, 4262, check)
      call createCurrent(P_G0, P_HPlus, P_WMinus, 9086, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_GPlus, P_Hl, 8066, check)
      call createCurrent(P_Ha, P_ghWp, P_ghWpAnti, P_Ha, 3666, check)
      call createCurrent(P_GPlus, P_Z, P_Z, P_HMinus, 9408, check)
      call createCurrent(P_WQMinus, P_t, P_bAnti, 3471, check)
      call createCurrent(P_ghA, P_GMinus, P_Hh, P_ghWmAnti, 3320, check)
      call createCurrent(P_ghZ, P_Ha, P_ghWpAnti, P_GPlus, 9295, check)
      call createCurrent(P_HhQ, P_GPlus, P_WQMinus, 3737, check)
      call createCurrent(P_GQPlus, P_GMinus, P_GMinus, P_GQPlus, 6762, check)
      call createCurrent(P_Hl, P_GMinus, P_ghAAnti, P_ghWp, 234, check)
      call createCurrent(P_Hl, P_Ha, P_GPlus, P_GMinus, 9905, check)
      call createCurrent(P_Ha, P_GPlus, P_Hh, P_GMinus, 10008, check)
      call createCurrent(P_Ha, P_HPlus, P_Ha, P_GMinus, 453, check)
      call createCurrent(P_G0, P_ghWpAnti, P_GPlus, P_ghA, 3553, check)
      call createCurrent(P_GQPlus, P_Z, P_G0, P_WQMinus, 7101, check)
      call createCurrent(P_HhQ, P_HPlus, P_Hh, P_HQMinus, 2624, check)
      call createCurrent(P_GQPlus, P_GMinus, P_HPlus, P_HQMinus, 1401, check)
      call createCurrent(P_HPlus, P_Ha, P_Hh, P_HMinus, 9512, check)
      call createCurrent(P_ghZAnti, P_ghA, P_GMinus, P_GQPlus, 7819, check)
      call createCurrent(P_HhQ, P_Z, P_WMinus, P_GQPlus, 3487, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_Hh, P_GMinus, 4312, check)
      call createCurrent(P_G0, P_ghZ, P_HPlus, P_ghWpAnti, 9669, check)
      call createCurrent(P_A, P_HMinus, P_Z, P_HPlus, 2942, check)
      call createCurrent(P_HlQ, P_HMinus, P_GPlus, P_GQ0, 2826, check)
      call createCurrent(P_ZQ, P_WPlus, P_A, P_WQMinus, 5502, check)
      call createCurrent(P_HMinus, P_GPlus, P_ghWm, P_ghWmAnti, 10177, check)
      call createCurrent(P_HQPlus, P_GMinus, P_Hh, P_HlQ, 7897, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Hh, P_Hl, 10130, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_G0, P_HPlus, 9491, check)
      call createCurrent(P_HPlus, P_G0, P_GMinus, P_Ha, 654, check)
      call createCurrent(P_A, P_Hl, P_Hh, P_A, 10727, check)
      call createCurrent(P_GMinus, P_Hh, P_ghZAnti, P_ghWp, 6932, check)
      call createCurrent(P_AQ, P_Ha, P_HPlus, P_WQMinus, 1449, check)
      call createCurrent(P_GQMinus, P_c, P_sAnti, 4597, check)
      call createCurrent(P_WQMinus, P_Hl, P_HQPlus, 5543, check)
      call createCurrent(P_dAnti, P_u, P_WQMinus, 3687, check)
      call createCurrent(P_WQPlus, P_A, P_GMinus, P_HlQ, 6954, check)
      call createCurrent(P_Z, P_HPlus, P_Hl, P_WMinus, 5017, check)
      call createCurrent(P_Hh, P_Hh, P_GPlus, P_GMinus, 385, check)
      call createCurrent(P_GPlus, P_WMinus, P_Hh, P_Z, 8786, check)
      call createCurrent(P_GQ0, P_s, P_sAnti, 936, check)
      call createCurrent(P_WQPlus, P_GMinus, P_GQ0, 1460, check)
      call createCurrent(P_GQMinus, P_Ha, P_HPlus, P_HlQ, 2838, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_HlQ, 5272, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_HMinus, P_HaQ, 3674, check)
      call createCurrent(P_Z, P_A, 10436, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_GMinus, P_ghA, 5299, check)
      call createCurrent(P_Ha, P_GMinus, P_G0, P_GPlus, 6054, check)
      call createCurrent(P_GQ0, P_G0, P_Ha, P_GQ0, 4728, check)
      call createCurrent(P_Z, P_ghWp, P_ghAAnti, P_WMinus, 17, check)
      call createCurrent(P_GQMinus, P_Hh, P_ghZAnti, P_ghWp, 2419, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Hl, P_GQ0, 941, check)
      call createCurrent(P_Hl, P_ghWpAnti, P_HPlus, P_ghA, 7654, check)
      call createCurrent(P_ghZ, P_WPlus, P_WMinus, P_ghAAnti, 1479, check)
      call createCurrent(P_WMinus, P_Z, P_Ha, P_HPlus, 4171, check)
      call createCurrent(P_HaQ, P_Z, P_Z, P_HaQ, 7951, check)
      call createCurrent(P_HMinus, P_G0, P_Ha, P_HPlus, 2217, check)
      call createCurrent(P_HMinus, P_Hl, P_ghAAnti, P_ghWp, 6175, check)
      call createCurrent(P_HPlus, P_A, P_GMinus, 9825, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_HMinus, P_HlQ, 724, check)
      call createCurrent(P_GQPlus, P_GMinus, P_HMinus, P_HQPlus, 3704, check)
      call createCurrent(P_Hh, P_GPlus, P_ghWpAnti, P_ghA, 1569, check)
      call createCurrent(P_HQMinus, P_Hl, P_ghWmAnti, P_ghZ, 2666, check)
      call createCurrent(P_ghA, P_WPlus, P_WMinus, P_ghAAnti, 8474, check)
      call createCurrent(P_Ha, P_ghWpAnti, P_GPlus, P_ghA, 10444, check)
      call createCurrent(P_Hh, P_Ha, P_G0, P_Hh, 1, check)
      call createCurrent(P_HQPlus, P_Hh, P_HMinus, P_HhQ, 681, check)
      call createCurrent(P_HhQ, P_Ha, P_HaQ, 4963, check)
      call createCurrent(P_GQ0, P_GPlus, P_ghAAnti, P_ghWm, 8274, check)
      call createCurrent(P_Hh, P_ghZAnti, P_ghWm, P_HPlus, 7507, check)
      call createCurrent(P_HhQ, P_G0, P_GQ0, 3445, check)
      call createCurrent(P_HhQ, P_GPlus, P_ghWpAnti, P_ghZ, 323, check)
      call createCurrent(P_HaQ, P_Hl, P_Hh, P_GQ0, 6745, check)
      call createCurrent(P_ghZ, P_HPlus, P_ghWpAnti, P_G0, 9975, check)
      call createCurrent(P_WPlus, P_Hl, P_Z, P_HMinus, 3016, check)
      call createCurrent(P_Ha, P_WPlus, P_WMinus, P_Ha, 1622, check)
      call createCurrent(P_G0, P_GMinus, P_WPlus, P_Z, 6531, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_Hl, 2291, check)
      call createCurrent(P_HMinus, P_ghZAnti, P_ghWp, 1101, check)
      call createCurrent(P_g, P_g, 10437, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_HPlus, P_HaQ, 1967, check)
      call createCurrent(P_ghWm, P_Hh, P_ghZAnti, P_GPlus, 2892, check)
      call createCurrent(P_G0, P_G0, P_Hh, 6989, check)
      call createCurrent(P_HPlus, P_ghWp, P_HMinus, P_ghWpAnti, 2511, check)
      call createCurrent(P_Hl, P_GPlus, P_Hl, P_GMinus, 2262, check)
      call createCurrent(P_Hh, P_HPlus, P_ghWpAnti, P_ghA, 4003, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_GMinus, P_ghZ, 2966, check)
      call createCurrent(P_ghWpAnti, P_G0, P_ghWp, P_Ha, 9953, check)
      call createCurrent(P_GQMinus, P_GPlus, P_HPlus, P_GQMinus, 2414, check)
      call createCurrent(P_tAnti, P_b, P_HPlus, 7469, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_G0, P_Ha, 8873, check)
      call createCurrent(P_HlQ, P_HPlus, P_Ha, P_GQMinus, 8820, check)
      call createCurrent(P_Z, P_Ha, P_A, P_Ha, 10122, check)
      call createCurrent(P_ZQ, P_WMinus, P_Hl, P_HQPlus, 2535, check)
      call createCurrent(P_HaQ, P_Hh, P_ghWmAnti, P_ghWm, 7628, check)
      call createCurrent(P_HhQ, P_Hl, P_GPlus, P_HQMinus, 483, check)
      call createCurrent(P_ghWp, P_Hh, P_ghZAnti, P_GQMinus, 3151, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_Hl, P_ghZ, 3964, check)
      call createCurrent(P_ghWpAnti, P_Ha, P_ghWp, P_HhQ, 8342, check)
      call createCurrent(P_u, P_uAnti, P_g, 4587, check)
      call createCurrent(P_ghWm, P_Hh, P_ghWmAnti, 882, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghA, 398, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_AQ, 6264, check)
      call createCurrent(P_HQPlus, P_GMinus, P_HhQ, 6451, check)
      call createCurrent(P_ghGAnti, P_ghG, P_g, P_gQ, 6586, check)
      call createCurrent(P_uAnti, P_u, P_AQ, 1660, check)
      call createCurrent(P_ZQ, P_t, P_tAnti, 5800, check)
      call createCurrent(P_GQ0, P_Ha, P_Hl, P_HlQ, 2712, check)
      call createCurrent(P_HQPlus, P_Z, P_WMinus, P_HhQ, 4172, check)
      call createCurrent(P_Hh, P_WMinus, P_WPlus, 4785, check)
      call createCurrent(P_HPlus, P_A, P_HMinus, 1048, check)
      call createCurrent(P_GQ0, P_WMinus, P_GPlus, P_ZQ, 545, check)
      call createCurrent(P_Hh, P_ghA, P_GMinus, P_ghWmAnti, 8259, check)
      call createCurrent(P_WPlus, P_A, P_Hl, P_GMinus, 494, check)
      call createCurrent(P_ghG, P_ghGAnti, P_g, P_g, 6374, check)
      call createCurrent(P_bAnti, P_HMinus, P_t, 7944, check)
      call createCurrent(P_HaQ, P_GPlus, P_Hh, P_GQMinus, 3272, check)
      call createCurrent(P_Ha, P_ghWpAnti, P_ghWp, P_Ha, 5810, check)
      call createCurrent(P_HlQ, P_Z, P_Hl, P_ZQ, 6889, check)
      call createCurrent(P_WQMinus, P_WPlus, P_ghA, P_ghAAnti, 8807, check)
      call createCurrent(P_HhQ, P_Ha, P_G0, P_HhQ, 8076, check)
      call createCurrent(P_HQPlus, P_GMinus, P_HMinus, P_HQPlus, 3289, check)
      call createCurrent(P_ghWm, P_Ha, P_ghZAnti, P_GPlus, 8990, check)
      call createCurrent(P_WMinus, P_A, P_ghZAnti, P_ghWp, 3603, check)
      call createCurrent(P_ZQ, P_uAnti, P_u, 1501, check)
      call createCurrent(P_ghZ, P_G0, P_G0, P_ghZAnti, 516, check)
      call createCurrent(P_WMinus, P_Hl, P_WPlus, P_Hh, 9980, check)
      call createCurrent(P_WPlus, P_ghZAnti, P_A, P_ghWm, 6532, check)
      call createCurrent(P_GMinus, P_ghA, P_ghAAnti, P_HPlus, 10042, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_Hl, P_ghZ, 4387, check)
      call createCurrent(P_GPlus, P_G0, P_Hl, P_GMinus, 9761, check)
      call createCurrent(P_GQPlus, P_Hl, P_G0, P_HQMinus, 4021, check)
      call createCurrent(P_HQMinus, P_Hh, P_G0, P_GQPlus, 2705, check)
      call createCurrent(P_A, P_HMinus, P_WPlus, P_Ha, 2591, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_GQPlus, 263, check)
      call createCurrent(P_HPlus, P_Ha, P_ghWpAnti, P_ghA, 8249, check)
      call createCurrent(P_HaQ, P_ghZAnti, P_HMinus, P_ghWp, 1557, check)
      call createCurrent(P_Hh, P_ghA, P_GPlus, P_ghWpAnti, 5828, check)
      call createCurrent(P_GQMinus, P_Hl, P_ghA, P_ghWmAnti, 2651, check)
      call createCurrent(P_Hl, P_GMinus, P_ghWp, P_ghAAnti, 4257, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_G0, P_GPlus, 7474, check)
      call createCurrent(P_HhQ, P_GMinus, P_ghWp, P_ghZAnti, 5677, check)
      call createCurrent(P_HMinus, P_ghWp, P_ghAAnti, P_Hl, 5140, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_HMinus, 4569, check)
      call createCurrent(P_HQMinus, P_ghAAnti, P_HPlus, P_ghA, 712, check)
      call createCurrent(P_ghWmAnti, P_Hl, P_ghWm, P_GQ0, 696, check)
      call createCurrent(P_Ha, P_GMinus, P_A, P_WPlus, 9708, check)
      call createCurrent(P_HlQ, P_HMinus, P_ghAAnti, P_ghWp, 6580, check)
      call createCurrent(P_GQMinus, P_HPlus, P_HPlus, P_GQMinus, 5035, check)
      call createCurrent(P_ghAAnti, P_ghA, P_HMinus, P_HQPlus, 1721, check)
      call createCurrent(P_HMinus, P_HPlus, P_WPlus, P_WMinus, 8501, check)
      call createCurrent(P_ghZ, P_ghAAnti, P_GPlus, P_HMinus, 9039, check)
      call createCurrent(P_ZQ, P_Z, P_Hh, P_HhQ, 338, check)
      call createCurrent(P_Hl, P_GPlus, P_ghWpAnti, P_ghZ, 4306, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghA, P_A, 3403, check)
      call createCurrent(P_GMinus, P_WPlus, P_Z, P_G0, 3912, check)
      call createCurrent(P_Hh, P_WMinus, P_A, P_GPlus, 4149, check)
      call createCurrent(P_GQ0, P_Hl, P_GMinus, P_HQPlus, 554, check)
      call createCurrent(P_GPlus, P_Hh, P_ghAAnti, P_ghWm, 4848, check)
      call createCurrent(P_HPlus, P_ghZAnti, P_ghWm, P_Hl, 774, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_HMinus, P_Hh, 4181, check)
      call createCurrent(P_GMinus, P_ghWm, P_ghWmAnti, P_HPlus, 10014, check)
      call createCurrent(P_Hl, P_Hh, P_WMinus, P_WPlus, 9383, check)
      call createCurrent(P_nu_tauAnti, P_tauMinus, P_GQPlus, 5737, check)
      call createCurrent(P_HhQ, P_WMinus, P_G0, P_WQPlus, 5086, check)
      call createCurrent(P_g, P_HMinus, P_g, P_HPlus, 10612, check)
      call createCurrent(P_HlQ, P_Hl, P_ghWm, P_ghWmAnti, 3282, check)
      call createCurrent(P_HaQ, P_Z, P_WPlus, P_HQMinus, 1223, check)
      call createCurrent(P_Z, P_ghZ, P_WPlus, P_ghWpAnti, 4416, check)
      call createCurrent(P_WQMinus, P_WPlus, P_Hh, P_HhQ, 2196, check)
      call createCurrent(P_ghWpAnti, P_A, P_ghA, P_WPlus, 3997, check)
      call createCurrent(P_WQMinus, P_HPlus, P_Hl, P_AQ, 6440, check)
      call createCurrent(P_WMinus, P_WPlus, P_Z, 3514, check)
      call createCurrent(P_Hl, P_GPlus, P_HMinus, P_Hl, 3580, check)
      call createCurrent(P_HhQ, P_Ha, P_Hh, P_HaQ, 7439, check)
      call createCurrent(P_Ha, P_ghZ, P_ghWpAnti, P_GPlus, 10084, check)
      call createCurrent(P_GPlus, P_HMinus, P_Ha, P_G0, 7765, check)
      call createCurrent(P_GMinus, P_Ha, P_G0, P_HPlus, 7782, check)
      call createCurrent(P_A, P_Hh, P_Z, 10472, check)
      call createCurrent(P_HMinus, P_HPlus, P_ghZAnti, P_ghA, 5929, check)
      call createCurrent(P_HQMinus, P_Ha, P_HPlus, P_HaQ, 7600, check)
      call createCurrent(P_Hh, P_WPlus, P_Z, P_GMinus, 5266, check)
      call createCurrent(P_Z, P_Z, P_HPlus, P_GMinus, 9911, check)
      call createCurrent(P_HPlus, P_HMinus, P_Z, P_A, 3150, check)
      call createCurrent(P_HhQ, P_GMinus, P_A, P_WQPlus, 3076, check)
      call createCurrent(P_ZQ, P_HPlus, P_A, P_HQMinus, 1505, check)
      call createCurrent(P_WMinus, P_HPlus, P_G0, P_Z, 9738, check)
      call createCurrent(P_ghA, P_HMinus, P_ghZAnti, P_HPlus, 7447, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_Ha, P_HPlus, 6232, check)
      call createCurrent(P_WQPlus, P_tAnti, P_b, 7857, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_WMinus, P_ghWp, 8008, check)
      call createCurrent(P_Hl, P_WMinus, P_WPlus, 6047, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_ghWm, P_A, 526, check)
      call createCurrent(P_HMinus, P_ghZAnti, P_GPlus, P_ghA, 9934, check)
      call createCurrent(P_WMinus, P_G0, P_GPlus, 2602, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_HMinus, P_HlQ, 2496, check)
      call createCurrent(P_HMinus, P_ePlus, P_nu_e, 3480, check)
      call createCurrent(P_u, P_dAnti, P_HMinus, 3862, check)
      call createCurrent(P_GPlus, P_A, P_WMinus, P_Hh, 5307, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_Hh, P_ghWm, 2072, check)
      call createCurrent(P_WPlus, P_g, P_g, P_WMinus, 10546, check)
      call createCurrent(P_GPlus, P_HMinus, P_A, P_Z, 10204, check)
      call createCurrent(P_HlQ, P_WMinus, P_A, P_HQPlus, 4250, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_Hl, P_GMinus, 6306, check)
      call createCurrent(P_GMinus, P_ghA, P_Ha, P_ghWmAnti, 10474, check)
      call createCurrent(P_Ha, P_Ha, P_Ha, P_Ha, 4684, check)
      call createCurrent(P_GPlus, P_Hh, P_GMinus, P_G0, 10221, check)
      call createCurrent(P_ghZ, P_Hh, P_ghWmAnti, P_HMinus, 4356, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_HPlus, P_Hl, 4162, check)
      call createCurrent(P_ghWp, P_HMinus, P_HPlus, P_ghWpAnti, 255, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghA, P_Hl, 1205, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_G0, P_ghWm, 2649, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_WPlus, P_ghA, 7291, check)
      call createCurrent(P_HQMinus, P_WPlus, P_Z, P_HaQ, 6867, check)
      call createCurrent(P_g, P_g, P_Hh, P_Hh, 10544, check)
      call createCurrent(P_GMinus, P_G0, P_HPlus, P_G0, 4227, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_HMinus, P_ghWp, 9373, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_HPlus, P_Ha, 3808, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_WMinus, P_WPlus, 6124, check)
      call createCurrent(P_G0, P_A, P_WPlus, P_HMinus, 9215, check)
      call createCurrent(P_ghWpAnti, P_Hl, P_ghZ, P_GPlus, 2944, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_Ha, P_GPlus, 9473, check)
      call createCurrent(P_GPlus, P_Ha, P_HMinus, 8173, check)
      call createCurrent(P_GMinus, P_GPlus, P_GPlus, P_HMinus, 8291, check)
      call createCurrent(P_Ha, P_G0, P_Ha, P_Ha, 7449, check)
      call createCurrent(P_ZQ, P_WMinus, P_WPlus, P_AQ, 8597, check)
      call createCurrent(P_WPlus, P_d, P_uAnti, 7332, check)
      call createCurrent(P_ghWp, P_Hl, P_ghWpAnti, P_GQ0, 3416, check)
      call createCurrent(P_tAnti, P_t, P_HaQ, 8398, check)
      call createCurrent(P_GMinus, P_bAnti, P_t, 2923, check)
      call createCurrent(P_WMinus, P_GPlus, P_Ha, P_A, 9293, check)
      call createCurrent(P_G0, P_HMinus, P_ghWp, P_ghZAnti, 9524, check)
      call createCurrent(P_ghA, P_GPlus, P_HMinus, P_ghAAnti, 9870, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_HMinus, P_G0, 9179, check)
      call createCurrent(P_Hh, P_GPlus, P_WMinus, P_Z, 6847, check)
      call createCurrent(P_GQMinus, P_GPlus, P_G0, P_HlQ, 6287, check)
      call createCurrent(P_GQPlus, P_HPlus, P_GMinus, P_HQMinus, 3505, check)
      call createCurrent(P_G0, P_g, P_g, P_G0, 10649, check)
      call createCurrent(P_GMinus, P_GPlus, P_ghZ, P_ghZAnti, 2358, check)
      call createCurrent(P_GMinus, P_WPlus, P_A, P_Ha, 9502, check)
      call createCurrent(P_Hl, P_Ha, P_G0, 6705, check)
      call createCurrent(P_GQPlus, P_GPlus, P_GMinus, P_HQMinus, 6285, check)
      call createCurrent(P_ghZAnti, P_HMinus, P_HPlus, P_ghA, 6668, check)
      call createCurrent(P_u, P_GMinus, P_dAnti, 226, check)
      call createCurrent(P_A, P_GPlus, P_WMinus, P_G0, 6449, check)
      call createCurrent(P_HQPlus, P_Hh, P_HQMinus, 4792, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghZ, P_HhQ, 6006, check)
      call createCurrent(P_eMinus, P_ePlus, P_Hl, 5942, check)
      call createCurrent(P_ghWp, P_Ha, P_ghWpAnti, P_G0, 9756, check)
      call createCurrent(P_HMinus, P_ghWmAnti, P_ghA, 704, check)
      call createCurrent(P_HMinus, P_ghWm, P_ghWmAnti, P_GPlus, 9368, check)
      call createCurrent(P_HMinus, P_HPlus, P_G0, P_G0, 4847, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghAAnti, P_A, 2187, check)
      call createCurrent(P_ghAAnti, P_Z, P_WPlus, P_ghWm, 5118, check)
      call createCurrent(P_HMinus, P_G0, P_HPlus, P_Hl, 10417, check)
      call createCurrent(P_HQMinus, P_A, P_WPlus, P_HlQ, 473, check)
      call createCurrent(P_Hl, P_ghWp, P_ghZAnti, P_GMinus, 3995, check)
      call createCurrent(P_G0, P_ghA, P_ghWmAnti, P_HMinus, 9510, check)
      call createCurrent(P_HlQ, P_HPlus, P_HMinus, P_HlQ, 2693, check)
      call createCurrent(P_A, P_WMinus, P_GPlus, P_G0, 8806, check)
      call createCurrent(P_G0, P_Hh, P_Ha, P_Hh, 7642, check)
      call createCurrent(P_Hl, P_Hl, P_Ha, P_Hl, 10712, check)
      call createCurrent(P_HPlus, P_g, P_HMinus, P_g, 10674, check)
      call createCurrent(P_HMinus, P_A, P_G0, P_WPlus, 9476, check)
      call createCurrent(P_Hh, P_A, P_HPlus, P_WMinus, 1021, check)
      call createCurrent(P_GQMinus, P_ghWmAnti, P_ghZ, 1268, check)
      call createCurrent(P_WMinus, P_WPlus, P_Hl, P_Hh, 9136, check)
      call createCurrent(P_GMinus, P_ghZ, P_HPlus, P_ghAAnti, 10201, check)
      call createCurrent(P_ZQ, P_WMinus, P_GPlus, P_HlQ, 3216, check)
      call createCurrent(P_HQPlus, P_GMinus, P_HPlus, P_HQMinus, 5145, check)
      call createCurrent(P_G0, P_Ha, P_Z, P_A, 10578, check)
      call createCurrent(P_ghZ, P_Ha, P_ghZAnti, P_G0, 10170, check)
      call createCurrent(P_Z, P_GPlus, P_WMinus, P_G0, 2761, check)
      call createCurrent(P_b, P_bAnti, P_AQ, 609, check)
      call createCurrent(P_HPlus, P_Ha, P_HMinus, 9169, check)
      call createCurrent(P_HPlus, P_Hh, P_Hl, P_GMinus, 1803, check)
      call createCurrent(P_Z, P_WPlus, P_HMinus, P_Hl, 8741, check)
      call createCurrent(P_HPlus, P_Hh, P_GMinus, 8472, check)
      call createCurrent(P_HMinus, P_HPlus, P_Hh, 3205, check)
      call createCurrent(P_HQMinus, P_GPlus, P_Ha, P_GQ0, 1195, check)
      call createCurrent(P_HlQ, P_WMinus, P_WQPlus, 8457, check)
      call createCurrent(P_tauPlus, P_A, P_tauMinus, 7506, check)
      call createCurrent(P_Z, P_Z, P_GPlus, P_GMinus, 8773, check)
      call createCurrent(P_HQMinus, P_HPlus, P_G0, P_HhQ, 1548, check)
      call createCurrent(P_Ha, P_ghWmAnti, P_ghZ, P_GMinus, 9865, check)
      call createCurrent(P_gQ, P_uAnti, P_u, 1232, check)
      call createCurrent(P_GQPlus, P_Hh, P_HMinus, P_GQ0, 7508, check)
      call createCurrent(P_Hh, P_GMinus, P_A, P_WPlus, 4395, check)
      call createCurrent(P_Hh, P_ghAAnti, P_ghWp, P_HMinus, 3136, check)
      call createCurrent(P_HMinus, P_WPlus, P_Hl, P_A, 8253, check)
      call createCurrent(P_HMinus, P_HPlus, P_Hl, P_Hh, 5372, check)
      call createCurrent(P_GPlus, P_ghZ, P_ghWpAnti, P_Hl, 6291, check)
      call createCurrent(P_A, P_GPlus, P_WMinus, 618, check)
      call createCurrent(P_Z, P_HMinus, P_G0, P_WPlus, 10349, check)
      call createCurrent(P_HPlus, P_ghWpAnti, P_Ha, P_ghA, 852, check)
      call createCurrent(P_GQPlus, P_GMinus, P_Z, P_AQ, 5004, check)
      call createCurrent(P_GQ0, P_Ha, P_G0, P_GQ0, 7293, check)
      call createCurrent(P_GQMinus, P_GPlus, P_HMinus, P_HQPlus, 8408, check)
      call createCurrent(P_A, P_HPlus, P_GMinus, P_A, 10139, check)
      call createCurrent(P_GPlus, P_ghWp, P_ghWpAnti, P_GMinus, 6337, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_HPlus, P_HlQ, 6164, check)
      call createCurrent(P_A, P_WMinus, P_WPlus, 8207, check)
      call createCurrent(P_Hh, P_GMinus, P_GPlus, P_Ha, 9216, check)
      call createCurrent(P_HhQ, P_Z, P_Z, P_HhQ, 2059, check)
      call createCurrent(P_GQ0, P_GMinus, P_HPlus, P_HhQ, 8723, check)
      call createCurrent(P_Z, P_Z, P_WPlus, P_WMinus, 4547, check)
      call createCurrent(P_Hh, P_ghWpAnti, P_ghWp, P_Hl, 9943, check)
      call createCurrent(P_Hh, P_ghZAnti, P_GMinus, P_ghWp, 2550, check)
      call createCurrent(P_HMinus, P_ghZAnti, P_G0, P_ghWp, 9416, check)
      call createCurrent(P_HMinus, P_A, P_GPlus, P_Z, 9892, check)
      call createCurrent(P_Hl, P_bAnti, P_b, 535, check)
      call createCurrent(P_WQMinus, P_ghWp, P_ghAAnti, 6810, check)
      call createCurrent(P_HhQ, P_G0, P_HMinus, P_HQPlus, 1635, check)
      call createCurrent(P_GMinus, P_ghZ, P_GPlus, P_ghAAnti, 5648, check)
      call createCurrent(P_WPlus, P_ghWm, P_ghZAnti, 4690, check)
      call createCurrent(P_Hl, P_g, P_Hh, P_g, 10698, check)
      call createCurrent(P_GQMinus, P_GPlus, P_HhQ, 7389, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_G0, P_ghWp, 8159, check)
      call createCurrent(P_WMinus, P_ghZ, P_ghWmAnti, P_A, 6804, check)
      call createCurrent(P_HPlus, P_Z, P_A, P_HMinus, 637, check)
      call createCurrent(P_ghWp, P_HMinus, P_Hl, P_ghZAnti, 8376, check)
      call createCurrent(P_WMinus, P_Ha, P_Z, P_GPlus, 9950, check)
      call createCurrent(P_GQ0, P_Hh, P_HaQ, 120, check)
      call createCurrent(P_Hl, P_ghZ, P_ghZAnti, P_Hh, 9890, check)
      call createCurrent(P_HPlus, P_ghA, P_ghWpAnti, P_Ha, 5951, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_Hh, P_ghWp, 2281, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghZ, 8239, check)
      call createCurrent(P_Hl, P_WMinus, P_GPlus, P_Z, 5917, check)
      call createCurrent(P_WQMinus, P_G0, P_WPlus, P_GQ0, 1855, check)
      call createCurrent(P_GMinus, P_Hl, P_ghWp, P_ghAAnti, 2686, check)
      call createCurrent(P_GMinus, P_Ha, P_Hh, P_GPlus, 9508, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_WPlus, P_AQ, 6462, check)
      call createCurrent(P_HMinus, P_WPlus, P_Z, P_Hh, 7881, check)
      call createCurrent(P_HQPlus, P_Ha, P_GQMinus, 5386, check)
      call createCurrent(P_ghZ, P_GPlus, P_HMinus, P_ghZAnti, 9382, check)
      call createCurrent(P_GMinus, P_ghA, P_ghWmAnti, 2118, check)
      call createCurrent(P_HPlus, P_ghWm, P_HMinus, P_ghWmAnti, 5953, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_GPlus, P_Hl, 732, check)
      call createCurrent(P_ghWm, P_Hh, P_ghWmAnti, P_HaQ, 5786, check)
      call createCurrent(P_GMinus, P_WPlus, P_Hl, P_A, 8379, check)
      call createCurrent(P_GQPlus, P_Hl, P_GMinus, P_HhQ, 8569, check)
      call createCurrent(P_HaQ, P_Hh, P_Hh, P_GQ0, 5655, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_Hh, P_ghZ, 37, check)
      call createCurrent(P_A, P_WPlus, P_ghWm, P_ghZAnti, 2119, check)
      call createCurrent(P_HPlus, P_GMinus, P_Hh, P_Ha, 7370, check)
      call createCurrent(P_Ha, P_G0, P_Hl, P_Hl, 537, check)
      call createCurrent(P_Ha, P_WMinus, P_G0, P_WPlus, 8959, check)
      call createCurrent(P_WPlus, P_HMinus, P_Z, P_Hl, 2495, check)
      call createCurrent(P_GQPlus, P_Hl, P_HMinus, P_GQ0, 2774, check)
      call createCurrent(P_WPlus, P_WMinus, P_ghWmAnti, P_ghWm, 5149, check)
      call createCurrent(P_WPlus, P_Z, P_GMinus, P_G0, 6669, check)
      call createCurrent(P_WPlus, P_ghWm, P_A, P_ghZAnti, 7095, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_GPlus, P_HhQ, 3277, check)
      call createCurrent(P_A, P_WPlus, P_Hh, P_HMinus, 2214, check)
      call createCurrent(P_g, P_g, P_Hl, P_Hh, 10517, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_ghWm, P_ZQ, 3299, check)
      call createCurrent(P_GQPlus, P_WMinus, P_Z, P_HhQ, 6582, check)
      call createCurrent(P_Z, P_Hl, P_G0, 1417, check)
      call createCurrent(P_HQMinus, P_Ha, P_GQPlus, 4393, check)
      call createCurrent(P_ghWmAnti, P_Hl, P_ghWm, P_Hh, 9044, check)
      call createCurrent(P_AQ, P_Hl, P_WPlus, P_GQMinus, 5464, check)
      call createCurrent(P_HaQ, P_G0, P_HPlus, P_GQMinus, 6186, check)
      call createCurrent(P_d, P_dAnti, P_gQ, 4201, check)
      call createCurrent(P_WPlus, P_GMinus, P_Hh, 4885, check)
      call createCurrent(P_GQ0, P_GPlus, P_ghZAnti, P_ghWm, 7543, check)
      call createCurrent(P_HlQ, P_Hh, P_G0, P_HaQ, 8751, check)
      call createCurrent(P_Hh, P_Hh, P_Ha, P_Hh, 10623, check)
      call createCurrent(P_AQ, P_Hh, P_GMinus, P_WQPlus, 3546, check)
      call createCurrent(P_GMinus, P_GPlus, 10279, check)
      call createCurrent(P_ghWm, P_HPlus, P_G0, P_ghZAnti, 10007, check)
      call createCurrent(P_GQMinus, P_GPlus, P_Ha, P_GQ0, 6332, check)
      call createCurrent(P_ghWm, P_Hh, P_HPlus, P_ghAAnti, 7905, check)
      call createCurrent(P_HaQ, P_Hl, P_Hl, P_HaQ, 2587, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghWm, P_G0, 8815, check)
      call createCurrent(P_HQPlus, P_HMinus, P_ghZAnti, P_ghA, 7681, check)
      call createCurrent(P_GPlus, P_HMinus, P_WPlus, P_WMinus, 10141, check)
      call createCurrent(P_g, P_G0, P_G0, P_g, 10536, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_ZQ, 4716, check)
      call createCurrent(P_ghWmAnti, P_G0, P_ghZ, P_GQMinus, 5053, check)
      call createCurrent(P_GPlus, P_G0, P_HMinus, P_Hl, 3844, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_HPlus, P_ghA, 8940, check)
      call createCurrent(P_WPlus, P_WMinus, P_Hl, P_Hl, 2142, check)
      call createCurrent(P_HMinus, P_ghZ, P_ghWmAnti, P_G0, 9583, check)
      call createCurrent(P_nu_mu, P_nu_muAnti, P_A, 9995, check)
      call createCurrent(P_nu_tauAnti, P_nu_tau, P_Z, 493, check)
      call createCurrent(P_HQPlus, P_A, P_HMinus, P_ZQ, 5303, check)
      call createCurrent(P_HhQ, P_tauMinus, P_tauPlus, 4390, check)
      call createCurrent(P_HlQ, P_GMinus, P_ghAAnti, P_ghWp, 7820, check)
      call createCurrent(P_g, P_Hh, P_g, 10488, check)
      call createCurrent(P_ghAAnti, P_HMinus, P_ghZ, P_GPlus, 10045, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_Hl, P_GPlus, 8435, check)
      call createCurrent(P_HQMinus, P_GPlus, P_Hh, P_HlQ, 2195, check)
      call createCurrent(P_GQMinus, P_Hh, P_GPlus, P_HaQ, 6829, check)
      call createCurrent(P_HQMinus, P_GPlus, P_Hl, P_HaQ, 2020, check)
      call createCurrent(P_ghA, P_ghZAnti, P_GPlus, P_HMinus, 9850, check)
      call createCurrent(P_ghZAnti, P_ghA, P_WMinus, P_WPlus, 4596, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_Hh, P_HQMinus, 84, check)
      call createCurrent(P_GPlus, P_ghWm, P_ghAAnti, 8223, check)
      call createCurrent(P_HQPlus, P_ghA, P_Hh, P_ghWpAnti, 6300, check)
      call createCurrent(P_ghZ, P_Ha, P_ghZAnti, P_Ha, 4102, check)
      call createCurrent(P_HhQ, P_HMinus, P_HPlus, P_HhQ, 7423, check)
      call createCurrent(P_Ha, P_A, P_Hh, 9443, check)
      call createCurrent(P_WMinus, P_WPlus, P_ghZ, P_ghZAnti, 5071, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_WMinus, P_A, 2435, check)
      call createCurrent(P_GMinus, P_Ha, P_HPlus, 2276, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghAAnti, P_GPlus, 2485, check)
      call createCurrent(P_WMinus, P_GPlus, P_Hh, P_Z, 8766, check)
      call createCurrent(P_ZQ, P_Z, P_Ha, P_HaQ, 4370, check)
      call createCurrent(P_Ha, P_Ha, P_ghZ, P_ghZAnti, 629, check)
      call createCurrent(P_G0, P_Z, P_Hh, 4091, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Ha, P_HhQ, 4689, check)
      call createCurrent(P_HMinus, P_Z, P_GPlus, P_A, 9568, check)
      call createCurrent(P_ghWm, P_HMinus, P_ghWmAnti, P_GPlus, 9230, check)
      call createCurrent(P_ZQ, P_HPlus, P_Hl, P_WQMinus, 3846, check)
      call createCurrent(P_Hh, P_WPlus, P_GMinus, P_A, 5410, check)
      call createCurrent(P_A, P_Hh, P_Z, P_Hh, 9177, check)
      call createCurrent(P_HQPlus, P_HMinus, P_ghWmAnti, P_ghWm, 4314, check)
      call createCurrent(P_ghA, P_GMinus, P_G0, P_ghWmAnti, 261, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_GMinus, P_HPlus, 10402, check)
      call createCurrent(P_Z, P_A, P_GMinus, P_GPlus, 6614, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_Z, P_WQMinus, 5612, check)
      call createCurrent(P_WPlus, P_Hl, P_Z, P_GMinus, 5217, check)
      call createCurrent(P_HQMinus, P_GPlus, P_GMinus, P_HQPlus, 8131, check)
      call createCurrent(P_AQ, P_tAnti, P_t, 7715, check)
      call createCurrent(P_GPlus, P_HMinus, P_ghA, P_ghAAnti, 10206, check)
      call createCurrent(P_AQ, P_Z, P_WMinus, P_WQPlus, 8129, check)
      call createCurrent(P_sAnti, P_c, P_GMinus, 1950, check)
      call createCurrent(P_WMinus, P_t, P_bAnti, 593, check)
      call createCurrent(P_ghWp, P_HMinus, P_ghZAnti, 1842, check)
      call createCurrent(P_HQPlus, P_ghA, P_Hl, P_ghWpAnti, 3194, check)
      call createCurrent(P_GMinus, P_GPlus, P_HMinus, P_GPlus, 2112, check)
      call createCurrent(P_Ha, P_HMinus, P_GPlus, P_Ha, 8736, check)
      call createCurrent(P_GPlus, P_ghAAnti, P_ghZ, P_GMinus, 4493, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_Ha, P_HQMinus, 159, check)
      call createCurrent(P_Hh, P_G0, P_GMinus, P_GPlus, 9013, check)
      call createCurrent(P_G0, P_Hl, P_Hl, P_G0, 857, check)
      call createCurrent(P_HhQ, P_ghWm, P_G0, P_ghWmAnti, 461, check)
      call createCurrent(P_c, P_cAnti, P_GQ0, 1863, check)
      call createCurrent(P_AQ, P_GMinus, P_GPlus, P_ZQ, 2909, check)
      call createCurrent(P_WPlus, P_ghA, P_Z, P_ghWpAnti, 3415, check)
      call createCurrent(P_HlQ, P_ghWmAnti, P_ghWm, 3404, check)
      call createCurrent(P_Hl, P_Z, P_Ha, 2424, check)
      call createCurrent(P_GMinus, P_Ha, P_ghWmAnti, P_ghZ, 9528, check)
      call createCurrent(P_HaQ, P_Hh, P_ghWp, P_ghWpAnti, 7736, check)
      call createCurrent(P_g, P_HPlus, P_GMinus, P_g, 10487, check)
      call createCurrent(P_GQPlus, P_Hh, P_ghWm, P_ghZAnti, 358, check)
      call createCurrent(P_Hl, P_ghZAnti, P_ghZ, P_Hl, 6314, check)
      call createCurrent(P_HhQ, P_GMinus, P_ghZAnti, P_ghWp, 8478, check)
      call createCurrent(P_Hl, P_dAnti, P_d, 2004, check)
      call createCurrent(P_b, P_Z, P_bAnti, 3443, check)
      call createCurrent(P_ghZ, P_Hl, P_ghZAnti, P_Hh, 10225, check)
      call createCurrent(P_cAnti, P_WPlus, P_s, 4672, check)
      call createCurrent(P_ghWpAnti, P_Hl, P_HPlus, P_ghA, 218, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_HPlus, P_HMinus, 2042, check)
      call createCurrent(P_HaQ, P_WMinus, P_WPlus, P_HaQ, 1770, check)
      call createCurrent(P_Hl, P_GMinus, P_A, P_WPlus, 7601, check)
      call createCurrent(P_HaQ, P_GPlus, P_HMinus, P_HaQ, 1944, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_GMinus, P_G0, 6693, check)
      call createCurrent(P_HMinus, P_HPlus, P_Ha, P_G0, 4788, check)
      call createCurrent(P_Z, P_GMinus, P_A, P_HPlus, 9156, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghZAnti, 786, check)
      call createCurrent(P_HaQ, P_eMinus, P_ePlus, 5691, check)
      call createCurrent(P_ghWm, P_Hl, P_ghWmAnti, P_Hl, 6165, check)
      call createCurrent(P_HhQ, P_Hl, P_Hl, P_HlQ, 1250, check)
      call createCurrent(P_GMinus, P_GPlus, P_G0, P_Hl, 10409, check)
      call createCurrent(P_Z, P_ghWm, P_ghWmAnti, P_A, 8491, check)
      call createCurrent(P_WQPlus, P_Z, P_GMinus, P_HhQ, 4373, check)
      call createCurrent(P_Ha, P_GPlus, P_HMinus, P_Hh, 2765, check)
      call createCurrent(P_ZQ, P_HMinus, P_WPlus, P_HaQ, 3605, check)
      call createCurrent(P_HPlus, P_ghZ, P_GMinus, P_ghAAnti, 9546, check)
      call createCurrent(P_Hh, P_ghAAnti, P_HPlus, P_ghWm, 5243, check)
      call createCurrent(P_GPlus, P_eMinus, P_nu_eAnti, 6612, check)
      call createCurrent(P_HlQ, P_HPlus, P_WQMinus, 7371, check)
      call createCurrent(P_Hh, P_G0, P_GMinus, P_HPlus, 7061, check)
      call createCurrent(P_ghZ, P_HPlus, P_ghWpAnti, P_HhQ, 3503, check)
      call createCurrent(P_GQMinus, P_G0, P_G0, P_HQPlus, 7841, check)
      call createCurrent(P_HaQ, P_G0, P_G0, P_GQ0, 6029, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghAAnti, 8503, check)
      call createCurrent(P_dAnti, P_g, P_d, 6699, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_WQMinus, 328, check)
      call createCurrent(P_ZQ, P_Hl, P_Z, P_HlQ, 1857, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_Hl, P_GQMinus, 4351, check)
      call createCurrent(P_WQMinus, P_Hh, P_HQPlus, 889, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_GPlus, P_ghA, 4444, check)
      call createCurrent(P_WPlus, P_Z, P_Hl, P_GMinus, 6729, check)
      call createCurrent(P_ghWmAnti, P_Hl, P_ghWm, P_HaQ, 4546, check)
      call createCurrent(P_nu_tau, P_Z, P_nu_tauAnti, 6040, check)
      call createCurrent(P_HhQ, P_Z, P_HaQ, 7986, check)
      call createCurrent(P_Hh, P_ghZAnti, P_Hl, P_ghZ, 10142, check)
      call createCurrent(P_HhQ, P_ghWpAnti, P_Ha, P_ghWp, 3905, check)
      call createCurrent(P_WPlus, P_Z, P_WMinus, P_A, 1427, check)
      call createCurrent(P_ghWpAnti, P_Ha, P_ghZ, P_GPlus, 9673, check)
      call createCurrent(P_ghWmAnti, P_HMinus, P_Ha, P_ghZ, 811, check)
      call createCurrent(P_HhQ, P_G0, P_WPlus, P_WQMinus, 2936, check)
      call createCurrent(P_Hl, P_Hh, P_HPlus, P_GMinus, 4427, check)
      call createCurrent(P_A, P_nu_e, P_nu_eAnti, 9837, check)
      call createCurrent(P_AQ, P_ghWmAnti, P_ghWm, 1932, check)
      call createCurrent(P_GQ0, P_Hh, P_Ha, P_HlQ, 7398, check)
      call createCurrent(P_bAnti, P_t, P_WMinus, 6339, check)
      call createCurrent(P_HMinus, P_GPlus, P_Z, 8929, check)
      call createCurrent(P_HQPlus, P_Hh, P_Hl, P_GQMinus, 1080, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_HPlus, P_GMinus, 9121, check)
      call createCurrent(P_HlQ, P_Ha, P_G0, P_HhQ, 4877, check)
      call createCurrent(P_ghA, P_GPlus, P_ghWpAnti, P_Ha, 10370, check)
      call createCurrent(P_HlQ, P_Hh, P_Ha, P_GQ0, 7125, check)
      call createCurrent(P_ghWmAnti, P_A, P_A, P_ghWm, 6937, check)
      call createCurrent(P_WMinus, P_Hh, P_GPlus, P_Z, 5781, check)
      call createCurrent(P_WQPlus, P_Hh, P_HMinus, P_AQ, 6467, check)
      call createCurrent(P_GQPlus, P_Hl, P_ghZAnti, P_ghWm, 8206, check)
      call createCurrent(P_ghWmAnti, P_Hl, P_ghWm, P_HlQ, 1652, check)
      call createCurrent(P_G0, P_HMinus, P_G0, P_GPlus, 2003, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Hh, P_HhQ, 3798, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_WPlus, P_ghZ, 2946, check)
      call createCurrent(P_HaQ, P_Ha, P_HPlus, P_GQMinus, 5633, check)
      call createCurrent(P_Ha, P_HPlus, P_GMinus, 3941, check)
      call createCurrent(P_HlQ, P_GPlus, P_ghWm, P_ghAAnti, 433, check)
      call createCurrent(P_ghAAnti, P_ghZ, P_HMinus, P_HQPlus, 8192, check)
      call createCurrent(P_HlQ, P_Hl, P_ghWpAnti, P_ghWp, 454, check)
      call createCurrent(P_HQMinus, P_Hh, P_GQPlus, 4277, check)
      call createCurrent(P_ghAAnti, P_ghZ, P_GPlus, P_GQMinus, 8540, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Ha, P_HaQ, 3098, check)
      call createCurrent(P_Hh, P_Z, P_WMinus, P_GPlus, 753, check)
      call createCurrent(P_gQ, P_ghG, P_g, P_ghGAnti, 23, check)
      call createCurrent(P_G0, P_Z, P_A, P_G0, 9675, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_A, P_WQMinus, 3932, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Ha, P_HhQ, 8082, check)
      call createCurrent(P_ghZ, P_A, P_WMinus, P_ghWmAnti, 3586, check)
      call createCurrent(P_WQMinus, P_ghWmAnti, P_Z, P_ghZ, 8203, check)
      call createCurrent(P_nu_eAnti, P_nu_e, P_A, 10345, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_WPlus, P_A, 2155, check)
      call createCurrent(P_A, P_WMinus, P_Hh, P_HPlus, 6246, check)
      call createCurrent(P_WQPlus, P_Hl, P_WMinus, P_HlQ, 948, check)
      call createCurrent(P_ghAAnti, P_ghZ, P_HPlus, P_GMinus, 8935, check)
      call createCurrent(P_A, P_ghWpAnti, P_ghWp, 364, check)
      call createCurrent(P_WPlus, P_A, P_ghWpAnti, P_ghA, 5995, check)
      call createCurrent(P_ghZAnti, P_HPlus, P_Hh, P_ghWm, 2023, check)
      call createCurrent(P_ghWpAnti, P_G0, P_HPlus, P_ghA, 10027, check)
      call createCurrent(P_GMinus, P_G0, P_Ha, P_HPlus, 6735, check)
      call createCurrent(P_Z, P_WPlus, P_GMinus, P_Ha, 10004, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_A, P_WMinus, 1866, check)
      call createCurrent(P_ZQ, P_WPlus, P_GMinus, P_HhQ, 279, check)
      call createCurrent(P_G0, P_ghZAnti, P_ghWp, P_GMinus, 384, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_A, P_WMinus, 2835, check)
      call createCurrent(P_GQMinus, P_HPlus, P_Hl, P_GQ0, 2271, check)
      call createCurrent(P_GQMinus, P_HPlus, P_G0, P_HaQ, 792, check)
      call createCurrent(P_Z, P_GMinus, P_GPlus, P_Z, 5147, check)
      call createCurrent(P_WQPlus, P_ghWm, P_ghZAnti, 6412, check)
      call createCurrent(P_ghWp, P_ghWmAnti, P_WMinus, P_WMinus, 5479, check)
      call createCurrent(P_ghWpAnti, P_Hh, P_ghZ, P_GQPlus, 4580, check)
      call createCurrent(P_Ha, P_A, P_Ha, P_Z, 10149, check)
      call createCurrent(P_WQPlus, P_GMinus, P_Z, P_HlQ, 2034, check)
      call createCurrent(P_Z, P_A, P_WMinus, P_WPlus, 1737, check)
      call createCurrent(P_ghZAnti, P_A, P_WMinus, P_ghWp, 4058, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Hl, P_Hh, 10227, check)
      call createCurrent(P_Hh, P_Hh, P_ghZ, P_ghZAnti, 4481, check)
      call createCurrent(P_Z, P_Hl, P_Hh, P_Z, 9762, check)
      call createCurrent(P_HQPlus, P_HMinus, P_A, P_ZQ, 113, check)
      call createCurrent(P_g, P_Ha, P_Ha, P_g, 10599, check)
      call createCurrent(P_ghWp, P_WMinus, P_Z, P_ghZAnti, 6976, check)
      call createCurrent(P_GPlus, P_nu_tauAnti, P_tauMinus, 3340, check)
      call createCurrent(P_ghZ, P_Hl, P_Hh, P_ghZAnti, 9303, check)
      call createCurrent(P_WMinus, P_Hh, P_GPlus, 4129, check)
      call createCurrent(P_Hl, P_HMinus, P_G0, P_GPlus, 1433, check)
      call createCurrent(P_Ha, P_HPlus, P_ghWm, P_ghAAnti, 2568, check)
      call createCurrent(P_GQPlus, P_Z, P_GMinus, P_ZQ, 5057, check)
      call createCurrent(P_A, P_WPlus, P_GMinus, P_Ha, 9542, check)
      call createCurrent(P_HPlus, P_ghWm, P_ghAAnti, P_Hl, 5381, check)
      call createCurrent(P_ghWm, P_Hh, P_Hh, P_ghWmAnti, 1951, check)
      call createCurrent(P_HhQ, P_A, P_HPlus, P_WQMinus, 1918, check)
      call createCurrent(P_HMinus, P_ghWmAnti, P_Hl, P_ghZ, 2891, check)
      call createCurrent(P_AQ, P_WPlus, P_Z, P_WQMinus, 2524, check)
      call createCurrent(P_muPlus, P_muMinus, P_HlQ, 3267, check)
      call createCurrent(P_HlQ, P_HMinus, P_Hh, P_GQPlus, 757, check)
      call createCurrent(P_HaQ, P_HMinus, P_ghWp, P_ghZAnti, 6100, check)
      call createCurrent(P_HMinus, P_GPlus, P_GPlus, P_HMinus, 3900, check)
      call createCurrent(P_ghWmAnti, P_Hl, P_GMinus, P_ghA, 4798, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_GMinus, 7334, check)
      call createCurrent(P_ghWpAnti, P_G0, P_ghWp, P_HhQ, 5578, check)
      call createCurrent(P_GPlus, P_ghWm, P_ghAAnti, P_Hl, 5928, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_ghZ, P_HMinus, 9726, check)
      call createCurrent(P_Z, P_A, P_GPlus, P_GMinus, 2088, check)
      call createCurrent(P_GMinus, P_c, P_sAnti, 2889, check)
      call createCurrent(P_GQMinus, P_Z, P_G0, P_WQPlus, 7759, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_GMinus, P_Hl, 5305, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_HPlus, 1350, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_Hh, P_HMinus, 33, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_HQPlus, 3243, check)
      call createCurrent(P_WQPlus, P_HMinus, P_Z, P_HhQ, 6319, check)
      call createCurrent(P_GQMinus, P_nu_mu, P_muPlus, 6471, check)
      call createCurrent(P_WPlus, P_WMinus, P_GPlus, P_GMinus, 5173, check)
      call createCurrent(P_HQMinus, P_HPlus, P_Hl, P_GQ0, 8079, check)
      call createCurrent(P_WQMinus, P_Hl, P_WPlus, P_HaQ, 367, check)
      call createCurrent(P_Ha, P_ghWmAnti, P_HMinus, P_ghZ, 1103, check)
      call createCurrent(P_HMinus, P_Z, P_WPlus, P_Ha, 7162, check)
      call createCurrent(P_GQMinus, P_A, P_Z, P_GQPlus, 3175, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghZAnti, P_Ha, 9795, check)
      call createCurrent(P_GQPlus, P_WMinus, P_G0, P_ZQ, 6402, check)
      call createCurrent(P_HlQ, P_Hl, P_WMinus, P_WQPlus, 5185, check)
      call createCurrent(P_Hh, P_dAnti, P_d, 2654, check)
      call createCurrent(P_ePlus, P_nu_e, P_HMinus, 8147, check)
      call createCurrent(P_Hh, P_HPlus, P_HMinus, P_Hl, 7272, check)
      call createCurrent(P_Ha, P_Hh, P_GPlus, P_HMinus, 1503, check)
      call createCurrent(P_HQPlus, P_Hh, P_ghWpAnti, P_ghA, 2082, check)
      call createCurrent(P_HMinus, P_HPlus, 9288, check)
      call createCurrent(P_ghZ, P_Hh, P_Hh, P_ghZAnti, 583, check)
      call createCurrent(P_WQMinus, P_WPlus, P_WPlus, P_WQMinus, 2099, check)
      call createCurrent(P_HaQ, P_GPlus, P_Ha, P_HQMinus, 5593, check)
      call createCurrent(P_ghWp, P_Hl, P_ghZAnti, P_GQMinus, 2607, check)
      call createCurrent(P_s, P_sAnti, P_Hl, 166, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Z, P_A, 7513, check)
      call createCurrent(P_HPlus, P_ghZAnti, P_GMinus, P_ghA, 10293, check)
      call createCurrent(P_GMinus, P_Ha, P_Hl, P_HPlus, 5232, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_HMinus, P_HhQ, 1235, check)
      call createCurrent(P_HMinus, P_ghWp, P_ghZAnti, 5801, check)
      call createCurrent(P_HPlus, P_Ha, P_GMinus, P_Ha, 2904, check)
      call createCurrent(P_nu_tau, P_GMinus, P_tauPlus, 6331, check)
      call createCurrent(P_ghZAnti, P_A, P_ghWp, P_WMinus, 3886, check)
      call createCurrent(P_Hh, P_GPlus, P_G0, P_GMinus, 10484, check)
      call createCurrent(P_HPlus, P_Ha, P_Ha, P_HMinus, 995, check)
      call createCurrent(P_ghWpAnti, P_Z, P_ghWp, 2421, check)
      call createCurrent(P_HPlus, P_Ha, P_ghZ, P_ghWpAnti, 5393, check)
      call createCurrent(P_ghWpAnti, P_Hl, P_ghZ, P_GQPlus, 4821, check)
      call createCurrent(P_HMinus, P_ghA, P_ghZAnti, P_HPlus, 6464, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_GPlus, 8711, check)
      call createCurrent(P_HhQ, P_WMinus, P_Hh, P_WQPlus, 217, check)
      call createCurrent(P_HQMinus, P_Hl, P_WPlus, P_ZQ, 8835, check)
      call createCurrent(P_HQPlus, P_ghZ, P_HMinus, P_ghZAnti, 1317, check)
      call createCurrent(P_ghWm, P_WPlus, P_Z, P_ghAAnti, 5548, check)
      call createCurrent(P_HhQ, P_GMinus, P_HPlus, P_HhQ, 6110, check)
      call createCurrent(P_GQ0, P_Ha, P_Hl, P_HhQ, 6310, check)
      call createCurrent(P_HMinus, P_WPlus, P_Z, P_G0, 9023, check)
      call createCurrent(P_GPlus, P_WMinus, P_Ha, P_Z, 9985, check)
      call createCurrent(P_G0, P_Hh, P_HMinus, P_GPlus, 8513, check)
      call createCurrent(P_HPlus, P_ghAAnti, P_HMinus, P_ghZ, 2285, check)
      call createCurrent(P_Ha, P_HPlus, P_GMinus, P_G0, 8014, check)
      call createCurrent(P_eMinus, P_ePlus, P_HhQ, 5129, check)
      call createCurrent(P_HPlus, P_A, P_Z, P_HMinus, 655, check)
      call createCurrent(P_AQ, P_ghWm, P_Z, P_ghWmAnti, 69, check)
      call createCurrent(P_ePlus, P_Hl, P_eMinus, 449, check)
      call createCurrent(P_HMinus, P_HPlus, P_Hh, P_Hh, 745, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Hh, P_HhQ, 5061, check)
      call createCurrent(P_HPlus, P_GMinus, P_Ha, P_Hh, 7963, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Hl, P_Hh, 9653, check)
      call createCurrent(P_HMinus, P_ghA, P_ghWmAnti, P_G0, 9529, check)
      call createCurrent(P_HMinus, P_A, P_WPlus, 5351, check)
      call createCurrent(P_GQ0, P_G0, P_GPlus, P_GQMinus, 5396, check)
      call createCurrent(P_Ha, P_G0, P_G0, P_G0, 701, check)
      call createCurrent(P_Hh, P_HMinus, P_ghWp, P_ghZAnti, 7504, check)
      call createCurrent(P_WQPlus, P_A, P_HMinus, P_HaQ, 1347, check)
      call createCurrent(P_HMinus, P_Ha, P_Ha, P_HPlus, 6283, check)
      call createCurrent(P_ghWm, P_G0, P_GPlus, P_ghZAnti, 6078, check)
      call createCurrent(P_Z, P_WMinus, P_HPlus, P_Hl, 4527, check)
      call createCurrent(P_HlQ, P_GPlus, P_ghAAnti, P_ghWm, 1763, check)
      call createCurrent(P_WMinus, P_ghWp, P_ghZAnti, 4722, check)
      call createCurrent(P_GQ0, P_Hl, P_Hh, P_HaQ, 8297, check)
      call createCurrent(P_ghA, P_HMinus, P_ghWmAnti, P_G0, 10230, check)
      call createCurrent(P_HQMinus, P_Z, P_WQPlus, 91, check)
      call createCurrent(P_ghAAnti, P_HMinus, P_ghWp, P_Hh, 3412, check)
      call createCurrent(P_Hl, P_GMinus, P_Z, P_WPlus, 5429, check)
      call createCurrent(P_Ha, P_Hl, P_G0, 814, check)
      call createCurrent(P_tauMinus, P_Ha, P_tauPlus, 5184, check)
      call createCurrent(P_Hl, P_tauPlus, P_tauMinus, 8785, check)
      call createCurrent(P_Hl, P_HPlus, P_HMinus, P_Hh, 6385, check)
      call createCurrent(P_HaQ, P_G0, P_GMinus, P_HQPlus, 2641, check)
      call createCurrent(P_HQMinus, P_muPlus, P_nu_mu, 8679, check)
      call createCurrent(P_Hh, P_Z, P_Z, 7313, check)
      call createCurrent(P_GMinus, P_ghAAnti, P_ghWp, P_Hh, 2016, check)
      call createCurrent(P_ghWpAnti, P_HPlus, P_GMinus, P_ghWp, 9402, check)
      call createCurrent(P_HMinus, P_Hh, P_GPlus, P_Hh, 1890, check)
      call createCurrent(P_ghZ, P_G0, P_Ha, P_ghZAnti, 9751, check)
      call createCurrent(P_HPlus, P_GMinus, P_Z, 10268, check)
      call createCurrent(P_nu_mu, P_Z, P_nu_muAnti, 475, check)
      call createCurrent(P_ghA, P_Hl, P_GMinus, P_ghWmAnti, 6825, check)
      call createCurrent(P_GQPlus, P_Ha, P_Ha, P_HQMinus, 2752, check)
      call createCurrent(P_GMinus, P_GPlus, P_GPlus, P_GMinus, 3528, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghAAnti, P_GQ0, 3732, check)
      call createCurrent(P_HhQ, P_HPlus, P_G0, P_GQMinus, 5857, check)
      call createCurrent(P_Ha, P_GPlus, P_Ha, P_HMinus, 2234, check)
      call createCurrent(P_GPlus, P_GMinus, P_G0, P_Ha, 4769, check)
      call createCurrent(P_ghG, P_g, P_ghGAnti, 6327, check)
      call createCurrent(P_HPlus, P_HMinus, P_ghWmAnti, P_ghWm, 471, check)
      call createCurrent(P_ghWpAnti, P_Hh, P_ghWp, P_Hl, 10421, check)
      call createCurrent(P_HaQ, P_GMinus, P_HPlus, P_HhQ, 6708, check)
      call createCurrent(P_GPlus, P_WMinus, P_Z, P_Hl, 3456, check)
      call createCurrent(P_ghZ, P_WMinus, P_ghZAnti, P_WPlus, 7931, check)
      call createCurrent(P_HhQ, P_HPlus, P_ghAAnti, P_ghWm, 766, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_HMinus, P_Hh, 7742, check)
      call createCurrent(P_ghWp, P_A, P_ghWpAnti, P_A, 2028, check)
      call createCurrent(P_A, P_g, P_g, P_A, 10608, check)
      call createCurrent(P_WQMinus, P_ghWmAnti, P_A, P_ghA, 4600, check)
      call createCurrent(P_HQPlus, P_A, P_HMinus, P_AQ, 3179, check)
      call createCurrent(P_GPlus, P_HMinus, P_ghA, P_ghZAnti, 9915, check)
      call createCurrent(P_Z, P_ghA, P_ghWmAnti, P_WMinus, 713, check)
      call createCurrent(P_ghZ, P_A, P_WPlus, P_ghWpAnti, 6585, check)
      call createCurrent(P_WPlus, P_GMinus, P_Ha, P_A, 8931, check)
      call createCurrent(P_AQ, P_G0, P_GMinus, P_WQPlus, 4236, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghA, 5921, check)
      call createCurrent(P_g, P_Z, P_g, P_A, 10579, check)
      call createCurrent(P_ghA, P_HMinus, P_G0, P_ghWmAnti, 9679, check)
      call createCurrent(P_Hh, P_HPlus, P_Z, P_WMinus, 539, check)
      call createCurrent(P_GQ0, P_HMinus, P_G0, P_GQPlus, 2508, check)
      call createCurrent(P_HQMinus, P_bAnti, P_t, 2968, check)
      call createCurrent(P_HMinus, P_HMinus, P_GPlus, P_HPlus, 3961, check)
      call createCurrent(P_WQPlus, P_Z, P_GQMinus, 8322, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_GPlus, 125, check)
      call createCurrent(P_GPlus, P_G0, P_HMinus, 8194, check)
      call createCurrent(P_HaQ, P_WMinus, P_HPlus, P_ZQ, 4348, check)
      call createCurrent(P_muPlus, P_muMinus, P_HaQ, 2149, check)
      call createCurrent(P_ghAAnti, P_HPlus, P_ghWm, P_HlQ, 6154, check)
      call createCurrent(P_ghA, P_A, P_ghWmAnti, P_WQMinus, 1741, check)
      call createCurrent(P_ghZ, P_WMinus, P_Z, P_ghWmAnti, 6728, check)
      call createCurrent(P_WQMinus, P_G0, P_WPlus, P_HlQ, 6941, check)
      call createCurrent(P_HQPlus, P_Ha, P_HMinus, P_HaQ, 5019, check)
      call createCurrent(P_HaQ, P_Hl, P_ZQ, 2569, check)
      call createCurrent(P_ghWm, P_Hh, P_GPlus, P_ghAAnti, 2978, check)
      call createCurrent(P_ZQ, P_WMinus, P_HPlus, P_HhQ, 553, check)
      call createCurrent(P_Hl, P_Hl, P_Hl, P_Hh, 8681, check)
      call createCurrent(P_ghWpAnti, P_Z, P_ghWp, P_Z, 3984, check)
      call createCurrent(P_eMinus, P_Ha, P_ePlus, 3960, check)
      call createCurrent(P_ZQ, P_WMinus, P_Z, P_WQPlus, 8672, check)
      call createCurrent(P_GPlus, P_Hl, P_HMinus, P_Hh, 4723, check)
      call createCurrent(P_GPlus, P_ghZ, P_GMinus, P_ghAAnti, 2905, check)
      call createCurrent(P_Hh, P_HMinus, P_HPlus, P_G0, 9642, check)
      call createCurrent(P_A, P_A, P_G0, P_G0, 10645, check)
      call createCurrent(P_Hl, P_Hh, P_Hl, 3987, check)
      call createCurrent(P_ghWpAnti, P_Ha, P_HPlus, P_ghZ, 3954, check)
      call createCurrent(P_Hl, P_HPlus, P_ghWpAnti, P_ghZ, 4702, check)
      call createCurrent(P_G0, P_s, P_sAnti, 627, check)
      call createCurrent(P_Hh, P_HPlus, P_GMinus, P_Hh, 5636, check)
      call createCurrent(P_GPlus, P_HMinus, P_g, P_g, 10513, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_Ha, P_HMinus, 3689, check)
      call createCurrent(P_Ha, P_GMinus, P_ghAAnti, P_ghWp, 9097, check)
      call createCurrent(P_G0, P_A, P_Ha, P_A, 10692, check)
      call createCurrent(P_HPlus, P_Ha, P_Hl, P_HMinus, 10128, check)
      call createCurrent(P_ghWpAnti, P_Hh, P_GPlus, P_ghZ, 8070, check)
      call createCurrent(P_ZQ, P_ghWmAnti, P_ghWm, 8448, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_Hl, P_HPlus, 7575, check)
      call createCurrent(P_HaQ, P_HPlus, P_G0, P_GQMinus, 6659, check)
      call createCurrent(P_GQPlus, P_GMinus, P_Ha, P_HaQ, 1492, check)
      call createCurrent(P_Ha, P_Hl, P_Ha, 7747, check)
      call createCurrent(P_WQMinus, P_Hh, P_GPlus, P_ZQ, 1399, check)
      call createCurrent(P_HPlus, P_Hh, P_ghWpAnti, P_ghZ, 1908, check)
      call createCurrent(P_ghWmAnti, P_HMinus, P_ghZ, P_HaQ, 8664, check)
      call createCurrent(P_GMinus, P_HPlus, P_G0, P_G0, 6790, check)
      call createCurrent(P_HMinus, P_ghAAnti, P_GPlus, P_ghA, 10298, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_GPlus, P_Hh, 7030, check)
      call createCurrent(P_G0, P_Hl, P_HPlus, P_HMinus, 9363, check)
      call createCurrent(P_HlQ, P_HMinus, P_Ha, P_GQPlus, 1450, check)
      call createCurrent(P_WPlus, P_ghA, P_ghZAnti, P_WMinus, 6736, check)
      call createCurrent(P_HhQ, P_WPlus, P_WMinus, P_HhQ, 7288, check)
      call createCurrent(P_b, P_bAnti, P_Hh, 8083, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_Ha, P_HQPlus, 5933, check)
      call createCurrent(P_HMinus, P_Hl, P_Hl, P_HPlus, 8734, check)
      call createCurrent(P_HMinus, P_G0, P_GPlus, 1480, check)
      call createCurrent(P_GMinus, P_ghWp, P_ghZAnti, 1720, check)
      call createCurrent(P_HPlus, P_HMinus, P_G0, P_Ha, 1880, check)
      call createCurrent(P_Ha, P_ghA, P_ghWpAnti, P_GPlus, 9154, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_G0, P_HlQ, 5590, check)
      call createCurrent(P_Hl, P_ghZ, P_HMinus, P_ghWmAnti, 175, check)
      call createCurrent(P_t, P_bAnti, P_GMinus, 8464, check)
      call createCurrent(P_HMinus, P_G0, P_ghWp, P_ghAAnti, 9101, check)
      call createCurrent(P_HMinus, P_GPlus, P_Hh, P_Ha, 7421, check)
      call createCurrent(P_WPlus, P_Z, P_HMinus, 5557, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Hl, P_Hh, 10058, check)
      call createCurrent(P_ghWmAnti, P_A, P_ghWm, P_Z, 7573, check)
      call createCurrent(P_GQ0, P_Z, P_G0, P_ZQ, 1282, check)
      call createCurrent(P_HaQ, P_HMinus, P_GPlus, P_HlQ, 2415, check)
      call createCurrent(P_c, P_cAnti, P_AQ, 4741, check)
      call createCurrent(P_WQPlus, P_A, P_HMinus, P_HlQ, 8280, check)
      call createCurrent(P_GMinus, P_WPlus, P_Hl, P_Z, 6425, check)
      call createCurrent(P_HMinus, P_GPlus, P_HPlus, P_GMinus, 4893, check)
      call createCurrent(P_GMinus, P_ghWp, P_ghZAnti, P_Ha, 9398, check)
      call createCurrent(P_HhQ, P_Ha, P_HPlus, P_GQMinus, 6698, check)
      call createCurrent(P_WQPlus, P_Z, P_WQMinus, 6361, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_Hh, P_GQPlus, 5670, check)
      call createCurrent(P_HaQ, P_Hh, P_Hl, P_HaQ, 54, check)
      call createCurrent(P_ghWm, P_Hl, P_HPlus, P_ghZAnti, 2492, check)
      call createCurrent(P_GMinus, P_ghWp, P_HPlus, P_ghWpAnti, 9898, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghZ, P_Hh, 5444, check)
      call createCurrent(P_WPlus, P_Hh, P_GMinus, 3027, check)
      call createCurrent(P_WQPlus, P_Ha, P_Ha, P_WQMinus, 7166, check)
      call createCurrent(P_WPlus, P_Ha, P_WMinus, P_G0, 8953, check)
      call createCurrent(P_WQMinus, P_ghZ, P_A, P_ghWmAnti, 1733, check)
      call createCurrent(P_GMinus, P_Hl, P_HPlus, 1917, check)
      call createCurrent(P_ghZ, P_Hh, P_HPlus, P_ghWpAnti, 685, check)
      call createCurrent(P_ghWpAnti, P_Hl, P_ghWp, P_Hh, 9656, check)
      call createCurrent(P_HhQ, P_ghZ, P_GPlus, P_ghWpAnti, 2026, check)
      call createCurrent(P_Hh, P_G0, P_HMinus, P_GPlus, 2144, check)
      call createCurrent(P_HhQ, P_GPlus, P_Z, P_WQMinus, 6221, check)
      call createCurrent(P_ghWm, P_WPlus, P_A, P_ghZAnti, 4556, check)
      call createCurrent(P_g, P_GPlus, P_g, P_GMinus, 10709, check)
      call createCurrent(P_HhQ, P_ghWpAnti, P_ghWp, 487, check)
      call createCurrent(P_Hh, P_GMinus, P_Z, P_WPlus, 2191, check)
      call createCurrent(P_WPlus, P_GMinus, P_Hh, P_A, 7777, check)
      call createCurrent(P_s, P_sAnti, P_A, 3508, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_GPlus, P_HlQ, 892, check)
      call createCurrent(P_A, P_Hl, P_HPlus, P_WMinus, 6741, check)
      call createCurrent(P_GQ0, P_HMinus, P_HQPlus, 4402, check)
      call createCurrent(P_HhQ, P_Hh, P_GMinus, P_GQPlus, 5256, check)
      call createCurrent(P_Hl, P_HPlus, P_GMinus, P_Ha, 557, check)
      call createCurrent(P_Hl, P_Hl, P_Ha, P_Ha, 7014, check)
      call createCurrent(P_WQMinus, P_A, P_WPlus, P_ZQ, 2653, check)
      call createCurrent(P_Hl, P_GMinus, P_WPlus, P_A, 5956, check)
      call createCurrent(P_A, P_HPlus, P_GMinus, 8921, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_Ha, P_GMinus, 9040, check)
      call createCurrent(P_GPlus, P_ghWp, P_HMinus, P_ghWpAnti, 9390, check)
      call createCurrent(P_Z, P_bAnti, P_b, 3275, check)
      call createCurrent(P_WQPlus, P_Hh, P_HMinus, P_ZQ, 1627, check)
      call createCurrent(P_A, P_Hh, P_HPlus, P_WMinus, 622, check)
      call createCurrent(P_Ha, P_A, P_HMinus, P_WPlus, 847, check)
      call createCurrent(P_AQ, P_HPlus, P_Hl, P_WQMinus, 6866, check)
      call createCurrent(P_HQMinus, P_HPlus, P_GPlus, P_GQMinus, 489, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghA, P_GMinus, 1071, check)
      call createCurrent(P_WMinus, P_ghWp, P_ghWpAnti, P_WPlus, 5389, check)
      call createCurrent(P_A, P_WMinus, P_A, P_WPlus, 5324, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_A, P_WQPlus, 4357, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_WPlus, P_Z, 363, check)
      call createCurrent(P_sAnti, P_Hh, P_s, 798, check)
      call createCurrent(P_WPlus, P_A, P_GMinus, P_G0, 689, check)
      call createCurrent(P_GPlus, P_Hh, P_ghWm, P_ghAAnti, 3969, check)
      call createCurrent(P_HlQ, P_A, P_WMinus, P_GQPlus, 7286, check)
      call createCurrent(P_HMinus, P_ghZ, P_ghAAnti, P_GPlus, 9322, check)
      call createCurrent(P_ZQ, P_Z, P_ghWmAnti, P_ghWm, 646, check)
      call createCurrent(P_A, P_uAnti, P_u, 6005, check)
      call createCurrent(P_HMinus, P_ghWp, P_Hl, P_ghAAnti, 1183, check)
      call createCurrent(P_ghZAnti, P_Hh, P_ghWm, P_GQPlus, 8240, check)
      call createCurrent(P_GPlus, P_HMinus, P_ghWmAnti, P_ghWm, 9671, check)
      call createCurrent(P_WQMinus, P_ghZ, P_WPlus, P_ghZAnti, 5457, check)
      call createCurrent(P_ZQ, P_Hh, P_ZQ, 8808, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_Z, P_WMinus, 2140, check)
      call createCurrent(P_uAnti, P_u, 9787, check)
      call createCurrent(P_ghAAnti, P_HPlus, P_ghWm, P_HaQ, 7655, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_WPlus, P_A, 4200, check)
      call createCurrent(P_G0, P_G0, P_Z, P_Z, 2483, check)
      call createCurrent(P_HhQ, P_WPlus, P_WQMinus, 950, check)
      call createCurrent(P_A, P_ghWp, P_ghZAnti, P_WMinus, 8242, check)
      call createCurrent(P_Hl, P_Hl, P_GPlus, P_GMinus, 8096, check)
      call createCurrent(P_ghWm, P_Ha, P_ghAAnti, P_HPlus, 8747, check)
      call createCurrent(P_Z, P_WMinus, P_ghWmAnti, P_ghA, 6967, check)
      call createCurrent(P_GPlus, P_HMinus, P_Ha, P_Hh, 7812, check)
      call createCurrent(P_HlQ, P_HMinus, P_ghWp, P_ghZAnti, 1543, check)
      call createCurrent(P_ghZ, P_A, P_ghWpAnti, P_WQPlus, 6990, check)
      call createCurrent(P_WQMinus, P_Ha, P_HQPlus, 8586, check)
      call createCurrent(P_b, P_Hh, P_bAnti, 1273, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghZ, P_Z, 3823, check)
      call createCurrent(P_ghA, P_Ha, P_HMinus, P_ghWmAnti, 6228, check)
      call createCurrent(P_ghWp, P_Hl, P_ghAAnti, P_GMinus, 8262, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghWpAnti, P_WPlus, 8480, check)
      call createCurrent(P_s, P_sAnti, P_Z, 1976, check)
      call createCurrent(P_HPlus, P_G0, P_WMinus, P_A, 10121, check)
      call createCurrent(P_GMinus, P_ghAAnti, P_ghZ, P_GPlus, 6253, check)
      call createCurrent(P_HhQ, P_ghWp, P_HMinus, P_ghAAnti, 4986, check)
      call createCurrent(P_HMinus, P_ghA, P_ghWmAnti, P_Ha, 6701, check)
      call createCurrent(P_Z, P_ghWm, P_ghWmAnti, 6143, check)
      call createCurrent(P_HPlus, P_ghAAnti, P_ghA, P_GMinus, 9223, check)
      call createCurrent(P_A, P_ghZAnti, P_ghWm, P_WPlus, 6277, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_G0, P_ghZ, 4345, check)
      call createCurrent(P_Ha, P_ghWmAnti, P_GMinus, P_ghA, 10110, check)
      call createCurrent(P_Z, P_Hh, P_WMinus, P_GPlus, 2204, check)
      call createCurrent(P_Hl, P_HPlus, P_WMinus, P_A, 8413, check)
      call createCurrent(P_Hl, P_Hl, P_A, P_Z, 10347, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_HPlus, 7248, check)
      call createCurrent(P_GQPlus, P_GMinus, P_Hl, P_HhQ, 3344, check)
      call createCurrent(P_Hh, P_Z, P_A, 10485, check)
      call createCurrent(P_HMinus, P_bAnti, P_t, 1468, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghAAnti, P_Ha, 8987, check)
      call createCurrent(P_HQMinus, P_Hh, P_GPlus, P_HhQ, 4920, check)
      call createCurrent(P_GPlus, P_ghWm, P_Hl, P_ghAAnti, 2193, check)
      call createCurrent(P_HMinus, P_g, P_GPlus, P_g, 10586, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_G0, P_GQPlus, 321, check)
      call createCurrent(P_HaQ, P_HPlus, P_Z, P_WQMinus, 548, check)
      call createCurrent(P_HlQ, P_HPlus, P_WMinus, P_ZQ, 4521, check)
      call createCurrent(P_ghAAnti, P_G0, P_ghWp, P_GMinus, 5925, check)
      call createCurrent(P_WMinus, P_G0, P_WPlus, P_Ha, 10218, check)
      call createCurrent(P_GQPlus, P_GMinus, P_ghAAnti, P_ghA, 5627, check)
      call createCurrent(P_ZQ, P_HPlus, P_HMinus, P_AQ, 1937, check)
      call createCurrent(P_G0, P_Ha, P_HMinus, P_HPlus, 8222, check)
      call createCurrent(P_cAnti, P_Hl, P_c, 4530, check)
      call createCurrent(P_HhQ, P_GPlus, P_Hh, P_GQMinus, 7429, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Hl, 600, check)
      call createCurrent(P_WMinus, P_GPlus, P_A, P_Hl, 5034, check)
      call createCurrent(P_Hh, P_Hl, P_A, P_Z, 10489, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_HMinus, P_ghA, 10134, check)
      call createCurrent(P_HhQ, P_HPlus, P_ghZ, P_ghWpAnti, 2652, check)
      call createCurrent(P_WQMinus, P_WPlus, P_A, P_ZQ, 5757, check)
      call createCurrent(P_GQPlus, P_Z, P_WMinus, P_HhQ, 5873, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_ghWp, P_Ha, 9691, check)
      call createCurrent(P_Z, P_HPlus, P_GMinus, P_Z, 10202, check)
      call createCurrent(P_HMinus, P_HPlus, P_Hl, P_G0, 10208, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghZ, P_HMinus, 9145, check)
      call createCurrent(P_ghWmAnti, P_ghWp, P_WMinus, P_WQMinus, 4168, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_WQMinus, 7144, check)
      call createCurrent(P_ghWpAnti, P_Hh, P_ghA, P_HPlus, 6497, check)
      call createCurrent(P_GPlus, P_GMinus, P_ghZ, P_ghZAnti, 2512, check)
      call createCurrent(P_ZQ, P_WPlus, P_G0, P_GQMinus, 4582, check)
      call createCurrent(P_GMinus, P_HPlus, P_ghAAnti, P_ghZ, 10187, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_G0, P_Ha, 10228, check)
      call createCurrent(P_HQMinus, P_HPlus, P_Ha, P_HaQ, 2667, check)
      call createCurrent(P_u, P_Hh, P_uAnti, 1168, check)
      call createCurrent(P_HhQ, P_HMinus, P_WPlus, P_ZQ, 5602, check)
      call createCurrent(P_WMinus, P_GPlus, P_Z, 2404, check)
      call createCurrent(P_GQ0, P_ghWm, P_GPlus, P_ghAAnti, 313, check)
      call createCurrent(P_WMinus, P_A, P_GPlus, P_Hl, 7417, check)
      call createCurrent(P_uAnti, P_G0, P_u, 8479, check)
      call createCurrent(P_ghAAnti, P_HMinus, P_ghA, P_GPlus, 8905, check)
      call createCurrent(P_GQ0, P_GMinus, P_Ha, P_HQPlus, 6377, check)
      call createCurrent(P_WQMinus, P_WPlus, P_WMinus, P_WQPlus, 6724, check)
      call createCurrent(P_GQPlus, P_Hh, P_WMinus, P_ZQ, 3452, check)
      call createCurrent(P_dAnti, P_d, P_Z, 7672, check)
      call createCurrent(P_ghA, P_Z, P_ghWpAnti, P_WQPlus, 7852, check)
      call createCurrent(P_A, P_ghWmAnti, P_ghWm, 3860, check)
      call createCurrent(P_GMinus, P_WPlus, P_Hl, 5165, check)
      call createCurrent(P_HlQ, P_A, P_HMinus, P_WQPlus, 4626, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Ha, P_HlQ, 6877, check)
      call createCurrent(P_ghWmAnti, P_G0, P_HMinus, P_ghZ, 9099, check)
      call createCurrent(P_HhQ, P_Z, P_GQ0, 1905, check)
      call createCurrent(P_ghZ, P_ghAAnti, P_HPlus, P_HMinus, 6094, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghWmAnti, P_HhQ, 6097, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghZAnti, P_HlQ, 3851, check)
      call createCurrent(P_Z, P_G0, P_GPlus, P_WMinus, 662, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghWm, P_Ha, 9625, check)
      call createCurrent(P_WPlus, P_WMinus, P_GPlus, P_HMinus, 8887, check)
      call createCurrent(P_WMinus, P_HPlus, P_Hl, P_Z, 6503, check)
      call createCurrent(P_AQ, P_GMinus, P_GQPlus, 6760, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_Hh, P_HQMinus, 8094, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_A, P_WPlus, 830, check)
      call createCurrent(P_WMinus, P_WPlus, P_Z, P_Z, 8000, check)
      call createCurrent(P_WPlus, P_G0, P_Z, P_GMinus, 5163, check)
      call createCurrent(P_g, P_Ha, P_G0, P_g, 10621, check)
      call createCurrent(P_ghA, P_HPlus, P_ghWpAnti, 5212, check)
      call createCurrent(P_ghWpAnti, P_Z, P_ghZ, P_WPlus, 7150, check)
      call createCurrent(P_GPlus, P_A, P_GMinus, 4910, check)
      call createCurrent(P_GMinus, P_HPlus, P_HPlus, P_HMinus, 311, check)
      call createCurrent(P_Hh, P_Ha, P_Z, 8661, check)
      call createCurrent(P_ghWp, P_A, P_ghWpAnti, 3675, check)
      call createCurrent(P_ghWm, P_G0, P_ghWmAnti, P_Ha, 10394, check)
      call createCurrent(P_Ha, P_Z, P_WPlus, P_HMinus, 1689, check)
      call createCurrent(P_Z, P_ghWp, P_WMinus, P_ghZAnti, 8516, check)
      call createCurrent(P_eMinus, P_A, P_ePlus, 5719, check)
      call createCurrent(P_Hl, P_GPlus, P_HMinus, P_G0, 41, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_G0, P_GMinus, 7330, check)
      call createCurrent(P_GMinus, P_ghWp, P_G0, P_ghZAnti, 7119, check)
      call createCurrent(P_A, P_WPlus, P_HMinus, P_Hl, 5676, check)
      call createCurrent(P_Z, P_Hl, P_Z, P_Hl, 7995, check)
      call createCurrent(P_ghWmAnti, P_Ha, P_GMinus, P_ghA, 8941, check)
      call createCurrent(P_HlQ, P_Hh, P_Hh, P_HlQ, 7517, check)
      call createCurrent(P_A, P_ghWmAnti, P_ghA, P_WMinus, 2012, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_GQ0, 6678, check)
      call createCurrent(P_ghZAnti, P_ghA, P_GPlus, P_GQMinus, 657, check)
      call createCurrent(P_HhQ, P_ePlus, P_eMinus, 6862, check)
      call createCurrent(P_g, P_g, P_GMinus, P_GPlus, 10563, check)
      call createCurrent(P_bAnti, P_Ha, P_b, 1115, check)
      call createCurrent(P_HhQ, P_Z, P_HMinus, P_WQPlus, 6270, check)
      call createCurrent(P_AQ, P_ghAAnti, P_WPlus, P_ghWm, 427, check)
      call createCurrent(P_ghWpAnti, P_Hl, P_ghA, P_HPlus, 2405, check)
      call createCurrent(P_WQPlus, P_Hh, P_Hh, P_WQMinus, 2436, check)
      call createCurrent(P_Hl, P_ghZ, P_ghWmAnti, P_GMinus, 5603, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Hh, P_HaQ, 233, check)
      call createCurrent(P_muMinus, P_muPlus, P_Ha, 5089, check)
      call createCurrent(P_ZQ, P_WPlus, P_HMinus, P_HaQ, 5814, check)
      call createCurrent(P_WPlus, P_HMinus, P_Hl, P_Z, 2808, check)
      call createCurrent(P_GPlus, P_GMinus, P_Hl, P_G0, 10109, check)
      call createCurrent(P_GQPlus, P_Z, P_WMinus, P_GQ0, 6711, check)
      call createCurrent(P_Hh, P_GPlus, P_GMinus, 4763, check)
      call createCurrent(P_ZQ, P_HMinus, P_Ha, P_WQPlus, 1075, check)
      call createCurrent(P_G0, P_Z, P_GPlus, P_WMinus, 3048, check)
      call createCurrent(P_AQ, P_Z, P_HPlus, P_HQMinus, 5988, check)
      call createCurrent(P_ZQ, P_WPlus, P_HMinus, P_HhQ, 2207, check)
      call createCurrent(P_G0, P_G0, P_WPlus, P_WMinus, 7340, check)
      call createCurrent(P_ghWmAnti, P_HPlus, P_GMinus, P_ghWm, 10336, check)
      call createCurrent(P_gQ, P_g, P_gQ, 8793, check)
      call createCurrent(P_HQPlus, P_ghWm, P_Hh, P_ghZAnti, 7410, check)
      call createCurrent(P_ghA, P_Hh, P_ghWmAnti, P_GMinus, 7300, check)
      call createCurrent(P_g, P_g, P_ghG, P_ghGAnti, 1789, check)
      call createCurrent(P_ghWpAnti, P_Hh, P_HPlus, P_ghZ, 2859, check)
      call createCurrent(P_ghWpAnti, P_G0, P_ghA, P_GPlus, 4177, check)
      call createCurrent(P_Hl, P_GMinus, P_Hl, P_HPlus, 1381, check)
      call createCurrent(P_GMinus, P_HPlus, P_ghZ, P_ghAAnti, 8875, check)
      call createCurrent(P_ghAAnti, P_ghZ, P_HPlus, P_HMinus, 2465, check)
      call createCurrent(P_GQ0, P_GMinus, P_GQPlus, 750, check)
      call createCurrent(P_ePlus, P_nu_e, P_WMinus, 7761, check)
      call createCurrent(P_HhQ, P_HMinus, P_Hl, P_GQPlus, 780, check)
      call createCurrent(P_Z, P_Hh, P_GPlus, P_WMinus, 6813, check)
      call createCurrent(P_ghAAnti, P_HMinus, P_ghWp, 3099, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_ghWm, 7093, check)
      call createCurrent(P_GQMinus, P_Hl, P_ghWmAnti, P_ghA, 3981, check)
      call createCurrent(P_ghAAnti, P_ghA, P_GMinus, P_GPlus, 625, check)
      call createCurrent(P_dAnti, P_Hh, P_d, 3925, check)
      call createCurrent(P_GQMinus, P_A, P_A, P_GQPlus, 2603, check)
      call createCurrent(P_nu_e, P_ePlus, P_HMinus, 6609, check)
      call createCurrent(P_WMinus, P_WPlus, P_g, P_g, 10682, check)
      call createCurrent(P_HPlus, P_ghWm, P_Ha, P_ghZAnti, 8599, check)
      call createCurrent(P_GQPlus, P_HPlus, P_HMinus, P_HQMinus, 6105, check)
      call createCurrent(P_Hl, P_ghWmAnti, P_ghWm, P_Hh, 10203, check)
      call createCurrent(P_A, P_A, P_Hl, P_Hl, 10568, check)
      call createCurrent(P_ghZAnti, P_G0, P_HPlus, P_ghWm, 9620, check)
      call createCurrent(P_GQ0, P_WPlus, P_A, P_GQMinus, 3620, check)
      call createCurrent(P_Hh, P_HPlus, P_Hh, P_HMinus, 2441, check)
      call createCurrent(P_A, P_Z, P_Hh, P_Hl, 10736, check)
      call createCurrent(P_GMinus, P_ghWpAnti, P_HPlus, P_ghWp, 9978, check)
      call createCurrent(P_A, P_sAnti, P_s, 1037, check)
      call createCurrent(P_GMinus, P_Ha, P_GPlus, P_Hl, 9516, check)
      call createCurrent(P_GMinus, P_GPlus, P_G0, P_Ha, 5175, check)
      call createCurrent(P_Ha, P_GMinus, P_G0, P_HPlus, 5302, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_HMinus, P_G0, 10064, check)
      call createCurrent(P_Hl, P_ghWp, P_Hl, P_ghWpAnti, 8606, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_Ha, P_HPlus, 8155, check)
      call createCurrent(P_AQ, P_b, P_bAnti, 641, check)
      call createCurrent(P_WPlus, P_HMinus, P_HPlus, P_WMinus, 4510, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_Hh, P_GMinus, 5952, check)
      call createCurrent(P_G0, P_ghWpAnti, P_ghA, P_HPlus, 9041, check)
      call createCurrent(P_GPlus, P_ghA, P_Hh, P_ghWpAnti, 5741, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_HQMinus, 2865, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghAAnti, P_A, 4938, check)
      call createCurrent(P_WMinus, P_WPlus, P_HMinus, P_GPlus, 9294, check)
      call createCurrent(P_Ha, P_Ha, P_ghWm, P_ghWmAnti, 5850, check)
      call createCurrent(P_HaQ, P_GPlus, P_G0, P_GQMinus, 6876, check)
      call createCurrent(P_ghA, P_Hl, P_HMinus, P_ghWmAnti, 7894, check)
      call createCurrent(P_ghA, P_GPlus, P_ghAAnti, P_GQMinus, 1861, check)
      call createCurrent(P_AQ, P_GMinus, P_Z, P_GQPlus, 1383, check)
      call createCurrent(P_G0, P_Hh, P_G0, 5319, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_HPlus, P_GMinus, 10439, check)
      call createCurrent(P_HMinus, P_ghWp, P_ghZAnti, P_G0, 10462, check)
      call createCurrent(P_GMinus, P_GPlus, P_Ha, P_Hl, 10377, check)
      call createCurrent(P_WQMinus, P_ghWpAnti, P_WPlus, P_ghWp, 7097, check)
      call createCurrent(P_Z, P_WMinus, P_GPlus, P_Ha, 9628, check)
      call createCurrent(P_HlQ, P_HMinus, P_Ha, P_HQPlus, 6061, check)
      call createCurrent(P_HhQ, P_HMinus, P_GPlus, P_HlQ, 7204, check)
      call createCurrent(P_cAnti, P_s, P_GPlus, 4952, check)
      call createCurrent(P_G0, P_A, P_GMinus, P_WPlus, 598, check)
      call createCurrent(P_Z, P_A, P_g, P_g, 10650, check)
      call createCurrent(P_Z, P_HPlus, P_WMinus, P_Hh, 2208, check)
      call createCurrent(P_GQPlus, P_WMinus, P_HlQ, 3679, check)
      call createCurrent(P_Z, P_GMinus, P_A, P_GPlus, 4404, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_GPlus, P_G0, 8598, check)
      call createCurrent(P_Ha, P_Hh, P_Hl, P_G0, 7556, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_WMinus, P_Z, 8254, check)
      call createCurrent(P_Ha, P_HPlus, P_Hl, P_GMinus, 1487, check)
      call createCurrent(P_ghWmAnti, P_Ha, P_ghWm, P_HlQ, 3038, check)
      call createCurrent(P_GPlus, P_ghWm, P_HMinus, P_ghWmAnti, 10025, check)
      call createCurrent(P_Z, P_WPlus, P_GMinus, 4679, check)
      call createCurrent(P_HPlus, P_ghZAnti, P_Hl, P_ghWm, 8157, check)
      call createCurrent(P_Ha, P_HMinus, P_WPlus, P_Z, 3655, check)
      call createCurrent(P_WQMinus, P_WPlus, P_GQ0, 6981, check)
      call createCurrent(P_ghAAnti, P_HPlus, P_Hl, P_ghWm, 690, check)
      call createCurrent(P_ZQ, P_G0, P_WMinus, P_GQPlus, 3306, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_ghZ, P_WQPlus, 3411, check)
      call createCurrent(P_HPlus, P_Hl, P_Hl, P_HMinus, 6780, check)
      call createCurrent(P_HPlus, P_ghA, P_G0, P_ghWpAnti, 10346, check)
      call createCurrent(P_ghZ, P_WPlus, P_ghZAnti, P_WQMinus, 2295, check)
      call createCurrent(P_ghWm, P_Hl, P_ghZAnti, P_GQPlus, 7898, check)
      call createCurrent(P_Z, P_Z, P_G0, P_G0, 7197, check)
      call createCurrent(P_Ha, P_WMinus, P_HPlus, P_Z, 5409, check)
      call createCurrent(P_GQ0, P_WPlus, P_WMinus, P_GQ0, 7401, check)
      call createCurrent(P_HlQ, P_Z, P_ZQ, 7083, check)
      call createCurrent(P_HQPlus, P_ghWpAnti, P_Hh, P_ghA, 4837, check)
      call createCurrent(P_GPlus, P_Ha, P_HMinus, P_Ha, 2983, check)
      call createCurrent(P_ZQ, P_tauMinus, P_tauPlus, 1131, check)
      call createCurrent(P_HlQ, P_Hl, P_Hl, P_HlQ, 775, check)
      call createCurrent(P_ghWmAnti, P_Hl, P_ghZ, P_GMinus, 7958, check)
      call createCurrent(P_Hh, P_ghWp, P_ghZAnti, P_HMinus, 6608, check)
      call createCurrent(P_Hl, P_GPlus, P_ghWm, P_ghAAnti, 5727, check)
      call createCurrent(P_ghA, P_HPlus, P_ghAAnti, P_HMinus, 4192, check)
      call createCurrent(P_Ha, P_Hh, P_HMinus, P_GPlus, 2043, check)
      call createCurrent(P_A, P_Z, P_Hh, P_Hh, 9081, check)
      call createCurrent(P_HhQ, P_Z, P_Hh, P_ZQ, 1044, check)
      call createCurrent(P_ghZAnti, P_G0, P_G0, P_ghZ, 5202, check)
      call createCurrent(P_A, P_Hh, P_GPlus, P_WMinus, 7348, check)
      call createCurrent(P_Hl, P_HPlus, P_ghWm, P_ghAAnti, 571, check)
      call createCurrent(P_WMinus, P_GPlus, P_GMinus, P_WPlus, 1626, check)
      call createCurrent(P_GQ0, P_WMinus, P_Hl, P_WQPlus, 2233, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_WMinus, P_WPlus, 3127, check)
      call createCurrent(P_ghWmAnti, P_Hl, P_ghZ, P_GQMinus, 4199, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghA, P_G0, 5340, check)
      call createCurrent(P_ghWpAnti, P_Hl, P_Hl, P_ghWp, 2308, check)
      call createCurrent(P_HMinus, P_A, P_Z, P_HPlus, 5693, check)
      call createCurrent(P_ghWp, P_GMinus, P_Hh, P_ghAAnti, 5779, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghA, P_Z, 7380, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_GMinus, P_Ha, 9609, check)
      call createCurrent(P_WPlus, P_GMinus, P_WMinus, P_GPlus, 8690, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_Hl, P_HMinus, 5529, check)
      call createCurrent(P_nu_tau, P_tauPlus, P_GMinus, 2883, check)
      call createCurrent(P_muMinus, P_muPlus, P_Hh, 1354, check)
      call createCurrent(P_ghWp, P_HMinus, P_Hh, P_ghAAnti, 4768, check)
      call createCurrent(P_A, P_ghWm, P_WPlus, P_ghAAnti, 4612, check)
      call createCurrent(P_ghWpAnti, P_G0, P_GPlus, P_ghZ, 1023, check)
      call createCurrent(P_WMinus, P_ghAAnti, P_ghWp, P_Z, 8256, check)
      call createCurrent(P_HPlus, P_HMinus, P_g, P_g, 10560, check)
      call createCurrent(P_HQPlus, P_WMinus, P_Z, P_HlQ, 6501, check)
      call createCurrent(P_HMinus, P_Ha, P_GPlus, P_G0, 4676, check)
      call createCurrent(P_c, P_HMinus, P_sAnti, 3492, check)
      call createCurrent(P_GQ0, P_ghWpAnti, P_G0, P_ghWp, 4075, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_A, P_Z, 4059, check)
      call createCurrent(P_WQPlus, P_ghWpAnti, P_A, P_ghZ, 7448, check)
      call createCurrent(P_u, P_uAnti, P_HaQ, 8611, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_GPlus, P_HhQ, 5508, check)
      call createCurrent(P_AQ, P_Z, P_ghWpAnti, P_ghWp, 3703, check)
      call createCurrent(P_HlQ, P_ghWm, P_HPlus, P_ghAAnti, 8810, check)
      call createCurrent(P_GQMinus, P_GPlus, P_Hh, P_GQ0, 8485, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_G0, P_HlQ, 4046, check)
      call createCurrent(P_WPlus, P_Z, P_GMinus, 1809, check)
      call createCurrent(P_GMinus, P_ghZ, P_Hl, P_ghWmAnti, 7902, check)
      call createCurrent(P_Hh, P_Ha, P_HPlus, P_GMinus, 6021, check)
      call createCurrent(P_Hl, P_Ha, P_HPlus, P_GMinus, 6444, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghZ, P_Hh, 1945, check)
      call createCurrent(P_A, P_ghWpAnti, P_WPlus, P_ghA, 6751, check)
      call createCurrent(P_b, P_bAnti, P_HaQ, 4932, check)
      call createCurrent(P_HlQ, P_ghWp, P_HMinus, P_ghAAnti, 8351, check)
      call createCurrent(P_GMinus, P_A, P_GPlus, 2799, check)
      call createCurrent(P_WMinus, P_Z, P_Hh, P_GPlus, 491, check)
      call createCurrent(P_HPlus, P_A, P_HMinus, P_Z, 5238, check)
      call createCurrent(P_GPlus, P_ghAAnti, P_G0, P_ghWm, 5369, check)
      call createCurrent(P_Hl, P_ghWpAnti, P_ghA, P_HPlus, 5584, check)
      call createCurrent(P_GMinus, P_GPlus, P_GMinus, P_GPlus, 3355, check)
      call createCurrent(P_Z, P_HPlus, P_HMinus, 5959, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_A, P_ghA, 2417, check)
      call createCurrent(P_A, P_g, P_Z, P_g, 10606, check)
      call createCurrent(P_GMinus, P_GPlus, P_Hl, 4983, check)
      call createCurrent(P_g, P_uAnti, P_u, 6460, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_GPlus, P_ghWm, 4905, check)
      call createCurrent(P_GPlus, P_ghWm, P_ghAAnti, P_Ha, 9105, check)
      call createCurrent(P_ZQ, P_ghWp, P_WMinus, P_ghAAnti, 6113, check)
      call createCurrent(P_HlQ, P_HMinus, P_GPlus, P_HaQ, 3762, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_ghWm, 2766, check)
      call createCurrent(P_GQ0, P_Hl, P_HPlus, P_HQMinus, 6906, check)
      call createCurrent(P_Z, P_WPlus, P_Hl, P_HMinus, 8117, check)
      call createCurrent(P_ghWm, P_G0, P_HPlus, P_ghZAnti, 8986, check)
      call createCurrent(P_HlQ, P_GMinus, P_ghWmAnti, P_ghZ, 4480, check)
      call createCurrent(P_Ha, P_ghZAnti, P_HPlus, P_ghWm, 3072, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghZ, P_GQMinus, 2336, check)
      call createCurrent(P_Hh, P_G0, P_HMinus, P_HPlus, 9352, check)
      call createCurrent(P_tauMinus, P_Hl, P_tauPlus, 4455, check)
      call createCurrent(P_Ha, P_HMinus, P_WPlus, P_A, 7130, check)
      call createCurrent(P_G0, P_ghZAnti, P_ghZ, P_G0, 7635, check)
      call createCurrent(P_ghWmAnti, P_HMinus, P_ghA, P_Hl, 1834, check)
      call createCurrent(P_Hh, P_Z, P_Z, P_Hh, 6087, check)
      call createCurrent(P_HQPlus, P_GMinus, P_Hl, P_HhQ, 575, check)
      call createCurrent(P_ghA, P_HMinus, P_ghZAnti, P_GPlus, 9271, check)
      call createCurrent(P_Hl, P_ghZAnti, P_Hl, P_ghZ, 7226, check)
      call createCurrent(P_WMinus, P_HPlus, P_Z, P_Hl, 1378, check)
      call createCurrent(P_muPlus, P_Z, P_muMinus, 6151, check)
      call createCurrent(P_ghAAnti, P_Ha, P_HMinus, P_ghWp, 3095, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_GMinus, P_Ha, 9084, check)
      call createCurrent(P_Ha, P_HPlus, P_Hh, P_HMinus, 9569, check)
      call createCurrent(P_A, P_A, P_Hl, 10717, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghZ, 4101, check)
      call createCurrent(P_HPlus, P_g, P_g, P_GMinus, 10576, check)
      call createCurrent(P_ghZAnti, P_Hl, P_GMinus, P_ghWp, 6365, check)
      call createCurrent(P_Ha, P_Z, P_A, P_G0, 10616, check)
      call createCurrent(P_Hh, P_GPlus, P_ghZ, P_ghWpAnti, 4489, check)
      call createCurrent(P_Z, P_Hh, P_HMinus, P_WPlus, 8614, check)
      call createCurrent(P_HlQ, P_ghZAnti, P_GPlus, P_ghWm, 7440, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_GMinus, P_HhQ, 8539, check)
      call createCurrent(P_GMinus, P_Hh, P_GPlus, P_Hh, 1797, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghA, P_Z, 235, check)
      call createCurrent(P_HQPlus, P_Z, P_Z, P_HQMinus, 1609, check)
      call createCurrent(P_HMinus, P_GPlus, P_A, P_Z, 10455, check)
      call createCurrent(P_Hh, P_Hh, P_g, P_g, 10634, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_GPlus, P_Ha, 10169, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghAAnti, P_HhQ, 6602, check)
      call createCurrent(P_ZQ, P_HPlus, P_Hh, P_WQMinus, 6568, check)
      call createCurrent(P_Z, P_A, P_Z, P_A, 10694, check)
      call createCurrent(P_WPlus, P_Z, P_ghWpAnti, P_ghA, 3467, check)
      call createCurrent(P_A, P_Hl, P_Hl, P_Z, 10238, check)
      call createCurrent(P_Z, P_cAnti, P_c, 7693, check)
      call createCurrent(P_A, P_Ha, P_Z, P_G0, 10553, check)
      call createCurrent(P_HPlus, P_HPlus, P_GMinus, P_HMinus, 6680, check)
      call createCurrent(P_GMinus, P_HPlus, P_Ha, P_Hh, 2047, check)
      call createCurrent(P_ZQ, P_GPlus, P_Z, P_GQMinus, 460, check)
      call createCurrent(P_GQMinus, P_Hh, P_Hl, P_HQPlus, 974, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_HMinus, 8782, check)
      call createCurrent(P_HMinus, P_GPlus, P_HMinus, P_HPlus, 339, check)
      call createCurrent(P_WMinus, P_HPlus, 9082, check)
      call createCurrent(P_A, P_A, P_Hl, P_Hh, 10573, check)
      call createCurrent(P_HhQ, P_Hh, P_ghZ, P_ghZAnti, 6712, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_Hl, P_HQPlus, 7623, check)
      call createCurrent(P_HQPlus, P_WMinus, P_Hh, P_ZQ, 3889, check)
      call createCurrent(P_GPlus, P_Ha, P_WMinus, P_Z, 9311, check)
      call createCurrent(P_HaQ, P_WMinus, P_Z, P_HQPlus, 8582, check)
      call createCurrent(P_HQPlus, P_Z, P_WQMinus, 8345, check)
      call createCurrent(P_HPlus, P_Hh, P_WMinus, 8177, check)
      call createCurrent(P_HQMinus, P_Hl, P_HPlus, P_GQ0, 32, check)
      call createCurrent(P_GMinus, P_ghWp, P_ghAAnti, P_Hl, 1384, check)
      call createCurrent(P_GQPlus, P_HMinus, P_GPlus, P_GQMinus, 2321, check)
      call createCurrent(P_HMinus, P_G0, P_G0, P_HPlus, 3301, check)
      call createCurrent(P_Ha, P_GMinus, P_ghWmAnti, P_ghZ, 10250, check)
      call createCurrent(P_HPlus, P_G0, P_GMinus, 5700, check)
      call createCurrent(P_GQ0, P_GMinus, P_WQPlus, 3645, check)
      call createCurrent(P_ghZAnti, P_HMinus, P_ghWp, P_HlQ, 8578, check)
      call createCurrent(P_ZQ, P_muMinus, P_muPlus, 672, check)
      call createCurrent(P_GPlus, P_GMinus, P_HPlus, P_GMinus, 2937, check)
      call createCurrent(P_HPlus, P_HMinus, P_G0, P_G0, 6654, check)
      call createCurrent(P_HlQ, P_ghAAnti, P_GMinus, P_ghWp, 3184, check)
      call createCurrent(P_Hh, P_GMinus, P_Ha, P_GPlus, 9228, check)
      call createCurrent(P_ghZ, P_HMinus, P_Hh, P_ghWmAnti, 5180, check)
      call createCurrent(P_HaQ, P_GMinus, P_Hh, P_HQPlus, 3897, check)
      call createCurrent(P_GQMinus, P_Hl, P_HPlus, P_GQ0, 2384, check)
      call createCurrent(P_Z, P_Z, P_Hh, P_Hl, 9285, check)
      call createCurrent(P_ghWpAnti, P_Hl, P_Hh, P_ghWp, 9068, check)
      call createCurrent(P_HhQ, P_GPlus, P_ghWm, P_ghZAnti, 2541, check)
      call createCurrent(P_A, P_WPlus, P_Ha, P_GMinus, 10050, check)
      call createCurrent(P_HPlus, P_Hl, P_HMinus, P_Hh, 2172, check)
      call createCurrent(P_WQMinus, P_HPlus, P_A, P_HaQ, 1725, check)
      call createCurrent(P_WQPlus, P_ghA, P_Z, P_ghWpAnti, 1777, check)
      call createCurrent(P_A, P_WPlus, P_GMinus, P_Hh, 7121, check)
      call createCurrent(P_t, P_bAnti, P_HMinus, 2316, check)
      call createCurrent(P_Ha, P_A, P_WPlus, P_GMinus, 9316, check)
      call createCurrent(P_WPlus, P_Z, P_Ha, P_GMinus, 10283, check)
      call createCurrent(P_Hl, P_Hh, P_G0, P_Ha, 6072, check)
      call createCurrent(P_g, P_GMinus, P_g, P_HPlus, 10539, check)
      call createCurrent(P_Hl, P_WMinus, P_Hh, P_WPlus, 10340, check)
      call createCurrent(P_HMinus, P_Hh, P_ghWmAnti, P_ghA, 1441, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_HMinus, P_ghWp, 9799, check)
      call createCurrent(P_HQMinus, P_WPlus, P_Z, P_HlQ, 8453, check)
      call createCurrent(P_GQPlus, P_WMinus, P_Hh, P_ZQ, 5763, check)
      call createCurrent(P_ghWm, P_GPlus, P_Hl, P_ghZAnti, 1674, check)
      call createCurrent(P_ZQ, P_G0, P_GPlus, P_WQMinus, 5476, check)
      call createCurrent(P_HMinus, P_HPlus, P_ghWm, P_ghWmAnti, 4734, check)
      call createCurrent(P_HhQ, P_Z, P_WPlus, P_HQMinus, 2229, check)
      call createCurrent(P_HQMinus, P_HPlus, P_Hl, P_HlQ, 7251, check)
      call createCurrent(P_tAnti, P_G0, P_t, 1102, check)
      call createCurrent(P_GMinus, P_Ha, P_GPlus, 10280, check)
      call createCurrent(P_ghWp, P_HMinus, P_ghAAnti, P_Hh, 6459, check)
      call createCurrent(P_ghAAnti, P_Ha, P_ghWm, P_HPlus, 7741, check)
      call createCurrent(P_GPlus, P_Hh, P_HMinus, P_G0, 4731, check)
      call createCurrent(P_GPlus, P_WMinus, P_Hl, P_A, 870, check)
      call createCurrent(P_WMinus, P_HPlus, P_A, P_G0, 9635, check)
      call createCurrent(P_HPlus, P_A, P_WMinus, 4487, check)
      call createCurrent(P_tAnti, P_Z, P_t, 8326, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_GMinus, P_GPlus, 4746, check)
      call createCurrent(P_Hh, P_G0, P_HPlus, P_GMinus, 6383, check)
      call createCurrent(P_Hh, P_muMinus, P_muPlus, 3517, check)
      call createCurrent(P_GPlus, P_Ha, P_Hl, P_HMinus, 1104, check)
      call createCurrent(P_GQ0, P_Z, P_WPlus, P_GQMinus, 220, check)
      call createCurrent(P_WMinus, P_Hh, P_Z, P_GPlus, 6121, check)
      call createCurrent(P_HMinus, P_GPlus, P_Ha, P_Hl, 7621, check)
      call createCurrent(P_ghAAnti, P_ghA, P_GMinus, P_HPlus, 10231, check)
      call createCurrent(P_ghZAnti, P_ghA, P_GMinus, P_HPlus, 9012, check)
      call createCurrent(P_GQPlus, P_GMinus, P_G0, P_GQ0, 5101, check)
      call createCurrent(P_G0, P_WPlus, P_WMinus, P_G0, 5169, check)
      call createCurrent(P_AQ, P_WMinus, P_ghWp, P_ghAAnti, 1953, check)
      call createCurrent(P_Z, P_WMinus, P_Hh, P_GPlus, 476, check)
      call createCurrent(P_HPlus, P_G0, P_ghZ, P_ghWpAnti, 9830, check)
      call createCurrent(P_GQMinus, P_GPlus, P_ghAAnti, P_ghA, 5042, check)
      call createCurrent(P_ghZ, P_GPlus, P_GMinus, P_ghAAnti, 1677, check)
      call createCurrent(P_G0, P_WPlus, P_GMinus, P_Z, 8834, check)
      call createCurrent(P_Ha, P_ghAAnti, P_GMinus, P_ghWp, 8897, check)
      call createCurrent(P_GPlus, P_Ha, P_GMinus, P_Hl, 10363, check)
      call createCurrent(P_HQPlus, P_GMinus, P_GMinus, P_GQPlus, 8301, check)
      call createCurrent(P_Hh, P_Hh, P_Z, P_Z, 807, check)
      call createCurrent(P_Hl, P_WPlus, P_Hh, P_WMinus, 9967, check)
      call createCurrent(P_HQMinus, P_Hl, P_WQPlus, 4736, check)
      call createCurrent(P_WPlus, P_ghZAnti, P_WMinus, P_ghA, 5639, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_ghZ, P_WPlus, 2961, check)
      call createCurrent(P_HaQ, P_GPlus, P_Hh, P_HQMinus, 3939, check)
      call createCurrent(P_Ha, P_Ha, P_Hh, P_Hl, 3139, check)
      call createCurrent(P_Hl, P_G0, P_Hh, P_G0, 7242, check)
      call createCurrent(P_ghZAnti, P_Hh, P_ghWp, P_HMinus, 6204, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_ghWp, 7368, check)
      call createCurrent(P_Hl, P_HMinus, P_WPlus, P_A, 4010, check)
      call createCurrent(P_GMinus, P_Hl, P_ghZ, P_ghWmAnti, 6575, check)
      call createCurrent(P_WMinus, P_Z, P_HPlus, 3426, check)
      call createCurrent(P_GQMinus, P_GPlus, P_WMinus, P_WQPlus, 306, check)
      call createCurrent(P_AQ, P_HMinus, P_HPlus, P_ZQ, 7052, check)
      call createCurrent(P_ghWmAnti, P_Ha, P_ghWm, P_G0, 10009, check)
      call createCurrent(P_HlQ, P_WMinus, P_HPlus, P_ZQ, 520, check)
      call createCurrent(P_Hh, P_Ha, P_A, 10099, check)
      call createCurrent(P_Hh, P_Hh, P_A, P_Z, 9052, check)
      call createCurrent(P_dAnti, P_A, P_d, 7331, check)
      call createCurrent(P_AQ, P_ghWmAnti, P_Z, P_ghWm, 7920, check)
      call createCurrent(P_GQ0, P_WPlus, P_Hh, P_WQMinus, 4888, check)
      call createCurrent(P_WPlus, P_ghA, P_ghWpAnti, P_Z, 5152, check)
      call createCurrent(P_HlQ, P_eMinus, P_ePlus, 3821, check)
      call createCurrent(P_WPlus, P_Z, P_ghWm, P_ghZAnti, 4414, check)
      call createCurrent(P_ghAAnti, P_ghA, P_GPlus, P_HMinus, 8969, check)
      call createCurrent(P_GQPlus, P_ghWpAnti, P_ghA, 7845, check)
      call createCurrent(P_ghWmAnti, P_Ha, P_G0, P_ghWm, 9343, check)
      call createCurrent(P_ghZAnti, P_Hl, P_ghZ, P_HlQ, 935, check)
      call createCurrent(P_A, P_G0, P_WPlus, P_HMinus, 10292, check)
      call createCurrent(P_GPlus, P_Hl, P_ghWm, P_ghZAnti, 3054, check)
      call createCurrent(P_Hh, P_Ha, P_HMinus, P_HPlus, 9432, check)
      call createCurrent(P_GQMinus, P_Z, P_A, P_GQPlus, 5109, check)
      call createCurrent(P_WMinus, P_ghAAnti, P_ghZ, P_WPlus, 2992, check)
      call createCurrent(P_Hl, P_ghWmAnti, P_HMinus, P_ghZ, 4755, check)
      call createCurrent(P_s, P_cAnti, P_HQPlus, 7302, check)
      call createCurrent(P_dAnti, P_d, P_Ha, 4362, check)
      call createCurrent(P_GQMinus, P_G0, P_ghWmAnti, P_ghZ, 4279, check)
      call createCurrent(P_GPlus, P_G0, P_GMinus, P_Ha, 5328, check)
      call createCurrent(P_G0, P_ghWmAnti, P_HMinus, P_ghA, 9451, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_ghA, P_GPlus, 8813, check)
      call createCurrent(P_Z, P_Z, P_GMinus, P_HPlus, 8910, check)
      call createCurrent(P_GPlus, P_ghWm, P_ghZAnti, P_Hl, 8761, check)
      call createCurrent(P_ZQ, P_HMinus, P_HQPlus, 904, check)
      call createCurrent(P_ghWm, P_HPlus, P_Hl, P_ghAAnti, 127, check)
      call createCurrent(P_ghWpAnti, P_Z, P_WPlus, P_ghA, 5885, check)
      call createCurrent(P_HPlus, P_Hh, P_GMinus, P_Hl, 4721, check)
      call createCurrent(P_GQ0, P_HMinus, P_HPlus, P_GQ0, 7236, check)
      call createCurrent(P_GMinus, P_GPlus, P_Z, P_A, 718, check)
      call createCurrent(P_HQMinus, P_HPlus, P_Hl, P_HhQ, 5032, check)
      call createCurrent(P_HQPlus, P_GMinus, P_GPlus, P_GQMinus, 8364, check)
      call createCurrent(P_Ha, P_ghWp, P_Ha, P_ghWpAnti, 3210, check)
      call createCurrent(P_Hl, P_ghWm, P_ghAAnti, P_HPlus, 6757, check)
      call createCurrent(P_G0, P_G0, P_Hh, P_Hh, 3564, check)
      call createCurrent(P_Ha, P_ghA, P_HPlus, P_ghWpAnti, 5587, check)
      call createCurrent(P_nu_muAnti, P_nu_mu, P_Z, 7017, check)
      call createCurrent(P_HaQ, P_ghZ, P_HPlus, P_ghWpAnti, 5875, check)
      call createCurrent(P_Hl, P_A, P_GMinus, P_WPlus, 214, check)
      call createCurrent(P_HQMinus, P_GPlus, P_GQ0, 1481, check)
      call createCurrent(P_GMinus, P_Ha, P_HPlus, P_G0, 2830, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_ghA, P_HPlus, 9047, check)
      call createCurrent(P_GPlus, P_HMinus, 9480, check)
      call createCurrent(P_ZQ, P_A, P_WPlus, P_WQMinus, 1290, check)
      call createCurrent(P_sAnti, P_c, P_WMinus, 8333, check)
      call createCurrent(P_HPlus, P_ghZ, P_Ha, P_ghWpAnti, 5673, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_HMinus, P_Hh, 2177, check)
      call createCurrent(P_WMinus, P_A, P_ghWp, P_ghZAnti, 4397, check)
      call createCurrent(P_WMinus, P_Ha, P_G0, P_WPlus, 10306, check)
      call createCurrent(P_Ha, P_WPlus, P_Z, P_GMinus, 9397, check)
      call createCurrent(P_ghWm, P_Ha, P_ghWmAnti, P_HlQ, 5513, check)
      call createCurrent(P_A, P_WMinus, P_G0, P_GPlus, 1956, check)
      call createCurrent(P_GPlus, P_Hl, P_WMinus, 5866, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_A, P_WMinus, 4989, check)
      call createCurrent(P_HMinus, P_Ha, P_WPlus, 2590, check)
      call createCurrent(P_GPlus, P_WMinus, P_Hh, 8321, check)
      call createCurrent(P_GPlus, P_WMinus, P_Z, P_G0, 7868, check)
      call createCurrent(P_GQ0, P_Hh, P_ghWm, P_ghWmAnti, 4272, check)
      call createCurrent(P_HlQ, P_G0, P_HPlus, P_HQMinus, 7273, check)
      call createCurrent(P_HQMinus, P_Hl, P_Hl, P_HQPlus, 590, check)
      call createCurrent(P_ZQ, P_WPlus, P_ghWm, P_ghZAnti, 4403, check)
      call createCurrent(P_Ha, P_Hl, P_Ha, P_Hh, 7973, check)
      call createCurrent(P_Hh, P_Hh, P_ghWm, P_ghWmAnti, 3841, check)
      call createCurrent(P_HQPlus, P_ghWm, P_Hl, P_ghZAnti, 959, check)
      call createCurrent(P_Hl, P_ghWm, P_ghZAnti, P_HPlus, 8049, check)
      call createCurrent(P_G0, P_ghZAnti, P_G0, P_ghZ, 2391, check)
      call createCurrent(P_gQ, P_dAnti, P_d, 5045, check)
      call createCurrent(P_GQMinus, P_WPlus, P_HhQ, 967, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_Hl, P_HQPlus, 8337, check)
      call createCurrent(P_Hh, P_GMinus, P_GPlus, P_Hl, 6893, check)
      call createCurrent(P_Hh, P_HPlus, P_WMinus, 5231, check)
      call createCurrent(P_HPlus, P_ghWm, P_ghAAnti, 5743, check)
      call createCurrent(P_Ha, P_GPlus, P_ghWm, P_ghZAnti, 10088, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghWm, P_WQPlus, 1425, check)
      call createCurrent(P_GPlus, P_Z, P_WMinus, 4063, check)
      call createCurrent(P_ghWp, P_Hh, P_ghWpAnti, P_Hh, 1886, check)
      call createCurrent(P_A, P_HPlus, P_A, P_HMinus, 6413, check)
      call createCurrent(P_ghAAnti, P_HMinus, P_ghWp, P_G0, 9564, check)
      call createCurrent(P_HlQ, P_ghWpAnti, P_Hl, P_ghWp, 1620, check)
      call createCurrent(P_ghWmAnti, P_Hh, P_ghWm, 6740, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_HMinus, P_Ha, 3753, check)
      call createCurrent(P_WQMinus, P_Z, P_Hh, P_HQPlus, 1518, check)
      call createCurrent(P_ghWmAnti, P_WPlus, P_ghWm, P_WMinus, 5133, check)
      call createCurrent(P_GQ0, P_ghWp, P_GMinus, P_ghZAnti, 4549, check)
      call createCurrent(P_HhQ, P_eMinus, P_ePlus, 4002, check)
      call createCurrent(P_Hl, P_ghZ, P_Hh, P_ghZAnti, 9091, check)
      call createCurrent(P_HhQ, P_Ha, P_Ha, P_HlQ, 3408, check)
      call createCurrent(P_ghZ, P_WMinus, P_ghWmAnti, P_Z, 4484, check)
      call createCurrent(P_GMinus, P_ghWm, P_ghWmAnti, P_GPlus, 5332, check)
      call createCurrent(P_Hl, P_Hh, P_Z, P_A, 10622, check)
      call createCurrent(P_HQMinus, P_GPlus, P_GPlus, P_HQMinus, 1470, check)
      call createCurrent(P_HPlus, P_HMinus, P_HPlus, P_GMinus, 4482, check)
      call createCurrent(P_GPlus, P_GMinus, P_A, 1746, check)
      call createCurrent(P_GQMinus, P_Hh, P_Hh, P_GQPlus, 4670, check)
      call createCurrent(P_tauMinus, P_Hh, P_tauPlus, 5073, check)
      call createCurrent(P_ZQ, P_Hh, P_HPlus, P_WQMinus, 7609, check)
      call createCurrent(P_HMinus, P_ghWmAnti, P_ghZ, P_Ha, 4631, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_Hl, P_GQMinus, 4333, check)
      call createCurrent(P_uAnti, P_u, P_HlQ, 6144, check)
      call createCurrent(P_HaQ, P_Z, P_HPlus, P_WQMinus, 5224, check)
      call createCurrent(P_HaQ, P_Hl, P_ghWp, P_ghWpAnti, 4068, check)
      call createCurrent(P_ghAAnti, P_HMinus, P_G0, P_ghWp, 9804, check)
      call createCurrent(P_HMinus, P_HPlus, P_Z, P_A, 1685, check)
      call createCurrent(P_HQMinus, P_HMinus, P_HPlus, P_GQPlus, 3892, check)
      call createCurrent(P_ghWp, P_A, P_WMinus, P_ghAAnti, 464, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_GMinus, 5365, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghAAnti, P_GQPlus, 7350, check)
      call createCurrent(P_GMinus, P_Z, P_WPlus, P_Hh, 3440, check)
      call createCurrent(P_WMinus, P_GPlus, P_A, P_G0, 5774, check)
      call createCurrent(P_A, P_ghWpAnti, P_Z, P_ghWp, 1167, check)
      call createCurrent(P_GQ0, P_Hh, P_ghWpAnti, P_ghWp, 3672, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghA, 3235, check)
      call createCurrent(P_Z, P_WPlus, P_ghWm, P_ghAAnti, 1302, check)
      call createCurrent(P_dAnti, P_d, P_gQ, 171, check)
      call createCurrent(P_Hh, P_HPlus, P_G0, P_GMinus, 3736, check)
      call createCurrent(P_bAnti, P_b, P_A, 1234, check)
      call createCurrent(P_WPlus, P_WMinus, P_ghA, P_ghZAnti, 8357, check)
      call createCurrent(P_GPlus, P_GMinus, P_ghWm, P_ghWmAnti, 3592, check)
      call createCurrent(P_HPlus, P_Hh, P_Ha, P_HMinus, 9079, check)
      call createCurrent(P_ghWm, P_G0, P_ghZAnti, P_HPlus, 9968, check)
      call createCurrent(P_GQPlus, P_GMinus, P_HhQ, 3319, check)
      call createCurrent(P_WMinus, P_HPlus, P_A, 6036, check)
      call createCurrent(P_ghZ, P_Hh, P_GMinus, P_ghWmAnti, 4163, check)
      call createCurrent(P_HPlus, P_ghAAnti, P_GMinus, P_ghA, 9966, check)
      call createCurrent(P_WMinus, P_HMinus, P_WPlus, P_HPlus, 4624, check)
      call createCurrent(P_Hh, P_Hl, P_HPlus, P_GMinus, 3634, check)
      call createCurrent(P_nu_mu, P_nu_muAnti, P_ZQ, 3379, check)
      call createCurrent(P_Hl, P_Hl, P_Z, P_A, 9406, check)
      call createCurrent(P_Hh, P_A, P_WMinus, P_HPlus, 327, check)
      call createCurrent(P_ghWp, P_WPlus, P_WMinus, P_ghWpAnti, 7384, check)
      call createCurrent(P_HPlus, P_ghWpAnti, P_Hh, P_ghZ, 6330, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_Ha, P_Ha, 6031, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_WQMinus, 3778, check)
      call createCurrent(P_GQMinus, P_HPlus, P_HlQ, 7190, check)
      call createCurrent(P_ghWp, P_Hl, P_ghWpAnti, P_Hh, 9434, check)
      call createCurrent(P_ghA, P_GPlus, P_HMinus, P_ghZAnti, 9936, check)
      call createCurrent(P_GMinus, P_HPlus, P_GMinus, P_HPlus, 5950, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_G0, P_GMinus, 1961, check)
      call createCurrent(P_b, P_GPlus, P_tAnti, 3201, check)
      call createCurrent(P_A, P_A, P_Ha, P_Ha, 10600, check)
      call createCurrent(P_ghZ, P_Ha, P_Ha, P_ghZAnti, 4034, check)
      call createCurrent(P_HhQ, P_WMinus, P_WQPlus, 5638, check)
      call createCurrent(P_GMinus, P_Hh, P_HPlus, P_Hh, 3929, check)
      call createCurrent(P_HQMinus, P_G0, P_HPlus, P_HlQ, 5679, check)
      call createCurrent(P_GQ0, P_GPlus, P_G0, P_GQMinus, 1509, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_Ha, P_ghWp, 9662, check)
      call createCurrent(P_Ha, P_HPlus, P_WMinus, 7541, check)
      call createCurrent(P_HPlus, P_A, P_A, P_GMinus, 9899, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghA, P_A, 923, check)
      call createCurrent(P_WQMinus, P_Ha, P_HPlus, P_ZQ, 5062, check)
      call createCurrent(P_Ha, P_WMinus, P_A, P_GPlus, 9886, check)
      call createCurrent(P_WMinus, P_nu_tau, P_tauPlus, 1269, check)
      call createCurrent(P_GMinus, P_HPlus, P_Z, 9486, check)
      call createCurrent(P_WMinus, P_A, P_Z, P_WPlus, 2337, check)
      call createCurrent(P_WQMinus, P_Z, P_Hh, P_GQPlus, 8134, check)
      call createCurrent(P_b, P_WPlus, P_tAnti, 2170, check)
      call createCurrent(P_HMinus, P_ghA, P_ghWmAnti, P_Hl, 4092, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_GPlus, P_Ha, 8963, check)
      call createCurrent(P_Hl, P_Ha, P_Hh, P_G0, 1020, check)
      call createCurrent(P_t, P_bAnti, P_GQMinus, 3417, check)
      call createCurrent(P_HQPlus, P_ghWpAnti, P_Hh, P_ghZ, 8656, check)
      call createCurrent(P_WMinus, P_A, P_HPlus, P_Hh, 8214, check)
      call createCurrent(P_HPlus, P_ghA, P_ghAAnti, P_HMinus, 6116, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_Hl, P_HQMinus, 2231, check)
      call createCurrent(P_HPlus, P_WMinus, P_G0, 9885, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_HPlus, P_Hl, 1586, check)
      call createCurrent(P_Ha, P_G0, P_HMinus, P_GPlus, 705, check)
      call createCurrent(P_HQMinus, P_Hl, P_ghA, P_ghWmAnti, 5308, check)
      call createCurrent(P_GQMinus, P_nu_tau, P_tauPlus, 8165, check)
      call createCurrent(P_HMinus, P_ghAAnti, P_Hh, P_ghWp, 5706, check)
      call createCurrent(P_ghZ, P_Z, P_WPlus, P_ghWpAnti, 5618, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_G0, P_HhQ, 2021, check)
      call createCurrent(P_HMinus, P_Hh, P_HPlus, P_Ha, 9963, check)
      call createCurrent(P_Ha, P_ghWpAnti, P_ghZ, P_HPlus, 1653, check)
      call createCurrent(P_u, P_dAnti, P_WQMinus, 4109, check)
      call createCurrent(P_A, P_HPlus, P_Ha, P_WMinus, 2025, check)
      call createCurrent(P_ghA, P_Ha, P_ghWmAnti, P_HMinus, 8105, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_HMinus, P_HhQ, 157, check)
      call createCurrent(P_ghZAnti, P_HMinus, P_ghWp, P_HaQ, 5363, check)
      call createCurrent(P_HlQ, P_GPlus, P_ghWpAnti, P_ghZ, 1483, check)
      call createCurrent(P_ghZAnti, P_G0, P_ghWm, P_GPlus, 8587, check)
      call createCurrent(P_WMinus, P_A, P_ghZ, P_ghWmAnti, 6045, check)
      call createCurrent(P_dAnti, P_u, P_HQMinus, 3845, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_A, P_ghZ, 1515, check)
      call createCurrent(P_WPlus, P_G0, P_A, P_GMinus, 6106, check)
      call createCurrent(P_GMinus, P_ghAAnti, P_ghA, P_GPlus, 1755, check)
      call createCurrent(P_ghWm, P_WMinus, P_WPlus, P_ghWmAnti, 7704, check)
      call createCurrent(P_Hl, P_uAnti, P_u, 4974, check)
      call createCurrent(P_HPlus, P_ghWm, P_ghZAnti, P_G0, 10135, check)
      call createCurrent(P_HQPlus, P_GMinus, P_G0, P_HlQ, 4520, check)
      call createCurrent(P_ePlus, P_A, P_eMinus, 8444, check)
      call createCurrent(P_Hh, P_ghWm, P_ghAAnti, P_GPlus, 3389, check)
      call createCurrent(P_HhQ, P_ghWp, P_Ha, P_ghWpAnti, 503, check)
      call createCurrent(P_ghA, P_HMinus, P_Hl, P_ghWmAnti, 318, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Z, 3942, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_WMinus, P_WPlus, 8733, check)
      call createCurrent(P_HhQ, P_Hh, P_GPlus, P_HQMinus, 6299, check)
      call createCurrent(P_GPlus, P_Hh, P_ghWm, P_ghZAnti, 7684, check)
      call createCurrent(P_G0, P_WMinus, P_A, P_HPlus, 10222, check)
      call createCurrent(P_A, P_GMinus, P_HPlus, 8950, check)
      call createCurrent(P_ZQ, P_WMinus, P_HQPlus, 8473, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_A, P_ghA, 3876, check)
      call createCurrent(P_HMinus, P_ghWpAnti, P_ghWp, P_HPlus, 5220, check)
      call createCurrent(P_ghZ, P_Hh, P_HMinus, P_ghWmAnti, 3641, check)
      call createCurrent(P_WQMinus, P_Hl, P_HPlus, P_ZQ, 3171, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_HMinus, P_HlQ, 4773, check)
      call createCurrent(P_A, P_HPlus, P_GMinus, P_Z, 9858, check)
      call createCurrent(P_HMinus, P_HPlus, P_HMinus, P_HPlus, 1374, check)
      call createCurrent(P_HaQ, P_HPlus, P_A, P_WQMinus, 2980, check)
      call createCurrent(P_GQ0, P_GMinus, P_Hh, P_GQPlus, 196, check)
      call createCurrent(P_HhQ, P_cAnti, P_c, 3334, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_GMinus, P_HPlus, 10075, check)
      call createCurrent(P_c, P_G0, P_cAnti, 5827, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_AQ, 1984, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_GMinus, P_G0, 674, check)
      call createCurrent(P_WQMinus, P_ePlus, P_nu_e, 1391, check)
      call createCurrent(P_G0, P_HPlus, P_G0, P_HMinus, 5535, check)
      call createCurrent(P_GMinus, P_Ha, P_A, P_WPlus, 10093, check)
      call createCurrent(P_HMinus, P_GPlus, P_ghAAnti, P_ghZ, 10301, check)
      call createCurrent(P_ghWmAnti, P_Z, P_A, P_ghWm, 8553, check)
      call createCurrent(P_ghA, P_HPlus, P_G0, P_ghWpAnti, 9941, check)
      call createCurrent(P_ghWm, P_Hh, P_HPlus, P_ghZAnti, 2750, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_Hl, P_Hh, 9539, check)
      call createCurrent(P_Ha, P_ghWm, P_HPlus, P_ghZAnti, 2691, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_Hl, P_GQPlus, 7087, check)
      call createCurrent(P_WQMinus, P_Hh, P_Z, P_HQPlus, 1086, check)
      call createCurrent(P_HhQ, P_s, P_sAnti, 3183, check)
      call createCurrent(P_muMinus, P_muPlus, P_G0, 3336, check)
      call createCurrent(P_ghZ, P_WMinus, P_ghWmAnti, 354, check)
      call createCurrent(P_HQPlus, P_Z, P_A, P_HQMinus, 7284, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_Hl, P_HMinus, 5223, check)
      call createCurrent(P_Hh, P_eMinus, P_ePlus, 8772, check)
      call createCurrent(P_HMinus, P_G0, P_HPlus, P_Hh, 9601, check)
      call createCurrent(P_ghWm, P_HPlus, P_Hh, P_ghZAnti, 3271, check)
      call createCurrent(P_WQPlus, P_ghZAnti, P_WMinus, P_ghZ, 254, check)
      call createCurrent(P_ghWm, P_GMinus, P_ghWmAnti, P_HPlus, 10397, check)
      call createCurrent(P_Hl, P_HPlus, P_ghWm, P_ghZAnti, 4789, check)
      call createCurrent(P_HlQ, P_WPlus, P_WMinus, P_HlQ, 7366, check)
      call createCurrent(P_Ha, P_HMinus, P_HPlus, P_Hl, 10284, check)
      call createCurrent(P_GQPlus, P_Hl, P_Z, P_WQMinus, 295, check)
      call createCurrent(P_WMinus, P_A, P_G0, P_HPlus, 9577, check)
      call createCurrent(P_GQMinus, P_GPlus, P_GPlus, P_HQMinus, 7036, check)
      call createCurrent(P_HPlus, P_ghAAnti, P_Ha, P_ghWm, 5957, check)
      call createCurrent(P_HPlus, P_ghAAnti, P_Hl, P_ghWm, 8739, check)
      call createCurrent(P_ghG, P_ghGAnti, P_g, P_gQ, 4170, check)
      call createCurrent(P_ghZ, P_Hh, P_ghZAnti, P_HhQ, 7638, check)
      call createCurrent(P_ghAAnti, P_ghA, P_GMinus, P_GQPlus, 854, check)
      call createCurrent(P_G0, P_ghZ, P_HMinus, P_ghWmAnti, 10152, check)
      call createCurrent(P_WMinus, P_ghZAnti, P_Z, P_ghWp, 6284, check)
      call createCurrent(P_ghWp, P_Hh, P_HMinus, P_ghZAnti, 4140, check)
      call createCurrent(P_HPlus, P_HMinus, P_A, P_Z, 2482, check)
      call createCurrent(P_A, P_GMinus, P_GPlus, 7382, check)
      call createCurrent(P_HlQ, P_G0, P_G0, P_HhQ, 2728, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_WMinus, P_ghA, 314, check)
      call createCurrent(P_ghWpAnti, P_GMinus, P_HPlus, P_ghWp, 9770, check)
      call createCurrent(P_GMinus, P_ghA, P_ghWmAnti, P_Hl, 8433, check)
      call createCurrent(P_c, P_sAnti, P_GMinus, 5565, check)
      call createCurrent(P_AQ, P_A, P_HMinus, P_HQPlus, 1134, check)
      call createCurrent(P_ghA, P_Z, P_ghWmAnti, P_WMinus, 3998, check)
      call createCurrent(P_gQ, P_d, P_dAnti, 4515, check)
      call createCurrent(P_HlQ, P_Ha, P_Ha, P_HlQ, 6037, check)
      call createCurrent(P_GMinus, P_Hl, P_ghWp, P_ghZAnti, 3213, check)
      call createCurrent(P_G0, P_Hh, P_GPlus, P_HMinus, 5856, check)
      call createCurrent(P_d, P_dAnti, P_Hl, 691, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Ha, P_HlQ, 6702, check)
      call createCurrent(P_GQ0, P_HPlus, P_Ha, P_HQMinus, 8640, check)
      call createCurrent(P_ZQ, P_u, P_uAnti, 6213, check)
      call createCurrent(P_Hh, P_ghZ, P_ghZAnti, 6002, check)
      call createCurrent(P_Hl, P_Hh, P_ghZ, P_ghZAnti, 9617, check)
      call createCurrent(P_G0, P_GMinus, P_Hl, P_GPlus, 8967, check)
      call createCurrent(P_HlQ, P_ghWmAnti, P_Ha, P_ghWm, 2338, check)
      call createCurrent(P_HlQ, P_ghZAnti, P_HPlus, P_ghWm, 3637, check)
      call createCurrent(P_HQPlus, P_WMinus, P_A, P_HaQ, 4050, check)
      call createCurrent(P_Z, P_ghAAnti, P_ghWm, P_WPlus, 3328, check)
      call createCurrent(P_u, P_uAnti, P_G0, 823, check)
      call createCurrent(P_HlQ, P_GPlus, P_GMinus, P_HlQ, 2502, check)
      call createCurrent(P_HlQ, P_muMinus, P_muPlus, 2110, check)
      call createCurrent(P_Hh, P_GMinus, P_Hl, P_GPlus, 1133, check)
      call createCurrent(P_GPlus, P_ghAAnti, P_Hl, P_ghWm, 5606, check)
      call createCurrent(P_WQPlus, P_Hh, P_WMinus, P_HaQ, 5580, check)
      call createCurrent(P_HPlus, P_GMinus, P_G0, P_Hh, 3145, check)
      call createCurrent(P_GMinus, P_WPlus, P_Hh, P_Z, 2959, check)
      call createCurrent(P_G0, P_GPlus, P_ghZAnti, P_ghWm, 3956, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghZ, P_Hl, 4784, check)
      call createCurrent(P_HQPlus, P_ghWm, P_Ha, P_ghZAnti, 5663, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Ha, P_G0, 10124, check)
      call createCurrent(P_ghA, P_A, P_ghWpAnti, P_WQPlus, 4990, check)
      call createCurrent(P_ghWpAnti, P_G0, P_HPlus, P_ghZ, 9132, check)
      call createCurrent(P_HMinus, P_G0, P_Hh, P_GPlus, 7659, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_G0, P_Ha, 9160, check)
      call createCurrent(P_G0, P_ghAAnti, P_ghWm, P_GPlus, 3447, check)
      call createCurrent(P_WPlus, P_tauMinus, P_nu_tauAnti, 994, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Hh, P_Hh, 3297, check)
      call createCurrent(P_Hl, P_g, P_g, P_Hh, 10510, check)
      call createCurrent(P_ghWm, P_GPlus, P_Hl, P_ghAAnti, 6023, check)
      call createCurrent(P_Hh, P_ghA, P_ghWmAnti, P_HMinus, 6447, check)
      call createCurrent(P_WMinus, P_A, P_Hh, P_HPlus, 608, check)
      call createCurrent(P_ghWmAnti, P_Hh, P_ghWm, P_HhQ, 1745, check)
      call createCurrent(P_Hl, P_Hl, P_Ha, P_G0, 3296, check)
      call createCurrent(P_WPlus, P_ghA, P_ghAAnti, P_WMinus, 8492, check)
      call createCurrent(P_HPlus, P_HMinus, P_ghAAnti, P_ghZ, 2734, check)
      call createCurrent(P_G0, P_WMinus, P_Z, P_HPlus, 9939, check)
      call createCurrent(P_GPlus, P_Hl, P_WMinus, P_A, 6681, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_A, P_ZQ, 1541, check)
      call createCurrent(P_Hl, P_ghWm, P_ghAAnti, P_GPlus, 7530, check)
      call createCurrent(P_HPlus, P_ghWpAnti, P_ghZ, P_G0, 9543, check)
      call createCurrent(P_HQPlus, P_Hl, P_Hl, P_HQMinus, 2847, check)
      call createCurrent(P_HPlus, P_ghWmAnti, P_HMinus, P_ghWm, 6436, check)
      call createCurrent(P_HaQ, P_Hl, P_GMinus, P_HQPlus, 4603, check)
      call createCurrent(P_GPlus, P_Hl, P_ghWpAnti, P_ghZ, 5270, check)
      call createCurrent(P_A, P_GPlus, P_WMinus, P_Ha, 9849, check)
      call createCurrent(P_HhQ, P_HPlus, P_GQMinus, 3258, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_HPlus, P_Ha, 2510, check)
      call createCurrent(P_ZQ, P_HMinus, P_HPlus, P_ZQ, 7206, check)
      call createCurrent(P_A, P_GMinus, P_HPlus, P_A, 9681, check)
      call createCurrent(P_HlQ, P_Hl, P_HhQ, 8730, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghWmAnti, P_GQ0, 1999, check)
      call createCurrent(P_HlQ, P_ghZAnti, P_HMinus, P_ghWp, 3024, check)
      call createCurrent(P_GPlus, P_Hl, P_ghWm, P_ghAAnti, 6671, check)
      call createCurrent(P_GQPlus, P_Hh, P_Hh, P_GQMinus, 7824, check)
      call createCurrent(P_A, P_WMinus, P_GPlus, P_Hh, 2928, check)
      call createCurrent(P_GMinus, P_Ha, P_Z, P_WPlus, 9045, check)
      call createCurrent(P_WPlus, P_A, P_ghAAnti, P_ghWm, 2210, check)
      call createCurrent(P_d, P_HPlus, P_uAnti, 8136, check)
      call createCurrent(P_HMinus, P_ghAAnti, P_ghWp, P_Hl, 4507, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghA, P_GPlus, 2663, check)
      call createCurrent(P_HlQ, P_Z, P_GPlus, P_WQMinus, 2124, check)
      call createCurrent(P_u, P_A, P_uAnti, 7903, check)
      call createCurrent(P_GMinus, P_Hh, P_Z, P_WPlus, 5688, check)
      call createCurrent(P_gQ, P_bAnti, P_b, 3582, check)
      call createCurrent(P_Hl, P_Ha, P_HPlus, P_HMinus, 10470, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_A, P_WMinus, 1584, check)
      call createCurrent(P_Hl, P_ghWpAnti, P_Hh, P_ghWp, 9442, check)
      call createCurrent(P_HMinus, P_Hl, P_ghWp, P_ghAAnti, 5960, check)
      call createCurrent(P_GQ0, P_G0, P_ghWpAnti, P_ghWp, 3458, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_WPlus, 4787, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_GPlus, 112, check)
      call createCurrent(P_WQPlus, P_A, P_WMinus, P_AQ, 518, check)
      call createCurrent(P_HaQ, P_G0, P_GPlus, P_HQMinus, 1309, check)
      call createCurrent(P_GMinus, P_Ha, P_Hh, P_HPlus, 8510, check)
      call createCurrent(P_G0, P_A, P_WPlus, P_GMinus, 5331, check)
      call createCurrent(P_GPlus, P_HMinus, P_Ha, 8706, check)
      call createCurrent(P_GMinus, P_ghAAnti, P_GPlus, P_ghA, 2832, check)
      call createCurrent(P_Hl, P_GMinus, P_ghWmAnti, P_ghZ, 5975, check)
      call createCurrent(P_WPlus, P_GMinus, P_Z, P_G0, 5938, check)
      call createCurrent(P_g, P_A, P_g, P_g, 10681, check)
      call createCurrent(P_Ha, P_ghWp, P_HMinus, P_ghZAnti, 5435, check)
      call createCurrent(P_HMinus, P_HPlus, P_G0, P_Hh, 8999, check)
      call createCurrent(P_WMinus, P_Ha, P_WPlus, P_G0, 9796, check)
      call createCurrent(P_G0, P_GMinus, P_HPlus, P_Ha, 5521, check)
      call createCurrent(P_HPlus, P_Ha, P_WMinus, P_Z, 3812, check)
      call createCurrent(P_HQMinus, P_Ha, P_WPlus, P_AQ, 6670, check)
      call createCurrent(P_HPlus, P_ghZ, P_ghAAnti, P_HMinus, 297, check)
      call createCurrent(P_GQMinus, P_G0, P_GPlus, P_HaQ, 8748, check)
      call createCurrent(P_GQPlus, P_G0, P_ghWpAnti, P_ghA, 5241, check)
      call createCurrent(P_WPlus, P_GMinus, P_Ha, 9244, check)
      call createCurrent(P_HPlus, P_ghWm, P_ghZAnti, 4965, check)
      call createCurrent(P_HQMinus, P_Hl, P_Hl, P_GQPlus, 7886, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_HPlus, P_GMinus, 9717, check)
      call createCurrent(P_WQPlus, P_ghWpAnti, P_Z, P_ghA, 27, check)
      call createCurrent(P_GQ0, P_HMinus, P_Ha, P_HQPlus, 920, check)
      call createCurrent(P_GQ0, P_Hh, P_GPlus, P_GQMinus, 2527, check)
      call createCurrent(P_GQMinus, P_A, P_WPlus, P_HlQ, 3763, check)
      call createCurrent(P_HaQ, P_Hl, P_GMinus, P_GQPlus, 8118, check)
      call createCurrent(P_GQ0, P_sAnti, P_s, 2179, check)
      call createCurrent(P_GMinus, P_GPlus, P_Ha, P_G0, 1818, check)
      call createCurrent(P_GQ0, P_Hh, P_Hl, P_GQ0, 7365, check)
      call createCurrent(P_HhQ, P_ghAAnti, P_GPlus, P_ghWm, 8185, check)
      call createCurrent(P_c, P_sAnti, P_GQMinus, 703, check)
      call createCurrent(P_GQPlus, P_GMinus, P_Hl, P_GQ0, 3300, check)
      call createCurrent(P_HhQ, P_Hl, P_Ha, P_HaQ, 4861, check)
      call createCurrent(P_Ha, P_A, P_WPlus, P_HMinus, 8044, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_G0, P_GPlus, 3197, check)
      call createCurrent(P_GQMinus, P_u, P_dAnti, 3096, check)
      call createCurrent(P_ghAAnti, P_HPlus, P_HMinus, P_ghA, 8010, check)
      call createCurrent(P_HlQ, P_Ha, P_HMinus, P_GQPlus, 7964, check)
      call createCurrent(P_Hh, P_G0, P_A, 9148, check)
      call createCurrent(P_HlQ, P_GPlus, P_WQMinus, 2877, check)
      call createCurrent(P_ghAAnti, P_G0, P_HPlus, P_ghWm, 10277, check)
      call createCurrent(P_g, P_g, P_G0, P_G0, 10585, check)
      call createCurrent(P_HlQ, P_ghWp, P_ghWpAnti, 4132, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghZ, P_HlQ, 2954, check)
      call createCurrent(P_Hh, P_WPlus, P_Z, P_HMinus, 7510, check)
      call createCurrent(P_WPlus, P_ghZ, P_ghZAnti, P_WMinus, 2062, check)
      call createCurrent(P_ghA, P_GMinus, P_Hl, P_ghWmAnti, 5720, check)
      call createCurrent(P_WPlus, P_ghWm, P_WMinus, P_ghWmAnti, 1216, check)
      call createCurrent(P_HPlus, P_ghA, P_HMinus, P_ghAAnti, 221, check)
      call createCurrent(P_GPlus, P_G0, P_GMinus, P_G0, 332, check)
      call createCurrent(P_muPlus, P_WMinus, P_nu_mu, 1256, check)
      call createCurrent(P_Ha, P_HPlus, P_HMinus, P_Hl, 8876, check)
      call createCurrent(P_HaQ, P_G0, P_Ha, P_HaQ, 4231, check)
      call createCurrent(P_Z, P_GPlus, P_Hh, P_WMinus, 5694, check)
      call createCurrent(P_ZQ, P_ghZAnti, P_WPlus, P_ghWm, 6672, check)
      call createCurrent(P_Hl, P_Hl, P_ghWm, P_ghWmAnti, 6088, check)
      call createCurrent(P_WQPlus, P_Hl, P_WMinus, P_GQ0, 3999, check)
      call createCurrent(P_A, P_WPlus, P_Ha, P_HMinus, 6916, check)
      call createCurrent(P_ghWp, P_HMinus, P_G0, P_ghZAnti, 10361, check)
      call createCurrent(P_s, P_sAnti, P_Ha, 2566, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_A, P_A, 1958, check)
      call createCurrent(P_HMinus, P_ghWmAnti, P_Ha, P_ghA, 5131, check)
      call createCurrent(P_HlQ, P_HPlus, P_Hl, P_GQMinus, 406, check)
      call createCurrent(P_GQMinus, P_A, P_GPlus, P_AQ, 6410, check)
      call createCurrent(P_A, P_ghWmAnti, P_WMinus, P_ghZ, 4384, check)
      call createCurrent(P_AQ, P_A, P_WPlus, P_WQMinus, 1790, check)
      call createCurrent(P_ghWp, P_Z, P_ghWpAnti, P_A, 3705, check)
      call createCurrent(P_GQMinus, P_HPlus, P_Hl, P_HlQ, 5892, check)
      call createCurrent(P_GPlus, P_GMinus, P_Hl, P_Hh, 3434, check)
      call createCurrent(P_GMinus, P_G0, P_ghWp, P_ghAAnti, 2778, check)
      call createCurrent(P_uAnti, P_Hh, P_u, 2706, check)
      call createCurrent(P_muMinus, P_Ha, P_muPlus, 5654, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_ghWm, P_Z, 8238, check)
      call createCurrent(P_d, P_dAnti, P_g, 2376, check)
      call createCurrent(P_Ha, P_g, P_g, P_G0, 10557, check)
      call createCurrent(P_ghZ, P_Z, P_ghWpAnti, P_WQPlus, 1607, check)
      call createCurrent(P_ghA, P_HPlus, P_GMinus, P_ghZAnti, 10005, check)
      call createCurrent(P_HQMinus, P_HPlus, P_ghA, P_ghAAnti, 7379, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_HPlus, P_Hl, 114, check)
      call createCurrent(P_GMinus, P_GPlus, P_WMinus, P_WPlus, 3527, check)
      call createCurrent(P_HQMinus, P_dAnti, P_u, 3367, check)
      call createCurrent(P_ghWpAnti, P_HPlus, P_ghZ, P_Hl, 2484, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_GPlus, P_Hl, 8047, check)
      call createCurrent(P_GQMinus, P_GPlus, P_Hl, P_HaQ, 3910, check)
      call createCurrent(P_Ha, P_HMinus, P_HPlus, P_G0, 1644, check)
      call createCurrent(P_WMinus, P_Ha, P_HPlus, P_Z, 7743, check)
      call createCurrent(P_GQMinus, P_Ha, P_Ha, P_HQPlus, 1155, check)
      call createCurrent(P_t, P_tAnti, P_GQ0, 4203, check)
      call createCurrent(P_WQMinus, P_HPlus, P_AQ, 5491, check)
      call createCurrent(P_HlQ, P_GMinus, P_GPlus, P_HhQ, 7081, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghWmAnti, P_WMinus, 7232, check)
      call createCurrent(P_HlQ, P_Z, P_WPlus, P_GQMinus, 2491, check)
      call createCurrent(P_HaQ, P_Hl, P_GPlus, P_HQMinus, 3973, check)
      call createCurrent(P_GQPlus, P_HMinus, P_HPlus, P_HQMinus, 2211, check)
      call createCurrent(P_WQMinus, P_WPlus, P_ghZ, P_ghAAnti, 4265, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_GMinus, P_Hl, 1373, check)
      call createCurrent(P_HQPlus, P_HMinus, P_Hh, P_HlQ, 5462, check)
      call createCurrent(P_ghWp, P_HMinus, P_ghZAnti, P_HaQ, 6809, check)
      call createCurrent(P_GQPlus, P_HMinus, P_GPlus, P_HQMinus, 3022, check)
      call createCurrent(P_GQ0, P_Hl, P_Hh, P_GQ0, 7051, check)
      call createCurrent(P_WPlus, P_Ha, P_G0, P_WMinus, 9836, check)
      call createCurrent(P_A, P_ghZ, P_WMinus, P_ghWmAnti, 7387, check)
      call createCurrent(P_HaQ, P_Ha, P_Z, P_ZQ, 4289, check)
      call createCurrent(P_Hl, P_G0, P_Hh, P_Ha, 8020, check)
      call createCurrent(P_GQ0, P_Ha, P_GPlus, P_HQMinus, 3273, check)
      call createCurrent(P_GQMinus, P_Hl, P_GPlus, P_HaQ, 3565, check)
      call createCurrent(P_HMinus, P_HPlus, P_G0, P_Ha, 1530, check)
      call createCurrent(P_HMinus, P_HPlus, P_Hl, P_Hl, 8385, check)
      call createCurrent(P_Hh, P_G0, P_Ha, P_Hl, 7804, check)
      call createCurrent(P_WMinus, P_G0, P_Z, P_HPlus, 9540, check)
      call createCurrent(P_HMinus, P_ghWmAnti, P_ghZ, 4410, check)
      call createCurrent(P_GPlus, P_GMinus, P_WMinus, P_WPlus, 7720, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghZ, P_G0, 1993, check)
      call createCurrent(P_HPlus, P_GMinus, P_Hh, P_Hl, 132, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghWmAnti, P_WQMinus, 379, check)
      call createCurrent(P_GMinus, P_Hl, P_Hh, P_GPlus, 2359, check)
      call createCurrent(P_GMinus, P_Ha, P_WPlus, P_A, 9035, check)
      call createCurrent(P_ghA, P_Z, P_WMinus, P_ghWmAnti, 3310, check)
      call createCurrent(P_A, P_WMinus, P_ghZAnti, P_ghWp, 3446, check)
      call createCurrent(P_GQMinus, P_GPlus, P_ghZ, P_ghZAnti, 2626, check)
      call createCurrent(P_GQMinus, P_Hl, P_ghZAnti, P_ghWp, 2279, check)
      call createCurrent(P_HlQ, P_WMinus, P_WPlus, P_HlQ, 436, check)
      call createCurrent(P_dAnti, P_Z, P_d, 3067, check)
      call createCurrent(P_HlQ, P_GMinus, P_WPlus, P_ZQ, 8011, check)
      call createCurrent(P_G0, P_GPlus, P_HMinus, P_G0, 6692, check)
      call createCurrent(P_HlQ, P_GMinus, P_HPlus, P_HaQ, 4360, check)
      call createCurrent(P_g, P_ghG, P_ghGAnti, 5155, check)
      call createCurrent(P_AQ, P_uAnti, P_u, 8229, check)
      call createCurrent(P_ghA, P_A, P_ghWmAnti, P_WMinus, 5970, check)
      call createCurrent(P_GQ0, P_G0, P_Hl, P_HlQ, 2434, check)
      call createCurrent(P_A, P_WPlus, P_GMinus, P_G0, 2542, check)
      call createCurrent(P_t, P_tAnti, P_Z, 7592, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghWp, P_WQMinus, 6663, check)
      call createCurrent(P_ghZAnti, P_Hh, P_ghWp, P_GQMinus, 7719, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_Hl, P_GQPlus, 6415, check)
      call createCurrent(P_WPlus, P_GMinus, P_Z, 8702, check)
      call createCurrent(P_Hh, P_ghWm, P_GPlus, P_ghZAnti, 3560, check)
      call createCurrent(P_HQMinus, P_ghWmAnti, P_Hl, P_ghZ, 5816, check)
      call createCurrent(P_HQMinus, P_Hl, P_GQPlus, 1860, check)
      call createCurrent(P_GQMinus, P_ghWp, P_Hl, P_ghZAnti, 6371, check)
      call createCurrent(P_G0, P_Hh, P_Z, 1326, check)
      call createCurrent(P_ghWp, P_Ha, P_ghWpAnti, P_Ha, 8424, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_A, P_A, 7536, check)
      call createCurrent(P_GQPlus, P_ghZ, P_Hh, P_ghWpAnti, 8235, check)
      call createCurrent(P_GPlus, P_Hl, P_Ha, P_HMinus, 174, check)
      call createCurrent(P_GQ0, P_ghZ, P_GPlus, P_ghWpAnti, 7650, check)
      call createCurrent(P_Z, P_WMinus, P_ghAAnti, P_ghWp, 6832, check)
      call createCurrent(P_GQMinus, P_GPlus, P_A, P_ZQ, 6420, check)
      call createCurrent(P_ghZ, P_G0, P_GPlus, P_ghWpAnti, 5498, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_Hh, P_HQMinus, 2507, check)
      call createCurrent(P_AQ, P_ghZAnti, P_WPlus, P_ghWm, 1665, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_Ha, P_GMinus, 9246, check)
      call createCurrent(P_HQMinus, P_Hl, P_Z, P_WQPlus, 4364, check)
      call createCurrent(P_HQPlus, P_ghZAnti, P_Hl, P_ghWm, 3549, check)
      call createCurrent(P_WMinus, P_ghZ, P_WPlus, P_ghZAnti, 7712, check)
      call createCurrent(P_WQMinus, P_ghA, P_ghWmAnti, 2623, check)
      call createCurrent(P_HQMinus, P_G0, P_GQPlus, 45, check)
      call createCurrent(P_GPlus, P_ghWm, P_ghZAnti, P_Ha, 10481, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghA, P_Hh, 5383, check)
      call createCurrent(P_GQPlus, P_Z, P_A, P_GQMinus, 8036, check)
      call createCurrent(P_HlQ, P_GPlus, P_G0, P_HQMinus, 5686, check)
      call createCurrent(P_A, P_Ha, P_WMinus, P_GPlus, 9797, check)
      call createCurrent(P_HQMinus, P_GPlus, P_HMinus, P_GQPlus, 6517, check)
      call createCurrent(P_Hh, P_WMinus, P_Z, P_GPlus, 981, check)
      call createCurrent(P_GQPlus, P_Z, P_GQMinus, 4895, check)
      call createCurrent(P_ghWm, P_HPlus, P_ghWmAnti, P_GMinus, 10116, check)
      call createCurrent(P_Z, P_WMinus, P_HPlus, P_Ha, 6049, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghWm, P_WPlus, 85, check)
      call createCurrent(P_HPlus, P_Hh, P_Hl, P_HMinus, 2456, check)
      call createCurrent(P_WQMinus, P_WPlus, P_GMinus, P_GQPlus, 8775, check)
      call createCurrent(P_GQ0, P_GPlus, P_Ha, P_GQMinus, 6303, check)
      call createCurrent(P_AQ, P_Hl, P_GPlus, P_WQMinus, 2121, check)
      call createCurrent(P_GQPlus, P_GMinus, P_HlQ, 673, check)
      call createCurrent(P_GQPlus, P_GMinus, P_ghZAnti, P_ghA, 3650, check)
      call createCurrent(P_HPlus, P_Hh, P_HMinus, 4503, check)
      call createCurrent(P_ZQ, P_GPlus, P_GMinus, P_ZQ, 2246, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghWp, P_Ha, 8841, check)
      call createCurrent(P_HhQ, P_GPlus, P_Ha, P_HQMinus, 3230, check)
      call createCurrent(P_HMinus, P_ghZ, P_ghZAnti, P_HPlus, 831, check)
      call createCurrent(P_HlQ, P_Hl, P_HPlus, P_GQMinus, 5695, check)
      call createCurrent(P_HPlus, P_ghWm, P_ghZAnti, P_Hh, 3748, check)
      call createCurrent(P_ghWp, P_G0, P_ghAAnti, P_GMinus, 6811, check)
      call createCurrent(P_GQ0, P_eMinus, P_ePlus, 1242, check)
      call createCurrent(P_GPlus, P_G0, P_Ha, P_GMinus, 4434, check)
      call createCurrent(P_HMinus, P_ghWp, P_ghZAnti, P_Hh, 8525, check)
      call createCurrent(P_A, P_eMinus, P_ePlus, 5537, check)
      call createCurrent(P_Ha, P_G0, P_Hh, P_Hh, 8309, check)
      call createCurrent(P_AQ, P_GPlus, P_G0, P_WQMinus, 601, check)
      call createCurrent(P_WMinus, P_A, P_WPlus, 7127, check)
      call createCurrent(P_WPlus, P_A, P_Hh, P_HMinus, 8312, check)
      call createCurrent(P_WMinus, P_WPlus, P_HPlus, P_HMinus, 4215, check)
      call createCurrent(P_Hh, P_Hl, P_ghZAnti, P_ghZ, 10350, check)
      call createCurrent(P_Hl, P_G0, P_HPlus, P_GMinus, 1822, check)
      call createCurrent(P_GMinus, P_Ha, P_ghWp, P_ghAAnti, 9596, check)
      call createCurrent(P_WQPlus, P_muMinus, P_nu_muAnti, 6457, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_A, P_Z, 7746, check)
      call createCurrent(P_G0, P_ghWmAnti, P_HMinus, P_ghZ, 9173, check)
      call createCurrent(P_Ha, P_muPlus, P_muMinus, 1963, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghZ, 628, check)
      call createCurrent(P_HPlus, P_ghA, P_Hl, P_ghWpAnti, 1403, check)
      call createCurrent(P_ghZAnti, P_HPlus, P_GMinus, P_ghZ, 10360, check)
      call createCurrent(P_nu_tau, P_tauPlus, P_HMinus, 6673, check)
      call createCurrent(P_HPlus, P_WMinus, P_Ha, 3576, check)
      call createCurrent(P_HQPlus, P_A, P_Z, P_HQMinus, 3159, check)
      call createCurrent(P_Hh, P_ghZAnti, P_GPlus, P_ghWm, 4726, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_HlQ, 1780, check)
      call createCurrent(P_GPlus, P_Hh, P_GMinus, P_Ha, 9399, check)
      call createCurrent(P_WQPlus, P_Z, P_Hl, P_HQMinus, 7011, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_WPlus, 5568, check)
      call createCurrent(P_GQMinus, P_ghWmAnti, P_Hl, P_ghA, 7048, check)
      call createCurrent(P_GQPlus, P_ghA, P_G0, P_ghWpAnti, 6062, check)
      call createCurrent(P_HMinus, P_GPlus, P_GMinus, P_HPlus, 5516, check)
      call createCurrent(P_GMinus, P_Ha, P_GPlus, P_G0, 3783, check)
      call createCurrent(P_HlQ, P_Hl, P_ghWmAnti, P_ghWm, 5983, check)
      call createCurrent(P_WMinus, P_GPlus, P_A, P_Ha, 10185, check)
      call createCurrent(P_Hh, P_WPlus, P_WMinus, P_Hl, 9643, check)
      call createCurrent(P_HPlus, P_A, P_Ha, P_WMinus, 4923, check)
      call createCurrent(P_WQMinus, P_WPlus, P_Z, P_ZQ, 4857, check)
      call createCurrent(P_GMinus, P_Hh, P_Ha, P_HPlus, 585, check)
      call createCurrent(P_Hl, P_Hl, P_GPlus, P_HMinus, 7794, check)
      call createCurrent(P_Z, P_Z, P_HMinus, P_GPlus, 10192, check)
      call createCurrent(P_G0, P_HPlus, P_G0, P_GMinus, 3036, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghWmAnti, P_WMinus, 219, check)
      call createCurrent(P_WPlus, P_HMinus, P_A, P_Ha, 1875, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_WMinus, P_ghZ, 6139, check)
      call createCurrent(P_HhQ, P_WMinus, P_A, P_HQPlus, 3298, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_Hh, P_HQPlus, 6525, check)
      call createCurrent(P_ghAAnti, P_HPlus, P_HMinus, P_ghZ, 1147, check)
      call createCurrent(P_ghZ, P_Hh, P_ghWmAnti, P_GMinus, 2897, check)
      call createCurrent(P_GQPlus, P_A, P_Z, P_GQMinus, 8572, check)
      call createCurrent(P_WPlus, P_WMinus, P_Hh, P_Hh, 6537, check)
      call createCurrent(P_Hl, P_HMinus, P_GPlus, P_G0, 4661, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_WPlus, P_ghWm, 6685, check)
      call createCurrent(P_HMinus, P_ghWmAnti, P_HPlus, P_ghWm, 5282, check)
      call createCurrent(P_AQ, P_WMinus, P_Hh, P_HQPlus, 137, check)
      call createCurrent(P_ghWmAnti, P_HMinus, P_Hh, P_ghZ, 5855, check)
      call createCurrent(P_ghWp, P_Hl, P_ghAAnti, P_HMinus, 1294, check)
      call createCurrent(P_HaQ, P_bAnti, P_b, 5665, check)
      call createCurrent(P_HPlus, P_A, P_A, P_HMinus, 2640, check)
      call createCurrent(P_Hl, P_GPlus, P_ghAAnti, P_ghWm, 4630, check)
      call createCurrent(P_WMinus, P_Z, P_WPlus, P_Z, 4729, check)
      call createCurrent(P_HPlus, P_GMinus, P_Hl, P_Hl, 1757, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_GPlus, P_G0, 2256, check)
      call createCurrent(P_HPlus, P_ghWpAnti, P_Hl, P_ghA, 560, check)
      call createCurrent(P_ghAAnti, P_HPlus, P_Hh, P_ghWm, 4770, check)
      call createCurrent(P_WPlus, P_WMinus, P_Ha, P_G0, 9970, check)
      call createCurrent(P_Ha, P_Z, P_Hl, 2345, check)
      call createCurrent(P_AQ, P_A, P_ghWmAnti, P_ghWm, 4590, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_WMinus, P_WQPlus, 3212, check)
      call createCurrent(P_A, P_ghAAnti, P_ghWm, P_WPlus, 8178, check)
      call createCurrent(P_ZQ, P_Ha, P_Ha, P_ZQ, 6176, check)
      call createCurrent(P_WQPlus, P_ghWmAnti, P_WMinus, P_ghWm, 2704, check)
      call createCurrent(P_Hh, P_Z, P_HMinus, P_WPlus, 4822, check)
      call createCurrent(P_GQ0, P_ghZAnti, P_GPlus, P_ghWm, 1533, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghZ, P_Ha, 9548, check)
      call createCurrent(P_G0, P_ghA, P_GMinus, P_ghWmAnti, 715, check)
      call createCurrent(P_G0, P_GMinus, P_GPlus, P_Hh, 10368, check)
      call createCurrent(P_G0, P_Hl, P_Z, 7180, check)
      call createCurrent(P_GQ0, P_GMinus, P_Ha, P_GQPlus, 2105, check)
      call createCurrent(P_cAnti, P_c, P_Hh, 7317, check)
      call createCurrent(P_HPlus, P_ghZ, P_GMinus, P_ghZAnti, 9812, check)
      call createCurrent(P_G0, P_GMinus, P_G0, P_GPlus, 7241, check)
      call createCurrent(P_HMinus, P_WMinus, P_WPlus, P_GPlus, 9856, check)
      call createCurrent(P_HlQ, P_GPlus, P_Hh, P_HQMinus, 4926, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_Hl, P_HQPlus, 3274, check)
      call createCurrent(P_Hh, P_G0, P_G0, 8031, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_Hl, P_GPlus, 2918, check)
      call createCurrent(P_HQMinus, P_Ha, P_Hl, P_GQPlus, 815, check)
      call createCurrent(P_HPlus, P_Z, P_WMinus, P_Hl, 6159, check)
      call createCurrent(P_HPlus, P_Z, P_HMinus, P_A, 6038, check)
      call createCurrent(P_GQ0, P_G0, P_HPlus, P_HQMinus, 8495, check)
      call createCurrent(P_HPlus, P_GMinus, P_Z, P_Z, 9483, check)
      call createCurrent(P_ghZAnti, P_G0, P_GMinus, P_ghWp, 4103, check)
      call createCurrent(P_ghWpAnti, P_Z, P_ghA, P_WPlus, 99, check)
      call createCurrent(P_GPlus, P_Z, P_G0, P_WMinus, 5419, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghZAnti, P_GQ0, 6603, check)
      call createCurrent(P_HQMinus, P_GMinus, P_HPlus, P_HQPlus, 3934, check)
      call createCurrent(P_ghWm, P_G0, P_ghAAnti, P_GPlus, 2833, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_HQMinus, 2206, check)
      call createCurrent(P_A, P_A, P_GMinus, P_GPlus, 8306, check)
      call createCurrent(P_AQ, P_Z, P_ghWmAnti, P_ghWm, 3222, check)
      call createCurrent(P_HPlus, P_Hl, P_G0, P_GMinus, 6610, check)
      call createCurrent(P_HhQ, P_GMinus, P_HPlus, P_HlQ, 3915, check)
      call createCurrent(P_Ha, P_GPlus, P_Hl, P_GMinus, 9312, check)
      call createCurrent(P_Hl, P_ghZAnti, P_HMinus, P_ghWp, 6152, check)
      call createCurrent(P_ghWp, P_HMinus, P_ghAAnti, 5588, check)
      call createCurrent(P_HlQ, P_WPlus, P_GQMinus, 5869, check)
      call createCurrent(P_ghZ, P_WPlus, P_ghAAnti, P_WQMinus, 4955, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_WMinus, 6999, check)
      call createCurrent(P_A, P_Z, P_GPlus, P_HMinus, 8904, check)
      call createCurrent(P_GMinus, P_HPlus, P_Hl, P_Hl, 3804, check)
      call createCurrent(P_HlQ, P_HMinus, P_G0, P_HQPlus, 2873, check)
      call createCurrent(P_HQPlus, P_HPlus, P_GMinus, P_GQMinus, 8201, check)
      call createCurrent(P_Hl, P_G0, P_GMinus, P_GPlus, 10289, check)
      call createCurrent(P_HQMinus, P_GPlus, P_G0, P_HaQ, 5675, check)
      call createCurrent(P_Hh, P_s, P_sAnti, 4044, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghZ, P_Hh, 647, check)
      call createCurrent(P_HPlus, P_GMinus, P_ghWm, P_ghWmAnti, 9595, check)
      call createCurrent(P_ghWpAnti, P_G0, P_ghZ, P_HPlus, 10473, check)
      call createCurrent(P_G0, P_A, P_Z, P_G0, 9889, check)
      call createCurrent(P_GQ0, P_GMinus, P_Z, P_WQPlus, 5926, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghWmAnti, 8776, check)
      call createCurrent(P_Z, P_ghWm, P_Z, P_ghWmAnti, 7879, check)
      call createCurrent(P_ghWmAnti, P_Hh, P_GMinus, P_ghZ, 2145, check)
      call createCurrent(P_Ha, P_Z, P_G0, P_A, 10707, check)
      call createCurrent(P_WPlus, P_GMinus, P_A, P_Ha, 10352, check)
      call createCurrent(P_GMinus, P_GPlus, P_ghWp, P_ghWpAnti, 8144, check)
      call createCurrent(P_HhQ, P_Hl, P_Hh, P_HhQ, 2562, check)
      call createCurrent(P_Hl, P_ghWmAnti, P_ghWm, P_Hl, 362, check)
      call createCurrent(P_GMinus, P_Hl, P_ghAAnti, P_ghWp, 653, check)
      call createCurrent(P_GMinus, P_Z, P_WPlus, P_G0, 6345, check)
      call createCurrent(P_Hl, P_G0, P_GMinus, P_HPlus, 5707, check)
      call createCurrent(P_GQPlus, P_G0, P_ghWm, P_ghZAnti, 8196, check)
      call createCurrent(P_HMinus, P_ghWmAnti, P_Hh, P_ghA, 8774, check)
      call createCurrent(P_HhQ, P_ghWmAnti, P_Hh, P_ghWm, 1241, check)
      call createCurrent(P_HQPlus, P_Hl, P_ghZ, P_ghWpAnti, 8404, check)
      call createCurrent(P_GQMinus, P_A, P_WPlus, P_GQ0, 5941, check)
      call createCurrent(P_WPlus, P_WMinus, P_A, 2489, check)
      call createCurrent(P_WPlus, P_ghWmAnti, P_WMinus, P_ghWm, 1447, check)
      call createCurrent(P_HMinus, P_ghZ, P_HPlus, P_ghAAnti, 6784, check)
      call createCurrent(P_nu_muAnti, P_nu_mu, 9862, check)
      call createCurrent(P_HPlus, P_WMinus, P_Z, P_Ha, 6636, check)
      call createCurrent(P_Hh, P_ghA, P_ghWpAnti, P_GPlus, 5350, check)
      call createCurrent(P_Ha, P_Ha, P_G0, P_G0, 2866, check)
      call createCurrent(P_G0, P_Hh, P_HMinus, P_HPlus, 9699, check)
      call createCurrent(P_HaQ, P_tauPlus, P_tauMinus, 7323, check)
      call createCurrent(P_G0, P_GPlus, P_Hh, P_HMinus, 2880, check)
      call createCurrent(P_HMinus, P_HPlus, P_GPlus, P_HMinus, 429, check)
      call createCurrent(P_Z, P_ghWmAnti, P_ghWm, 6499, check)
      call createCurrent(P_GQPlus, P_GMinus, P_HaQ, 8336, check)
      call createCurrent(P_HPlus, P_Hh, P_WMinus, P_Z, 4418, check)
      call createCurrent(P_Ha, P_GPlus, P_G0, P_HMinus, 2844, check)
      call createCurrent(P_ghWm, P_WMinus, P_ghWmAnti, P_WQPlus, 7151, check)
      call createCurrent(P_HMinus, P_GMinus, P_GPlus, P_GPlus, 3642, check)
      call createCurrent(P_WQPlus, P_WMinus, P_Z, P_AQ, 1225, check)
      call createCurrent(P_GQMinus, P_GPlus, P_ghZAnti, P_ghA, 6721, check)
      call createCurrent(P_Ha, P_GMinus, P_Ha, P_GPlus, 925, check)
      call createCurrent(P_dAnti, P_u, P_WMinus, 5234, check)
      call createCurrent(P_HaQ, P_ghWmAnti, P_Hh, P_ghWm, 6793, check)
      call createCurrent(P_ghZ, P_ghAAnti, P_HMinus, P_GPlus, 10380, check)
      call createCurrent(P_g, P_g, P_GPlus, P_GMinus, 10519, check)
      call createCurrent(P_u, P_uAnti, P_Hl, 4632, check)
      call createCurrent(P_HaQ, P_Ha, P_HhQ, 4180, check)
      call createCurrent(P_c, P_Ha, P_cAnti, 7228, check)
      call createCurrent(P_HMinus, P_ghA, P_ghAAnti, P_GPlus, 9951, check)
      call createCurrent(P_HQPlus, P_G0, P_GMinus, P_HaQ, 3192, check)
      call createCurrent(P_bAnti, P_b, P_GQ0, 7757, check)
      call createCurrent(P_HhQ, P_Z, P_ZQ, 1613, check)
      call createCurrent(P_HQPlus, P_WMinus, P_ZQ, 7484, check)
      call createCurrent(P_eMinus, P_nu_eAnti, P_GPlus, 2894, check)
      call createCurrent(P_Ha, P_WPlus, P_WMinus, P_G0, 9700, check)
      call createCurrent(P_nu_tau, P_tauPlus, P_WQMinus, 5812, check)
      call createCurrent(P_Ha, P_Hh, P_GPlus, P_GMinus, 10215, check)
      call createCurrent(P_GQ0, P_HMinus, P_HPlus, P_HaQ, 8015, check)
      call createCurrent(P_HhQ, P_HPlus, P_Ha, P_HQMinus, 8314, check)
      call createCurrent(P_GQPlus, P_Hl, P_HMinus, P_HlQ, 86, check)
      call createCurrent(P_G0, P_G0, P_ghWpAnti, P_ghWp, 6982, check)
      call createCurrent(P_ghWpAnti, P_GMinus, P_ghWp, P_GPlus, 4035, check)
      call createCurrent(P_ghA, P_GPlus, P_ghZAnti, P_HMinus, 9854, check)
      call createCurrent(P_HhQ, P_WMinus, P_HPlus, P_ZQ, 983, check)
      call createCurrent(P_HhQ, P_A, P_WPlus, P_GQMinus, 3448, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_G0, P_ghZ, 7098, check)
      call createCurrent(P_HaQ, P_Hh, P_HPlus, P_GQMinus, 6022, check)
      call createCurrent(P_AQ, P_Ha, P_HMinus, P_WQPlus, 2784, check)
      call createCurrent(P_WQMinus, P_G0, P_GPlus, P_ZQ, 2796, check)
      call createCurrent(P_ghWpAnti, P_HPlus, P_Hl, P_ghA, 5208, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_GPlus, P_HMinus, 9334, check)
      call createCurrent(P_Hh, P_Hl, P_WMinus, P_WPlus, 8922, check)
      call createCurrent(P_GMinus, P_GPlus, P_Hh, P_G0, 9893, check)
      call createCurrent(P_HaQ, P_Hh, P_Ha, P_HhQ, 415, check)
      call createCurrent(P_ghA, P_HMinus, P_ghWmAnti, P_Ha, 1436, check)
      call createCurrent(P_muPlus, P_Hl, P_muMinus, 7231, check)
      call createCurrent(P_Hh, P_HMinus, P_GPlus, P_G0, 4315, check)
      call createCurrent(P_ghAAnti, P_HMinus, P_GPlus, P_ghA, 9676, check)
      call createCurrent(P_HPlus, P_GMinus, P_HMinus, P_GPlus, 3895, check)
      call createCurrent(P_HPlus, P_Hl, P_WMinus, 3547, check)
      call createCurrent(P_HQPlus, P_Hl, P_GQMinus, 2820, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_GMinus, P_Hl, 3283, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_A, P_Z, 4693, check)
      call createCurrent(P_HMinus, P_Hl, P_GPlus, P_Hl, 911, check)
      call createCurrent(P_ghA, P_Ha, P_GPlus, P_ghWpAnti, 8957, check)
      call createCurrent(P_WQMinus, P_Hh, P_Z, P_GQPlus, 8245, check)
      call createCurrent(P_HQMinus, P_HPlus, P_HMinus, P_GQPlus, 7826, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_HPlus, P_Ha, 933, check)
      call createCurrent(P_dAnti, P_WMinus, P_u, 2780, check)
      call createCurrent(P_GQPlus, P_ghWm, P_Hl, P_ghZAnti, 7749, check)
      call createCurrent(P_ZQ, P_WPlus, P_GMinus, P_GQ0, 6018, check)
      call createCurrent(P_HPlus, P_b, P_tAnti, 8483, check)
      call createCurrent(P_Ha, P_GMinus, P_HPlus, P_Hh, 438, check)
      call createCurrent(P_GMinus, P_G0, P_HPlus, P_Hh, 4186, check)
      call createCurrent(P_Ha, P_GPlus, P_ghAAnti, P_ghWm, 10457, check)
      call createCurrent(P_HlQ, P_GMinus, P_ghZAnti, P_ghWp, 5011, check)
      call createCurrent(P_GQMinus, P_ghA, P_GPlus, P_ghAAnti, 2870, check)
      call createCurrent(P_ghA, P_GMinus, P_ghWmAnti, P_G0, 8347, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Z, 5604, check)
      call createCurrent(P_WQPlus, P_d, P_uAnti, 6933, check)
      call createCurrent(P_GPlus, P_Ha, P_GMinus, P_Hh, 9026, check)
      call createCurrent(P_HMinus, P_HPlus, P_WMinus, P_WPlus, 7405, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_HMinus, P_HQPlus, 3085, check)
      call createCurrent(P_GPlus, P_HPlus, P_HMinus, P_HMinus, 8349, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_GPlus, P_HhQ, 7435, check)
      call createCurrent(P_HQMinus, P_ghZAnti, P_HPlus, P_ghZ, 1500, check)
      call createCurrent(P_HaQ, P_Hl, P_Ha, P_HlQ, 7367, check)
      call createCurrent(P_GQMinus, P_Hl, P_Hh, P_GQPlus, 3013, check)
      call createCurrent(P_HlQ, P_HPlus, P_ghZ, P_ghWpAnti, 4750, check)
      call createCurrent(P_GQMinus, P_ghZAnti, P_G0, P_ghWp, 1057, check)
      call createCurrent(P_HQPlus, P_Hl, P_GMinus, P_HlQ, 4875, check)
      call createCurrent(P_HMinus, P_Hh, P_ghA, P_ghWmAnti, 6480, check)
      call createCurrent(P_G0, P_ghWpAnti, P_HPlus, P_ghA, 9819, check)
      call createCurrent(P_HQPlus, P_Hh, P_GMinus, P_GQ0, 2926, check)
      call createCurrent(P_ghZAnti, P_Hl, P_GPlus, P_ghWm, 5010, check)
      call createCurrent(P_HQMinus, P_GPlus, P_HaQ, 4331, check)
      call createCurrent(P_tAnti, P_t, P_gQ, 192, check)
      call createCurrent(P_Hh, P_ghAAnti, P_GMinus, P_ghWp, 3983, check)
      call createCurrent(P_HQMinus, P_G0, P_GPlus, P_HlQ, 326, check)
      call createCurrent(P_Hh, P_ghWpAnti, P_GPlus, P_ghA, 4620, check)
      call createCurrent(P_HQPlus, P_GPlus, P_GMinus, P_HQMinus, 1694, check)
      call createCurrent(P_ghAAnti, P_ghZ, P_WPlus, P_WQMinus, 8278, check)
      call createCurrent(P_ZQ, P_HPlus, P_HQMinus, 4483, check)
      call createCurrent(P_WPlus, P_G0, P_GMinus, P_A, 6019, check)
      call createCurrent(P_HaQ, P_HPlus, P_ghZ, P_ghWpAnti, 7932, check)
      call createCurrent(P_ghWmAnti, P_Z, P_ghZ, P_WMinus, 8402, check)
      call createCurrent(P_WMinus, P_ghAAnti, P_ghA, P_WPlus, 345, check)
      call createCurrent(P_ghZ, P_Hh, P_ghZAnti, 7118, check)
      call createCurrent(P_G0, P_ghZ, P_ghZAnti, P_G0, 4571, check)
      call createCurrent(P_Ha, P_A, P_A, P_G0, 10632, check)
      call createCurrent(P_HPlus, P_Ha, P_Z, P_WMinus, 5802, check)
      call createCurrent(P_HPlus, P_ghWmAnti, P_ghWm, P_HMinus, 7843, check)
      call createCurrent(P_ghZ, P_HMinus, P_ghAAnti, P_HPlus, 6737, check)
      call createCurrent(P_A, P_WPlus, P_Hl, P_HMinus, 620, check)
      call createCurrent(P_HMinus, P_WPlus, P_WMinus, P_GPlus, 8927, check)
      call createCurrent(P_tauPlus, P_Ha, P_tauMinus, 1419, check)
      call createCurrent(P_GMinus, P_GPlus, P_ghWmAnti, P_ghWm, 2141, check)
      call createCurrent(P_Z, P_GMinus, P_WPlus, P_Hl, 232, check)
      call createCurrent(P_muPlus, P_muMinus, P_Z, 2747, check)
      call createCurrent(P_GQ0, P_ghWmAnti, P_Hh, P_ghWm, 7699, check)
      call createCurrent(P_HPlus, P_Z, P_A, P_GMinus, 9964, check)
      call createCurrent(P_HQMinus, P_HPlus, P_HPlus, P_GQMinus, 6953, check)
      call createCurrent(P_Hh, P_GMinus, P_ghZAnti, P_ghWp, 5455, check)
      call createCurrent(P_ghZ, P_G0, P_ghZAnti, P_GQ0, 2261, check)
      call createCurrent(P_HQMinus, P_GPlus, P_G0, P_GQ0, 2044, check)
      call createCurrent(P_Ha, P_HMinus, P_HPlus, P_Hh, 10322, check)
      call createCurrent(P_ghWm, P_Hh, P_ghWmAnti, P_GQ0, 788, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Z, P_Z, 8794, check)
      call createCurrent(P_Hh, P_ghWp, P_ghWpAnti, P_Hl, 9317, check)
      call createCurrent(P_A, P_GMinus, P_Z, P_GPlus, 6068, check)
      call createCurrent(P_GQ0, P_GPlus, P_ghZ, P_ghWpAnti, 8725, check)
      call createCurrent(P_HhQ, P_HPlus, P_WMinus, P_ZQ, 4263, check)
      call createCurrent(P_GQPlus, P_Hl, P_HMinus, P_HhQ, 8470, check)
      call createCurrent(P_ghZAnti, P_Hl, P_ghWp, P_GMinus, 5541, check)
      call createCurrent(P_WMinus, P_HPlus, P_A, P_Hl, 6254, check)
      call createCurrent(P_Z, P_Z, P_WMinus, P_WPlus, 139, check)
      call createCurrent(P_WMinus, P_ghWpAnti, P_ghWp, P_WPlus, 5583, check)
      call createCurrent(P_t, P_A, P_tAnti, 6376, check)
      call createCurrent(P_WMinus, P_Ha, P_HPlus, 3723, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_GPlus, P_GQMinus, 1513, check)
      call createCurrent(P_HPlus, P_A, P_Z, P_GMinus, 9236, check)
      call createCurrent(P_GQ0, P_HPlus, P_GMinus, P_HlQ, 8537, check)
      call createCurrent(P_HPlus, P_A, P_Hh, P_WMinus, 2095, check)
      call createCurrent(P_Z, P_A, P_Hh, 9544, check)
      call createCurrent(P_cAnti, P_c, P_Z, 2558, check)
      call createCurrent(P_GMinus, P_sAnti, P_c, 1786, check)
      call createCurrent(P_GQ0, P_HPlus, P_Hl, P_HQMinus, 1799, check)
      call createCurrent(P_HPlus, P_ghZAnti, P_Hh, P_ghWm, 3873, check)
      call createCurrent(P_GMinus, P_Ha, P_WPlus, 9263, check)
      call createCurrent(P_Hh, P_Ha, P_Ha, 5005, check)
      call createCurrent(P_WQPlus, P_Z, P_GMinus, P_GQ0, 4419, check)
      call createCurrent(P_G0, P_Ha, P_g, P_g, 10508, check)
      call createCurrent(P_ZQ, P_WMinus, P_Hh, P_GQPlus, 3372, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_G0, P_ghWm, 7177, check)
      call createCurrent(P_WPlus, P_Z, P_ghAAnti, P_ghWm, 8281, check)
      call createCurrent(P_ghZAnti, P_A, P_ghWm, P_WPlus, 7407, check)
      call createCurrent(P_HaQ, P_HMinus, P_GPlus, P_GQ0, 1335, check)
      call createCurrent(P_cAnti, P_c, P_AQ, 1798, check)
      call createCurrent(P_HPlus, P_ghZ, P_ghWpAnti, P_G0, 10209, check)
      call createCurrent(P_G0, P_ghWpAnti, P_G0, P_ghWp, 5375, check)
      call createCurrent(P_GQMinus, P_Hl, P_HQPlus, 1456, check)
      call createCurrent(P_HPlus, P_HMinus, P_A, P_A, 134, check)
      call createCurrent(P_HMinus, P_Hl, P_A, P_WPlus, 2241, check)
      call createCurrent(P_ghA, P_GMinus, P_ghAAnti, P_GQPlus, 6125, check)
      call createCurrent(P_tauPlus, P_nu_tau, P_GQMinus, 7295, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghA, P_Ha, 9981, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_A, P_WPlus, 4610, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Hh, P_HhQ, 3656, check)
      call createCurrent(P_ghWm, P_HPlus, P_Hh, P_ghAAnti, 2703, check)
      call createCurrent(P_ghWm, P_Z, P_ghWmAnti, P_ZQ, 6859, check)
      call createCurrent(P_HlQ, P_HPlus, P_GMinus, P_HhQ, 1054, check)
      call createCurrent(P_HQPlus, P_Hl, P_HMinus, P_HlQ, 2472, check)
      call createCurrent(P_ghWmAnti, P_Hh, P_Hh, P_ghWm, 2956, check)
      call createCurrent(P_dAnti, P_G0, P_d, 3994, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_WPlus, P_Z, 16, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_Z, 2890, check)
      call createCurrent(P_ghZAnti, P_Hh, P_GMinus, P_ghWp, 35, check)
      call createCurrent(P_GMinus, P_Hl, P_ghWmAnti, P_ghA, 8633, check)
      call createCurrent(P_A, P_A, P_g, P_g, 10509, check)
      call createCurrent(P_Z, P_G0, P_A, P_G0, 8964, check)
      call createCurrent(P_eMinus, P_Z, P_ePlus, 1281, check)
      call createCurrent(P_GQ0, P_WMinus, P_G0, P_WQPlus, 2687, check)
      call createCurrent(P_GQMinus, P_G0, P_WPlus, P_AQ, 661, check)
      call createCurrent(P_WPlus, P_cAnti, P_s, 8475, check)
      call createCurrent(P_G0, P_Hl, P_Ha, 5804, check)
      call createCurrent(P_G0, P_HPlus, P_WMinus, P_A, 9219, check)
      call createCurrent(P_ghWmAnti, P_Z, P_ghWm, P_A, 8407, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghWpAnti, P_HhQ, 8405, check)
      call createCurrent(P_GPlus, P_Z, P_HMinus, P_A, 10351, check)
      call createCurrent(P_GQ0, P_HMinus, P_G0, P_HQPlus, 6134, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_ghWm, P_Hl, 2284, check)
      call createCurrent(P_Z, P_GPlus, P_HMinus, P_Z, 10020, check)
      call createCurrent(P_ghWp, P_WMinus, P_WMinus, P_ghWmAnti, 8520, check)
      call createCurrent(P_AQ, P_WMinus, P_WPlus, P_AQ, 5047, check)
      call createCurrent(P_ghWpAnti, P_G0, P_ghWp, P_GQ0, 5532, check)
      call createCurrent(P_GMinus, P_ghWpAnti, P_ghWp, P_HPlus, 8861, check)
      call createCurrent(P_muPlus, P_muMinus, P_Ha, 7906, check)
      call createCurrent(P_HQMinus, P_G0, P_G0, P_HQPlus, 488, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_Hh, P_HhQ, 843, check)
      call createCurrent(P_A, P_Z, P_Ha, P_Ha, 9709, check)
      call createCurrent(P_HhQ, P_c, P_cAnti, 4806, check)
      call createCurrent(P_Ha, P_GMinus, P_Ha, P_HPlus, 1629, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_G0, P_HPlus, 9207, check)
      call createCurrent(P_GMinus, P_HPlus, P_G0, P_Hl, 1696, check)
      call createCurrent(P_HhQ, P_ghWp, P_GMinus, P_ghAAnti, 1680, check)
      call createCurrent(P_GPlus, P_WMinus, P_G0, P_Z, 2111, check)
      call createCurrent(P_GPlus, P_Z, P_WMinus, P_Hh, 2674, check)
      call createCurrent(P_Hh, P_g, P_g, P_Hl, 10515, check)
      call createCurrent(P_G0, P_ghWpAnti, P_GPlus, P_ghZ, 8518, check)
      call createCurrent(P_Hh, P_HPlus, P_ghWm, P_ghZAnti, 6869, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_Hl, P_ghWm, 4422, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_Hl, P_GQPlus, 6066, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_HPlus, P_HMinus, 2692, check)
      call createCurrent(P_GMinus, P_HPlus, P_Hh, P_Ha, 6856, check)
      call createCurrent(P_GPlus, P_Ha, P_ghA, P_ghWpAnti, 10294, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_ghWp, P_Ha, 9582, check)
      call createCurrent(P_g, P_Hh, P_Hh, P_g, 10703, check)
      call createCurrent(P_ghAAnti, P_Hl, P_HMinus, P_ghWp, 2708, check)
      call createCurrent(P_HlQ, P_GMinus, P_G0, P_HQPlus, 4884, check)
      call createCurrent(P_WMinus, P_Hl, P_GPlus, P_Z, 5235, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghZAnti, P_Ha, 10264, check)
      call createCurrent(P_GQ0, P_G0, P_Z, P_ZQ, 7013, check)
      call createCurrent(P_HMinus, P_Hh, P_HPlus, P_Hl, 5984, check)
      call createCurrent(P_WPlus, P_A, P_Hl, P_HMinus, 6583, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_ghWm, P_Hh, 5910, check)
      call createCurrent(P_GMinus, P_HPlus, P_G0, P_Hh, 6752, check)
      call createCurrent(P_muMinus, P_muPlus, P_HlQ, 8243, check)
      call createCurrent(P_WMinus, P_HPlus, P_Hh, P_A, 7809, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_A, P_ghA, 7901, check)
      call createCurrent(P_HQMinus, P_GPlus, P_Hl, P_HhQ, 5595, check)
      call createCurrent(P_HlQ, P_HMinus, P_HQPlus, 3946, check)
      call createCurrent(P_WQPlus, P_Ha, P_WMinus, P_HlQ, 4116, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_A, P_WMinus, 2154, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_GMinus, P_Ha, 9032, check)
      call createCurrent(P_WPlus, P_HPlus, P_WMinus, P_HMinus, 1892, check)
      call createCurrent(P_Hh, P_GMinus, P_HPlus, 7516, check)
      call createCurrent(P_ghWpAnti, P_HPlus, P_ghZ, 6250, check)
      call createCurrent(P_HlQ, P_GPlus, P_ghZ, P_ghWpAnti, 3639, check)
      call createCurrent(P_Hh, P_A, P_G0, 9933, check)
      call createCurrent(P_GPlus, P_A, P_Z, P_GMinus, 3559, check)
      call createCurrent(P_HMinus, P_Hh, P_Hh, P_HPlus, 1451, check)
      call createCurrent(P_GPlus, P_Hh, P_Hh, P_HMinus, 7992, check)
      call createCurrent(P_Hl, P_ghZAnti, P_ghWp, P_HMinus, 1909, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_ghA, P_WQMinus, 150, check)
      call createCurrent(P_GPlus, P_ghA, P_ghAAnti, P_HMinus, 8923, check)
      call createCurrent(P_G0, P_HMinus, P_Ha, P_GPlus, 6053, check)
      call createCurrent(P_HhQ, P_G0, P_GMinus, P_HQPlus, 167, check)
      call createCurrent(P_g, P_g, P_Hl, P_Hl, 10524, check)
      call createCurrent(P_GQPlus, P_HMinus, P_GQ0, 2446, check)
      call createCurrent(P_GQ0, P_GPlus, P_Hl, P_GQMinus, 3759, check)
      call createCurrent(P_G0, P_HPlus, P_GMinus, P_Hl, 7109, check)
      call createCurrent(P_HaQ, P_Hh, P_ghWm, P_ghWmAnti, 1327, check)
      call createCurrent(P_GQPlus, P_ghA, P_GMinus, P_ghZAnti, 5021, check)
      call createCurrent(P_HMinus, P_GPlus, P_G0, P_G0, 1716, check)
      call createCurrent(P_Hh, P_Hl, P_Hh, P_Hh, 7419, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_Hh, P_GQMinus, 897, check)
      call createCurrent(P_WPlus, P_Hh, P_HMinus, P_Z, 7856, check)
      call createCurrent(P_Ha, P_ghWm, P_HPlus, P_ghAAnti, 3253, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghAAnti, P_Hl, 7745, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_GPlus, P_ghA, 2671, check)
      call createCurrent(P_ZQ, P_ghZAnti, P_WMinus, P_ghWp, 5505, check)
      call createCurrent(P_Hl, P_Hl, P_ghZAnti, P_ghZ, 3601, check)
      call createCurrent(P_WMinus, P_HPlus, P_WPlus, P_HMinus, 2166, check)
      call createCurrent(P_HMinus, P_ghZAnti, P_ghWp, P_Ha, 6848, check)
      call createCurrent(P_WMinus, P_G0, P_G0, P_WPlus, 3644, check)
      call createCurrent(P_HPlus, P_ghWpAnti, P_Hl, P_ghZ, 4089, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghZAnti, P_GQPlus, 6951, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_A, P_AQ, 144, check)
      call createCurrent(P_GQMinus, P_A, P_WPlus, P_HhQ, 1088, check)
      call createCurrent(P_GQPlus, P_Z, P_WMinus, P_HlQ, 268, check)
      call createCurrent(P_Z, P_ghAAnti, P_ghWp, P_WMinus, 4179, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_GMinus, P_GQ0, 6305, check)
      call createCurrent(P_ZQ, P_WMinus, P_G0, P_GQPlus, 4229, check)
      call createCurrent(P_Hl, P_HPlus, P_Ha, P_GMinus, 7266, check)
      call createCurrent(P_WQPlus, P_GMinus, P_A, P_HlQ, 7357, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_HPlus, P_Hl, 7676, check)
      call createCurrent(P_HPlus, P_ghA, P_ghAAnti, P_GMinus, 9743, check)
      call createCurrent(P_GMinus, P_Hh, P_Hl, P_HPlus, 4688, check)
      call createCurrent(P_WMinus, P_A, P_WPlus, P_Z, 6696, check)
      call createCurrent(P_WPlus, P_HMinus, P_Hl, 169, check)
      call createCurrent(P_A, P_Ha, P_WPlus, P_HMinus, 1659, check)
      call createCurrent(P_ghZ, P_WPlus, P_WMinus, P_ghZAnti, 3826, check)
      call createCurrent(P_GQPlus, P_Hh, P_ghWpAnti, P_ghZ, 5090, check)
      call createCurrent(P_GQ0, P_HPlus, P_HMinus, P_HaQ, 5206, check)
      call createCurrent(P_GMinus, P_GMinus, P_HPlus, P_HPlus, 1814, check)
      call createCurrent(P_GMinus, P_Hl, P_GPlus, P_Hh, 4244, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_Ha, P_GMinus, 10086, check)
      call createCurrent(P_WMinus, P_GPlus, P_Z, P_Hh, 2274, check)
      call createCurrent(P_ghA, P_WPlus, P_ghAAnti, P_WMinus, 42, check)
      call createCurrent(P_WPlus, P_A, P_ghZAnti, P_ghWm, 6542, check)
      call createCurrent(P_nu_eAnti, P_eMinus, P_GPlus, 1795, check)
      call createCurrent(P_ZQ, P_WMinus, P_ghWp, P_ghZAnti, 2528, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_GPlus, P_HhQ, 4335, check)
      call createCurrent(P_eMinus, P_ePlus, P_HlQ, 7915, check)
      call createCurrent(P_WMinus, P_G0, P_Ha, P_WPlus, 9727, check)
      call createCurrent(P_G0, P_HPlus, P_HMinus, 9485, check)
      call createCurrent(P_muPlus, P_muMinus, P_Hh, 5123, check)
      call createCurrent(P_ghZAnti, P_Z, P_ghWp, P_WMinus, 4452, check)
      call createCurrent(P_HQMinus, P_HPlus, P_ghZAnti, P_ghZ, 11, check)
      call createCurrent(P_HPlus, P_ghWpAnti, P_ghZ, P_Hl, 8584, check)
      call createCurrent(P_HPlus, P_GMinus, P_Z, P_A, 9444, check)
      call createCurrent(P_g, P_g, P_Ha, P_G0, 10640, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_G0, P_GQPlus, 538, check)
      call createCurrent(P_G0, P_GPlus, P_Z, P_WMinus, 2772, check)
      call createCurrent(P_ghA, P_WMinus, P_WPlus, P_ghAAnti, 4375, check)
      call createCurrent(P_HlQ, P_HMinus, P_GPlus, P_HlQ, 7940, check)
      call createCurrent(P_ghA, P_G0, P_HMinus, P_ghWmAnti, 9337, check)
      call createCurrent(P_Hl, P_A, P_WPlus, P_HMinus, 212, check)
      call createCurrent(P_ghWp, P_GMinus, P_Hl, P_ghZAnti, 51, check)
      call createCurrent(P_ghWp, P_G0, P_ghZAnti, P_GMinus, 5257, check)
      call createCurrent(P_GPlus, P_ghA, P_ghZAnti, P_HMinus, 8994, check)
      call createCurrent(P_GPlus, P_Z, P_Hh, P_WMinus, 6925, check)
      call createCurrent(P_ghZAnti, P_G0, P_Ha, P_ghZ, 10321, check)
      call createCurrent(P_HaQ, P_HPlus, P_Ha, P_HQMinus, 3816, check)
      call createCurrent(P_WPlus, P_ghZAnti, P_ghWm, P_A, 8224, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_HPlus, P_HMinus, 2093, check)
      call createCurrent(P_HlQ, P_Hh, P_HMinus, P_HQPlus, 3002, check)
      call createCurrent(P_Ha, P_HPlus, P_ghWpAnti, P_ghZ, 146, check)
      call createCurrent(P_HlQ, P_bAnti, P_b, 515, check)
      call createCurrent(P_Z, P_dAnti, P_d, 4699, check)
      call createCurrent(P_cAnti, P_Z, P_c, 8088, check)
      call createCurrent(P_Hl, P_GMinus, P_HPlus, P_Ha, 5135, check)
      call createCurrent(P_A, P_Ha, P_WMinus, P_HPlus, 6684, check)
      call createCurrent(P_eMinus, P_WPlus, P_nu_eAnti, 8507, check)
      call createCurrent(P_G0, P_Hl, P_Hh, P_Ha, 3200, check)
      call createCurrent(P_A, P_HMinus, P_WPlus, P_Hl, 1888, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_G0, P_ghA, 2845, check)
      call createCurrent(P_HlQ, P_s, P_sAnti, 8180, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_HPlus, P_ghWm, 10355, check)
      call createCurrent(P_ghWm, P_GPlus, P_G0, P_ghAAnti, 2571, check)
      call createCurrent(P_WQPlus, P_WMinus, P_AQ, 1817, check)
      call createCurrent(P_Hh, P_ghWp, P_ghZAnti, P_GMinus, 3262, check)
      call createCurrent(P_HMinus, P_A, P_Ha, P_WPlus, 534, check)
      call createCurrent(P_HhQ, P_Hl, P_Ha, P_GQ0, 7666, check)
      call createCurrent(P_HhQ, P_Hl, P_HPlus, P_GQMinus, 7222, check)
      call createCurrent(P_ePlus, P_eMinus, P_ZQ, 3538, check)
      call createCurrent(P_ghWpAnti, P_HPlus, P_ghA, 1372, check)
      call createCurrent(P_Hl, P_Hh, P_A, P_A, 10745, check)
      call createCurrent(P_GPlus, P_G0, P_ghWpAnti, P_ghZ, 7349, check)
      call createCurrent(P_ghZ, P_WMinus, P_WPlus, P_ghZAnti, 5330, check)
      call createCurrent(P_ghZ, P_HPlus, P_Hl, P_ghWpAnti, 5317, check)
      call createCurrent(P_ghWp, P_Hh, P_ghAAnti, P_GMinus, 7420, check)
      call createCurrent(P_Hl, P_Ha, P_GPlus, P_HMinus, 1943, check)
      call createCurrent(P_GQ0, P_G0, P_GPlus, P_HQMinus, 2614, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_Hl, P_HMinus, 1270, check)
      call createCurrent(P_Hh, P_GMinus, P_Hh, P_GPlus, 829, check)
      call createCurrent(P_A, P_Ha, P_HPlus, P_WMinus, 3591, check)
      call createCurrent(P_GQ0, P_ghZAnti, P_GMinus, P_ghWp, 3428, check)
      call createCurrent(P_ZQ, P_A, P_GMinus, P_GQPlus, 4438, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_HPlus, P_HlQ, 7442, check)
      call createCurrent(P_ghWp, P_A, P_WMinus, P_ghZAnti, 5456, check)
      call createCurrent(P_A, P_muPlus, P_muMinus, 472, check)
      call createCurrent(P_ghWp, P_HMinus, P_ghZAnti, P_G0, 9075, check)
      call createCurrent(P_HhQ, P_GPlus, P_GMinus, P_HlQ, 666, check)
      call createCurrent(P_WQMinus, P_Hh, P_HPlus, P_ZQ, 486, check)
      call createCurrent(P_Hh, P_HMinus, P_ghZAnti, P_ghWp, 202, check)
      call createCurrent(P_ZQ, P_Ha, P_HlQ, 4891, check)
      call createCurrent(P_Ha, P_Hl, P_HPlus, P_HMinus, 9733, check)
      call createCurrent(P_GPlus, P_Hh, P_WMinus, P_A, 8756, check)
      call createCurrent(P_HlQ, P_Hh, P_HhQ, 6085, check)
      call createCurrent(P_Z, P_WPlus, P_ghWpAnti, P_ghZ, 2022, check)
      call createCurrent(P_GMinus, P_WPlus, P_G0, 3629, check)
      call createCurrent(P_ghWm, P_G0, P_ghAAnti, P_HPlus, 9607, check)
      call createCurrent(P_GQ0, P_ghWmAnti, P_ghWm, 5845, check)
      call createCurrent(P_GPlus, P_A, P_WMinus, P_G0, 6368, check)
      call createCurrent(P_GPlus, P_Hh, P_A, P_WMinus, 6086, check)
      call createCurrent(P_ghWpAnti, P_Ha, P_ghZ, P_HQPlus, 3715, check)
      call createCurrent(P_GPlus, P_Z, P_HMinus, 10046, check)
      call createCurrent(P_Hl, P_GMinus, P_HPlus, P_Hh, 5937, check)
      call createCurrent(P_Hh, P_Hh, P_Hl, P_Hh, 425, check)
      call createCurrent(P_WMinus, P_g, P_WPlus, P_g, 10535, check)
      call createCurrent(P_ghZAnti, P_Hh, P_Hl, P_ghZ, 10012, check)
      call createCurrent(P_Hl, P_G0, P_Z, 2848, check)
      call createCurrent(P_WMinus, P_Z, P_GPlus, P_Hh, 4325, check)
      call createCurrent(P_WQMinus, P_G0, P_GQPlus, 4188, check)
      call createCurrent(P_G0, P_G0, P_ghWm, P_ghWmAnti, 4144, check)
      call createCurrent(P_muMinus, P_nu_muAnti, P_WPlus, 851, check)
      call createCurrent(P_GQMinus, P_WMinus, P_WPlus, P_GQPlus, 770, check)
      call createCurrent(P_Hl, P_HMinus, P_ghWmAnti, P_ghZ, 2950, check)
      call createCurrent(P_WMinus, P_A, P_Ha, P_GPlus, 9519, check)
      call createCurrent(P_Z, P_WMinus, P_GPlus, P_G0, 1443, check)
      call createCurrent(P_GQ0, P_Ha, P_Hh, P_HhQ, 8054, check)
      call createCurrent(P_ghZAnti, P_Hl, P_ghWm, P_HQPlus, 8037, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_Ha, 1181, check)
      call createCurrent(P_WQPlus, P_Ha, P_WMinus, P_HaQ, 7792, check)
      call createCurrent(P_ghWmAnti, P_Ha, P_ghWm, P_HaQ, 1592, check)
      call createCurrent(P_Ha, P_ghWpAnti, P_Ha, P_ghWp, 8637, check)
      call createCurrent(P_Z, P_WMinus, P_G0, P_GPlus, 6910, check)
      call createCurrent(P_AQ, P_Hl, P_WPlus, P_HQMinus, 6208, check)
      call createCurrent(P_AQ, P_WMinus, P_GQPlus, 3523, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_ghA, P_HPlus, 10198, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_Hh, P_HMinus, 5380, check)
      call createCurrent(P_HhQ, P_Ha, P_WPlus, P_WQMinus, 6920, check)
      call createCurrent(P_HMinus, P_ghWm, P_ghWmAnti, P_HPlus, 1416, check)
      call createCurrent(P_G0, P_A, P_Ha, P_Z, 10583, check)
      call createCurrent(P_HMinus, P_HPlus, P_A, 3050, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_HPlus, P_Ha, 8215, check)
      call createCurrent(P_WQPlus, P_WMinus, P_GQ0, 7817, check)
      call createCurrent(P_Ha, P_HPlus, P_G0, P_HMinus, 7364, check)
      call createCurrent(P_Hl, P_A, P_WPlus, P_GMinus, 8827, check)
      call createCurrent(P_GPlus, P_Hh, P_HMinus, 2620, check)
      call createCurrent(P_Hh, P_Hl, P_GPlus, P_GMinus, 1708, check)
      call createCurrent(P_HQMinus, P_nu_mu, P_muPlus, 7444, check)
      call createCurrent(P_Z, P_HMinus, P_HPlus, P_A, 960, check)
      call createCurrent(P_ghZ, P_HPlus, P_ghWpAnti, P_HaQ, 8687, check)
      call createCurrent(P_GMinus, P_HPlus, P_ghWpAnti, P_ghWp, 9877, check)
      call createCurrent(P_AQ, P_ghAAnti, P_WMinus, P_ghWp, 6726, check)
      call createCurrent(P_HPlus, P_ghZ, P_ghWpAnti, P_Ha, 7319, check)
      call createCurrent(P_c, P_cAnti, P_A, 6245, check)
      call createCurrent(P_ZQ, P_G0, P_G0, P_ZQ, 4720, check)
      call createCurrent(P_HaQ, P_WPlus, P_Z, P_HQMinus, 5962, check)
      call createCurrent(P_Hh, P_A, P_HMinus, P_WPlus, 416, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghA, P_Hl, 2834, check)
      call createCurrent(P_Ha, P_sAnti, P_s, 7754, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_HMinus, P_GPlus, 9011, check)
      call createCurrent(P_GQPlus, P_GMinus, P_G0, P_HhQ, 898, check)
      call createCurrent(P_ghA, P_Hl, P_ghWmAnti, P_HMinus, 3800, check)
      call createCurrent(P_ghA, P_ghZAnti, P_GMinus, P_HPlus, 10267, check)
      call createCurrent(P_Hl, P_ghZAnti, P_ghWp, P_GMinus, 7173, check)
      call createCurrent(P_WMinus, P_WPlus, P_Hl, 5913, check)
      call createCurrent(P_HMinus, P_G0, P_GPlus, P_Ha, 6682, check)
      call createCurrent(P_nu_tau, P_A, P_nu_tauAnti, 10199, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_GPlus, P_Ha, 9095, check)
      call createCurrent(P_HPlus, P_HMinus, P_GMinus, P_HPlus, 7591, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghWm, P_HPlus, 9167, check)
      call createCurrent(P_GQPlus, P_HMinus, P_HlQ, 3112, check)
      call createCurrent(P_HPlus, P_ghZ, P_ghZAnti, P_GMinus, 9721, check)
      call createCurrent(P_WQMinus, P_WPlus, P_Ha, P_HaQ, 3935, check)
      call createCurrent(P_ghZ, P_GPlus, P_Hl, P_ghWpAnti, 6205, check)
      call createCurrent(P_A, P_d, P_dAnti, 1169, check)
      call createCurrent(P_Ha, P_WMinus, P_Ha, P_WPlus, 876, check)
      call createCurrent(P_Hl, P_Hl, 9646, check)
      call createCurrent(P_GPlus, P_HMinus, P_G0, 3631, check)
      call createCurrent(P_GPlus, P_tauMinus, P_nu_tauAnti, 7778, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_G0, P_Ha, 10172, check)
      call createCurrent(P_GQMinus, P_Ha, P_GPlus, P_GQ0, 1340, check)
      call createCurrent(P_G0, P_Hl, P_Hl, P_Hl, 10528, check)
      call createCurrent(P_HlQ, P_Hl, P_GPlus, P_HQMinus, 1009, check)
      call createCurrent(P_Ha, P_GMinus, P_HPlus, 8795, check)
      call createCurrent(P_nu_mu, P_muPlus, P_HQMinus, 7337, check)
      call createCurrent(P_muPlus, P_nu_mu, P_WMinus, 688, check)
      call createCurrent(P_HQMinus, P_ghWmAnti, P_Ha, P_ghZ, 1119, check)
      call createCurrent(P_WQMinus, P_A, P_GPlus, P_HhQ, 1920, check)
      call createCurrent(P_ePlus, P_eMinus, P_Ha, 7155, check)
      call createCurrent(P_WQPlus, P_WMinus, P_Hl, P_HaQ, 1066, check)
      call createCurrent(P_Hh, P_Hh, P_GMinus, P_HPlus, 2329, check)
      call createCurrent(P_GMinus, P_GPlus, P_Hh, P_Ha, 9841, check)
      call createCurrent(P_Z, P_Hh, P_A, P_Hl, 10729, check)
      call createCurrent(P_HPlus, P_G0, P_GMinus, P_Hl, 2092, check)
      call createCurrent(P_GPlus, P_Hl, P_HMinus, 7756, check)
      call createCurrent(P_A, P_Hl, P_Z, P_Hl, 10263, check)
      call createCurrent(P_HhQ, P_ghAAnti, P_HMinus, P_ghWp, 1283, check)
      call createCurrent(P_Ha, P_Ha, P_G0, P_Ha, 2164, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_Hl, P_GPlus, 5318, check)
      call createCurrent(P_HMinus, P_WPlus, P_GPlus, P_WMinus, 10445, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_Ha, P_ghA, 10150, check)
      call createCurrent(P_GMinus, P_Hh, P_ghAAnti, P_ghWp, 7658, check)
      call createCurrent(P_GPlus, P_GMinus, P_Hh, P_Ha, 9908, check)
      call createCurrent(P_A, P_nu_muAnti, P_nu_mu, 9560, check)
      call createCurrent(P_HQPlus, P_WMinus, P_HhQ, 53, check)
      call createCurrent(P_Z, P_WPlus, P_ghZAnti, P_ghWm, 6328, check)
      call createCurrent(P_G0, P_WMinus, P_GPlus, P_A, 3658, check)
      call createCurrent(P_Hl, P_G0, P_HPlus, P_HMinus, 9211, check)
      call createCurrent(P_HMinus, P_GPlus, P_HPlus, P_HMinus, 2970, check)
      call createCurrent(P_G0, P_GPlus, P_HMinus, P_Hh, 5378, check)
      call createCurrent(P_G0, P_ghWpAnti, P_ghZ, P_GPlus, 96, check)
      call createCurrent(P_GPlus, P_ghA, P_HMinus, P_ghZAnti, 8988, check)
      call createCurrent(P_ghWm, P_Ha, P_G0, P_ghWmAnti, 9120, check)
      call createCurrent(P_WQMinus, P_Z, P_Hl, P_GQPlus, 8307, check)
      call createCurrent(P_WQPlus, P_Z, P_HMinus, P_HaQ, 7927, check)
      call createCurrent(P_ghZAnti, P_Hl, P_ghWp, P_GQMinus, 1643, check)
      call createCurrent(P_G0, P_G0, P_HMinus, P_GPlus, 1764, check)
      call createCurrent(P_GPlus, P_Ha, P_Hh, P_GMinus, 10097, check)
      call createCurrent(P_ghWpAnti, P_Hh, P_ghWp, 3154, check)
      call createCurrent(P_ghWm, P_GMinus, P_HPlus, P_ghWmAnti, 9421, check)
      call createCurrent(P_HPlus, P_GMinus, P_Hl, P_Ha, 319, check)
      call createCurrent(P_ghAAnti, P_ghZ, P_GMinus, P_HPlus, 8854, check)
      call createCurrent(P_GPlus, P_HMinus, P_GPlus, P_HMinus, 2908, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_Hh, 8666, check)
      call createCurrent(P_ghA, P_A, P_WPlus, P_ghWpAnti, 4654, check)
      call createCurrent(P_HPlus, P_G0, P_HMinus, P_Hl, 9835, check)
      call createCurrent(P_ghWm, P_GPlus, P_GMinus, P_ghWmAnti, 181, check)
      call createCurrent(P_WQMinus, P_Hl, P_GQPlus, 1800, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghAAnti, P_AQ, 6225, check)
      call createCurrent(P_GMinus, P_HPlus, P_Hh, 1178, check)
      call createCurrent(P_ghWp, P_Ha, P_ghAAnti, P_GMinus, 10039, check)
      call createCurrent(P_AQ, P_d, P_dAnti, 7590, check)
      call createCurrent(P_ZQ, P_WPlus, P_GMinus, P_HlQ, 5871, check)
      call createCurrent(P_ZQ, P_Hl, P_HaQ, 7860, check)
      call createCurrent(P_HQPlus, P_ghZAnti, P_ghWm, 8441, check)
      call createCurrent(P_HQPlus, P_Hl, P_Ha, P_GQMinus, 4543, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_A, P_A, 5424, check)
      call createCurrent(P_HQPlus, P_GMinus, P_Hh, P_GQ0, 7846, check)
      call createCurrent(P_Ha, P_HPlus, P_GMinus, P_Ha, 3345, check)
      call createCurrent(P_ghA, P_HPlus, P_ghZAnti, P_HQMinus, 4897, check)
      call createCurrent(P_ghZ, P_WPlus, P_ghAAnti, P_WMinus, 8395, check)
      call createCurrent(P_ghWm, P_G0, P_HPlus, P_ghAAnti, 9245, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_HPlus, P_HQMinus, 4800, check)
      call createCurrent(P_HPlus, P_G0, P_Hh, P_GMinus, 7312, check)
      call createCurrent(P_HQMinus, P_ghZ, P_Ha, P_ghWmAnti, 6224, check)
      call createCurrent(P_GPlus, P_HMinus, P_Hl, P_Hh, 152, check)
      call createCurrent(P_ghZAnti, P_Hh, P_ghWm, P_HPlus, 8193, check)
      call createCurrent(P_WPlus, P_A, P_HMinus, P_Hh, 7957, check)
      call createCurrent(P_HhQ, P_Z, P_WPlus, P_GQMinus, 7278, check)
      call createCurrent(P_HaQ, P_Ha, P_GMinus, P_HQPlus, 7934, check)
      call createCurrent(P_Hh, P_HMinus, P_ghZ, P_ghWmAnti, 482, check)
      call createCurrent(P_Ha, P_Hl, P_Hl, P_Ha, 2363, check)
      call createCurrent(P_d, P_uAnti, P_HPlus, 5377, check)
      call createCurrent(P_HMinus, P_Z, P_HPlus, P_A, 2899, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_Hh, P_HPlus, 4928, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_ZQ, 1426, check)
      call createCurrent(P_WQMinus, P_GPlus, P_Hh, P_AQ, 3176, check)
      call createCurrent(P_A, P_Z, P_ghWm, P_ghWmAnti, 1267, check)
      call createCurrent(P_GPlus, P_HMinus, P_GMinus, P_HPlus, 8103, check)
      call createCurrent(P_HlQ, P_Hl, P_HMinus, P_HQPlus, 1218, check)
      call createCurrent(P_HlQ, P_ghWp, P_Hl, P_ghWpAnti, 5139, check)
      call createCurrent(P_Hl, P_ghWpAnti, P_GPlus, P_ghA, 939, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Hh, 5668, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_Hl, P_GPlus, 2793, check)
      call createCurrent(P_ZQ, P_WMinus, P_ghWp, P_ghAAnti, 6922, check)
      call createCurrent(P_HlQ, P_G0, P_GQ0, 6722, check)
      call createCurrent(P_Hl, P_ghWm, P_ghWmAnti, P_Hh, 10441, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_Z, P_ghZ, 2447, check)
      call createCurrent(P_Ha, P_GMinus, P_ghWp, P_ghZAnti, 10147, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghWm, P_WPlus, 4715, check)
      call createCurrent(P_G0, P_Ha, P_Hl, P_Hh, 8367, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_GQMinus, 828, check)
      call createCurrent(P_GPlus, P_Hh, P_HMinus, P_Hh, 1904, check)
      call createCurrent(P_ePlus, P_eMinus, P_Hh, 4408, check)
      call createCurrent(P_WQMinus, P_GPlus, P_G0, P_AQ, 5715, check)
      call createCurrent(P_ghWp, P_Ha, P_ghWpAnti, P_HaQ, 8779, check)
      call createCurrent(P_WQPlus, P_GMinus, P_G0, P_AQ, 2455, check)
      call createCurrent(P_Hl, P_ghWp, P_ghAAnti, P_HMinus, 7892, check)
      call createCurrent(P_WMinus, P_HMinus, P_HPlus, P_WPlus, 5466, check)
      call createCurrent(P_A, P_WMinus, P_Hl, P_GPlus, 4020, check)
      call createCurrent(P_Ha, P_HMinus, P_ghWp, P_ghZAnti, 2036, check)
      call createCurrent(P_ghWm, P_Z, P_ghZAnti, P_WPlus, 1246, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Hl, P_HlQ, 3269, check)
      call createCurrent(P_WQMinus, P_nu_mu, P_muPlus, 2581, check)
      call createCurrent(P_ghAAnti, P_ghZ, P_GMinus, P_GQPlus, 7416, check)
      call createCurrent(P_GPlus, P_GMinus, P_ghZAnti, P_ghA, 2269, check)
      call createCurrent(P_ghWp, P_HPlus, P_GMinus, P_ghWpAnti, 9511, check)
      call createCurrent(P_GPlus, P_Hh, P_Hl, P_HMinus, 2063, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_A, P_WMinus, 2639, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_GPlus, P_GMinus, 4466, check)
      call createCurrent(P_ghWm, P_Z, P_ghWmAnti, P_A, 604, check)
      call createCurrent(P_ghAAnti, P_HPlus, P_Ha, P_ghWm, 6732, check)
      call createCurrent(P_Z, P_HMinus, P_WPlus, 1650, check)
      call createCurrent(P_Hh, P_Ha, P_Hh, P_Ha, 1351, check)
      call createCurrent(P_WPlus, P_Hh, P_HMinus, P_A, 7669, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghAAnti, P_GQ0, 6649, check)
      call createCurrent(P_WQPlus, P_HMinus, P_Hh, P_AQ, 614, check)
      call createCurrent(P_GPlus, P_G0, P_HMinus, P_G0, 8580, check)
      call createCurrent(P_ghWpAnti, P_HPlus, P_HMinus, P_ghWp, 5684, check)
      call createCurrent(P_HMinus, P_Z, P_WPlus, P_Hl, 8763, check)
      call createCurrent(P_Z, P_ghWmAnti, P_ghWm, P_A, 3624, check)
      call createCurrent(P_ghZ, P_GPlus, P_Ha, P_ghWpAnti, 10207, check)
      call createCurrent(P_HPlus, P_ghZ, P_G0, P_ghWpAnti, 9769, check)
      call createCurrent(P_HPlus, P_ghZAnti, P_ghWm, P_Ha, 4606, check)
      call createCurrent(P_ghWm, P_HPlus, P_ghAAnti, P_Hl, 652, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_HMinus, P_HPlus, 8099, check)
      call createCurrent(P_GQ0, P_Ha, P_Ha, P_HaQ, 1060, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_WMinus, P_Z, 5552, check)
      call createCurrent(P_Ha, P_HMinus, P_Hh, P_HPlus, 9986, check)
      call createCurrent(P_HMinus, P_Hl, P_HPlus, P_Hl, 1702, check)
      call createCurrent(P_GQMinus, P_HPlus, P_GPlus, P_HQMinus, 3278, check)
      call createCurrent(P_HMinus, P_Hh, P_Hh, P_GPlus, 765, check)
      call createCurrent(P_HMinus, P_GPlus, P_G0, P_Hh, 1762, check)
      call createCurrent(P_GQPlus, P_WMinus, P_A, P_GQ0, 1634, check)
      call createCurrent(P_A, P_GMinus, P_Hh, P_WPlus, 7728, check)
      call createCurrent(P_ghWm, P_HPlus, P_ghZAnti, P_Hl, 1295, check)
      call createCurrent(P_G0, P_HPlus, P_Z, P_WMinus, 9307, check)
      call createCurrent(P_GQ0, P_GPlus, P_HMinus, P_HaQ, 7458, check)
      call createCurrent(P_Hl, P_ghWmAnti, P_GMinus, P_ghA, 3622, check)
      call createCurrent(P_G0, P_Ha, P_GPlus, P_HMinus, 7548, check)
      call createCurrent(P_HlQ, P_Ha, P_GPlus, P_GQMinus, 4488, check)
      call createCurrent(P_GMinus, P_A, P_Hh, P_WPlus, 3172, check)
      call createCurrent(P_G0, P_ghZ, P_ghWmAnti, P_HMinus, 9061, check)
      call createCurrent(P_GMinus, P_HPlus, P_Ha, 4913, check)
      call createCurrent(P_Hh, P_Hh, P_G0, P_G0, 6795, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_HQMinus, 6816, check)
      call createCurrent(P_HlQ, P_G0, P_GPlus, P_GQMinus, 1371, check)
      call createCurrent(P_Z, P_GPlus, P_Z, P_GMinus, 894, check)
      call createCurrent(P_Hl, P_ghWpAnti, P_ghWp, P_Hh, 10235, check)
      call createCurrent(P_ghWmAnti, P_Hh, P_ghWm, P_GQ0, 7050, check)
      call createCurrent(P_HhQ, P_WPlus, P_HMinus, P_ZQ, 5721, check)
      call createCurrent(P_Hl, P_HMinus, P_HPlus, P_Hh, 6407, check)
      call createCurrent(P_AQ, P_Z, P_GMinus, P_GQPlus, 2475, check)
      call createCurrent(P_WPlus, P_WMinus, P_WMinus, P_WPlus, 5575, check)
      call createCurrent(P_g, P_G0, P_g, P_Ha, 10595, check)
      call createCurrent(P_GMinus, P_ghA, P_HPlus, P_ghAAnti, 9341, check)
      call createCurrent(P_HMinus, P_Hl, P_GPlus, P_Ha, 2354, check)
      call createCurrent(P_GMinus, P_ghAAnti, P_Ha, P_ghWp, 10140, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_HMinus, P_Hh, 4704, check)
      call createCurrent(P_HlQ, P_GMinus, P_ghWp, P_ghZAnti, 2828, check)
      call createCurrent(P_HlQ, P_ghWm, P_HPlus, P_ghZAnti, 8380, check)
      call createCurrent(P_GQMinus, P_Hh, P_HQPlus, 4469, check)
      call createCurrent(P_G0, P_Z, P_WMinus, P_GPlus, 2439, check)
      call createCurrent(P_GQMinus, P_Hh, P_ghWmAnti, P_ghZ, 3801, check)
      call createCurrent(P_HhQ, P_G0, P_GPlus, P_GQMinus, 6429, check)
      call createCurrent(P_eMinus, P_Hl, P_ePlus, 6820, check)
      call createCurrent(P_Z, P_nu_tauAnti, P_nu_tau, 551, check)
      call createCurrent(P_HlQ, P_ghZAnti, P_GMinus, P_ghWp, 3190, check)
      call createCurrent(P_ghWmAnti, P_G0, P_ghZ, P_GMinus, 1478, check)
      call createCurrent(P_G0, P_HPlus, P_ghZAnti, P_ghWm, 9272, check)
      call createCurrent(P_ZQ, P_Z, P_HhQ, 2200, check)
      call createCurrent(P_HhQ, P_Hh, P_Hl, P_HlQ, 3536, check)
      call createCurrent(P_GQPlus, P_GMinus, P_Hh, P_HhQ, 3604, check)
      call createCurrent(P_HaQ, P_WPlus, P_HQMinus, 4326, check)
      call createCurrent(P_Ha, P_G0, P_ghWmAnti, P_ghWm, 10311, check)
      call createCurrent(P_GMinus, P_WPlus, P_WMinus, P_HPlus, 9290, check)
      call createCurrent(P_HQMinus, P_GPlus, P_Hl, P_GQ0, 5554, check)
      call createCurrent(P_HQMinus, P_GPlus, P_Hh, P_GQ0, 5366, check)
      call createCurrent(P_eMinus, P_GPlus, P_nu_eAnti, 4732, check)
      call createCurrent(P_GQPlus, P_d, P_uAnti, 2349, check)
      call createCurrent(P_Ha, P_tAnti, P_t, 5432, check)
      call createCurrent(P_HaQ, P_Hl, P_HPlus, P_HQMinus, 2827, check)
      call createCurrent(P_GMinus, P_Ha, P_ghWmAnti, P_ghA, 9518, check)
      call createCurrent(P_HaQ, P_A, P_WMinus, P_HQPlus, 6808, check)
      call createCurrent(P_GQ0, P_GPlus, P_WQMinus, 4906, check)
      call createCurrent(P_GMinus, P_ghA, P_GPlus, P_ghZAnti, 1556, check)
      call createCurrent(P_HPlus, P_ghZ, P_Hl, P_ghWpAnti, 8339, check)
      call createCurrent(P_tAnti, P_b, P_GQPlus, 8696, check)
      call createCurrent(P_uAnti, P_d, P_HPlus, 4591, check)
      call createCurrent(P_ghWpAnti, P_Hl, P_HPlus, P_ghZ, 3785, check)
      call createCurrent(P_ghWp, P_G0, P_ghWpAnti, P_G0, 1836, check)
      call createCurrent(P_HMinus, P_A, P_WPlus, P_Hl, 2564, check)
      call createCurrent(P_HMinus, P_GMinus, P_HPlus, P_GPlus, 4593, check)
      call createCurrent(P_HlQ, P_G0, P_GMinus, P_GQPlus, 684, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_HPlus, P_HlQ, 3081, check)
      call createCurrent(P_HhQ, P_GMinus, P_GPlus, P_HhQ, 8680, check)
      call createCurrent(P_dAnti, P_d, P_Hh, 1774, check)
      call createCurrent(P_Z, P_HPlus, P_Z, P_GMinus, 9661, check)
      call createCurrent(P_WQMinus, P_Hl, P_GPlus, P_AQ, 544, check)
      call createCurrent(P_GQMinus, P_ghA, P_ghWmAnti, 2194, check)
      call createCurrent(P_GMinus, P_ghAAnti, P_ghWp, P_G0, 2056, check)
      call createCurrent(P_Z, P_A, P_ghWpAnti, P_ghWp, 8605, check)
      call createCurrent(P_AQ, P_Z, P_GPlus, P_GQMinus, 5597, check)
      call createCurrent(P_ghWpAnti, P_A, P_ghWp, 2426, check)
      call createCurrent(P_Ha, P_GPlus, P_HMinus, 3390, check)
      call createCurrent(P_G0, P_GMinus, P_Z, P_WPlus, 7211, check)
      call createCurrent(P_uAnti, P_u, P_Hh, 5219, check)
      call createCurrent(P_HQMinus, P_WPlus, P_HlQ, 2604, check)
      call createCurrent(P_HPlus, P_HPlus, P_GMinus, P_GMinus, 1024, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_WMinus, P_A, 7643, check)
      call createCurrent(P_GQMinus, P_G0, P_ghWp, P_ghZAnti, 502, check)
      call createCurrent(P_G0, P_GMinus, P_Ha, P_GPlus, 6926, check)
      call createCurrent(P_WQPlus, P_b, P_tAnti, 7268, check)
      call createCurrent(P_ghAAnti, P_HPlus, P_ghWm, P_HhQ, 3945, check)
      call createCurrent(P_Hh, P_G0, P_Hh, P_G0, 7687, check)
      call createCurrent(P_G0, P_ghZAnti, P_HPlus, P_ghWm, 10237, check)
      call createCurrent(P_ZQ, P_Z, P_ghWm, P_ghWmAnti, 8655, check)
      call createCurrent(P_GPlus, P_GMinus, P_ghA, P_ghZAnti, 4738, check)
      call createCurrent(P_HQPlus, P_ghAAnti, P_HMinus, P_ghZ, 1277, check)
      call createCurrent(P_dAnti, P_d, P_HaQ, 7482, check)
      call createCurrent(P_HhQ, P_G0, P_HPlus, P_HQMinus, 1011, check)
      call createCurrent(P_HQMinus, P_ghZ, P_ghWmAnti, 307, check)
      call createCurrent(P_Hl, P_Hh, P_Z, P_Z, 8894, check)
      call createCurrent(P_ghWmAnti, P_Hh, P_ghA, P_HMinus, 3671, check)
      call createCurrent(P_Ha, P_WPlus, P_GMinus, 10113, check)
      call createCurrent(P_WPlus, P_GMinus, P_A, P_Hh, 7965, check)
      call createCurrent(P_ghA, P_WPlus, P_ghAAnti, P_WQMinus, 3614, check)
      call createCurrent(P_Hl, P_WMinus, P_HPlus, P_Z, 727, check)
      call createCurrent(P_HPlus, P_GMinus, P_A, 9608, check)
      call createCurrent(P_GPlus, P_Ha, P_Ha, P_GMinus, 739, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_HhQ, 6123, check)
      call createCurrent(P_tAnti, P_t, P_ZQ, 7113, check)
      call createCurrent(P_HhQ, P_tAnti, P_t, 964, check)
      call createCurrent(P_AQ, P_Z, P_HMinus, P_HQPlus, 3820, check)
      call createCurrent(P_ghZ, P_HPlus, P_ghAAnti, P_GMinus, 10194, check)
      call createCurrent(P_A, P_GPlus, P_A, P_HMinus, 9883, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_A, P_ghWp, 3466, check)
      call createCurrent(P_HQPlus, P_nu_tauAnti, P_tauMinus, 5146, check)
      call createCurrent(P_ghWpAnti, P_Hl, P_ghA, P_GPlus, 1585, check)
      call createCurrent(P_muMinus, P_muPlus, P_HaQ, 7025, check)
      call createCurrent(P_Hl, P_ghA, P_GPlus, P_ghWpAnti, 2658, check)
      call createCurrent(P_WQMinus, P_GPlus, P_Z, P_GQ0, 2871, check)
      call createCurrent(P_WPlus, P_GMinus, P_Hh, P_Z, 8558, check)
      call createCurrent(P_dAnti, P_d, P_A, 1608, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_G0, P_HMinus, 10317, check)
      call createCurrent(P_HhQ, P_HMinus, P_G0, P_GQPlus, 8583, check)
      call createCurrent(P_Hl, P_HPlus, P_ghWpAnti, P_ghA, 7038, check)
      call createCurrent(P_WMinus, P_HPlus, P_Ha, P_A, 2150, check)
      call createCurrent(P_Ha, P_ghZ, P_ghWmAnti, P_GMinus, 10320, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_Hl, P_HQMinus, 2029, check)
      call createCurrent(P_tauMinus, P_tauPlus, 9056, check)
      call createCurrent(P_ghZAnti, P_HPlus, P_G0, P_ghWm, 10403, check)
      call createCurrent(P_ghWm, P_HPlus, P_ghAAnti, P_HlQ, 496, check)
      call createCurrent(P_GQPlus, P_GMinus, P_GQ0, 5281, check)
      call createCurrent(P_G0, P_Hh, P_GMinus, P_HPlus, 8061, check)
      call createCurrent(P_GMinus, P_Ha, P_ghA, P_ghWmAnti, 9779, check)
      call createCurrent(P_GQPlus, P_GMinus, P_Hh, P_HlQ, 8320, check)
      call createCurrent(P_Hh, P_Hl, P_g, P_g, 10705, check)
      call createCurrent(P_ghA, P_WMinus, P_A, P_ghWmAnti, 1457, check)
      call createCurrent(P_G0, P_HPlus, P_Ha, P_HMinus, 8632, check)
      call createCurrent(P_g, P_b, P_bAnti, 180, check)
      call createCurrent(P_GPlus, P_Hl, P_ghZ, P_ghWpAnti, 5600, check)
      call createCurrent(P_Z, P_Hh, P_Hh, P_A, 9175, check)
      call createCurrent(P_ghZAnti, P_Hh, P_Hh, P_ghZ, 8603, check)
      call createCurrent(P_Hh, P_HPlus, P_G0, P_HMinus, 8886, check)
      call createCurrent(P_GQ0, P_GMinus, P_HPlus, P_GQ0, 8624, check)
      call createCurrent(P_AQ, P_tauPlus, P_tauMinus, 2627, check)
      call createCurrent(P_HMinus, P_WPlus, P_Hl, 4841, check)
      call createCurrent(P_Hh, P_HMinus, P_HPlus, P_Hl, 5785, check)
      call createCurrent(P_HlQ, P_WMinus, P_Z, P_GQPlus, 3312, check)
      call createCurrent(P_WQMinus, P_Z, P_GQPlus, 1572, check)
      call createCurrent(P_ghA, P_ghAAnti, P_HMinus, P_GPlus, 9730, check)
      call createCurrent(P_HhQ, P_G0, P_ghWp, P_ghWpAnti, 371, check)
      call createCurrent(P_GPlus, P_WMinus, P_A, P_G0, 2509, check)
      call createCurrent(P_Ha, P_GMinus, P_GPlus, P_Hl, 8855, check)
      call createCurrent(P_WPlus, P_ghA, P_A, P_ghWpAnti, 2618, check)
      call createCurrent(P_GMinus, P_HPlus, P_ghWm, P_ghWmAnti, 9790, check)
      call createCurrent(P_g, P_Hh, P_g, P_Hh, 10497, check)
      call createCurrent(P_ghWp, P_Hh, P_Hl, P_ghWpAnti, 9234, check)
      call createCurrent(P_b, P_HPlus, P_tAnti, 4248, check)
      call createCurrent(P_HPlus, P_HMinus, P_Ha, P_G0, 6261, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_GMinus, P_GPlus, 2709, check)
      call createCurrent(P_HlQ, P_Ha, P_Hl, P_HaQ, 1833, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_A, P_Z, 8296, check)
      call createCurrent(P_ghWpAnti, P_G0, P_ghWp, P_G0, 5148, check)
      call createCurrent(P_GQPlus, P_GMinus, P_WPlus, P_WQMinus, 7916, check)
      call createCurrent(P_ghZ, P_ghAAnti, P_HPlus, P_GMinus, 9478, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghWp, P_GMinus, 7677, check)
      call createCurrent(P_Ha, P_ghZ, P_GPlus, P_ghWpAnti, 9437, check)
      call createCurrent(P_G0, P_GPlus, P_GMinus, P_Hl, 9030, check)
      call createCurrent(P_HaQ, P_Ha, P_HMinus, P_HQPlus, 5116, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_HPlus, P_G0, 9182, check)
      call createCurrent(P_ghZ, P_Hh, P_Hl, P_ghZAnti, 8851, check)
      call createCurrent(P_ghA, P_ghAAnti, P_WMinus, P_WPlus, 1126, check)
      call createCurrent(P_HQPlus, P_Hl, P_HMinus, P_GQ0, 6915, check)
      call createCurrent(P_GQMinus, P_Z, P_WPlus, P_HhQ, 7159, check)
      call createCurrent(P_WPlus, P_ghZAnti, P_ghWm, P_Z, 3526, check)
      call createCurrent(P_ghZ, P_HPlus, P_ghWpAnti, 5425, check)
      call createCurrent(P_ghZAnti, P_Hl, P_ghWm, P_HPlus, 2869, check)
      call createCurrent(P_Ha, P_WMinus, P_GPlus, 9279, check)
      call createCurrent(P_WQMinus, P_WMinus, P_ghWp, P_ghWmAnti, 1097, check)
      call createCurrent(P_A, P_HPlus, P_WMinus, 4778, check)
      call createCurrent(P_Hh, P_GPlus, P_ghZAnti, P_ghWm, 8372, check)
      call createCurrent(P_HMinus, P_ghWp, P_ghAAnti, 924, check)
      call createCurrent(P_HlQ, P_GPlus, P_ghWm, P_ghZAnti, 3974, check)
      call createCurrent(P_A, P_Hl, P_A, P_Hh, 10558, check)
      call createCurrent(P_HlQ, P_Hh, P_HlQ, 2290, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_Hh, P_HQMinus, 3042, check)
      call createCurrent(P_ghAAnti, P_HMinus, P_GPlus, P_ghZ, 9944, check)
      call createCurrent(P_HhQ, P_WMinus, P_HQPlus, 7896, check)
      call createCurrent(P_GQ0, P_GPlus, P_Hl, P_HQMinus, 4420, check)
      call createCurrent(P_AQ, P_u, P_uAnti, 2257, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_ghWp, P_Hl, 4914, check)
      call createCurrent(P_GMinus, P_GPlus, P_Hl, P_Hh, 2907, check)
      call createCurrent(P_Hh, P_WMinus, P_HPlus, P_A, 6129, check)
      call createCurrent(P_HQPlus, P_Hh, P_HMinus, P_HaQ, 4939, check)
      call createCurrent(P_Hl, P_GPlus, P_GMinus, P_G0, 8907, check)
      call createCurrent(P_Z, P_g, P_g, P_g, 10511, check)
      call createCurrent(P_GPlus, P_Hl, P_G0, P_HMinus, 8427, check)
      call createCurrent(P_Hl, P_A, P_HPlus, P_WMinus, 1870, check)
      call createCurrent(P_Z, P_Hl, P_WPlus, P_GMinus, 8401, check)
      call createCurrent(P_HlQ, P_WMinus, P_GQPlus, 532, check)
      call createCurrent(P_ZQ, P_HMinus, P_A, P_HQPlus, 5576, check)
      call createCurrent(P_WPlus, P_A, P_WMinus, 8657, check)
      call createCurrent(P_uAnti, P_u, P_Ha, 8012, check)
      call createCurrent(P_G0, P_Hl, P_Ha, P_Hl, 1969, check)
      call createCurrent(P_ghWmAnti, P_Hl, P_HMinus, P_ghZ, 3265, check)
      call createCurrent(P_GMinus, P_WPlus, P_A, P_G0, 5422, check)
      call createCurrent(P_HlQ, P_WMinus, P_A, P_GQPlus, 2882, check)
      call createCurrent(P_Z, P_WPlus, P_ghWm, P_ghZAnti, 3500, check)
      call createCurrent(P_G0, P_WPlus, P_Ha, P_WMinus, 8895, check)
      call createCurrent(P_GPlus, P_GMinus, P_g, P_g, 10531, check)
      call createCurrent(P_GPlus, P_ghAAnti, P_ghWm, P_Ha, 9701, check)
      call createCurrent(P_GPlus, P_Hl, P_Hl, P_HMinus, 7787, check)
      call createCurrent(P_G0, P_GPlus, P_Hl, P_HMinus, 4987, check)
      call createCurrent(P_GMinus, P_Ha, P_Ha, P_HPlus, 8092, check)
      call createCurrent(P_A, P_ghWp, P_WMinus, P_ghAAnti, 7358, check)
      call createCurrent(P_WPlus, P_GMinus, P_Hl, 61, check)
      call createCurrent(P_HhQ, P_G0, P_HMinus, P_GQPlus, 6695, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_WMinus, P_AQ, 8213, check)
      call createCurrent(P_GMinus, P_GPlus, P_Z, 7952, check)
      call createCurrent(P_HlQ, P_GMinus, P_HPlus, P_HlQ, 2972, check)
      call createCurrent(P_ZQ, P_ghWp, P_ghWpAnti, 5459, check)
      call createCurrent(P_HQMinus, P_WPlus, P_Ha, P_AQ, 4074, check)
      call createCurrent(P_ghZAnti, P_Ha, P_HPlus, P_ghWm, 5788, check)
      call createCurrent(P_GPlus, P_G0, P_WMinus, P_Z, 5865, check)
      call createCurrent(P_ghZAnti, P_Hl, P_ghZ, P_Hl, 3664, check)
      call createCurrent(P_Hh, P_GMinus, P_GPlus, P_Hh, 3276, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_WPlus, 7978, check)
      call createCurrent(P_Ha, P_Hh, P_G0, P_Hh, 8091, check)
      call createCurrent(P_GMinus, P_HPlus, P_WMinus, P_WPlus, 9741, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghZAnti, P_Hl, 4935, check)
      call createCurrent(P_ghWm, P_HMinus, P_ghWmAnti, P_HQPlus, 8499, check)
      call createCurrent(P_Hh, P_Hh, P_A, P_A, 10651, check)
      call createCurrent(P_Hh, P_HPlus, P_HMinus, P_Ha, 10406, check)
      call createCurrent(P_GQ0, P_WPlus, P_GMinus, P_ZQ, 1850, check)
      call createCurrent(P_HMinus, P_ghZAnti, P_ghWp, P_Hl, 1122, check)
      call createCurrent(P_g, P_g, P_g, P_Z, 10684, check)
      call createCurrent(P_WMinus, P_Hh, P_WPlus, P_Hh, 4804, check)
      call createCurrent(P_A, P_G0, P_G0, P_A, 10715, check)
      call createCurrent(P_bAnti, P_WMinus, P_t, 6594, check)
      call createCurrent(P_s, P_sAnti, P_HaQ, 838, check)
      call createCurrent(P_HhQ, P_ghWmAnti, P_HMinus, P_ghZ, 5560, check)
      call createCurrent(P_Ha, P_bAnti, P_b, 3521, check)
      call createCurrent(P_Ha, P_ghWpAnti, P_ghZ, P_GPlus, 9694, check)
      call createCurrent(P_muPlus, P_GMinus, P_nu_mu, 1128, check)
      call createCurrent(P_HhQ, P_Ha, P_Hl, P_HaQ, 4999, check)
      call createCurrent(P_HQMinus, P_Hh, P_ghA, P_ghWmAnti, 2526, check)
      call createCurrent(P_Z, P_A, P_Ha, P_Ha, 9492, check)
      call createCurrent(P_HQMinus, P_Z, P_Z, P_HQPlus, 1504, check)
      call createCurrent(P_Z, P_WMinus, P_HPlus, 7721, check)
      call createCurrent(P_ghZAnti, P_HPlus, P_ghWm, P_G0, 9053, check)
      call createCurrent(P_A, P_HMinus, P_Hl, P_WPlus, 3921, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_A, P_WPlus, 7346, check)
      call createCurrent(P_ghWmAnti, P_Hl, P_Hh, P_ghWm, 9087, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_G0, 2759, check)
      call createCurrent(P_ghA, P_WMinus, P_ghZAnti, P_WQPlus, 1062, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_HMinus, P_HPlus, 6282, check)
      call createCurrent(P_ghA, P_HPlus, P_ghAAnti, P_GMinus, 9208, check)
      call createCurrent(P_ghZAnti, P_HMinus, P_Ha, P_ghWp, 253, check)
      call createCurrent(P_HaQ, P_Hh, P_HaQ, 5115, check)
      call createCurrent(P_G0, P_Z, P_Hl, 386, check)
      call createCurrent(P_ghWmAnti, P_HMinus, P_ghWm, P_HPlus, 2694, check)
      call createCurrent(P_HPlus, P_WMinus, P_Ha, P_A, 5072, check)
      call createCurrent(P_HPlus, P_WMinus, P_Hl, P_Z, 7783, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_Ha, P_HMinus, 8738, check)
      call createCurrent(P_Z, P_HPlus, P_WMinus, 795, check)
      call createCurrent(P_HaQ, P_HPlus, P_ghWpAnti, P_ghZ, 3074, check)
      call createCurrent(P_ZQ, P_Hl, P_GQ0, 5075, check)
      call createCurrent(P_HPlus, P_Hl, P_WMinus, P_A, 1773, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_Z, P_ghWm, 758, check)
      call createCurrent(P_ghA, P_G0, P_ghWmAnti, P_GQMinus, 7181, check)
      call createCurrent(P_Ha, P_G0, P_A, P_Z, 10657, check)
      call createCurrent(P_ghAAnti, P_Hh, P_ghWp, P_GMinus, 6272, check)
      call createCurrent(P_G0, P_WPlus, P_HMinus, 9371, check)
      call createCurrent(P_Hl, P_HPlus, P_ghA, P_ghWpAnti, 3414, check)
      call createCurrent(P_Ha, P_GPlus, P_Hl, P_HMinus, 3510, check)
      call createCurrent(P_WPlus, P_A, P_G0, P_GMinus, 8471, check)
      call createCurrent(P_Z, P_Z, 10219, check)
      call createCurrent(P_Hh, P_GPlus, P_GMinus, P_Hh, 2038, check)
      call createCurrent(P_HQMinus, P_ghZ, P_Hl, P_ghWmAnti, 2958, check)
      call createCurrent(P_ghAAnti, P_HMinus, P_HPlus, P_ghA, 5645, check)
      call createCurrent(P_HaQ, P_HMinus, P_Ha, P_GQPlus, 1355, check)
      call createCurrent(P_GPlus, P_GMinus, P_ghA, P_ghAAnti, 4471, check)
      call createCurrent(P_HPlus, P_HMinus, P_WMinus, P_WPlus, 8183, check)
      call createCurrent(P_WMinus, P_WPlus, P_A, P_A, 867, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_HPlus, P_HlQ, 3135, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_HaQ, 10, check)
      call createCurrent(P_Hh, P_ghWmAnti, P_Hl, P_ghWm, 9752, check)
      call createCurrent(P_ePlus, P_nu_e, P_GMinus, 4447, check)
      call createCurrent(P_HlQ, P_Ha, P_ghWpAnti, P_ghWp, 7597, check)
      call createCurrent(P_WQMinus, P_GPlus, P_G0, P_ZQ, 1682, check)
      call createCurrent(P_HlQ, P_WPlus, P_Ha, P_WQMinus, 4585, check)
      call createCurrent(P_HhQ, P_GPlus, P_HMinus, P_HaQ, 5448, check)
      call createCurrent(P_HPlus, P_A, P_WMinus, P_Ha, 6719, check)
      call createCurrent(P_Hl, P_ghA, P_HPlus, P_ghWpAnti, 3742, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_HPlus, P_G0, 9329, check)
      call createCurrent(P_Z, P_A, P_Hl, P_Hh, 10667, check)
      call createCurrent(P_HlQ, P_G0, P_ghWm, P_ghWmAnti, 1439, check)
      call createCurrent(P_HMinus, P_Ha, P_ghWp, P_ghZAnti, 7487, check)
      call createCurrent(P_ghWpAnti, P_Z, P_ghWp, P_AQ, 8174, check)
      call createCurrent(P_Hh, P_GMinus, P_HPlus, P_G0, 3809, check)
      call createCurrent(P_Hl, P_ghZAnti, P_GMinus, P_ghWp, 2644, check)
      call createCurrent(P_HQPlus, P_Hl, P_WMinus, P_ZQ, 4411, check)
      call createCurrent(P_GQMinus, P_Hh, P_GPlus, P_HhQ, 1782, check)
      call createCurrent(P_A, P_WMinus, P_Ha, P_GPlus, 10286, check)
      call createCurrent(P_HhQ, P_WMinus, P_Z, P_HQPlus, 7694, check)
      call createCurrent(P_GQ0, P_ghWp, P_GMinus, P_ghAAnti, 1392, check)
      call createCurrent(P_G0, P_GPlus, P_Hl, P_GMinus, 10091, check)
      call createCurrent(P_HQPlus, P_ghWpAnti, P_ghZ, 3731, check)
      call createCurrent(P_HPlus, P_ghWpAnti, P_GMinus, P_ghWp, 9355, check)
      call createCurrent(P_A, P_WPlus, P_Hh, P_GMinus, 81, check)
      call createCurrent(P_WPlus, P_Z, P_ghZ, P_ghWpAnti, 1919, check)
      call createCurrent(P_ghZ, P_ghAAnti, P_GPlus, P_GMinus, 2215, check)
      call createCurrent(P_Hh, P_Hl, P_ghWmAnti, P_ghWm, 10431, check)
      call createCurrent(P_ZQ, P_WPlus, P_HMinus, P_HlQ, 4308, check)
      call createCurrent(P_nu_tauAnti, P_GPlus, P_tauMinus, 3952, check)
      call createCurrent(P_ghWp, P_HMinus, P_ghWpAnti, P_HPlus, 335, check)
      call createCurrent(P_ghWpAnti, P_HPlus, P_ghZ, P_HaQ, 8668, check)
      call createCurrent(P_G0, P_HPlus, P_ghA, P_ghWpAnti, 9720, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_HPlus, P_HhQ, 5207, check)
      call createCurrent(P_WQPlus, P_GMinus, P_GPlus, P_WQMinus, 197, check)
      call createCurrent(P_WMinus, P_A, P_WPlus, P_A, 3288, check)
      call createCurrent(P_HMinus, P_Ha, P_GPlus, P_Ha, 6479, check)
      call createCurrent(P_HPlus, P_Hh, P_ghA, P_ghWpAnti, 2066, check)
      call createCurrent(P_WMinus, P_GPlus, P_Z, P_Ha, 9610, check)
      call createCurrent(P_HhQ, P_GPlus, P_GMinus, P_HhQ, 5134, check)
      call createCurrent(P_HhQ, P_Ha, P_GPlus, P_HQMinus, 7805, check)
      call createCurrent(P_HMinus, P_G0, P_G0, P_GPlus, 8669, check)
      call createCurrent(P_Hh, P_Hh, P_ghWp, P_ghWpAnti, 5858, check)
      call createCurrent(P_HhQ, P_Hl, P_HlQ, 6492, check)
      call createCurrent(P_Ha, P_WMinus, P_WPlus, P_Ha, 8777, check)
      call createCurrent(P_GQMinus, P_G0, P_GPlus, P_HlQ, 8368, check)
      call createCurrent(P_Ha, P_ghAAnti, P_ghWm, P_GPlus, 10047, check)
      call createCurrent(P_muMinus, P_nu_muAnti, P_GPlus, 3342, check)
      call createCurrent(P_GQMinus, P_GPlus, P_G0, P_HhQ, 2297, check)
      call createCurrent(P_WPlus, P_ghAAnti, P_WMinus, P_ghZ, 105, check)
      call createCurrent(P_WPlus, P_GMinus, P_G0, P_Z, 2102, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_HMinus, P_Hl, 8762, check)
      call createCurrent(P_t, P_tAnti, P_A, 4812, check)
      call createCurrent(P_bAnti, P_b, P_HaQ, 7074, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghZAnti, P_HhQ, 1657, check)
      call createCurrent(P_WMinus, P_WPlus, P_ghAAnti, P_ghA, 4264, check)
      call createCurrent(P_G0, P_G0, P_G0, P_Ha, 6201, check)
      call createCurrent(P_WPlus, P_Hl, P_A, P_HMinus, 3360, check)
      call createCurrent(P_WMinus, P_Z, P_GPlus, P_G0, 776, check)
      call createCurrent(P_Ha, P_A, P_G0, P_Z, 10534, check)
      call createCurrent(P_HQMinus, P_WPlus, P_Hl, P_ZQ, 1135, check)
      call createCurrent(P_ghWm, P_Hl, P_ghWmAnti, P_Hh, 9490, check)
      call createCurrent(P_Z, P_G0, P_G0, P_A, 9630, check)
      call createCurrent(P_HMinus, P_HPlus, P_Ha, P_Hl, 10393, check)
      call createCurrent(P_WQMinus, P_Z, P_Z, P_WQPlus, 5874, check)
      call createCurrent(P_A, P_ghWp, P_WMinus, P_ghZAnti, 4767, check)
      call createCurrent(P_WMinus, P_ghWp, P_ghZAnti, P_Z, 7968, check)
      call createCurrent(P_HlQ, P_HPlus, P_Hl, P_HQMinus, 3916, check)
      call createCurrent(P_GQ0, P_WPlus, P_GQMinus, 4485, check)
      call createCurrent(P_GQ0, P_GMinus, P_ghWp, P_ghZAnti, 642, check)
      call createCurrent(P_G0, P_ghWm, P_ghZAnti, P_GPlus, 3424, check)
      call createCurrent(P_ghA, P_GMinus, P_ghAAnti, P_HPlus, 10303, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_Z, P_ghZ, 1532, check)
      call createCurrent(P_WPlus, P_A, P_A, P_WMinus, 8828, check)
      call createCurrent(P_Hl, P_A, P_WMinus, P_GPlus, 5747, check)
      call createCurrent(P_HQMinus, P_A, P_A, P_HQPlus, 1336, check)
      call createCurrent(P_HlQ, P_WMinus, P_G0, P_WQPlus, 3877, check)
      call createCurrent(P_GMinus, P_HPlus, P_ghZAnti, P_ghA, 9555, check)
      call createCurrent(P_GQ0, P_Hh, P_Hh, P_GQ0, 716, check)
      call createCurrent(P_ghWm, P_G0, P_ghWmAnti, P_G0, 2717, check)
      call createCurrent(P_Z, P_Hl, P_WMinus, P_GPlus, 1368, check)
      call createCurrent(P_tauMinus, P_HPlus, P_nu_tauAnti, 5579, check)
      call createCurrent(P_HPlus, P_Ha, P_G0, P_HMinus, 8369, check)
      call createCurrent(P_HQMinus, P_A, P_HPlus, P_AQ, 638, check)
      call createCurrent(P_HQPlus, P_uAnti, P_d, 5399, check)
      call createCurrent(P_HlQ, P_G0, P_ghWmAnti, P_ghWm, 2979, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_HPlus, P_Hh, 4814, check)
      call createCurrent(P_HQMinus, P_G0, P_HPlus, P_HaQ, 7158, check)
      call createCurrent(P_WMinus, P_nu_mu, P_muPlus, 5406, check)
      call createCurrent(P_AQ, P_GMinus, P_Hl, P_WQPlus, 4023, check)
      call createCurrent(P_WMinus, P_Z, P_HPlus, P_Hh, 7143, check)
      call createCurrent(P_AQ, P_WPlus, P_ghZAnti, P_ghWm, 6135, check)
      call createCurrent(P_WPlus, P_Z, P_G0, P_GMinus, 208, check)
      call createCurrent(P_GQPlus, P_A, P_WMinus, P_GQ0, 5934, check)
      call createCurrent(P_G0, P_u, P_uAnti, 6541, check)
      call createCurrent(P_HQMinus, P_HPlus, P_G0, P_HlQ, 8308, check)
      call createCurrent(P_WPlus, P_GMinus, P_A, 6991, check)
      call createCurrent(P_g, P_g, P_Hh, P_Hl, 10552, check)
      call createCurrent(P_GQ0, P_GMinus, P_Hl, P_HQPlus, 4317, check)
      call createCurrent(P_G0, P_WMinus, P_A, P_GPlus, 1811, check)
      call createCurrent(P_HPlus, P_ghZ, P_ghWpAnti, P_Hl, 389, check)
      call createCurrent(P_HPlus, P_muMinus, P_nu_muAnti, 2273, check)
      call createCurrent(P_u, P_dAnti, P_WMinus, 645, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_Ha, P_HPlus, 2157, check)
      call createCurrent(P_Hl, P_g, P_g, 10624, check)
      call createCurrent(P_HMinus, P_WPlus, P_A, P_Hh, 5730, check)
      call createCurrent(P_WMinus, P_Z, P_ghZAnti, P_ghWp, 8125, check)
      call createCurrent(P_ghZ, P_HMinus, P_Hl, P_ghWmAnti, 7752, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_Z, P_WPlus, 6864, check)
      call createCurrent(P_HhQ, P_tauPlus, P_tauMinus, 7294, check)
      call createCurrent(P_ghWp, P_ghWmAnti, P_WMinus, P_WQMinus, 2696, check)
      call createCurrent(P_HQMinus, P_HPlus, P_Ha, P_GQ0, 5441, check)
      call createCurrent(P_Hl, P_A, P_A, 10710, check)
      call createCurrent(P_Hh, P_u, P_uAnti, 6645, check)
      call createCurrent(P_Z, P_Z, P_g, P_g, 10734, check)
      call createCurrent(P_WQPlus, P_A, P_ghZ, P_ghWpAnti, 4334, check)
      call createCurrent(P_GPlus, P_Hh, P_ghZAnti, P_ghWm, 404, check)
      call createCurrent(P_HMinus, P_GPlus, P_Hh, P_Hl, 5932, check)
      call createCurrent(P_WQPlus, P_WMinus, P_ghAAnti, P_ghA, 484, check)
      call createCurrent(P_ZQ, P_Hh, P_GMinus, P_WQPlus, 7318, check)
      call createCurrent(P_G0, P_WMinus, P_Z, P_GPlus, 7022, check)
      call createCurrent(P_HlQ, P_GMinus, P_Hh, P_GQPlus, 2183, check)
      call createCurrent(P_GQMinus, P_Hh, P_Ha, P_HQPlus, 4138, check)
      call createCurrent(P_Hl, P_Hh, P_ghZAnti, P_ghZ, 9994, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_Ha, P_HMinus, 2539, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_Hh, P_GQPlus, 5735, check)
      call createCurrent(P_Ha, P_ghWmAnti, P_ghWm, P_G0, 9394, check)
      call createCurrent(P_HMinus, P_Hh, P_HPlus, 819, check)
      call createCurrent(P_ZQ, P_WPlus, P_ghZAnti, P_ghWm, 7021, check)
      call createCurrent(P_sAnti, P_c, P_HMinus, 6837, check)
      call createCurrent(P_GMinus, P_HPlus, P_g, P_g, 10602, check)
      call createCurrent(P_ghAAnti, P_HMinus, P_ghWp, P_HlQ, 5226, check)
      call createCurrent(P_HMinus, P_ghZ, P_Hh, P_ghWmAnti, 6470, check)
      call createCurrent(P_GPlus, P_Hh, P_ghA, P_ghWpAnti, 1684, check)
      call createCurrent(P_Z, P_ghA, P_WPlus, P_ghWpAnti, 7020, check)
      call createCurrent(P_GQ0, P_ghAAnti, P_GPlus, P_ghWm, 1771, check)
      call createCurrent(P_tauPlus, P_Hl, P_tauMinus, 2128, check)
      call createCurrent(P_HPlus, P_ghWm, P_G0, P_ghAAnti, 10451, check)
      call createCurrent(P_GQMinus, P_Ha, P_HQPlus, 1081, check)
      call createCurrent(P_WPlus, P_ghWm, P_ghWmAnti, P_WMinus, 729, check)
      call createCurrent(P_GPlus, P_A, P_GMinus, P_Z, 8486, check)
      call createCurrent(P_GPlus, P_WMinus, P_Hh, P_A, 8003, check)
      call createCurrent(P_WMinus, P_WPlus, P_GPlus, P_HMinus, 10051, check)
      call createCurrent(P_ghZ, P_Hl, P_Hl, P_ghZAnti, 8709, check)
      call createCurrent(P_cAnti, P_A, P_c, 26, check)
      call createCurrent(P_WPlus, P_G0, P_GMinus, P_Z, 3430, check)
      call createCurrent(P_Hl, P_A, P_A, P_Hl, 10522, check)
      call createCurrent(P_AQ, P_ghWp, P_Z, P_ghWpAnti, 7339, check)
      call createCurrent(P_AQ, P_WPlus, P_G0, P_GQMinus, 8260, check)
      call createCurrent(P_GQPlus, P_Hh, P_GMinus, P_GQ0, 1110, check)
      call createCurrent(P_HMinus, P_ghWp, P_G0, P_ghZAnti, 10133, check)
      call createCurrent(P_ghWm, P_HPlus, P_ghZAnti, P_HhQ, 5247, check)
      call createCurrent(P_ghA, P_ghZAnti, P_HPlus, P_HMinus, 3711, check)
      call createCurrent(P_A, P_WPlus, P_ghWpAnti, P_ghZ, 48, check)
      call createCurrent(P_WQMinus, P_Hh, P_HPlus, P_AQ, 6973, check)
      call createCurrent(P_muMinus, P_muPlus, 8852, check)
      call createCurrent(P_G0, P_Hl, P_GMinus, P_GPlus, 10458, check)
      call createCurrent(P_HPlus, P_s, P_cAnti, 63, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghZAnti, P_ZQ, 869, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_WMinus, P_ghWp, 5198, check)
      call createCurrent(P_bAnti, P_b, P_G0, 4160, check)
      call createCurrent(P_WQPlus, P_WMinus, P_Hh, P_HaQ, 6818, check)
      call createCurrent(P_HQPlus, P_G0, P_Ha, P_HQMinus, 735, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Hl, P_GQ0, 6353, check)
      call createCurrent(P_GMinus, P_GPlus, P_GMinus, P_HPlus, 2648, check)
      call createCurrent(P_Hl, P_ghWp, P_ghAAnti, P_GMinus, 4143, check)
      call createCurrent(P_GPlus, P_GMinus, P_Hh, P_Hl, 4310, check)
      call createCurrent(P_WPlus, P_nu_muAnti, P_muMinus, 6384, check)
      call createCurrent(P_HQMinus, P_Hh, P_HQPlus, 1681, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_ghWp, P_Z, 968, check)
      call createCurrent(P_Hh, P_WPlus, P_A, P_GMinus, 7285, check)
      call createCurrent(P_WMinus, P_c, P_sAnti, 777, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_Ha, P_GPlus, 9137, check)
      call createCurrent(P_GMinus, P_Hl, P_A, P_WPlus, 1437, check)
      call createCurrent(P_HaQ, P_Hh, P_HMinus, P_GQPlus, 7574, check)
      call createCurrent(P_HaQ, P_HMinus, P_HQPlus, 1056, check)
      call createCurrent(P_GQMinus, P_Hl, P_G0, P_HQPlus, 6676, check)
      call createCurrent(P_Hl, P_G0, P_Hl, P_Ha, 3166, check)
      call createCurrent(P_Hh, P_ghZAnti, P_HMinus, P_ghWp, 1214, check)
      call createCurrent(P_Hl, P_ghAAnti, P_HPlus, P_ghWm, 8199, check)
      call createCurrent(P_Hl, P_WPlus, P_Hl, P_WMinus, 1477, check)
      call createCurrent(P_G0, P_WMinus, P_HPlus, 9347, check)
      call createCurrent(P_s, P_sAnti, P_Hh, 5203, check)
      call createCurrent(P_GMinus, P_Z, P_HPlus, P_Z, 9410, check)
      call createCurrent(P_HPlus, P_Z, P_Hl, P_WMinus, 7071, check)
      call createCurrent(P_HMinus, P_Hh, P_ghWp, P_ghZAnti, 8554, check)
      call createCurrent(P_GQMinus, P_Hl, P_WPlus, P_AQ, 6396, check)
      call createCurrent(P_ghWpAnti, P_HMinus, P_GPlus, P_ghWp, 9891, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_A, 7791, check)
      call createCurrent(P_Hl, P_Hh, P_ghWpAnti, P_ghWp, 9788, check)
      call createCurrent(P_GQ0, P_WPlus, P_Hl, P_WQMinus, 6486, check)
      call createCurrent(P_A, P_Hh, P_Hh, P_A, 10759, check)
      call createCurrent(P_Hh, P_ghWm, P_ghWmAnti, P_Hl, 9299, check)
      call createCurrent(P_ghWpAnti, P_Hh, P_ghA, P_GQPlus, 8058, check)
      call createCurrent(P_Hh, P_ghZ, P_ghWmAnti, P_HMinus, 5907, check)
      call createCurrent(P_HQMinus, P_GPlus, P_Hh, P_HaQ, 3257, check)
      call createCurrent(P_WMinus, P_GPlus, P_A, 5023, check)
      call createCurrent(P_Ha, P_ghWpAnti, P_HPlus, P_ghA, 7917, check)
      call createCurrent(P_ZQ, P_Hh, P_WPlus, P_HQMinus, 2401, check)
      call createCurrent(P_HMinus, P_GMinus, P_HPlus, P_HPlus, 5807, check)
      call createCurrent(P_GMinus, P_GPlus, P_Ha, P_Ha, 3959, check)
      call createCurrent(P_HPlus, P_ghAAnti, P_ghWm, P_Hh, 3765, check)
      call createCurrent(P_WPlus, P_A, P_WMinus, P_A, 4558, check)
      call createCurrent(P_A, P_Z, P_Z, P_Z, 10687, check)
      call createCurrent(P_WQPlus, P_Z, P_G0, P_GQMinus, 374, check)
      call createCurrent(P_uAnti, P_d, P_GQPlus, 5760, check)
      call createCurrent(P_Z, P_Hl, P_HMinus, P_WPlus, 1069, check)
      call createCurrent(P_A, P_ghZAnti, P_WPlus, P_ghWm, 8830, check)
      call createCurrent(P_HhQ, P_Hh, P_WMinus, P_WQPlus, 4086, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_HMinus, P_HaQ, 3676, check)
      call createCurrent(P_Hh, P_HPlus, P_HMinus, P_G0, 10212, check)
      call createCurrent(P_ghWmAnti, P_Hh, P_ghWm, P_Hl, 9589, check)
      call createCurrent(P_GMinus, P_HPlus, P_ghA, P_ghAAnti, 9309, check)
      call createCurrent(P_HQPlus, P_Hl, P_Hh, P_GQMinus, 5022, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_HhQ, 8063, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_Ha, P_HQPlus, 1176, check)
      call createCurrent(P_HQMinus, P_HPlus, P_Hh, P_HhQ, 5289, check)
      call createCurrent(P_G0, P_GMinus, P_Ha, P_HPlus, 6220, check)
      call createCurrent(P_HPlus, P_HMinus, P_Hl, P_Hh, 1566, check)
      call createCurrent(P_u, P_uAnti, P_AQ, 4030, check)
      call createCurrent(P_Ha, P_ghWm, P_ghZAnti, P_GPlus, 9261, check)
      call createCurrent(P_HMinus, P_Ha, P_G0, P_GPlus, 4204, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_G0, P_GQPlus, 2458, check)
      call createCurrent(P_Z, P_WMinus, P_ghA, P_ghWmAnti, 7768, check)
      call createCurrent(P_HPlus, P_ghAAnti, P_ghA, P_HMinus, 409, check)
      call createCurrent(P_Hh, P_G0, P_G0, P_Hl, 4018, check)
      call createCurrent(P_Hl, P_HMinus, P_ghZ, P_ghWmAnti, 7220, check)
      call createCurrent(P_nu_eAnti, P_nu_e, 9141, check)
      call createCurrent(P_GQ0, P_Ha, P_GPlus, P_GQMinus, 6986, check)
      call createCurrent(P_A, P_GMinus, P_GPlus, P_A, 1211, check)
      call createCurrent(P_GQ0, P_Hh, P_HPlus, P_GQMinus, 7822, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghZ, 4128, check)
      call createCurrent(P_GPlus, P_ghAAnti, P_GMinus, P_ghZ, 6779, check)
      call createCurrent(P_Hh, P_G0, P_GPlus, P_HMinus, 1837, check)
      call createCurrent(P_G0, P_ghAAnti, P_HPlus, P_ghWm, 10013, check)
      call createCurrent(P_Z, P_HPlus, P_A, P_GMinus, 9623, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Hl, P_HlQ, 1562, check)
      call createCurrent(P_GQ0, P_GMinus, P_ghAAnti, P_ghWp, 4233, check)
      call createCurrent(P_Ha, P_Z, P_HMinus, P_WPlus, 8089, check)
      call createCurrent(P_ghZAnti, P_HMinus, P_ghWp, 6900, check)
      call createCurrent(P_ghA, P_Hh, P_ghWmAnti, P_HMinus, 4614, check)
      call createCurrent(P_HhQ, P_Hl, P_G0, P_GQ0, 1794, check)
      call createCurrent(P_HMinus, P_G0, P_WPlus, P_A, 10188, check)
      call createCurrent(P_Hh, P_ghZ, P_ghWmAnti, P_GMinus, 6521, check)
      call createCurrent(P_Hh, P_HMinus, P_G0, P_GPlus, 2394, check)
      call createCurrent(P_GPlus, P_HMinus, P_G0, P_Hh, 3883, check)
      call createCurrent(P_HlQ, P_dAnti, P_d, 7434, check)
      call createCurrent(P_GMinus, P_Z, P_Hl, P_WPlus, 1323, check)
      call createCurrent(P_ZQ, P_Hh, P_HMinus, P_WQPlus, 1312, check)
      call createCurrent(P_HMinus, P_GPlus, P_Hl, P_Hl, 3975, check)
      call createCurrent(P_GQMinus, P_ghZ, P_ghWmAnti, 523, check)
      call createCurrent(P_HMinus, P_GPlus, P_GPlus, P_GMinus, 349, check)
      call createCurrent(P_GPlus, P_WMinus, P_WPlus, P_GMinus, 8831, check)
      call createCurrent(P_HQPlus, P_ghZAnti, P_Ha, P_ghWm, 2486, check)
      call createCurrent(P_tauMinus, P_nu_tauAnti, P_HQPlus, 2403, check)
      call createCurrent(P_ghZAnti, P_HPlus, P_HMinus, P_ghA, 885, check)
      call createCurrent(P_HhQ, P_WMinus, P_GQPlus, 1826, check)
      call createCurrent(P_GQPlus, P_Ha, P_HMinus, P_HlQ, 4680, check)
      call createCurrent(P_Ha, P_GMinus, P_HPlus, P_G0, 679, check)
      call createCurrent(P_GQ0, P_G0, P_HlQ, 123, check)
      call createCurrent(P_ZQ, P_nu_e, P_nu_eAnti, 8411, check)
      call createCurrent(P_ghZAnti, P_HPlus, P_ghA, P_HQMinus, 299, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_Hl, P_GQMinus, 8128, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_Hl, P_ghA, 577, check)
      call createCurrent(P_GPlus, P_Hl, P_Hh, P_HMinus, 3597, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_Z, P_WPlus, 6686, check)
      call createCurrent(P_HQMinus, P_HPlus, P_Hh, P_HaQ, 7307, check)
      call createCurrent(P_GQ0, P_GPlus, P_HMinus, P_HhQ, 2347, check)
      call createCurrent(P_HPlus, P_G0, P_HMinus, P_G0, 1130, check)
      call createCurrent(P_ghWm, P_HMinus, P_HPlus, P_ghWmAnti, 8694, check)
      call createCurrent(P_Ha, P_ghWm, P_ghAAnti, P_GPlus, 9729, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_Ha, P_HQPlus, 8737, check)
      call createCurrent(P_G0, P_Ha, P_ghZ, P_ghZAnti, 9760, check)
      call createCurrent(P_ZQ, P_WMinus, P_Hl, P_GQPlus, 2228, check)
      call createCurrent(P_WPlus, P_GMinus, P_HPlus, P_WMinus, 10103, check)
      call createCurrent(P_b, P_tAnti, P_HPlus, 6997, check)
      call createCurrent(P_c, P_sAnti, P_HMinus, 1819, check)
      call createCurrent(P_GQPlus, P_G0, P_WMinus, P_ZQ, 5273, check)
      call createCurrent(P_WMinus, P_A, P_A, P_WPlus, 8647, check)
      call createCurrent(P_G0, P_Hl, P_G0, P_Hh, 3103, check)
      call createCurrent(P_G0, P_GMinus, P_G0, P_HPlus, 8019, check)
      call createCurrent(P_WPlus, P_WMinus, P_ghAAnti, P_ghZ, 1827, check)
      call createCurrent(P_nu_eAnti, P_eMinus, P_HQPlus, 3970, check)
      call createCurrent(P_HlQ, P_HMinus, P_Z, P_WQPlus, 8502, check)
      call createCurrent(P_GQMinus, P_Hh, P_HPlus, P_HlQ, 140, check)
      call createCurrent(P_A, P_Hl, P_A, 10635, check)
      call createCurrent(P_ghWp, P_Hl, P_Hh, P_ghWpAnti, 9128, check)
      call createCurrent(P_ZQ, P_WPlus, P_HQMinus, 5083, check)
      call createCurrent(P_HhQ, P_GPlus, P_Hl, P_GQMinus, 7301, check)
      call createCurrent(P_Hh, P_Z, P_G0, 4417, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_HlQ, 7616, check)
      call createCurrent(P_Z, P_GPlus, P_WMinus, P_Hl, 8217, check)
      call createCurrent(P_tauPlus, P_tauMinus, 10253, check)
      call createCurrent(P_Z, P_ghZ, P_WMinus, P_ghWmAnti, 5497, check)
      call createCurrent(P_WQMinus, P_Z, P_ghWmAnti, P_ghZ, 4653, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_ghWm, P_AQ, 7727, check)
      call createCurrent(P_G0, P_Hl, P_HPlus, P_GMinus, 60, check)
      call createCurrent(P_HhQ, P_Hh, P_ghWpAnti, P_ghWp, 5641, check)
      call createCurrent(P_Ha, P_ghZAnti, P_Ha, P_ghZ, 376, check)
      call createCurrent(P_G0, P_HMinus, P_HPlus, P_Hl, 9713, check)
      call createCurrent(P_WPlus, P_GPlus, P_WMinus, P_HMinus, 9093, check)
      call createCurrent(P_ghWmAnti, P_Z, P_ghA, P_WMinus, 6662, check)
      call createCurrent(P_ghWp, P_G0, P_G0, P_ghWpAnti, 4069, check)
      call createCurrent(P_ghWmAnti, P_Z, P_ghWm, P_ZQ, 1428, check)
      call createCurrent(P_HQPlus, P_Hl, P_ghWpAnti, P_ghZ, 5029, check)
      call createCurrent(P_Ha, P_WPlus, P_G0, P_WMinus, 9076, check)
      call createCurrent(P_HPlus, P_A, P_Hl, P_WMinus, 4754, check)
      call createCurrent(P_Z, P_HMinus, P_GPlus, P_A, 9423, check)
      call createCurrent(P_GQPlus, P_GPlus, P_HMinus, P_GQMinus, 7569, check)
      call createCurrent(P_GMinus, P_HPlus, P_ghZ, P_ghZAnti, 10226, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_Hh, P_Hl, 9180, check)
      call createCurrent(P_dAnti, P_d, P_GQ0, 580, check)
      call createCurrent(P_GQPlus, P_HMinus, P_Hh, P_GQ0, 4185, check)
      call createCurrent(P_t, P_tAnti, P_HaQ, 5808, check)
      call createCurrent(P_HlQ, P_GMinus, P_Hl, P_HQPlus, 1648, check)
      call createCurrent(P_Hh, P_WMinus, P_WPlus, P_Hh, 7878, check)
      call createCurrent(P_Z, P_WPlus, P_WMinus, 3474, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_WPlus, P_Z, 2103, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_HPlus, P_HMinus, 1787, check)
      call createCurrent(P_ghA, P_ghZAnti, P_HMinus, P_HPlus, 7631, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_WMinus, P_A, 2957, check)
      call createCurrent(P_ghAAnti, P_HMinus, P_HPlus, P_ghZ, 616, check)
      call createCurrent(P_WQMinus, P_WPlus, P_Z, P_AQ, 7871, check)
      call createCurrent(P_WPlus, P_uAnti, P_d, 5268, check)
      call createCurrent(P_GQMinus, P_HPlus, P_HPlus, P_HQMinus, 8086, check)
      call createCurrent(P_HQPlus, P_Ha, P_HMinus, P_GQ0, 5879, check)
      call createCurrent(P_ghWm, P_Hl, P_ghWmAnti, P_HlQ, 8771, check)
      call createCurrent(P_HQMinus, P_Hh, P_Z, P_WQPlus, 6140, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_GPlus, P_Hl, 5884, check)
      call createCurrent(P_WQPlus, P_Hl, P_Z, P_HQMinus, 4743, check)
      call createCurrent(P_GPlus, P_ghZ, P_Ha, P_ghWpAnti, 9949, check)
      call createCurrent(P_Hh, P_GPlus, P_HMinus, P_Hh, 8529, check)
      call createCurrent(P_ghWmAnti, P_GPlus, P_ghWm, P_GMinus, 572, check)
      call createCurrent(P_ghWm, P_Hh, P_ghAAnti, P_HPlus, 3382, check)
      call createCurrent(P_WQPlus, P_GMinus, P_Z, P_GQ0, 8745, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_A, 6657, check)
      call createCurrent(P_GQMinus, P_Hl, P_Ha, P_HQPlus, 7223, check)
      call createCurrent(P_G0, P_HMinus, P_A, P_WPlus, 9458, check)
      call createCurrent(P_uAnti, P_A, P_u, 5766, check)
      call createCurrent(P_G0, P_ghWp, P_ghZAnti, P_HMinus, 9477, check)
      call createCurrent(P_GQ0, P_GPlus, P_ghWm, P_ghAAnti, 6858, check)
      call createCurrent(P_ghA, P_ghZAnti, P_GPlus, P_GMinus, 6370, check)
      call createCurrent(P_Ha, P_ghZ, P_ghZAnti, P_Ha, 5179, check)
      call createCurrent(P_WPlus, P_Ha, P_HMinus, P_A, 5517, check)
      call createCurrent(P_ghWmAnti, P_Hh, P_ghZ, P_HQMinus, 5847, check)
      call createCurrent(P_HPlus, P_G0, P_WMinus, 9844, check)
      call createCurrent(P_ghWmAnti, P_HMinus, P_ghWm, P_HQPlus, 7837, check)
      call createCurrent(P_HMinus, P_GPlus, P_g, P_g, 10713, check)
      call createCurrent(P_HMinus, P_A, P_GPlus, P_A, 9920, check)
      call createCurrent(P_WQMinus, P_ghWmAnti, P_ghA, 7815, check)
      call createCurrent(P_Ha, P_GMinus, P_ghWp, P_ghAAnti, 10452, check)
      call createCurrent(P_A, P_nu_eAnti, P_nu_e, 9979, check)
      call createCurrent(P_HQPlus, P_GMinus, P_G0, P_HaQ, 8072, check)
      call createCurrent(P_G0, P_ghZAnti, P_ghWp, P_HMinus, 10329, check)
      call createCurrent(P_GQPlus, P_ghZ, P_GMinus, P_ghAAnti, 3551, check)
      call createCurrent(P_GQ0, P_HMinus, P_Hh, P_HQPlus, 7766, check)
      call createCurrent(P_Hh, P_ghZAnti, P_ghWm, P_GPlus, 5263, check)
      call createCurrent(P_HMinus, P_Z, P_Z, P_HPlus, 4339, check)
      call createCurrent(P_HMinus, P_Hh, P_A, P_WPlus, 6767, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Z, 2695, check)
      call createCurrent(P_nu_eAnti, P_Z, P_nu_e, 5482, check)
      call createCurrent(P_HaQ, P_Ha, P_G0, P_GQ0, 5373, check)
      call createCurrent(P_AQ, P_Hl, P_HPlus, P_WQMinus, 7411, check)
      call createCurrent(P_HMinus, P_GPlus, P_ghWmAnti, P_ghWm, 10362, check)
      call createCurrent(P_ghA, P_HMinus, P_Hh, P_ghWmAnti, 1587, check)
      call createCurrent(P_Ha, P_Hl, P_GMinus, P_GPlus, 9166, check)
      call createCurrent(P_HaQ, P_ghWpAnti, P_HPlus, P_ghZ, 4301, check)
      call createCurrent(P_WPlus, P_Ha, P_WMinus, P_Ha, 5347, check)
      call createCurrent(P_HMinus, P_Hh, P_GPlus, 2355, check)
      call createCurrent(P_WQPlus, P_A, P_GMinus, P_GQ0, 8230, check)
      call createCurrent(P_Ha, P_c, P_cAnti, 5065, check)
      call createCurrent(P_Hl, P_GMinus, P_GPlus, P_Ha, 9326, check)
      call createCurrent(P_Hl, P_Hh, P_GPlus, P_GMinus, 8381, check)
      call createCurrent(P_ZQ, P_HMinus, P_HPlus, P_AQ, 505, check)
      call createCurrent(P_WQPlus, P_Hh, P_GQMinus, 4652, check)
      call createCurrent(P_HlQ, P_A, P_WPlus, P_GQMinus, 3165, check)
      call createCurrent(P_GQMinus, P_GPlus, P_HPlus, P_HQMinus, 5561, check)
      call createCurrent(P_GQPlus, P_GMinus, P_AQ, 6157, check)
      call createCurrent(P_WQMinus, P_GMinus, P_WPlus, P_GQPlus, 6231, check)
      call createCurrent(P_Hh, P_ghWp, P_Hl, P_ghWpAnti, 10391, check)
      call createCurrent(P_ZQ, P_WMinus, P_WPlus, P_ZQ, 1948, check)
      call createCurrent(P_GMinus, P_ghAAnti, P_HPlus, P_ghA, 10328, check)
      call createCurrent(P_G0, P_b, P_bAnti, 458, check)
      call createCurrent(P_Hh, P_GPlus, P_Ha, P_GMinus, 9775, check)
      call createCurrent(P_HPlus, P_Ha, P_Hl, P_GMinus, 8100, check)
      call createCurrent(P_HMinus, P_GMinus, P_GPlus, P_HPlus, 6333, check)
      call createCurrent(P_Z, P_ghWm, P_A, P_ghWmAnti, 4014, check)
      call createCurrent(P_HaQ, P_HMinus, P_Hh, P_GQPlus, 5170, check)
      call createCurrent(P_HQPlus, P_GMinus, P_Ha, P_GQ0, 1329, check)
      call createCurrent(P_ghA, P_ghAAnti, P_WPlus, P_WMinus, 850, check)
      call createCurrent(P_Hh, P_ghWmAnti, P_ghWm, P_Hl, 9591, check)
      call createCurrent(P_AQ, P_GMinus, P_G0, P_WQPlus, 4562, check)
      call createCurrent(P_Hl, P_HMinus, P_WPlus, P_Z, 3032, check)
      call createCurrent(P_GMinus, P_WPlus, P_Ha, 10387, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghWmAnti, P_HMinus, 10348, check)
      call createCurrent(P_WQPlus, P_HMinus, P_HlQ, 4671, check)
      call createCurrent(P_ghZ, P_Ha, P_ghWpAnti, P_HPlus, 3464, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_HMinus, P_HPlus, 7276, check)
      call createCurrent(P_uAnti, P_Ha, P_u, 6518, check)
      call createCurrent(P_WQPlus, P_Z, P_HQMinus, 6661, check)
      call createCurrent(P_ghAAnti, P_HPlus, P_ghWm, 5771, check)
      call createCurrent(P_WQPlus, P_WMinus, P_WPlus, P_WQMinus, 102, check)
      call createCurrent(P_ghWm, P_G0, P_Ha, P_ghWmAnti, 9535, check)
      call createCurrent(P_Ha, P_A, P_GPlus, P_WMinus, 8973, check)
      call createCurrent(P_HQPlus, P_WMinus, P_Hl, P_AQ, 2995, check)
      call createCurrent(P_HPlus, P_WMinus, P_Hh, P_Z, 7520, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_Ha, P_GMinus, 8898, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_Ha, P_HPlus, 5704, check)
      call createCurrent(P_GQPlus, P_G0, P_ghZ, P_ghWpAnti, 1202, check)
      call createCurrent(P_HMinus, P_GPlus, P_ghZAnti, P_ghA, 9530, check)
      call createCurrent(P_Hh, P_Ha, P_G0, P_Hl, 5003, check)
      call createCurrent(P_ghZ, P_WMinus, P_ghAAnti, P_WQPlus, 6564, check)
      call createCurrent(P_GPlus, P_Ha, P_Ha, P_HMinus, 4267, check)
      call createCurrent(P_GPlus, P_ghAAnti, P_Ha, P_ghWm, 10018, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghZ, P_Z, 278, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_G0, P_Ha, 9495, check)
      call createCurrent(P_ghZ, P_Z, P_ghWmAnti, P_WQMinus, 6349, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_Hl, P_ghWp, 8551, check)
      call createCurrent(P_tAnti, P_WPlus, P_b, 6709, check)
      call createCurrent(P_Ha, P_HPlus, P_ghZAnti, P_ghWm, 1111, check)
      call createCurrent(P_HhQ, P_HPlus, P_Hh, P_GQMinus, 7084, check)
      call createCurrent(P_GQ0, P_Z, P_WMinus, P_GQPlus, 1337, check)
      call createCurrent(P_WPlus, P_Z, P_HMinus, P_G0, 9587, check)
      call createCurrent(P_uAnti, P_WPlus, P_d, 6772, check)
      call createCurrent(P_GMinus, P_Ha, P_WPlus, P_Z, 10443, check)
      call createCurrent(P_Hh, P_Hh, P_Hh, P_Ha, 10540, check)
      call createCurrent(P_ghZ, P_ghAAnti, P_HPlus, P_HQMinus, 3157, check)
      call createCurrent(P_muMinus, P_muPlus, P_ZQ, 1959, check)
      call createCurrent(P_Z, P_HMinus, P_WPlus, P_Hh, 7602, check)
      call createCurrent(P_s, P_sAnti, P_gQ, 8670, check)
      call createCurrent(P_G0, P_ghWmAnti, P_ghWm, P_Ha, 9449, check)
      call createCurrent(P_g, P_Hl, P_g, P_Hh, 10562, check)
      call createCurrent(P_Hh, P_WPlus, P_HMinus, 7345, check)
      call createCurrent(P_ghWpAnti, P_Hl, P_ghWp, P_HlQ, 8542, check)
      call createCurrent(P_ghZ, P_Hl, P_HPlus, P_ghWpAnti, 6904, check)
      call createCurrent(P_HhQ, P_G0, P_ghWpAnti, P_ghWp, 2906, check)
      call createCurrent(P_GMinus, P_HPlus, P_Z, P_A, 10313, check)
      call createCurrent(P_GPlus, P_ghA, P_Ha, P_ghWpAnti, 9784, check)
      call createCurrent(P_Ha, P_ePlus, P_eMinus, 5518, check)
      call createCurrent(P_HMinus, P_sAnti, P_c, 6930, check)
      call createCurrent(P_GQPlus, P_HMinus, P_G0, P_HaQ, 7864, check)
      call createCurrent(P_Hl, P_ghZ, P_ghWpAnti, P_HPlus, 5809, check)
      call createCurrent(P_Hl, P_WPlus, P_WMinus, 6892, check)
      call createCurrent(P_WQMinus, P_Z, P_G0, P_GQPlus, 4366, check)
      call createCurrent(P_AQ, P_G0, P_GPlus, P_WQMinus, 3677, check)
      call createCurrent(P_ghZ, P_Ha, P_GMinus, P_ghWmAnti, 9144, check)
      call createCurrent(P_GMinus, P_g, P_HPlus, P_g, 10607, check)
      call createCurrent(P_HPlus, P_ghZ, P_ghWpAnti, 4288, check)
      call createCurrent(P_GMinus, P_ghWp, P_ghAAnti, P_Ha, 9868, check)
      call createCurrent(P_HaQ, P_HPlus, P_HQMinus, 6703, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_Hh, P_GMinus, 2596, check)
      call createCurrent(P_HMinus, P_Z, P_Hh, P_WPlus, 8722, check)
      call createCurrent(P_GPlus, P_d, P_uAnti, 1098, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghWp, P_HMinus, 10055, check)
      call createCurrent(P_AQ, P_HMinus, P_Hl, P_WQPlus, 3694, check)
      call createCurrent(P_HMinus, P_HPlus, P_ghWpAnti, P_ghWp, 648, check)
      call createCurrent(P_HaQ, P_Hl, P_G0, P_HlQ, 3722, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_WPlus, P_ZQ, 39, check)
      call createCurrent(P_ghZAnti, P_Hh, P_HPlus, P_ghWm, 2293, check)
      call createCurrent(P_ghZ, P_HMinus, P_G0, P_ghWmAnti, 10066, check)
      call createCurrent(P_Ha, P_A, P_Z, P_Ha, 9660, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Hl, P_HlQ, 5852, check)
      call createCurrent(P_Ha, P_A, P_G0, P_A, 10504, check)
      call createCurrent(P_HQMinus, P_WPlus, P_Hh, P_AQ, 4329, check)
      call createCurrent(P_GPlus, P_ghZ, P_ghAAnti, P_GMinus, 7706, check)
      call createCurrent(P_AQ, P_GPlus, P_Z, P_GQMinus, 2565, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_GPlus, P_GQ0, 2628, check)
      call createCurrent(P_ghWmAnti, P_HPlus, P_HMinus, P_ghWm, 8247, check)
      call createCurrent(P_Hh, P_HPlus, P_A, P_WMinus, 4, check)
      call createCurrent(P_GQ0, P_muMinus, P_muPlus, 6731, check)
      call createCurrent(P_WMinus, P_ghA, P_ghZAnti, P_WPlus, 1563, check)
      call createCurrent(P_WPlus, P_Hl, P_GMinus, 1187, check)
      call createCurrent(P_G0, P_GPlus, P_WMinus, 8175, check)
      call createCurrent(P_ghWpAnti, P_Hl, P_ghWp, P_GQ0, 1137, check)
      call createCurrent(P_Hl, P_G0, P_GPlus, P_GMinus, 9472, check)
      call createCurrent(P_ghZAnti, P_ghA, P_WPlus, P_WQMinus, 5370, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_WMinus, P_WPlus, 6211, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_Hh, P_ghA, 2767, check)
      call createCurrent(P_GQ0, P_HMinus, P_GPlus, P_HhQ, 3248, check)
      call createCurrent(P_WPlus, P_HMinus, P_Ha, 7776, check)
      call createCurrent(P_WQPlus, P_Hl, P_Z, P_GQMinus, 7326, check)
      call createCurrent(P_Z, P_d, P_dAnti, 4399, check)
      call createCurrent(P_GMinus, P_Hl, P_ghA, P_ghWmAnti, 5426, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_WQMinus, 5818, check)
      call createCurrent(P_HPlus, P_WMinus, P_A, P_Hl, 4903, check)
      call createCurrent(P_HPlus, P_d, P_uAnti, 4352, check)
      call createCurrent(P_GPlus, P_GMinus, P_Ha, P_Hh, 10158, check)
      call createCurrent(P_G0, P_Ha, P_Z, P_Z, 9453, check)
      call createCurrent(P_A, P_WMinus, P_ghZ, P_ghWmAnti, 7252, check)
      call createCurrent(P_AQ, P_ghWpAnti, P_Z, P_ghWp, 6835, check)
      call createCurrent(P_WQPlus, P_WMinus, P_A, P_AQ, 4719, check)
      call createCurrent(P_HaQ, P_GMinus, P_GQPlus, 2611, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_GMinus, P_G0, 832, check)
      call createCurrent(P_WPlus, P_ghWm, P_ghZAnti, P_Z, 1796, check)
      call createCurrent(P_GQ0, P_Hh, P_GPlus, P_HQMinus, 6630, check)
      call createCurrent(P_ghWpAnti, P_A, P_ghA, P_WQPlus, 3144, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_A, 6664, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_WPlus, P_A, 8197, check)
      call createCurrent(P_Z, P_ghWpAnti, P_Z, P_ghWp, 6522, check)
      call createCurrent(P_GMinus, P_WPlus, P_Hh, 1421, check)
      call createCurrent(P_HQPlus, P_Ha, P_Hh, P_GQMinus, 4080, check)
      call createCurrent(P_Hl, P_WPlus, P_A, P_GMinus, 6995, check)
      call createCurrent(P_GPlus, P_HMinus, P_Hh, P_G0, 778, check)
      call createCurrent(P_cAnti, P_s, P_WPlus, 8275, check)
      call createCurrent(P_GQPlus, P_ghA, P_GMinus, P_ghAAnti, 148, check)
      call createCurrent(P_GQ0, P_Z, P_Z, P_GQ0, 4230, check)
      call createCurrent(P_HlQ, P_Hl, P_G0, P_HaQ, 7256, check)
      call createCurrent(P_HMinus, P_ghWmAnti, P_G0, P_ghA, 10265, check)
      call createCurrent(P_ghWp, P_GPlus, P_ghWpAnti, P_GMinus, 195, check)
      call createCurrent(P_HMinus, P_WMinus, P_WPlus, P_HPlus, 6974, check)
      call createCurrent(P_ghWmAnti, P_G0, P_G0, P_ghWm, 1931, check)
      call createCurrent(P_GQPlus, P_Ha, P_GMinus, P_HhQ, 1658, check)
      call createCurrent(P_AQ, P_WMinus, P_ghWp, P_ghZAnti, 7018, check)
      call createCurrent(P_WQPlus, P_Z, P_Hh, P_HQMinus, 8382, check)
      call createCurrent(P_A, P_nu_tau, P_nu_tauAnti, 9706, check)
      call createCurrent(P_Hl, P_GPlus, P_HMinus, P_Hh, 3787, check)
      call createCurrent(P_GMinus, P_WPlus, P_Z, P_Ha, 9318, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_Hh, 4165, check)
      call createCurrent(P_HhQ, P_ghWm, P_ghWmAnti, 5550, check)
      call createCurrent(P_ghWpAnti, P_A, P_ghZ, P_WQPlus, 6468, check)
      call createCurrent(P_tauPlus, P_nu_tau, P_WQMinus, 6227, check)
      call createCurrent(P_GMinus, P_WPlus, 9126, check)
      call createCurrent(P_Ha, P_G0, P_GMinus, P_HPlus, 2464, check)
      call createCurrent(P_ZQ, P_ghAAnti, P_WPlus, P_ghWm, 3370, check)
      call createCurrent(P_A, P_t, P_tAnti, 8187, check)
      call createCurrent(P_HMinus, P_Ha, P_WPlus, P_Z, 3567, check)
      call createCurrent(P_b, P_G0, P_bAnti, 4665, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_G0, P_ghWm, 8112, check)
      call createCurrent(P_GMinus, P_ghAAnti, P_ghZ, P_HPlus, 10384, check)
      call createCurrent(P_A, P_HMinus, P_Z, P_GPlus, 9112, check)
      call createCurrent(P_Hh, P_Z, P_GMinus, P_WPlus, 3630, check)
      call createCurrent(P_Hl, P_WMinus, P_GPlus, 3529, check)
      call createCurrent(P_Hl, P_Z, P_A, P_Hh, 10757, check)
      call createCurrent(P_GQMinus, P_Ha, P_GPlus, P_HaQ, 2742, check)
      call createCurrent(P_Hl, P_WMinus, P_WPlus, P_Hl, 1832, check)
      call createCurrent(P_GMinus, P_A, P_Z, P_HPlus, 10129, check)
      call createCurrent(P_G0, P_WPlus, P_HMinus, P_A, 9919, check)
      call createCurrent(P_G0, P_Hh, P_G0, P_Hh, 6872, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_HMinus, P_HlQ, 5105, check)
      call createCurrent(P_Ha, P_t, P_tAnti, 1516, check)
      call createCurrent(P_AQ, P_ghWm, P_WPlus, P_ghAAnti, 3391, check)
      call createCurrent(P_HMinus, P_ghA, P_G0, P_ghWmAnti, 9419, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_WPlus, P_Z, 5168, check)
      call createCurrent(P_GQPlus, P_HMinus, P_HMinus, P_HQPlus, 4927, check)
      call createCurrent(P_HMinus, P_ghZAnti, P_Hl, P_ghWp, 3657, check)
      call createCurrent(P_ghA, P_ghAAnti, P_HPlus, P_HMinus, 6160, check)
      call createCurrent(P_HlQ, P_Ha, P_Ha, P_HhQ, 2425, check)
      call createCurrent(P_tAnti, P_t, P_g, 8375, check)
      call createCurrent(P_ghWm, P_Hl, P_HPlus, P_ghAAnti, 3770, check)
      call createCurrent(P_Hh, P_ghZAnti, P_HPlus, P_ghWm, 6114, check)
      call createCurrent(P_Hl, P_GPlus, P_GMinus, P_Hl, 5357, check)
      call createCurrent(P_G0, P_Ha, P_HMinus, P_GPlus, 3131, check)
      call createCurrent(P_GPlus, P_ghZ, P_ghWpAnti, 2555, check)
      call createCurrent(P_GPlus, P_Ha, P_GMinus, P_G0, 6216, check)
      call createCurrent(P_GMinus, P_ghWp, P_ghAAnti, P_G0, 4212, check)
      call createCurrent(P_HPlus, P_GMinus, P_WPlus, P_WMinus, 9909, check)
      call createCurrent(P_nu_e, P_ePlus, P_WQMinus, 1306, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Ha, P_HhQ, 7079, check)
      call createCurrent(P_HPlus, P_ghA, P_GMinus, P_ghAAnti, 10468, check)
      call createCurrent(P_HQMinus, P_WPlus, P_ZQ, 8601, check)
      call createCurrent(P_ghWmAnti, P_Hl, P_ghA, P_HQMinus, 4929, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_G0, P_HPlus, 9810, check)
      call createCurrent(P_GMinus, P_WPlus, P_GPlus, P_WMinus, 7188, check)
      call createCurrent(P_eMinus, P_ePlus, P_G0, 3033, check)
      call createCurrent(P_WPlus, P_GMinus, P_A, P_G0, 6507, check)
      call createCurrent(P_s, P_sAnti, P_HlQ, 3347, check)
      call createCurrent(P_A, P_GPlus, P_A, P_GMinus, 6458, check)
      call createCurrent(P_GPlus, P_WMinus, P_G0, 6215, check)
      call createCurrent(P_HQMinus, P_Hh, P_WPlus, P_ZQ, 8107, check)
      call createCurrent(P_tAnti, P_b, P_WQPlus, 8004, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_Ha, P_GPlus, 9305, check)
      call createCurrent(P_ghZAnti, P_Hl, P_Hl, P_ghZ, 2429, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_GPlus, P_HMinus, 9903, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_Hl, P_GQPlus, 7836, check)
      call createCurrent(P_HaQ, P_Hh, P_Hh, P_HaQ, 4445, check)
      call createCurrent(P_ZQ, P_dAnti, P_d, 7309, check)
      call createCurrent(P_HPlus, P_GMinus, P_ghWp, P_ghWpAnti, 9168, check)
      call createCurrent(P_WQPlus, P_WMinus, P_ghZ, P_ghAAnti, 2305, check)
      call createCurrent(P_Hh, P_GPlus, P_ghAAnti, P_ghWm, 4048, check)
      call createCurrent(P_AQ, P_GPlus, P_GQMinus, 1983, check)
      call createCurrent(P_WPlus, P_HMinus, P_Ha, P_A, 1014, check)
      call createCurrent(P_Ha, P_Ha, P_GPlus, P_GMinus, 779, check)
      call createCurrent(P_HPlus, P_HPlus, P_HMinus, P_GMinus, 6138, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_HPlus, P_HMinus, 812, check)
      call createCurrent(P_HhQ, P_bAnti, P_b, 3315, check)
      call createCurrent(P_GQ0, P_GPlus, P_ghWm, P_ghZAnti, 1871, check)
      call createCurrent(P_ghWmAnti, P_HMinus, P_G0, P_ghA, 10246, check)
      call createCurrent(P_g, P_Hl, P_Hh, P_g, 10567, check)
      call createCurrent(P_GPlus, P_ghWp, P_GMinus, P_ghWpAnti, 1700, check)
      call createCurrent(P_GPlus, P_ghA, P_ghWpAnti, P_Hh, 2477, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_ghWm, P_G0, 563, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Hl, P_HlQ, 7607, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_WMinus, P_ghA, 1538, check)
      call createCurrent(P_GPlus, P_A, P_Z, P_HMinus, 10448, check)
      call createCurrent(P_GMinus, P_GPlus, P_Ha, 9651, check)
      call createCurrent(P_WPlus, P_ghZ, P_A, P_ghWpAnti, 2529, check)
      call createCurrent(P_Z, P_WMinus, P_GPlus, 6111, check)
      call createCurrent(P_HlQ, P_Ha, P_HPlus, P_HQMinus, 430, check)
      call createCurrent(P_nu_tauAnti, P_tauMinus, P_HQPlus, 8548, check)
      call createCurrent(P_ghWpAnti, P_WMinus, P_ghWp, P_WPlus, 5283, check)
      call createCurrent(P_t, P_tAnti, P_ZQ, 763, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_A, P_WQMinus, 8823, check)
      call createCurrent(P_Z, P_WMinus, P_ghWp, P_ghZAnti, 2816, check)
      call createCurrent(P_HlQ, P_c, P_cAnti, 6442, check)
      call createCurrent(P_tauPlus, P_Hh, P_tauMinus, 1534, check)
      call createCurrent(P_sAnti, P_s, P_HhQ, 5258, check)
      call createCurrent(P_GQMinus, P_GPlus, P_ghAAnti, P_ghZ, 2165, check)
      call createCurrent(P_WQMinus, P_c, P_sAnti, 6354, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_GPlus, P_GMinus, 5082, check)
      call createCurrent(P_WPlus, P_WMinus, P_GMinus, P_GPlus, 1885, check)
      call createCurrent(P_A, P_WPlus, P_Z, P_WMinus, 5701, check)
      call createCurrent(P_G0, P_GMinus, P_Hl, P_HPlus, 346, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Hl, 7667, check)
      call createCurrent(P_ghGAnti, P_g, P_g, P_ghG, 4984, check)
      call createCurrent(P_HMinus, P_HPlus, P_Ha, P_Ha, 1231, check)
      call createCurrent(P_A, P_g, P_g, P_Z, 10749, check)
      call createCurrent(P_ghZAnti, P_HPlus, P_ghA, P_HMinus, 2471, check)
      call createCurrent(P_WPlus, P_GMinus, P_Hl, P_Z, 2806, check)
      call createCurrent(P_HQMinus, P_ghZ, P_HPlus, P_ghAAnti, 2139, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghZAnti, P_A, 4782, check)
      call createCurrent(P_Hl, P_tauMinus, P_tauPlus, 4589, check)
      call createCurrent(P_A, P_WMinus, P_ghAAnti, P_ghWp, 7695, check)
      call createCurrent(P_Hh, P_b, P_bAnti, 4954, check)
      call createCurrent(P_G0, P_ghAAnti, P_HMinus, P_ghWp, 9816, check)
      call createCurrent(P_Hh, P_HMinus, P_GPlus, 3667, check)
      call createCurrent(P_HMinus, P_ghWp, P_Hh, P_ghAAnti, 4644, check)
      call createCurrent(P_HMinus, P_ghA, P_Hl, P_ghWmAnti, 5740, check)
      call createCurrent(P_GPlus, P_HPlus, P_HMinus, P_GMinus, 4557, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_A, 58, check)
      call createCurrent(P_ZQ, P_Hl, P_ZQ, 1625, check)
      call createCurrent(P_GPlus, P_Hl, P_GMinus, P_Ha, 10369, check)
      call createCurrent(P_G0, P_ghZ, P_ghWpAnti, P_GPlus, 4446, check)
      call createCurrent(P_WPlus, P_WMinus, P_Hh, 2646, check)
      call createCurrent(P_GQMinus, P_ghWmAnti, P_G0, P_ghZ, 1553, check)
      call createCurrent(P_GQMinus, P_ghZAnti, P_GPlus, P_ghZ, 2762, check)
      call createCurrent(P_GQMinus, P_Hl, P_HPlus, P_HlQ, 5992, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_Hh, P_GMinus, 972, check)
      call createCurrent(P_WQMinus, P_HPlus, P_Hh, P_AQ, 5108, check)
      call createCurrent(P_GPlus, P_uAnti, P_d, 5503, check)
      call createCurrent(P_ghWmAnti, P_HMinus, P_ghZ, P_Ha, 5980, check)
      call createCurrent(P_G0, P_tauMinus, P_tauPlus, 2955, check)
      call createCurrent(P_GPlus, P_ghZ, P_ghWpAnti, P_Hh, 2685, check)
      call createCurrent(P_Hl, P_ghWmAnti, P_HMinus, P_ghA, 7270, check)
      call createCurrent(P_HaQ, P_WMinus, P_A, P_HQPlus, 8608, check)
      call createCurrent(P_Hh, P_A, P_Z, P_Hh, 9357, check)
      call createCurrent(P_HhQ, P_GMinus, P_GQPlus, 2584, check)
      call createCurrent(P_Hl, P_ghWp, P_HMinus, P_ghAAnti, 5681, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Hh, P_HaQ, 8272, check)
      call createCurrent(P_muMinus, P_muPlus, P_Hl, 6233, check)
      call createCurrent(P_nu_tau, P_nu_tauAnti, 9469, check)
      call createCurrent(P_HlQ, P_G0, P_Ha, P_HlQ, 1628, check)
      call createCurrent(P_WMinus, P_Hl, P_GPlus, 8284, check)
      call createCurrent(P_GQ0, P_G0, P_GMinus, P_GQPlus, 1405, check)
      call createCurrent(P_Z, P_g, P_A, P_g, 10603, check)
      call createCurrent(P_WPlus, P_WMinus, P_HPlus, P_GMinus, 9353, check)
      call createCurrent(P_HQPlus, P_nu_muAnti, P_muMinus, 509, check)
      call createCurrent(P_ghWpAnti, P_G0, P_ghZ, P_GQPlus, 1409, check)
      call createCurrent(P_ghWm, P_Z, P_Z, P_ghWmAnti, 6774, check)
      call createCurrent(P_A, P_HMinus, P_GPlus, P_Z, 9374, check)
      call createCurrent(P_GQ0, P_GMinus, P_Hh, P_HQPlus, 2331, check)
      call createCurrent(P_G0, P_HMinus, P_GPlus, P_Hl, 1175, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_Ha, P_GMinus, 10475, check)
      call createCurrent(P_Z, P_A, P_GPlus, P_HMinus, 10323, check)
      call createCurrent(P_ghWp, P_HMinus, P_ghAAnti, P_Ha, 8805, check)
      call createCurrent(P_Hl, P_Hh, P_Hl, P_Hl, 5923, check)
      call createCurrent(P_HQMinus, P_Hl, P_HPlus, P_HlQ, 8039, check)
      call createCurrent(P_WPlus, P_ghZ, P_ghWpAnti, P_A, 8712, check)
      call createCurrent(P_ghWpAnti, P_HPlus, P_ghWp, P_GMinus, 10031, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_HPlus, P_HMinus, 3573, check)
      call createCurrent(P_ePlus, P_eMinus, P_Hl, 8378, check)
      call createCurrent(P_HQPlus, P_ghZ, P_ghWpAnti, 8232, check)
      call createCurrent(P_HhQ, P_GPlus, P_G0, P_HQMinus, 1271, check)
      call createCurrent(P_WPlus, P_Hh, P_WMinus, P_Hl, 9657, check)
      call createCurrent(P_ghWmAnti, P_Hh, P_HMinus, P_ghA, 177, check)
      call createCurrent(P_Hh, P_WPlus, P_GMinus, P_Z, 7678, check)
      call createCurrent(P_HPlus, P_HPlus, P_HMinus, P_HMinus, 8421, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_GMinus, 8832, check)
      call createCurrent(P_HMinus, P_Hh, P_WPlus, P_A, 1752, check)
      call createCurrent(P_A, P_WPlus, P_HMinus, P_G0, 8906, check)
      call createCurrent(P_HlQ, P_A, P_HPlus, P_WQMinus, 6980, check)
      call createCurrent(P_GPlus, P_G0, P_WMinus, 4765, check)
      call createCurrent(P_A, P_Hh, P_GMinus, P_WPlus, 8804, check)
      call createCurrent(P_ghZ, P_HMinus, P_ghZAnti, P_HQPlus, 4674, check)
      call createCurrent(P_HMinus, P_WPlus, P_Z, P_Hl, 4134, check)
      call createCurrent(P_WMinus, P_WPlus, P_ghZ, P_ghAAnti, 485, check)
      call createCurrent(P_WPlus, P_ghAAnti, P_ghA, P_WMinus, 8084, check)
      call createCurrent(P_HQPlus, P_G0, P_GMinus, P_HhQ, 6797, check)
      call createCurrent(P_ghWmAnti, P_HMinus, P_ghZ, P_HhQ, 3425, check)
      call createCurrent(P_GQ0, P_HPlus, P_HMinus, P_GQ0, 4477, check)
      call createCurrent(P_A, P_A, P_GMinus, P_HPlus, 10381, check)
      call createCurrent(P_Hl, P_Ha, P_Hl, P_Hl, 10496, check)
      call createCurrent(P_GQ0, P_tauPlus, P_tauMinus, 4663, check)
      call createCurrent(P_GMinus, P_GPlus, P_Hh, 3881, check)
      call createCurrent(P_HhQ, P_ghZAnti, P_GPlus, P_ghWm, 5836, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_HMinus, P_Hl, 2317, check)
      call createCurrent(P_ghWm, P_Hl, P_GPlus, P_ghZAnti, 4834, check)
      call createCurrent(P_GPlus, P_A, P_HMinus, P_A, 10159, check)
      call createCurrent(P_AQ, P_Hh, P_WMinus, P_GQPlus, 4701, check)
      call createCurrent(P_Hl, P_ghAAnti, P_ghWp, P_HMinus, 4123, check)
      call createCurrent(P_ghAAnti, P_HMinus, P_ghWp, P_HaQ, 6713, check)
      call createCurrent(P_HPlus, P_Ha, P_Ha, P_GMinus, 4536, check)
      call createCurrent(P_tAnti, P_A, P_t, 14, check)
      call createCurrent(P_HQMinus, P_Hh, P_WQPlus, 5345, check)
      call createCurrent(P_GQPlus, P_Hl, P_Hl, P_GQMinus, 6197, check)
      call createCurrent(P_HlQ, P_ghAAnti, P_HMinus, P_ghWp, 4115, check)
      call createCurrent(P_ZQ, P_tauPlus, P_tauMinus, 7003, check)
      call createCurrent(P_ghWp, P_HMinus, P_ghZAnti, P_HhQ, 1913, check)
      call createCurrent(P_u, P_Z, P_uAnti, 8361, check)
      call createCurrent(P_Ha, P_G0, P_ghWpAnti, P_ghWp, 8884, check)
      call createCurrent(P_ghA, P_GPlus, P_Hl, P_ghWpAnti, 6998, check)
      call createCurrent(P_HQMinus, P_Ha, P_Ha, P_GQPlus, 7005, check)
      call createCurrent(P_WMinus, P_G0, P_HPlus, P_A, 9042, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_Z, P_ghA, 3663, check)
      call createCurrent(P_HQPlus, P_G0, P_Hh, P_GQMinus, 1663, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_GPlus, P_G0, 5390, check)
      call createCurrent(P_GPlus, P_ghA, P_ghWpAnti, 5886, check)
      call createCurrent(P_ghWp, P_G0, P_ghWpAnti, P_GQ0, 6498, check)
      call createCurrent(P_GQPlus, P_GMinus, P_A, P_ZQ, 8030, check)
      call createCurrent(P_WQPlus, P_HMinus, P_Hl, P_AQ, 796, check)
      call createCurrent(P_ghA, P_GMinus, P_ghZAnti, P_GPlus, 4748, check)
      call createCurrent(P_G0, P_WPlus, P_GMinus, P_A, 4136, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_HPlus, 7664, check)
      call createCurrent(P_HQPlus, P_GMinus, P_GPlus, P_HQMinus, 2024, check)
      call createCurrent(P_HMinus, P_Hh, P_Ha, P_HPlus, 9764, check)
      call createCurrent(P_g, P_Ha, P_g, P_G0, 10551, check)
      call createCurrent(P_HMinus, P_ghZAnti, P_ghZ, P_GPlus, 9993, check)
      call createCurrent(P_WPlus, P_Z, P_ghA, P_ghWpAnti, 4967, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_WQPlus, 4542, check)
      call createCurrent(P_ePlus, P_eMinus, P_HhQ, 5490, check)
      call createCurrent(P_HPlus, P_Hl, P_G0, P_HMinus, 9066, check)
      call createCurrent(P_G0, P_Hl, P_GMinus, P_HPlus, 6397, check)
      call createCurrent(P_GPlus, P_GMinus, P_ghWp, P_ghWpAnti, 7126, check)
      call createCurrent(P_HQMinus, P_Ha, P_WPlus, P_ZQ, 7515, check)
      call createCurrent(P_GMinus, P_GPlus, P_g, P_g, 10666, check)
      call createCurrent(P_HQPlus, P_Hh, P_ghZ, P_ghWpAnti, 4096, check)
      call createCurrent(P_GPlus, P_G0, P_HMinus, P_Hh, 1458, check)
      call createCurrent(P_HlQ, P_uAnti, P_u, 5697, check)
      call createCurrent(P_ghZ, P_HPlus, P_HMinus, P_ghAAnti, 3871, check)
      call createCurrent(P_HQMinus, P_GMinus, P_HPlus, P_GQPlus, 6137, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghA, P_A, 5461, check)
      call createCurrent(P_HQMinus, P_GPlus, P_G0, P_HhQ, 2080, check)
      call createCurrent(P_HlQ, P_HPlus, P_G0, P_GQMinus, 4012, check)
      call createCurrent(P_GQ0, P_t, P_tAnti, 5924, check)
      call createCurrent(P_Z, P_g, P_Z, P_g, 10619, check)
      call createCurrent(P_Ha, P_ghWp, P_ghZAnti, P_HMinus, 119, check)
      call createCurrent(P_eMinus, P_nu_eAnti, P_WPlus, 1632, check)
      call createCurrent(P_ghA, P_ghZAnti, P_WMinus, P_WQPlus, 5189, check)
      call createCurrent(P_nu_tau, P_nu_tauAnti, P_ZQ, 719, check)
      call createCurrent(P_s, P_g, P_sAnti, 68, check)
      call createCurrent(P_ghZAnti, P_HPlus, P_Ha, P_ghWm, 687, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_Ha, P_ghWp, 9074, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_ghWm, P_GQ0, 2993, check)
      call createCurrent(P_ZQ, P_A, P_ghWmAnti, P_ghWm, 8133, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_WPlus, P_ZQ, 7059, check)
      call createCurrent(P_A, P_g, P_g, P_g, 10609, check)
      call createCurrent(P_ZQ, P_WMinus, P_Ha, P_HQPlus, 67, check)
      call createCurrent(P_ghZ, P_Hh, P_ghWpAnti, P_HQPlus, 2362, check)
      call createCurrent(P_s, P_cAnti, P_GQPlus, 2389, check)
      call createCurrent(P_Hh, P_GPlus, P_GMinus, P_G0, 10117, check)
      call createCurrent(P_WMinus, P_ghZAnti, P_ghWp, P_A, 2466, check)
      call createCurrent(P_HaQ, P_Hh, P_G0, P_HlQ, 7490, check)
      call createCurrent(P_G0, P_Hh, P_Hh, P_G0, 8052, check)
      call createCurrent(P_HQMinus, P_ePlus, P_nu_e, 4095, check)
      call createCurrent(P_WPlus, P_ghWp, P_ghWpAnti, P_WMinus, 4922, check)
      call createCurrent(P_HaQ, P_GMinus, P_Hl, P_HQPlus, 5119, check)
      call createCurrent(P_Hh, P_WPlus, P_WMinus, 3772, check)
      call createCurrent(P_GMinus, P_ghZ, P_ghWmAnti, P_G0, 835, check)
      call createCurrent(P_HPlus, P_Hl, P_Z, P_WMinus, 6262, check)
      call createCurrent(P_GQPlus, P_Hh, P_GMinus, P_HlQ, 6180, check)
      call createCurrent(P_HQMinus, P_ghWmAnti, P_Hh, P_ghA, 7873, check)
      call createCurrent(P_A, P_Hl, P_Ha, 9287, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Hl, P_HaQ, 4338, check)
      call createCurrent(P_ghZAnti, P_HMinus, P_ghA, P_GPlus, 9462, check)
      call createCurrent(P_Hl, P_Hl, P_G0, P_Hl, 10577, check)
      call createCurrent(P_HMinus, P_A, P_A, P_HPlus, 2650, check)
      call createCurrent(P_WPlus, P_HMinus, P_Hh, P_Z, 1549, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_WMinus, P_Z, 4534, check)
      call createCurrent(P_WMinus, P_Z, P_ghWmAnti, P_ghZ, 3080, check)
      call createCurrent(P_ghA, P_ghZAnti, P_HMinus, P_HQPlus, 3926, check)
      call createCurrent(P_GPlus, P_Hh, P_WMinus, 3958, check)
      call createCurrent(P_ghA, P_Hh, P_HPlus, P_ghWpAnti, 4858, check)
      call createCurrent(P_HMinus, P_GPlus, P_Hl, P_Ha, 4291, check)
      call createCurrent(P_Z, P_Z, P_G0, P_Ha, 9010, check)
      call createCurrent(P_ghZ, P_ghAAnti, P_HMinus, P_HPlus, 3438, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_Ha, P_GPlus, 9735, check)
      call createCurrent(P_WQPlus, P_WMinus, P_HlQ, 576, check)
      call createCurrent(P_HPlus, P_ghWpAnti, P_ghWp, P_GMinus, 10471, check)
      call createCurrent(P_nu_eAnti, P_eMinus, P_WQPlus, 2814, check)
      call createCurrent(P_HQMinus, P_HPlus, P_ghAAnti, P_ghZ, 7526, check)
      call createCurrent(P_ghZAnti, P_Hl, P_HMinus, P_ghWp, 5190, check)
      call createCurrent(P_ZQ, P_WPlus, P_GQMinus, 6912, check)
      call createCurrent(P_GMinus, P_GPlus, P_ghZAnti, P_ghA, 6409, check)
      call createCurrent(P_HlQ, P_GMinus, P_GPlus, P_HlQ, 4866, check)
      call createCurrent(P_HaQ, P_WPlus, P_HMinus, P_ZQ, 7397, check)
      call createCurrent(P_Hl, P_ghZAnti, P_ghZ, P_Hh, 10068, check)
      call createCurrent(P_ghWp, P_Z, P_WMinus, P_ghZAnti, 5335, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_HMinus, P_G0, 8909, check)
      call createCurrent(P_GQMinus, P_Hh, P_HPlus, P_HhQ, 3708, check)
      call createCurrent(P_ZQ, P_GMinus, P_WPlus, P_HhQ, 5267, check)
      call createCurrent(P_Z, P_Z, P_Z, P_Z, 10593, check)
      call createCurrent(P_ghWpAnti, P_Hh, P_ghA, P_GPlus, 7238, check)
      call createCurrent(P_AQ, P_Z, P_WPlus, P_WQMinus, 6581, check)
      call createCurrent(P_HlQ, P_Ha, P_GQ0, 6200, check)
      call createCurrent(P_GQPlus, P_GPlus, P_HMinus, P_HQMinus, 8330, check)
      call createCurrent(P_ghZ, P_Ha, P_HPlus, P_ghWpAnti, 1248, check)
      call createCurrent(P_t, P_g, P_tAnti, 990, check)
      call createCurrent(P_AQ, P_WPlus, P_Hl, P_GQMinus, 1753, check)
      call createCurrent(P_Hl, P_Z, P_HMinus, P_WPlus, 3236, check)
      call createCurrent(P_Hl, P_ghAAnti, P_ghWm, P_HPlus, 178, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_WMinus, P_WPlus, 4872, check)
      call createCurrent(P_GMinus, P_G0, P_ghWmAnti, P_ghZ, 6653, check)
      call createCurrent(P_GMinus, P_G0, P_GPlus, 9999, check)
      call createCurrent(P_WQMinus, P_HPlus, P_Hh, P_ZQ, 1229, check)
      call createCurrent(P_ghA, P_WPlus, P_ghWpAnti, 2715, check)
      call createCurrent(P_G0, P_ghWpAnti, P_ghZ, P_HPlus, 9110, check)
      call createCurrent(P_Ha, P_GPlus, P_HMinus, P_Hl, 3633, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Hh, P_HhQ, 1125, check)
      call createCurrent(P_A, P_WMinus, P_HPlus, P_Ha, 2812, check)
      call createCurrent(P_ghWp, P_Ha, P_Ha, P_ghWpAnti, 529, check)
      call createCurrent(P_GQPlus, P_ghZAnti, P_Hh, P_ghWm, 432, check)
      call createCurrent(P_Z, P_nu_muAnti, P_nu_mu, 8141, check)
      call createCurrent(P_G0, P_G0, P_Ha, P_G0, 6988, check)
      call createCurrent(P_HlQ, P_Hh, P_HPlus, P_HQMinus, 7877, check)
      call createCurrent(P_HQMinus, P_HPlus, P_Hh, P_GQ0, 5887, check)
      call createCurrent(P_HhQ, P_HMinus, P_Hl, P_HQPlus, 5822, check)
      call createCurrent(P_GQ0, P_GMinus, P_WPlus, P_ZQ, 7352, check)
      call createCurrent(P_GQMinus, P_GPlus, P_Z, P_ZQ, 8397, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_GMinus, P_GPlus, 2901, check)
      call createCurrent(P_ghWp, P_HMinus, P_ghZAnti, P_Ha, 8555, check)
      call createCurrent(P_ghA, P_G0, P_ghWmAnti, P_HMinus, 9792, check)
      call createCurrent(P_HPlus, P_HMinus, P_GMinus, P_GPlus, 1028, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghAAnti, P_GQMinus, 8171, check)
      call createCurrent(P_HQMinus, P_Hh, P_HPlus, P_HlQ, 3824, check)
      call createCurrent(P_ghWp, P_Z, P_ghAAnti, P_WMinus, 143, check)
      call createCurrent(P_Hh, P_A, P_Hl, P_A, 10516, check)
      call createCurrent(P_Hl, P_u, P_uAnti, 1059, check)
      call createCurrent(P_WPlus, P_WMinus, P_g, P_g, 10617, check)
      call createCurrent(P_t, P_tAnti, P_G0, 2378, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_GMinus, P_Hl, 7438, check)
      call createCurrent(P_WPlus, P_Ha, P_HMinus, 3238, check)
      call createCurrent(P_ghWp, P_HMinus, P_G0, P_ghAAnti, 9719, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Hh, P_GQ0, 3836, check)
      call createCurrent(P_HhQ, P_Hh, P_ghWp, P_ghWpAnti, 749, check)
      call createCurrent(P_Hl, P_Hl, P_Z, P_Z, 5107, check)
      call createCurrent(P_HMinus, P_Hl, P_Hl, P_GPlus, 7953, check)
      call createCurrent(P_HPlus, P_Hh, P_G0, P_HMinus, 8968, check)
      call createCurrent(P_HlQ, P_Hl, P_G0, P_GQ0, 519, check)
      call createCurrent(P_WMinus, P_A, P_ghA, P_ghWmAnti, 6935, check)
      call createCurrent(P_HMinus, P_WMinus, P_HPlus, P_WPlus, 8487, check)
      call createCurrent(P_g, P_u, P_uAnti, 1784, check)
      call createCurrent(P_d, P_WPlus, P_uAnti, 1025, check)
      call createCurrent(P_AQ, P_GPlus, P_GMinus, P_ZQ, 56, check)
      call createCurrent(P_A, P_Z, P_GMinus, P_HPlus, 9639, check)
      call createCurrent(P_HPlus, P_WMinus, P_G0, P_Z, 10154, check)
      call createCurrent(P_ghZ, P_Hl, P_ghZAnti, P_Hl, 8514, check)
      call createCurrent(P_nu_muAnti, P_GPlus, P_muMinus, 4302, check)
      call createCurrent(P_WQPlus, P_Hl, P_GMinus, P_ZQ, 2180, check)
      call createCurrent(P_ghZ, P_WPlus, P_Z, P_ghWpAnti, 4776, check)
      call createCurrent(P_ZQ, P_HPlus, P_WMinus, P_HlQ, 6738, check)
      call createCurrent(P_ghWpAnti, P_HPlus, P_ghWp, P_HMinus, 6552, check)
      call createCurrent(P_ghZ, P_GMinus, P_Hh, P_ghWmAnti, 6597, check)
      call createCurrent(P_HMinus, P_GPlus, P_Hl, P_G0, 4126, check)
      call createCurrent(P_HhQ, P_HMinus, P_GPlus, P_HhQ, 3571, check)
      call createCurrent(P_G0, P_GMinus, P_GPlus, P_G0, 3963, check)
      call createCurrent(P_A, P_GMinus, P_A, P_GPlus, 5666, check)
      call createCurrent(P_HPlus, P_ghZAnti, P_ghZ, P_GMinus, 8919, check)
      call createCurrent(P_Ha, P_Hh, P_Ha, P_Hh, 2313, check)
      call createCurrent(P_HQMinus, P_G0, P_Ha, P_HQPlus, 6030, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_GMinus, P_Ha, 10210, check)
      call createCurrent(P_eMinus, P_ePlus, P_Z, 5777, check)
      call createCurrent(P_HQPlus, P_Ha, P_GMinus, P_GQ0, 6993, check)
      call createCurrent(P_G0, P_Z, P_Ha, P_A, 10561, check)
      call createCurrent(P_HPlus, P_WMinus, P_Hh, P_A, 3401, check)
      call createCurrent(P_HMinus, P_HPlus, P_Ha, 9393, check)
      call createCurrent(P_t, P_tAnti, P_Hh, 165, check)
      call createCurrent(P_AQ, P_WMinus, P_ghAAnti, P_ghWp, 7711, check)
      call createCurrent(P_HPlus, P_GMinus, P_ghZAnti, P_ghA, 9113, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_A, P_WQMinus, 8715, check)
      call createCurrent(P_HPlus, P_WPlus, P_GMinus, P_WMinus, 9504, check)
      call createCurrent(P_ZQ, P_WPlus, P_Hl, P_GQMinus, 5028, check)
      call createCurrent(P_Hh, P_HPlus, P_WMinus, P_Z, 8293, check)
      call createCurrent(P_g, P_g, P_Z, P_A, 10756, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghZ, P_G0, 5401, check)
      call createCurrent(P_WPlus, P_ghAAnti, P_ghWm, 5311, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_Hh, P_ghWm, 4036, check)
      call createCurrent(P_HPlus, P_ghAAnti, P_ghWm, 5092, check)
      call createCurrent(P_HQMinus, P_Hl, P_ghZAnti, P_ghWp, 913, check)
      call createCurrent(P_WQMinus, P_A, P_ghWmAnti, P_ghA, 1288, check)
      call createCurrent(P_Hh, P_WPlus, P_GMinus, 7949, check)
      call createCurrent(P_GMinus, P_G0, P_G0, P_GPlus, 4392, check)
      call createCurrent(P_G0, P_G0, P_GPlus, P_HMinus, 2664, check)
      call createCurrent(P_HPlus, P_Hl, P_HMinus, P_G0, 9693, check)
      call createCurrent(P_ghWp, P_HPlus, P_HMinus, P_ghWpAnti, 5024, check)
      call createCurrent(P_WQMinus, P_GPlus, P_A, P_HhQ, 5097, check)
      call createCurrent(P_Hh, P_Hl, P_HMinus, P_GPlus, 7553, check)
      call createCurrent(P_HPlus, P_Z, P_GMinus, P_Z, 10392, check)
      call createCurrent(P_Hh, P_Hl, P_GPlus, P_HMinus, 8348, check)
      call createCurrent(P_ghZAnti, P_HPlus, P_GMinus, P_ghA, 9781, check)
      call createCurrent(P_WQPlus, P_GPlus, P_GMinus, P_WQMinus, 100, check)
      call createCurrent(P_ghWpAnti, P_Hl, P_ghA, P_GQPlus, 5853, check)
      call createCurrent(P_HPlus, P_Ha, P_ghWm, P_ghAAnti, 5489, check)
      call createCurrent(P_ghWmAnti, P_Hl, P_ghA, P_HMinus, 8350, check)
      call createCurrent(P_ZQ, P_A, P_HMinus, P_HQPlus, 211, check)
      call createCurrent(P_HaQ, P_WMinus, P_HQPlus, 2278, check)
      call createCurrent(P_WPlus, P_ghWp, P_WMinus, P_ghWpAnti, 6613, check)
      call createCurrent(P_Z, P_ghWp, P_ghWpAnti, 2545, check)
      call createCurrent(P_GQ0, P_Hl, P_HMinus, P_HQPlus, 6558, check)
      call createCurrent(P_d, P_dAnti, P_Z, 8517, check)
      call createCurrent(P_WQMinus, P_HPlus, P_HhQ, 492, check)
      call createCurrent(P_ZQ, P_Hh, P_Hh, P_ZQ, 4835, check)
      call createCurrent(P_WPlus, P_A, P_ghWm, P_ghZAnti, 4412, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_G0, P_GPlus, 5321, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghA, P_Z, 7475, check)
      call createCurrent(P_G0, P_HPlus, P_ghAAnti, P_ghWm, 9561, check)
      call createCurrent(P_Hh, P_d, P_dAnti, 2147, check)
      call createCurrent(P_Ha, P_ghZAnti, P_ghWp, P_HMinus, 6, check)
      call createCurrent(P_HPlus, P_WPlus, P_WMinus, P_HMinus, 5043, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_GMinus, P_Hh, 4425, check)
      call createCurrent(P_AQ, P_A, P_ghWpAnti, P_ghWp, 7324, check)
      call createCurrent(P_A, P_Z, P_A, P_A, 10625, check)
      call createCurrent(P_WMinus, P_ghA, P_ghWmAnti, P_Z, 6955, check)
      call createCurrent(P_ZQ, P_G0, P_HhQ, 591, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_HMinus, P_Hh, 4235, check)
      call createCurrent(P_GQ0, P_HMinus, P_Hl, P_HQPlus, 7102, check)
      call createCurrent(P_HaQ, P_HMinus, P_Hl, P_GQPlus, 945, check)
      call createCurrent(P_HlQ, P_WPlus, P_HMinus, P_ZQ, 6423, check)
      call createCurrent(P_Z, P_ghWpAnti, P_ghWp, 2917, check)
      call createCurrent(P_ghA, P_HPlus, P_GMinus, P_ghAAnti, 9736, check)
      call createCurrent(P_HQMinus, P_Hh, P_GPlus, P_HaQ, 6787, check)
      call createCurrent(P_GPlus, P_G0, P_ghAAnti, P_ghWm, 1907, check)
      call createCurrent(P_Hh, P_Z, P_Hl, P_Z, 9058, check)
      call createCurrent(P_Hh, P_Hh, P_Hh, P_Hl, 8271, check)
      call createCurrent(P_A, P_GMinus, P_Z, P_HPlus, 9418, check)
      call createCurrent(P_ghWm, P_Hl, P_GPlus, P_ghAAnti, 1278, check)
      call createCurrent(P_Hl, P_g, P_Hl, P_g, 10556, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_ghWp, P_GQ0, 5736, check)
      call createCurrent(P_ghWp, P_Ha, P_HMinus, P_ghAAnti, 184, check)
      call createCurrent(P_HQMinus, P_ghZ, P_HPlus, P_ghZAnti, 8426, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_Hl, P_GMinus, 7861, check)
      call createCurrent(P_Z, P_t, P_tAnti, 8549, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_G0, P_GQMinus, 5334, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_HPlus, 1423, check)
      call createCurrent(P_ghWp, P_A, P_ghWpAnti, P_AQ, 5624, check)
      call createCurrent(P_GMinus, P_G0, P_Hl, P_HPlus, 3025, check)
      call createCurrent(P_Ha, P_WPlus, P_Z, P_HMinus, 5137, check)
      call createCurrent(P_HPlus, P_g, P_GMinus, P_g, 10590, check)
      call createCurrent(P_Hl, P_Hl, P_ghWmAnti, P_ghWm, 3835, check)
      call createCurrent(P_HhQ, P_WPlus, P_Z, P_GQMinus, 6230, check)
      call createCurrent(P_GPlus, P_GMinus, P_HMinus, P_HPlus, 7314, check)
      call createCurrent(P_GQMinus, P_tauPlus, P_nu_tau, 6561, check)
      call createCurrent(P_Ha, P_Hl, P_A, 10482, check)
      call createCurrent(P_HlQ, P_Hl, P_ghZAnti, P_ghZ, 3376, check)
      call createCurrent(P_HlQ, P_G0, P_WMinus, P_WQPlus, 8713, check)
      call createCurrent(P_HPlus, P_Ha, P_GMinus, P_G0, 6559, check)
      call createCurrent(P_GQ0, P_Hh, P_ghWmAnti, P_ghWm, 7060, check)
      call createCurrent(P_HPlus, P_WPlus, P_HMinus, P_WMinus, 6063, check)
      call createCurrent(P_WMinus, P_Hl, P_HPlus, 6627, check)
      call createCurrent(P_WMinus, P_WPlus, P_Ha, P_Ha, 973, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghZAnti, P_GPlus, 5171, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_HPlus, P_Hh, 4739, check)
      call createCurrent(P_HMinus, P_Hl, P_ghWp, P_ghZAnti, 4531, check)
      call createCurrent(P_HaQ, P_ghWp, P_Hh, P_ghWpAnti, 3247, check)
      call createCurrent(P_A, P_A, P_A, P_A, 10699, check)
      call createCurrent(P_Hh, P_WMinus, P_Hl, P_WPlus, 9624, check)
      call createCurrent(P_HPlus, P_GMinus, P_Ha, P_Hl, 2804, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_Hl, P_HMinus, 4491, check)
      call createCurrent(P_b, P_bAnti, P_gQ, 6842, check)
      call createCurrent(P_ghZAnti, P_G0, P_ghWp, P_HMinus, 9125, check)
      call createCurrent(P_t, P_tAnti, P_Ha, 3891, check)
      call createCurrent(P_HPlus, P_WMinus, P_G0, P_A, 9292, check)
      call createCurrent(P_gQ, P_b, P_bAnti, 3380, check)
      call createCurrent(P_GQPlus, P_G0, P_Hh, P_HQMinus, 3866, check)
      call createCurrent(P_ghA, P_Ha, P_GMinus, P_ghWmAnti, 9503, check)
      call createCurrent(P_Hl, P_Hh, P_Hh, 7888, check)
      call createCurrent(P_A, P_GPlus, P_GMinus, 7191, check)
      call createCurrent(P_Hl, P_ghWpAnti, P_ghA, P_GPlus, 3429, check)
      call createCurrent(P_GQMinus, P_GPlus, P_GMinus, P_HQPlus, 7269, check)
      call createCurrent(P_HPlus, P_Z, P_WMinus, P_G0, 9199, check)
      call createCurrent(P_u, P_dAnti, P_HQMinus, 7994, check)
      call createCurrent(P_Z, P_ghWpAnti, P_ghWp, P_Z, 4218, check)
      call createCurrent(P_HMinus, P_ghWmAnti, P_Ha, P_ghZ, 126, check)
      call createCurrent(P_A, P_A, P_A, P_Z, 10512, check)
      call createCurrent(P_ghWmAnti, P_Hh, P_GMinus, P_ghA, 5754, check)
      call createCurrent(P_Hl, P_HMinus, P_Hh, P_GPlus, 5402, check)
      call createCurrent(P_HQMinus, P_Ha, P_ghWp, P_ghZAnti, 7065, check)
      call createCurrent(P_WPlus, P_WMinus, P_ghWpAnti, P_ghWp, 4295, check)
      call createCurrent(P_cAnti, P_c, P_G0, 5264, check)
      call createCurrent(P_ghWp, P_HMinus, P_ghAAnti, P_HlQ, 3913, check)
      call createCurrent(P_GMinus, P_ghAAnti, P_ghWp, P_Hl, 6845, check)
      call createCurrent(P_Hh, P_g, P_Hl, P_g, 10628, check)
      call createCurrent(P_HMinus, P_A, P_HPlus, P_Z, 6226, check)
      call createCurrent(P_WPlus, P_WPlus, P_ghWm, P_ghWpAnti, 922, check)
      call createCurrent(P_GMinus, P_GMinus, P_HPlus, P_GPlus, 2924, check)
      call createCurrent(P_ghWpAnti, P_Hh, P_ghWp, P_HaQ, 1219, check)
      call createCurrent(P_WQMinus, P_Ha, P_Ha, P_WQPlus, 584, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_ghA, P_GMinus, 6871, check)
      call createCurrent(P_HMinus, P_G0, P_WPlus, P_Z, 9976, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_ghA, P_GMinus, 1761, check)
      call createCurrent(P_Z, P_c, P_cAnti, 4758, check)
      call createCurrent(P_GQMinus, P_GPlus, P_ghZ, P_ghAAnti, 7760, check)
      call createCurrent(P_tAnti, P_b, P_GPlus, 324, check)
      call createCurrent(P_HQPlus, P_WMinus, P_Hl, P_ZQ, 7000, check)
      call createCurrent(P_Ha, P_Hh, P_G0, 4714, check)
      call createCurrent(P_HlQ, P_tAnti, P_t, 5671, check)
      call createCurrent(P_HQPlus, P_Hl, P_G0, P_GQMinus, 4228, check)
      call createCurrent(P_HMinus, P_WPlus, P_G0, P_Z, 9380, check)
      call createCurrent(P_GQ0, P_ghWpAnti, P_Hl, P_ghWp, 3091, check)
      call createCurrent(P_Hl, P_HMinus, P_ghWp, P_ghZAnti, 2420, check)
      call createCurrent(P_GQPlus, P_Hl, P_ghA, P_ghWpAnti, 4573, check)
      call createCurrent(P_HlQ, P_sAnti, P_s, 7923, check)
      call createCurrent(P_Hh, P_ghZAnti, P_ghWp, P_GMinus, 5117, check)
      call createCurrent(P_WMinus, P_A, P_Ha, P_HPlus, 6931, check)
      call createCurrent(P_nu_mu, P_GMinus, P_muPlus, 6266, check)
      call createCurrent(P_GMinus, P_Hl, P_ghWmAnti, P_ghZ, 7108, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_WMinus, 1209, check)
      call createCurrent(P_Hh, P_bAnti, P_b, 7094, check)
      call createCurrent(P_ghA, P_Hh, P_HMinus, P_ghWmAnti, 7604, check)
      call createCurrent(P_ghWp, P_G0, P_GMinus, P_ghAAnti, 2054, check)
      call createCurrent(P_HhQ, P_Hl, P_GMinus, P_HQPlus, 2948, check)
      call createCurrent(P_HhQ, P_GPlus, P_WMinus, P_ZQ, 5438, check)
      call createCurrent(P_HPlus, P_GMinus, P_WMinus, P_WPlus, 9159, check)
      call createCurrent(P_GQPlus, P_Hh, P_HQMinus, 1361, check)
      call createCurrent(P_Ha, P_HMinus, P_GPlus, 3819, check)
      call createCurrent(P_Ha, P_HMinus, P_WPlus, 1333, check)
      call createCurrent(P_A, P_A, P_Z, P_A, 10618, check)
      call createCurrent(P_GQMinus, P_Ha, P_G0, P_GQPlus, 5585, check)
      call createCurrent(P_g, P_WMinus, P_WPlus, P_g, 10580, check)
      call createCurrent(P_Hl, P_GMinus, P_WPlus, P_Z, 1511, check)
      call createCurrent(P_HaQ, P_HMinus, P_WQPlus, 6013, check)
      call createCurrent(P_nu_tauAnti, P_nu_tau, P_ZQ, 3114, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Hh, 6814, check)
      call createCurrent(P_HMinus, P_GPlus, P_Z, P_Z, 10342, check)
      call createCurrent(P_ghZAnti, P_ghA, P_GMinus, P_GPlus, 7735, check)
      call createCurrent(P_Hl, P_ghWmAnti, P_ghA, P_HMinus, 8592, check)
      call createCurrent(P_Hl, P_Hl, P_Hl, P_Hl, 3509, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_HPlus, P_Hh, 5121, check)
      call createCurrent(P_GPlus, P_Hh, P_GMinus, P_Hl, 840, check)
      call createCurrent(P_HMinus, P_ghZAnti, P_ghZ, P_HPlus, 989, check)
      call createCurrent(P_G0, P_Ha, P_HPlus, P_GMinus, 863, check)
      call createCurrent(P_HhQ, P_GPlus, P_ghZAnti, P_ghWm, 1995, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghZ, P_A, 1691, check)
      call createCurrent(P_Hl, P_ghZ, P_ghZAnti, 3116, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_HMinus, 4429, check)
      call createCurrent(P_AQ, P_GMinus, P_Hh, P_WQPlus, 2192, check)
      call createCurrent(P_G0, P_GPlus, P_ghWpAnti, P_ghZ, 8300, check)
      call createCurrent(P_nu_tauAnti, P_WPlus, P_tauMinus, 2130, check)
      call createCurrent(P_WQMinus, P_GMinus, P_GPlus, P_WQPlus, 8102, check)
      call createCurrent(P_Hh, P_HPlus, P_GMinus, P_Hl, 4492, check)
      call createCurrent(P_eMinus, P_ePlus, P_HaQ, 300, check)
      call createCurrent(P_HQMinus, P_ghWmAnti, P_Hl, P_ghA, 4675, check)
      call createCurrent(P_GMinus, P_ghA, P_ghWmAnti, P_Ha, 9746, check)
      call createCurrent(P_AQ, P_WPlus, P_WQMinus, 6718, check)
      call createCurrent(P_WQMinus, P_WPlus, P_ghZAnti, P_ghZ, 4038, check)
      call createCurrent(P_HlQ, P_HMinus, P_Hl, P_HQPlus, 635, check)
      call createCurrent(P_G0, P_GMinus, P_HPlus, P_G0, 982, check)
      call createCurrent(P_s, P_cAnti, P_GPlus, 844, check)
      call createCurrent(P_cAnti, P_c, P_A, 5187, check)
      call createCurrent(P_WMinus, P_Hl, P_A, P_GPlus, 3888, check)
      call createCurrent(P_HaQ, P_Ha, P_ghWmAnti, P_ghWm, 1448, check)
      call createCurrent(P_ghAAnti, P_HPlus, P_ghWm, P_G0, 8890, check)
      call createCurrent(P_G0, P_Ha, P_ghWpAnti, P_ghWp, 8979, check)
      call createCurrent(P_WPlus, P_GMinus, P_Z, P_Hh, 186, check)
      call createCurrent(P_GMinus, P_HPlus, P_WPlus, P_WMinus, 9875, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_GQPlus, 3786, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_GPlus, P_Hl, 3399, check)
      call createCurrent(P_Hl, P_Hl, P_A, P_A, 10724, check)
      call createCurrent(P_WMinus, P_ghA, P_ghWmAnti, 5156, check)
      call createCurrent(P_GQMinus, P_ghZ, P_Hl, P_ghWmAnti, 5252, check)
      call createCurrent(P_Ha, P_WPlus, P_A, P_GMinus, 9181, check)
      call createCurrent(P_GQPlus, P_G0, P_GMinus, P_HaQ, 4540, check)
      call createCurrent(P_WPlus, P_HMinus, P_Hh, P_A, 2247, check)
      call createCurrent(P_Ha, P_ghWp, P_GMinus, P_ghZAnti, 9987, check)
      call createCurrent(P_Hh, P_WPlus, P_HMinus, P_Z, 5278, check)
      call createCurrent(P_ghWp, P_HMinus, P_ghAAnti, P_G0, 10166, check)
      call createCurrent(P_HlQ, P_ghWpAnti, P_ghWp, 259, check)
      call createCurrent(P_ghWp, P_HMinus, P_Hl, P_ghAAnti, 4039, check)
      call createCurrent(P_HPlus, P_HMinus, P_Hh, P_Ha, 9723, check)
      call createCurrent(P_ZQ, P_HMinus, P_Z, P_HQPlus, 6504, check)
      call createCurrent(P_WMinus, P_Ha, P_Ha, P_WPlus, 4062, check)
      call createCurrent(P_GMinus, P_Ha, P_HPlus, P_Ha, 6476, check)
      call createCurrent(P_WQPlus, P_Z, P_ghWpAnti, P_ghZ, 8231, check)
      call createCurrent(P_Hh, P_HMinus, P_Hl, P_GPlus, 6289, check)
      call createCurrent(P_t, P_tAnti, 8836, check)
      call createCurrent(P_G0, P_Ha, P_GMinus, P_GPlus, 447, check)
      call createCurrent(P_ghWpAnti, P_HMinus, P_HPlus, P_ghWp, 2352, check)
      call createCurrent(P_eMinus, P_ePlus, P_AQ, 1675, check)
      call createCurrent(P_WQPlus, P_HMinus, P_HPlus, P_WQMinus, 8562, check)
      call createCurrent(P_HMinus, P_ghWpAnti, P_ghWp, P_GPlus, 9965, check)
      call createCurrent(P_Ha, P_ghZAnti, P_GMinus, P_ghWp, 9401, check)
      call createCurrent(P_sAnti, P_s, P_ZQ, 5906, check)
      call createCurrent(P_Z, P_G0, P_Hh, 7763, check)
      call createCurrent(P_WQMinus, P_ghWp, P_WMinus, P_ghWmAnti, 3263, check)
      call createCurrent(P_GMinus, P_ghAAnti, P_ghWp, 3045, check)
      call createCurrent(P_GQPlus, P_HMinus, P_HhQ, 2783, check)
      call createCurrent(P_Ha, P_ghWm, P_GPlus, P_ghAAnti, 8864, check)
      call createCurrent(P_GMinus, P_Ha, P_ghZ, P_ghWmAnti, 9300, check)
      call createCurrent(P_WMinus, P_A, P_ghWmAnti, P_ghA, 6911, check)
      call createCurrent(P_WQMinus, P_Hh, P_GQPlus, 6887, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_GPlus, P_HMinus, 9487, check)
      call createCurrent(P_WQMinus, P_ghWp, P_ghZAnti, 3029, check)
      call createCurrent(P_WQPlus, P_Z, P_Ha, P_HQMinus, 244, check)
      call createCurrent(P_HPlus, P_GMinus, P_G0, P_Hl, 8334, check)
      call createCurrent(P_muPlus, P_muMinus, P_ZQ, 4584, check)
      call createCurrent(P_HhQ, P_GPlus, P_ghAAnti, P_ghWm, 8028, check)
      call createCurrent(P_WMinus, P_HPlus, P_A, P_Hh, 4588, check)
      call createCurrent(P_WQMinus, P_WPlus, P_Ha, P_HhQ, 391, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghZ, P_Hl, 2637, check)
      call createCurrent(P_uAnti, P_u, P_A, 5054, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghWpAnti, P_Hh, 7993, check)
      call createCurrent(P_ghWp, P_Hl, P_ghZAnti, P_HQMinus, 5451, check)
      call createCurrent(P_Hl, P_ghWmAnti, P_ghWm, 3156, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_Ha, P_GMinus, 9389, check)
      call createCurrent(P_HhQ, P_A, P_WMinus, P_GQPlus, 3185, check)
      call createCurrent(P_WMinus, P_ghWp, P_ghWmAnti, P_WMinus, 8780, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_WMinus, 2260, check)
      call createCurrent(P_GQMinus, P_Hh, P_ghZ, P_ghWmAnti, 5549, check)
      call createCurrent(P_WQMinus, P_ghZAnti, P_WPlus, P_ghZ, 5619, check)
      call createCurrent(P_G0, P_Ha, P_Hh, P_Hl, 1881, check)
      call createCurrent(P_HQMinus, P_Ha, P_ghA, P_ghWmAnti, 2288, check)
      call createCurrent(P_HlQ, P_GPlus, P_GQMinus, 3884, check)
      call createCurrent(P_G0, P_Z, P_Z, P_G0, 3771, check)
      call createCurrent(P_ghWp, P_Ha, P_HMinus, P_ghZAnti, 8735, check)
      call createCurrent(P_tauPlus, P_HMinus, P_nu_tau, 8494, check)
      call createCurrent(P_ghWm, P_ghWpAnti, P_WPlus, P_WPlus, 6965, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_Hh, P_GPlus, 5903, check)
      call createCurrent(P_GMinus, P_ghWp, P_ghZAnti, P_G0, 2328, check)
      call createCurrent(P_Hl, P_GPlus, P_ghZAnti, P_ghWm, 3083, check)
      call createCurrent(P_ghA, P_HMinus, P_ghAAnti, P_HPlus, 1812, check)
      call createCurrent(P_GQMinus, P_G0, P_Hh, P_HQPlus, 8559, check)
      call createCurrent(P_GQMinus, P_Z, P_WPlus, P_GQ0, 4009, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_Hl, P_HQMinus, 3187, check)
      call createCurrent(P_GQ0, P_Z, P_HhQ, 4909, check)
      call createCurrent(P_GMinus, P_HPlus, P_GPlus, P_GMinus, 1004, check)
      call createCurrent(P_Ha, P_ghWp, P_HMinus, P_ghAAnti, 442, check)
      call createCurrent(P_tauMinus, P_nu_tauAnti, P_WPlus, 3971, check)
      call createCurrent(P_ghWmAnti, P_Ha, P_HMinus, P_ghA, 8703, check)
      call createCurrent(P_GQ0, P_tAnti, P_t, 1964, check)
      call createCurrent(P_ghA, P_Z, P_ghWmAnti, P_WQMinus, 7671, check)
      call createCurrent(P_ghAAnti, P_A, P_ghWp, P_WMinus, 1520, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghZAnti, P_Z, 7409, check)
      call createCurrent(P_WQMinus, P_A, P_ghA, P_ghWmAnti, 2162, check)
      call createCurrent(P_WQMinus, P_ghZ, P_Z, P_ghWmAnti, 8116, check)
      call createCurrent(P_GQ0, P_G0, P_ghZ, P_ghZAnti, 4641, check)
      call createCurrent(P_HQPlus, P_HMinus, P_ghAAnti, P_ghZ, 1310, check)
      call createCurrent(P_GQPlus, P_Hl, P_ghZ, P_ghWpAnti, 3479, check)
      call createCurrent(P_sAnti, P_Z, P_s, 5546, check)
      call createCurrent(P_g, P_g, P_WMinus, P_WPlus, 10591, check)
      call createCurrent(P_Hh, P_GMinus, P_GPlus, 4727, check)
      call createCurrent(P_GQPlus, P_ghWm, P_Hh, P_ghZAnti, 3953, check)
      call createCurrent(P_G0, P_Ha, P_Hh, 5275, check)
      call createCurrent(P_Z, P_muMinus, P_muPlus, 582, check)
      call createCurrent(P_ghWmAnti, P_Hh, P_ghWm, P_HaQ, 5306, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_GQPlus, 752, check)
      call createCurrent(P_HQMinus, P_ghA, P_Hl, P_ghWmAnti, 3513, check)
      call createCurrent(P_b, P_tAnti, P_GPlus, 4258, check)
      call createCurrent(P_HMinus, P_HMinus, P_GPlus, P_GPlus, 4647, check)
      call createCurrent(P_GMinus, P_WPlus, P_G0, P_A, 6422, check)
      call createCurrent(P_GQMinus, P_HPlus, P_G0, P_GQ0, 5792, check)
      call createCurrent(P_WMinus, P_G0, P_A, P_HPlus, 9386, check)
      call createCurrent(P_A, P_Hl, P_Z, P_Hh, 10637, check)
      call createCurrent(P_WQPlus, P_WMinus, P_HhQ, 1301, check)
      call createCurrent(P_Hl, P_ghA, P_ghWmAnti, P_GMinus, 3087, check)
      call createCurrent(P_HhQ, P_WMinus, P_Ha, P_WQPlus, 5591, check)
      call createCurrent(P_Ha, P_WMinus, P_Z, P_HPlus, 5589, check)
      call createCurrent(P_ghWmAnti, P_G0, P_ghWm, P_HhQ, 3459, check)
      call createCurrent(P_HlQ, P_ghWp, P_Ha, P_ghWpAnti, 8591, check)
      call createCurrent(P_A, P_A, P_Z, P_Z, 10629, check)
      call createCurrent(P_GMinus, P_WPlus, P_Z, 4634, check)
      call createCurrent(P_WQPlus, P_A, P_Z, P_WQMinus, 4956, check)
      call createCurrent(P_muMinus, P_nu_muAnti, P_WQPlus, 1514, check)
      call createCurrent(P_ghZ, P_G0, P_ghZAnti, P_G0, 3339, check)
      call createCurrent(P_A, P_ghZAnti, P_ghWp, P_WMinus, 3102, check)
      call createCurrent(P_GPlus, P_HMinus, P_Ha, P_Hl, 2675, check)
      call createCurrent(P_HPlus, P_ghA, P_ghZAnti, P_GMinus, 10233, check)
      call createCurrent(P_WMinus, P_ghA, P_A, P_ghWmAnti, 4962, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_Ha, P_ghA, 10083, check)
      call createCurrent(P_WMinus, P_GPlus, P_Hl, 7138, check)
      call createCurrent(P_HMinus, P_HPlus, P_HPlus, P_HMinus, 1030, check)
      call createCurrent(P_d, P_dAnti, P_HhQ, 2874, check)
      call createCurrent(P_GQMinus, P_G0, P_WQPlus, 3035, check)
      call createCurrent(P_HMinus, P_ghWmAnti, P_ghWm, P_HPlus, 57, check)
      call createCurrent(P_ghWm, P_G0, P_GPlus, P_ghAAnti, 1018, check)
      call createCurrent(P_GQ0, P_ghWp, P_Hh, P_ghWpAnti, 759, check)
      call createCurrent(P_WMinus, P_Z, P_G0, P_HPlus, 8983, check)
      call createCurrent(P_GQMinus, P_Hl, P_ghWp, P_ghZAnti, 1573, check)
      call createCurrent(P_ghA, P_HPlus, P_HMinus, P_ghAAnti, 5136, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_HPlus, P_G0, 10282, check)
      call createCurrent(P_u, P_uAnti, P_HlQ, 916, check)
      call createCurrent(P_ghZ, P_GMinus, P_GPlus, P_ghAAnti, 6756, check)
      call createCurrent(P_ghWpAnti, P_GMinus, P_ghWp, P_HPlus, 9526, check)
      call createCurrent(P_ghA, P_HPlus, P_HMinus, P_ghZAnti, 721, check)
      call createCurrent(P_ghZAnti, P_HMinus, P_Hl, P_ghWp, 7106, check)
      call createCurrent(P_WQMinus, P_sAnti, P_c, 3170, check)
      call createCurrent(P_ghZAnti, P_Ha, P_ghWm, P_HQPlus, 5254, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_ghZ, P_WQMinus, 1305, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_WMinus, P_WQPlus, 6747, check)
      call createCurrent(P_HQMinus, P_Hh, P_HPlus, P_GQ0, 7142, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghWm, P_WPlus, 3649, check)
      call createCurrent(P_GQMinus, P_ghWp, P_ghZAnti, 6944, check)
      call createCurrent(P_ghZ, P_HPlus, P_ghZAnti, P_HQMinus, 1528, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_Hl, P_GQMinus, 2722, check)
      call createCurrent(P_HhQ, P_GPlus, P_HMinus, P_HlQ, 3992, check)
      call createCurrent(P_Z, P_A, P_GMinus, P_HPlus, 8966, check)
      call createCurrent(P_WPlus, P_Hh, P_Z, P_GMinus, 6009, check)
      call createCurrent(P_HaQ, P_HPlus, P_Hh, P_GQMinus, 3377, check)
      call createCurrent(P_GQ0, P_Z, P_GMinus, P_WQPlus, 4844, check)
      call createCurrent(P_GQ0, P_A, P_WPlus, P_GQMinus, 5506, check)
      call createCurrent(P_A, P_Hh, P_WMinus, P_GPlus, 3093, check)
      call createCurrent(P_ghZ, P_Ha, P_GPlus, P_ghWpAnti, 9740, check)
      call createCurrent(P_HQMinus, P_HPlus, P_WMinus, P_WQPlus, 5573, check)
      call createCurrent(P_WMinus, P_bAnti, P_t, 4071, check)
      call createCurrent(P_ghAAnti, P_A, P_WMinus, P_ghWp, 1238, check)
      call createCurrent(P_Hh, P_WPlus, P_A, P_HMinus, 5059, check)
      call createCurrent(P_ghWpAnti, P_HPlus, P_ghWp, P_HQMinus, 373, check)
      call createCurrent(P_HlQ, P_WPlus, P_WQMinus, 5468, check)
      call createCurrent(P_G0, P_Z, P_A, P_Ha, 10620, check)
      call createCurrent(P_G0, P_ghA, P_ghWpAnti, P_HPlus, 10107, check)
      call createCurrent(P_AQ, P_WMinus, P_Z, P_WQPlus, 7271, check)
      call createCurrent(P_ghAAnti, P_ghZ, P_GMinus, P_GPlus, 2198, check)
      call createCurrent(P_ZQ, P_HMinus, P_WPlus, P_HhQ, 24, check)
      call createCurrent(P_GQMinus, P_HPlus, P_GQ0, 6985, check)
      call createCurrent(P_Hl, P_HMinus, P_GPlus, P_Ha, 6527, check)
      call createCurrent(P_Z, P_HMinus, P_Hh, P_WPlus, 1973, check)
      call createCurrent(P_GQ0, P_ghAAnti, P_GMinus, P_ghWp, 2736, check)
      call createCurrent(P_AQ, P_HMinus, P_Hh, P_WQPlus, 6199, check)
      call createCurrent(P_Ha, P_Hl, P_Hh, P_Ha, 4266, check)
      call createCurrent(P_WQMinus, P_HPlus, P_Ha, P_ZQ, 1070, check)
      call createCurrent(P_HhQ, P_Hh, P_HhQ, 5151, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_Z, P_WMinus, 445, check)
      call createCurrent(P_GMinus, P_ghA, P_G0, P_ghWmAnti, 4470, check)
      call createCurrent(P_HMinus, P_ghA, P_ghZAnti, P_GPlus, 10442, check)
      call createCurrent(P_G0, P_WPlus, P_A, P_HMinus, 9659, check)
      call createCurrent(P_WQMinus, P_A, P_ghZ, P_ghWmAnti, 574, check)
      call createCurrent(P_Hh, P_HPlus, P_HMinus, 3625, check)
      call createCurrent(P_A, P_Z, P_Ha, P_G0, 10675, check)
      call createCurrent(P_HMinus, P_ghWmAnti, P_ghWm, P_GPlus, 9638, check)
      call createCurrent(P_Ha, P_GPlus, P_A, P_WMinus, 10029, check)
      call createCurrent(P_HMinus, P_G0, P_GPlus, P_G0, 1571, check)
      call createCurrent(P_Hl, P_ghA, P_ghWpAnti, P_GPlus, 145, check)
      call createCurrent(P_ghZAnti, P_Hl, P_ghWm, P_GQPlus, 50, check)
      call createCurrent(P_ghA, P_Hl, P_ghWmAnti, P_GQMinus, 2369, check)
      call createCurrent(P_nu_eAnti, P_GPlus, P_eMinus, 7537, check)
      call createCurrent(P_GQ0, P_GMinus, P_ghWmAnti, P_ghZ, 5577, check)
      call createCurrent(P_HQMinus, P_Ha, P_WQPlus, 5460, check)
      call createCurrent(P_HMinus, P_HPlus, P_A, P_Z, 6806, check)
      call createCurrent(P_Z, P_WMinus, P_WPlus, P_A, 5000, check)
      call createCurrent(P_GPlus, P_ghWm, P_Hl, P_ghZAnti, 7280, check)
      call createCurrent(P_HaQ, P_ghWmAnti, P_Ha, P_ghWm, 6312, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghWpAnti, P_HlQ, 1772, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_HPlus, P_HQMinus, 5026, check)
      call createCurrent(P_Hh, P_Hh, P_Ha, P_Ha, 2902, check)
      call createCurrent(P_GQMinus, P_Hh, P_GPlus, P_HlQ, 8415, check)
      call createCurrent(P_GQPlus, P_WMinus, P_Hl, P_ZQ, 5433, check)
      call createCurrent(P_Hl, P_Hl, P_HPlus, P_GMinus, 3450, check)
      call createCurrent(P_GQMinus, P_WPlus, P_HlQ, 3613, check)
      call createCurrent(P_g, P_bAnti, P_b, 7263, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_Hh, P_ghWm, 7433, check)
      call createCurrent(P_WQMinus, P_WPlus, P_AQ, 1482, check)
      call createCurrent(P_ghZ, P_GPlus, P_G0, P_ghWpAnti, 6817, check)
      call createCurrent(P_GQPlus, P_Hl, P_HQMinus, 4883, check)
      call createCurrent(P_ghA, P_WMinus, P_ghWmAnti, 1193, check)
      call createCurrent(P_HQPlus, P_HMinus, P_GMinus, P_HQPlus, 550, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_WMinus, P_Z, 1082, check)
      call createCurrent(P_ghWmAnti, P_HMinus, P_GPlus, P_ghWm, 9629, check)
      call createCurrent(P_WPlus, P_HMinus, P_Z, 8459, check)
      call createCurrent(P_HQPlus, P_GMinus, P_Ha, P_HaQ, 3761, check)
      call createCurrent(P_GQ0, P_A, P_WMinus, P_GQPlus, 6335, check)
      call createCurrent(P_GPlus, P_ghA, P_ghZAnti, P_GMinus, 1191, check)
      call createCurrent(P_G0, P_Ha, P_Hl, P_Hl, 3173, check)
      call createCurrent(P_Ha, P_G0, P_Ha, P_G0, 8163, check)
      call createCurrent(P_HPlus, P_ghZAnti, P_GMinus, P_ghZ, 9698, check)
      call createCurrent(P_c, P_sAnti, P_WQMinus, 4032, check)
      call createCurrent(P_WMinus, P_sAnti, P_c, 562, check)
      call createCurrent(P_Hl, P_G0, P_Hl, P_G0, 7629, check)
      call createCurrent(P_Hh, P_ghZAnti, P_ghZ, P_Hh, 2815, check)
      call createCurrent(P_ghA, P_WPlus, P_WMinus, P_ghZAnti, 4015, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_Hh, P_ghWp, 4394, check)
      call createCurrent(P_Ha, P_HMinus, P_ghA, P_ghWmAnti, 316, check)
      call createCurrent(P_GPlus, P_GMinus, P_G0, 9481, check)
      call createCurrent(P_ghAAnti, P_ghA, P_GPlus, P_GMinus, 2560, check)
      call createCurrent(P_GQ0, P_Hh, P_WPlus, P_WQMinus, 1344, check)
      call createCurrent(P_HQMinus, P_WPlus, P_HaQ, 1491, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_HMinus, P_GPlus, 10291, check)
      call createCurrent(P_ghWp, P_Hh, P_ghAAnti, P_HMinus, 3058, check)
      call createCurrent(P_HQPlus, P_ghZ, P_Ha, P_ghWpAnti, 6546, check)
      call createCurrent(P_WQPlus, P_ghAAnti, P_WMinus, P_ghA, 4108, check)
      call createCurrent(P_A, P_ghWmAnti, P_ghWm, P_Z, 2911, check)
      call createCurrent(P_GPlus, P_ghWm, P_G0, P_ghZAnti, 2053, check)
      call createCurrent(P_G0, P_ghZAnti, P_ghWm, P_GPlus, 5571, check)
      call createCurrent(P_Ha, P_Z, P_A, P_Ha, 9283, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_HPlus, P_G0, 10106, check)
      call createCurrent(P_GPlus, P_A, P_WMinus, 7131, check)
      call createCurrent(P_HlQ, P_G0, P_GMinus, P_HQPlus, 6217, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_WMinus, 4863, check)
      call createCurrent(P_Hl, P_GMinus, P_HPlus, P_G0, 359, check)
      call createCurrent(P_ghWpAnti, P_HPlus, P_Hl, P_ghZ, 201, check)
      call createCurrent(P_HQPlus, P_ghWpAnti, P_Hl, P_ghA, 4278, check)
      call createCurrent(P_HhQ, P_G0, P_Hl, P_GQ0, 7086, check)
      call createCurrent(P_Ha, P_Hh, P_HPlus, P_GMinus, 5629, check)
      call createCurrent(P_GPlus, P_ghWm, P_ghZAnti, P_G0, 2098, check)
      call createCurrent(P_HhQ, P_Hl, P_HPlus, P_HQMinus, 3314, check)
      call createCurrent(P_ghWpAnti, P_GMinus, P_GPlus, P_ghWp, 6093, check)
      call createCurrent(P_HaQ, P_Ha, P_ghWm, P_ghWmAnti, 2060, check)
      call createCurrent(P_WQMinus, P_WPlus, P_ghWp, P_ghWpAnti, 5904, check)
      call createCurrent(P_WQPlus, P_HMinus, P_Ha, P_AQ, 6707, check)
      call createCurrent(P_HhQ, P_WPlus, P_A, P_HQMinus, 1807, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_G0, P_GMinus, 2178, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_WPlus, P_WMinus, 4298, check)
      call createCurrent(P_ghWmAnti, P_A, P_Z, P_ghWm, 4912, check)
      call createCurrent(P_ghWm, P_Ha, P_GPlus, P_ghZAnti, 8948, check)
      call createCurrent(P_G0, P_GMinus, P_A, P_WPlus, 8390, check)
      call createCurrent(P_A, P_WPlus, P_HMinus, P_Hh, 7501, check)
      call createCurrent(P_WQPlus, P_Z, P_HMinus, P_HlQ, 8596, check)
      call createCurrent(P_A, P_HPlus, P_WMinus, P_Hl, 3413, check)
      call createCurrent(P_eMinus, P_ePlus, P_ZQ, 7739, check)
      call createCurrent(P_ghZ, P_ghAAnti, P_WPlus, P_WMinus, 7512, check)
      call createCurrent(P_WMinus, P_Hh, P_WPlus, P_Hl, 9122, check)
      call createCurrent(P_HMinus, P_ghAAnti, P_HPlus, P_ghZ, 1170, check)
      call createCurrent(P_HhQ, P_Hh, P_GMinus, P_HQPlus, 7498, check)
      call createCurrent(P_HPlus, P_ghZ, P_HMinus, P_ghAAnti, 7229, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghA, P_Ha, 9940, check)
      call createCurrent(P_ghWp, P_HPlus, P_ghWpAnti, P_GMinus, 10181, check)
      call createCurrent(P_ghZ, P_HMinus, P_ghWmAnti, P_HhQ, 3420, check)
      call createCurrent(P_GPlus, P_WMinus, P_A, P_Ha, 10333, check)
      call createCurrent(P_ghWmAnti, P_A, P_ghWm, P_A, 6041, check)
      call createCurrent(P_WPlus, P_G0, P_A, P_HMinus, 10316, check)
      call createCurrent(P_HaQ, P_GPlus, P_HMinus, P_HlQ, 517, check)
      call createCurrent(P_WMinus, P_Hl, P_HPlus, P_A, 4687, check)
      call createCurrent(P_ZQ, P_GMinus, P_WPlus, P_HlQ, 266, check)
      call createCurrent(P_Z, P_ghWpAnti, P_ghZ, P_WPlus, 7795, check)
      call createCurrent(P_ghWpAnti, P_A, P_ghZ, P_WPlus, 8085, check)
      call createCurrent(P_A, P_GPlus, P_HMinus, P_Z, 10388, check)
      call createCurrent(P_ghZ, P_G0, P_ghWmAnti, P_GMinus, 1887, check)
      call createCurrent(P_Ha, P_HMinus, P_GPlus, P_G0, 8505, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_HMinus, P_Ha, 7335, check)
      call createCurrent(P_GMinus, P_WMinus, P_WPlus, P_GPlus, 2731, check)
      call createCurrent(P_GPlus, P_A, P_Ha, P_WMinus, 9155, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_ghWp, P_G0, 1382, check)
      call createCurrent(P_GQPlus, P_HMinus, P_G0, P_HhQ, 2724, check)
      call createCurrent(P_ghWm, P_WPlus, P_WMinus, P_ghWmAnti, 4094, check)
      call createCurrent(P_GMinus, P_GPlus, P_G0, P_G0, 3451, check)
      call createCurrent(P_HMinus, P_ghAAnti, P_Hl, P_ghWp, 2601, check)
      call createCurrent(P_GQPlus, P_Hl, P_WMinus, P_AQ, 4271, check)
      call createCurrent(P_GPlus, P_GMinus, P_GMinus, P_HPlus, 6079, check)
      call createCurrent(P_Z, P_ghWpAnti, P_ghA, P_WPlus, 4497, check)
      call createCurrent(P_HaQ, P_ghWm, P_Ha, P_ghWmAnti, 7615, check)
      call createCurrent(P_A, P_WPlus, P_ghAAnti, P_ghWm, 6452, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_Hl, P_HQMinus, 1114, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghZAnti, P_A, 5492, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_G0, P_HPlus, 10145, check)
      call createCurrent(P_tAnti, P_t, P_HhQ, 3368, check)
      call createCurrent(P_GQMinus, P_GPlus, P_Hl, P_HhQ, 8767, check)
      call createCurrent(P_HQPlus, P_HMinus, P_G0, P_GQ0, 5164, check)
      call createCurrent(P_GQ0, P_Hl, P_ghWpAnti, P_ghWp, 4284, check)
      call createCurrent(P_WQMinus, P_Z, P_ghZ, P_ghWmAnti, 8399, check)
      call createCurrent(P_GQMinus, P_WPlus, P_A, P_HhQ, 2078, check)
      call createCurrent(P_Z, P_muPlus, P_muMinus, 930, check)
      call createCurrent(P_b, P_Ha, P_bAnti, 6325, check)
      call createCurrent(P_A, P_Hh, P_WPlus, P_HMinus, 3789, check)
      call createCurrent(P_GPlus, P_A, P_Hh, P_WMinus, 200, check)
      call createCurrent(P_GMinus, P_GPlus, P_Hh, P_Hl, 730, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_Ha, P_HQMinus, 725, check)
      call createCurrent(P_ghZ, P_HPlus, P_Hh, P_ghWpAnti, 790, check)
      call createCurrent(P_G0, P_Hh, P_Hh, P_Ha, 7275, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_ghA, P_WPlus, 8801, check)
      call createCurrent(P_dAnti, P_d, P_G0, 8588, check)
      call createCurrent(P_Hh, P_HMinus, P_WPlus, P_A, 5473, check)
      call createCurrent(P_G0, P_cAnti, P_c, 7361, check)
      call createCurrent(P_G0, P_ghWp, P_ghZAnti, P_GMinus, 2488, check)
      call createCurrent(P_G0, P_ghA, P_ghWpAnti, P_GPlus, 8636, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Z, P_Z, 717, check)
      call createCurrent(P_HMinus, P_HPlus, P_ghA, P_ghAAnti, 5661, check)
      call createCurrent(P_ZQ, P_HPlus, P_Z, P_HQMinus, 2320, check)
      call createCurrent(P_ghWpAnti, P_Ha, P_ghA, P_GPlus, 10213, check)
      call createCurrent(P_WPlus, P_WPlus, P_ghWpAnti, P_ghWm, 6448, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_Z, P_WPlus, 8266, check)
      call createCurrent(P_HhQ, P_Hh, P_Hh, P_HhQ, 2621, check)
      call createCurrent(P_HPlus, P_Hl, P_ghWpAnti, P_ghA, 382, check)
      call createCurrent(P_WPlus, P_Hl, P_HMinus, 7217, check)
      call createCurrent(P_A, P_ghWp, P_ghWpAnti, P_Z, 400, check)
      call createCurrent(P_ghAAnti, P_ghA, P_WPlus, P_WQMinus, 8267, check)
      call createCurrent(P_Z, P_HPlus, P_WMinus, P_Hl, 2875, check)
      call createCurrent(P_WQPlus, P_Z, P_HMinus, P_HhQ, 3006, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_GPlus, P_Hh, 5431, check)
      call createCurrent(P_Hl, P_ghZAnti, P_Hh, P_ghZ, 10374, check)
      call createCurrent(P_nu_eAnti, P_nu_e, P_ZQ, 7497, check)
      call createCurrent(P_ghWm, P_HPlus, P_ghZAnti, P_HlQ, 7486, check)
      call createCurrent(P_WPlus, P_ghAAnti, P_ghWm, P_Z, 3225, check)
      call createCurrent(P_HPlus, P_ghZAnti, P_ghA, P_HMinus, 3600, check)
      call createCurrent(P_GQ0, P_GMinus, P_Hl, P_GQPlus, 2868, check)
      call createCurrent(P_Hl, P_Ha, P_G0, P_Hh, 2727, check)
      call createCurrent(P_Z, P_HPlus, P_GMinus, P_A, 9840, check)
      call createCurrent(P_Ha, P_WMinus, P_GPlus, P_Z, 9474, check)
      call createCurrent(P_G0, P_G0, P_A, P_A, 10499, check)
      call createCurrent(P_HPlus, P_Hl, P_ghZAnti, P_ghWm, 5625, check)
      call createCurrent(P_uAnti, P_d, P_WPlus, 305, check)
      call createCurrent(P_GMinus, P_WPlus, P_WMinus, P_GPlus, 7853, check)
      call createCurrent(P_AQ, P_sAnti, P_s, 7737, check)
      call createCurrent(P_Hh, P_ghAAnti, P_GPlus, P_ghWm, 322, check)
      call createCurrent(P_ghA, P_GPlus, P_ghWpAnti, P_Hh, 2768, check)
      call createCurrent(P_GQ0, P_A, P_GPlus, P_WQMinus, 7527, check)
      call createCurrent(P_G0, P_WMinus, P_WPlus, P_Ha, 9484, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghA, P_Hl, 4516, check)
      call createCurrent(P_WMinus, P_A, P_Hh, P_GPlus, 7112, check)
      call createCurrent(P_Ha, P_Z, P_Hh, 7264, check)
      call createCurrent(P_G0, P_g, P_g, P_Ha, 10653, check)
      call createCurrent(P_d, P_Z, P_dAnti, 3533, check)
      call createCurrent(P_GQPlus, P_Hl, P_GMinus, P_HlQ, 3364, check)
      call createCurrent(P_ghZ, P_ghAAnti, P_GMinus, P_HPlus, 8951, check)
      call createCurrent(P_HQPlus, P_Hh, P_Hh, P_GQMinus, 2377, check)
      call createCurrent(P_ghWmAnti, P_G0, P_ghZ, P_HMinus, 8914, check)
      call createCurrent(P_A, P_Z, P_HPlus, P_HMinus, 908, check)
      call createCurrent(P_Hl, P_Z, P_Z, P_Hl, 8512, check)
      call createCurrent(P_GQ0, P_GMinus, P_G0, P_HQPlus, 6109, check)
      call createCurrent(P_A, P_G0, P_Ha, P_A, 10700, check)
      call createCurrent(P_cAnti, P_s, P_HQPlus, 2763, check)
      call createCurrent(P_GQPlus, P_GMinus, P_G0, P_HlQ, 3044, check)
      call createCurrent(P_cAnti, P_c, P_Hl, 2397, check)
      call createCurrent(P_GPlus, P_GPlus, P_GMinus, P_GMinus, 2268, check)
      call createCurrent(P_GQPlus, P_Hh, P_Z, P_WQMinus, 5511, check)
      call createCurrent(P_HQMinus, P_u, P_dAnti, 2994, check)
      call createCurrent(P_ZQ, P_HMinus, P_Hh, P_WQPlus, 2858, check)
      call createCurrent(P_Hl, P_ghWmAnti, P_Hh, P_ghWm, 9210, check)
      call createCurrent(P_HQMinus, P_HPlus, P_ZQ, 2552, check)
      call createCurrent(P_GQPlus, P_Hl, P_WMinus, P_ZQ, 6478, check)
      call createCurrent(P_HlQ, P_Z, P_WMinus, P_GQPlus, 2219, check)
      call createCurrent(P_Z, P_ghWmAnti, P_WMinus, P_ghZ, 5167, check)
      call createCurrent(P_WQMinus, P_HPlus, P_Ha, P_AQ, 2168, check)
      call createCurrent(P_eMinus, P_HPlus, P_nu_eAnti, 1802, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_Hh, P_HQPlus, 587, check)
      call createCurrent(P_HaQ, P_HPlus, P_GMinus, P_GQ0, 4695, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_G0, P_GQMinus, 3292, check)
      call createCurrent(P_Hl, P_GMinus, P_ghZ, P_ghWmAnti, 3017, check)
      call createCurrent(P_GMinus, P_GPlus, P_HPlus, P_HMinus, 4710, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Z, P_AQ, 4576, check)
      call createCurrent(P_t, P_G0, P_tAnti, 8359, check)
      call createCurrent(P_g, P_Hl, P_g, 10665, check)
      call createCurrent(P_Ha, P_GPlus, P_Hh, P_HMinus, 5091, check)
      call createCurrent(P_WQPlus, P_WMinus, P_ghWmAnti, P_ghWm, 7500, check)
      call createCurrent(P_ghZ, P_Hl, P_ghWpAnti, P_GPlus, 7080, check)
      call createCurrent(P_ghWp, P_Hl, P_ghZAnti, P_GMinus, 2583, check)
      call createCurrent(P_HPlus, P_WMinus, P_Z, P_G0, 9576, check)
      call createCurrent(P_Hh, P_HMinus, P_GPlus, P_Hh, 75, check)
      call createCurrent(P_WMinus, P_Ha, P_GPlus, P_Z, 9734, check)
      call createCurrent(P_ghA, P_GPlus, P_GMinus, P_ghZAnti, 2129, check)
      call createCurrent(P_Ha, P_ghWmAnti, P_ghA, P_GMinus, 9928, check)
      call createCurrent(P_HPlus, P_g, P_g, P_HMinus, 10532, check)
      call createCurrent(P_AQ, P_WPlus, P_Ha, P_HQMinus, 3504, check)
      call createCurrent(P_HaQ, P_Ha, P_ghWp, P_ghWpAnti, 8595, check)
      call createCurrent(P_Hl, P_Hh, P_Ha, P_G0, 8639, check)
      call createCurrent(P_GQMinus, P_WPlus, P_WMinus, P_GQPlus, 8341, check)
      call createCurrent(P_HQMinus, P_Hh, P_Hl, P_HQPlus, 3557, check)
      call createCurrent(P_G0, P_GMinus, P_GPlus, 9467, check)
      call createCurrent(P_G0, P_ghWm, P_ghAAnti, P_GPlus, 6539, check)
      call createCurrent(P_HPlus, P_G0, P_G0, P_HMinus, 5973, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_Hh, P_ghA, 4667, check)
      call createCurrent(P_Ha, P_Z, P_Z, P_G0, 8868, check)
      call createCurrent(P_GQMinus, P_ghA, P_G0, P_ghWmAnti, 7522, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_HPlus, P_ghA, 10090, check)
      call createCurrent(P_ZQ, P_GPlus, P_A, P_GQMinus, 4797, check)
      call createCurrent(P_A, P_Hh, P_Ha, 9983, check)
      call createCurrent(P_GPlus, P_WMinus, P_Z, 5326, check)
      call createCurrent(P_HQMinus, P_ghWpAnti, P_HPlus, P_ghWp, 3937, check)
      call createCurrent(P_WPlus, P_HMinus, P_Z, P_Ha, 1049, check)
      call createCurrent(P_WPlus, P_A, P_Hh, P_GMinus, 6046, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_HPlus, P_Ha, 1461, check)
      call createCurrent(P_G0, P_ghZAnti, P_ghZ, P_Ha, 10338, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_ghWp, P_ZQ, 7117, check)
      call createCurrent(P_Hh, P_Hh, P_G0, P_Ha, 6107, check)
      call createCurrent(P_t, P_GMinus, P_bAnti, 8686, check)
      call createCurrent(P_HaQ, P_ghWpAnti, P_Ha, P_ghWp, 4208, check)
      call createCurrent(P_ghWp, P_Hh, P_HMinus, P_ghAAnti, 7890, check)
      call createCurrent(P_GMinus, P_Z, P_Z, P_GPlus, 414, check)
      call createCurrent(P_HPlus, P_ghZ, P_ghZAnti, P_HMinus, 6050, check)
      call createCurrent(P_HPlus, P_HMinus, P_ghZ, P_ghZAnti, 2481, check)
      call createCurrent(P_A, P_Ha, P_Ha, P_Z, 10243, check)
      call createCurrent(P_HlQ, P_HMinus, P_WQPlus, 6255, check)
      call createCurrent(P_G0, P_WPlus, P_WMinus, P_Ha, 9417, check)
      call createCurrent(P_G0, P_WPlus, P_A, P_GMinus, 5803, check)
      call createCurrent(P_Ha, P_ghAAnti, P_HMinus, P_ghWp, 6158, check)
      call createCurrent(P_GQMinus, P_Z, P_GQPlus, 6903, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_AQ, 258, check)
      call createCurrent(P_ghWp, P_Hl, P_ghZAnti, P_HMinus, 2645, check)
      call createCurrent(P_GQPlus, P_ghWpAnti, P_Hl, P_ghZ, 4532, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_GPlus, 4894, check)
      call createCurrent(P_HMinus, P_Z, P_WPlus, P_Hh, 3534, check)
      call createCurrent(P_GQMinus, P_ghWmAnti, P_Hh, P_ghZ, 5018, check)
      call createCurrent(P_WPlus, P_G0, P_HMinus, P_A, 9523, check)
      call createCurrent(P_AQ, P_Hh, P_WPlus, P_HQMinus, 329, check)
      call createCurrent(P_WPlus, P_Hl, P_GMinus, P_A, 3797, check)
      call createCurrent(P_WMinus, P_HPlus, P_Z, P_Hh, 2390, check)
      call createCurrent(P_WQMinus, P_Hl, P_HPlus, P_AQ, 7505, check)
      call createCurrent(P_G0, P_HPlus, P_HMinus, P_Hh, 9507, check)
      call createCurrent(P_G0, P_Ha, P_Ha, P_Ha, 8319, check)
      call createCurrent(P_HQMinus, P_Hl, P_WPlus, P_AQ, 4275, check)
      call createCurrent(P_HMinus, P_HPlus, P_G0, P_Hl, 8866, check)
      call createCurrent(P_GQPlus, P_GMinus, P_Hh, P_HaQ, 993, check)
      call createCurrent(P_Ha, P_G0, P_A, P_A, 10711, check)
      call createCurrent(P_gQ, P_g, P_ghGAnti, P_ghG, 5310, check)
      call createCurrent(P_G0, P_HMinus, P_HPlus, 9666, check)
      call createCurrent(P_GQ0, P_ghWm, P_Hl, P_ghWmAnti, 3433, check)
      call createCurrent(P_b, P_bAnti, P_G0, 5994, check)
      call createCurrent(P_Hl, P_ghZAnti, P_GPlus, P_ghWm, 5981, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_Hl, P_HMinus, 8628, check)
      call createCurrent(P_HlQ, P_ghWp, P_HMinus, P_ghZAnti, 1722, check)
      call createCurrent(P_Hl, P_HPlus, P_ghZAnti, P_ghWm, 3495, check)
      call createCurrent(P_Hh, P_Hh, P_Ha, P_G0, 8065, check)
      call createCurrent(P_HaQ, P_Ha, P_ghZ, P_ghZAnti, 508, check)
      call createCurrent(P_Hl, P_ghWmAnti, P_ghZ, P_GMinus, 865, check)
      call createCurrent(P_WPlus, P_Z, P_Z, P_WMinus, 5182, check)
      call createCurrent(P_A, P_GPlus, P_GMinus, P_Z, 1804, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_GMinus, P_HhQ, 1253, check)
      call createCurrent(P_HQMinus, P_Hl, P_GPlus, P_GQ0, 5346, check)
      call createCurrent(P_GQMinus, P_G0, P_ghZAnti, P_ghWp, 7257, check)
      call createCurrent(P_GQPlus, P_Hh, P_ghWpAnti, P_ghA, 7385, check)
      call createCurrent(P_HlQ, P_Hl, P_HMinus, P_GQPlus, 3086, check)
      call createCurrent(P_G0, P_muMinus, P_muPlus, 6145, check)
      call createCurrent(P_A, P_A, P_HMinus, P_HPlus, 6092, check)
      call createCurrent(P_HMinus, P_ghZ, P_ghWmAnti, P_Hh, 3901, check)
      call createCurrent(P_Z, P_ghWm, P_ghAAnti, P_WPlus, 5698, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_Hl, P_GQMinus, 2330, check)
      call createCurrent(P_WMinus, P_WPlus, P_A, P_Z, 1560, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_GPlus, P_G0, 31, check)
      call createCurrent(P_HQMinus, P_ghWp, P_Hl, P_ghZAnti, 4790, check)
      call createCurrent(P_WMinus, P_WPlus, P_HMinus, P_HPlus, 4564, check)
      call createCurrent(P_Hh, P_ghAAnti, P_ghWm, P_GPlus, 6579, check)
      call createCurrent(P_ghZ, P_WPlus, P_A, P_ghWpAnti, 4622, check)
      call createCurrent(P_Ha, P_Hh, P_Ha, 7388, check)
      call createCurrent(P_WPlus, P_Z, P_HMinus, P_Ha, 8770, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghZ, P_A, 8645, check)
      call createCurrent(P_HMinus, P_HPlus, P_HMinus, P_GPlus, 2382, check)
      call createCurrent(P_ghA, P_HMinus, P_ghWmAnti, P_Hl, 2885, check)
      call createCurrent(P_GQ0, P_HPlus, P_GMinus, P_HaQ, 6947, check)
      call createCurrent(P_GQ0, P_Ha, P_HMinus, P_HQPlus, 4947, check)
      call createCurrent(P_HPlus, P_Ha, P_HMinus, P_Hh, 9277, check)
      call createCurrent(P_AQ, P_muMinus, P_muPlus, 1865, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_GPlus, P_HMinus, 8908, check)
      call createCurrent(P_GQ0, P_cAnti, P_c, 5098, check)
      call createCurrent(P_ghWpAnti, P_Ha, P_G0, P_ghWp, 9025, check)
      call createCurrent(P_AQ, P_GPlus, P_Hh, P_WQMinus, 8287, check)
      call createCurrent(P_GQPlus, P_G0, P_HMinus, P_HlQ, 6563, check)
      call createCurrent(P_Z, P_GPlus, P_Z, P_HMinus, 9945, check)
      call createCurrent(P_HhQ, P_Hh, P_G0, P_HaQ, 1076, check)
      call createCurrent(P_GQMinus, P_Hh, P_Z, P_WQPlus, 2737, check)
      call createCurrent(P_HMinus, P_A, P_Hl, P_WPlus, 4318, check)
      call createCurrent(P_WMinus, P_ghZAnti, P_ghA, P_WPlus, 2853, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_Hl, P_GQMinus, 1257, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Hh, P_Hh, 767, check)
      call createCurrent(P_Ha, P_G0, P_G0, P_Ha, 8651, check)
      call createCurrent(P_uAnti, P_u, P_gQ, 4067, check)
      call createCurrent(P_HPlus, P_Hl, P_HMinus, P_Hl, 7262, check)
      call createCurrent(P_G0, P_HMinus, P_ghAAnti, P_ghWp, 10266, check)
      call createCurrent(P_HPlus, P_Z, P_HMinus, P_Z, 6739, check)
      call createCurrent(P_HlQ, P_HPlus, P_GMinus, P_HaQ, 3191, check)
      call createCurrent(P_GMinus, P_Z, P_GPlus, 94, check)
      call createCurrent(P_GQPlus, P_ghZ, P_G0, P_ghWpAnti, 873, check)
      call createCurrent(P_HQMinus, P_HPlus, P_ghZ, P_ghZAnti, 2432, check)
      call createCurrent(P_muPlus, P_muMinus, P_AQ, 1997, check)
      call createCurrent(P_AQ, P_WMinus, P_Ha, P_HQPlus, 4161, check)
      call createCurrent(P_HQPlus, P_HMinus, P_Z, P_ZQ, 8167, check)
      call createCurrent(P_Hh, P_Z, P_Hl, P_A, 10643, check)
      call createCurrent(P_HQMinus, P_WPlus, P_HhQ, 5244, check)
      call createCurrent(P_Hl, P_Hl, P_ghWp, P_ghWpAnti, 4825, check)
      call createCurrent(P_bAnti, P_t, P_HMinus, 5999, check)
      call createCurrent(P_ghZ, P_G0, P_ghWmAnti, P_HMinus, 9783, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_G0, P_HPlus, 8949, check)
      call createCurrent(P_GQMinus, P_GPlus, P_A, P_AQ, 8462, check)
      call createCurrent(P_HlQ, P_GMinus, P_Ha, P_HQPlus, 3473, check)
      call createCurrent(P_WMinus, P_Hl, P_Hl, P_WPlus, 8064, check)
      call createCurrent(P_ePlus, P_WMinus, P_nu_e, 8742, check)
      call createCurrent(P_t, P_tAnti, P_AQ, 5621, check)
      call createCurrent(P_g, P_HPlus, P_g, P_HMinus, 10626, check)
      call createCurrent(P_Z, P_Hh, P_GMinus, P_WPlus, 6852, check)
      call createCurrent(P_ghZAnti, P_Ha, P_ghWm, P_HPlus, 3028, check)
      call createCurrent(P_WQMinus, P_Ha, P_HPlus, P_AQ, 1488, check)
      call createCurrent(P_ghAAnti, P_HMinus, P_ghA, P_HQPlus, 6792, check)
      call createCurrent(P_HMinus, P_ghWp, P_ghAAnti, P_G0, 9088, check)
      call createCurrent(P_ghZ, P_HPlus, P_ghZAnti, P_HMinus, 3702, check)
      call createCurrent(P_A, P_WMinus, P_WPlus, P_A, 3104, check)
      call createCurrent(P_Hl, P_Hh, P_GMinus, P_HPlus, 1442, check)
      call createCurrent(P_GPlus, P_GMinus, P_GMinus, P_GPlus, 5325, check)
      call createCurrent(P_Z, P_GMinus, P_WPlus, P_Ha, 9962, check)
      call createCurrent(P_GMinus, P_HPlus, P_ghAAnti, P_ghA, 8844, check)
      call createCurrent(P_HhQ, P_GMinus, P_Hl, P_HQPlus, 3773, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_Hh, P_GPlus, 417, check)
      call createCurrent(P_HQMinus, P_nu_e, P_ePlus, 5971, check)
      call createCurrent(P_HPlus, P_ghWm, P_ghWmAnti, P_HMinus, 8728, check)
      call createCurrent(P_GPlus, P_Hl, P_HMinus, P_Hl, 1304, check)
      call createCurrent(P_A, P_Z, P_Hl, P_Hh, 10581, check)
      call createCurrent(P_Hh, P_ghWp, P_HMinus, P_ghAAnti, 2548, check)
      call createCurrent(P_GQMinus, P_GPlus, P_ghZAnti, P_ghZ, 3101, check)
      call createCurrent(P_GQ0, P_WPlus, P_G0, P_WQMinus, 2716, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_HMinus, P_HPlus, 668, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_HMinus, P_HaQ, 1052, check)
      call createCurrent(P_WPlus, P_ghZ, P_ghWpAnti, P_Z, 6375, check)
      call createCurrent(P_WQPlus, P_WMinus, P_ZQ, 871, check)
      call createCurrent(P_GPlus, P_GMinus, 10163, check)
      call createCurrent(P_ghWm, P_Z, P_ghAAnti, P_WPlus, 7218, check)
      call createCurrent(P_c, P_g, P_cAnti, 4756, check)
      call createCurrent(P_GPlus, P_HMinus, P_Hh, P_Hl, 6611, check)
      call createCurrent(P_Ha, P_WPlus, P_HMinus, P_Z, 5634, check)
      call createCurrent(P_HhQ, P_GMinus, P_Ha, P_HQPlus, 5616, check)
      call createCurrent(P_GQPlus, P_GMinus, P_ghA, P_ghAAnti, 5249, check)
      call createCurrent(P_GQPlus, P_HPlus, P_GMinus, P_GQMinus, 4771, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_Ha, P_ghZ, 9806, check)
      call createCurrent(P_Hl, P_Hl, P_Hl, 2186, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Hh, P_GQ0, 785, check)
      call createCurrent(P_ghAAnti, P_HPlus, P_ghWm, P_Hh, 3602, check)
      call createCurrent(P_GMinus, P_Hh, P_ghWp, P_ghAAnti, 4807, check)
      call createCurrent(P_GPlus, P_Hl, P_HMinus, P_Ha, 2746, check)
      call createCurrent(P_G0, P_ghWm, P_HPlus, P_ghAAnti, 10096, check)
      call createCurrent(P_u, P_Ha, P_uAnti, 4550, check)
      call createCurrent(P_ghZAnti, P_ghA, P_HMinus, P_GPlus, 10040, check)
      call createCurrent(P_HPlus, P_WMinus, P_Z, 4802, check)
      call createCurrent(P_HMinus, P_HPlus, P_ghZAnti, P_ghZ, 5607, check)
      call createCurrent(P_Hl, P_HMinus, P_ghWmAnti, P_ghA, 6560, check)
      call createCurrent(P_GPlus, P_G0, P_WMinus, P_A, 8124, check)
      call createCurrent(P_HPlus, P_ghAAnti, P_Hh, P_ghWm, 3885, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_Z, P_ghWm, 6596, check)
      call createCurrent(P_HaQ, P_HMinus, P_GQPlus, 8575, check)
      call createCurrent(P_cAnti, P_c, P_ZQ, 4388, check)
      call createCurrent(P_GPlus, P_ghWm, P_ghWmAnti, P_GMinus, 3865, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_HMinus, P_G0, 9073, check)
      call createCurrent(P_Hl, P_HMinus, P_GPlus, 2319, check)
      call createCurrent(P_Hl, P_WPlus, P_HMinus, P_A, 281, check)
      call createCurrent(P_ghA, P_HMinus, P_ghAAnti, P_GPlus, 9992, check)
      call createCurrent(P_Z, P_ghA, P_ghWpAnti, P_WPlus, 3294, check)
      call createCurrent(P_ghZ, P_WPlus, P_ghWpAnti, 969, check)
      call createCurrent(P_WQPlus, P_ghWpAnti, P_WPlus, P_ghWm, 5614, check)
      call createCurrent(P_HQPlus, P_tAnti, P_b, 8119, check)
      call createCurrent(P_ghWmAnti, P_ghWp, P_WMinus, P_WMinus, 4889, check)
      call createCurrent(P_ghWm, P_Hl, P_Hh, P_ghWmAnti, 9972, check)
      call createCurrent(P_sAnti, P_s, P_g, 7610, check)
      call createCurrent(P_HPlus, P_Hh, P_GMinus, P_Hh, 5405, check)
      call createCurrent(P_GMinus, P_dAnti, P_u, 7195, check)
      call createCurrent(P_AQ, P_ghWp, P_ghWpAnti, 6914, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_Hl, P_HPlus, 3181, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_WMinus, P_A, 5594, check)
      call createCurrent(P_GMinus, P_HPlus, P_HPlus, P_GMinus, 1568, check)
      call createCurrent(P_GMinus, P_Hl, P_GPlus, P_Ha, 9346, check)
      call createCurrent(P_HPlus, P_HMinus, P_Hh, P_Hl, 988, check)
      call createCurrent(P_G0, P_G0, P_Hh, P_Hl, 7199, check)
      call createCurrent(P_ghWpAnti, P_Hl, P_ghZ, P_HPlus, 2606, check)
      call createCurrent(P_HQPlus, P_Hh, P_HMinus, P_HlQ, 55, check)
      call createCurrent(P_s, P_sAnti, P_ZQ, 3830, check)
      call createCurrent(P_ghWm, P_HPlus, P_GMinus, P_ghWmAnti, 9634, check)
      call createCurrent(P_WQMinus, P_WPlus, P_Ha, P_HlQ, 6506, check)
      call createCurrent(P_Hh, P_ghWmAnti, P_GMinus, P_ghZ, 2248, check)
      call createCurrent(P_HMinus, P_Ha, P_Hl, P_HPlus, 9138, check)
      call createCurrent(P_GPlus, P_Hh, P_Ha, P_HMinus, 4490, check)
      call createCurrent(P_ghWm, P_Z, P_ghWmAnti, P_AQ, 1352, check)
      call createCurrent(P_Z, P_Z, P_Hh, 1928, check)
      call createCurrent(P_Z, P_WPlus, P_Ha, P_HMinus, 1848, check)
      call createCurrent(P_ghWmAnti, P_HMinus, P_ghZ, 6520, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_GMinus, P_GPlus, 8111, check)
      call createCurrent(P_AQ, P_ghWp, P_WMinus, P_ghAAnti, 8451, check)
      call createCurrent(P_Hl, P_Hl, P_Hh, P_Hl, 7674, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_Z, P_WQMinus, 2189, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_GPlus, P_ghWm, 1667, check)
      call createCurrent(P_eMinus, P_nu_eAnti, P_HPlus, 260, check)
      call createCurrent(P_Ha, P_ghZ, P_HPlus, P_ghWpAnti, 4980, check)
      call createCurrent(P_ghWp, P_G0, P_ghAAnti, P_HMinus, 9556, check)
      call createCurrent(P_ghZ, P_HMinus, P_ghZAnti, P_GPlus, 9778, check)
      call createCurrent(P_GMinus, P_Z, P_Ha, P_WPlus, 9004, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Hh, P_HaQ, 1485, check)
      call createCurrent(P_HPlus, P_Z, P_G0, P_WMinus, 10023, check)
      call createCurrent(P_Hl, P_HPlus, P_HMinus, 6342, check)
      call createCurrent(P_ghZ, P_Hl, P_ghWpAnti, P_HPlus, 7718, check)
      call createCurrent(P_HQPlus, P_HMinus, P_WPlus, P_WQMinus, 3611, check)
      call createCurrent(P_WMinus, P_GMinus, P_WPlus, P_GPlus, 153, check)
      call createCurrent(P_GQPlus, P_GMinus, P_HMinus, P_GQPlus, 4166, check)
      call createCurrent(P_ghZAnti, P_Hh, P_ghWm, P_GPlus, 3476, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Hh, 3636, check)
      call createCurrent(P_WPlus, P_Z, P_Ha, P_HMinus, 3685, check)
      call createCurrent(P_muMinus, P_muPlus, P_Z, 82, check)
      call createCurrent(P_G0, P_ghWp, P_ghAAnti, P_GMinus, 2326, check)
      call createCurrent(P_s, P_Hl, P_sAnti, 3146, check)
      call createCurrent(P_cAnti, P_s, P_GQPlus, 6545, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_Hh, P_GMinus, 6302, check)
      call createCurrent(P_ghA, P_ghZAnti, P_GMinus, P_GQPlus, 5510, check)
      call createCurrent(P_b, P_bAnti, P_Z, 2474, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_G0, P_GQ0, 4105, check)
      call createCurrent(P_Hl, P_Hl, P_GMinus, P_HPlus, 8002, check)
      call createCurrent(P_Hl, P_Ha, P_Ha, P_Hh, 2134, check)
      call createCurrent(P_HQPlus, P_Hl, P_GMinus, P_HhQ, 7984, check)
      call createCurrent(P_cAnti, P_HPlus, P_s, 4833, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_ghA, P_HMinus, 8954, check)
      call createCurrent(P_Hl, P_WPlus, P_A, P_HMinus, 2898, check)
      call createCurrent(P_GPlus, P_HMinus, P_HMinus, P_GPlus, 4673, check)
      call createCurrent(P_Hl, P_HPlus, P_GMinus, 377, check)
      call createCurrent(P_G0, P_GPlus, P_HMinus, 3293, check)
      call createCurrent(P_G0, P_ghWp, P_GMinus, P_ghAAnti, 3396, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghAAnti, 5649, check)
      call createCurrent(P_c, P_Z, P_cAnti, 5261, check)
      call createCurrent(P_GMinus, P_ghZ, P_ghAAnti, P_GPlus, 6170, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_Ha, P_ghZ, 10161, check)
      call createCurrent(P_ghAAnti, P_ghZ, P_HPlus, P_HQMinus, 370, check)
      call createCurrent(P_ghWmAnti, P_Ha, P_ghZ, P_HMinus, 4982, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_G0, P_GQMinus, 6455, check)
      call createCurrent(P_GPlus, P_GMinus, P_ghZ, P_ghAAnti, 2199, check)
      call createCurrent(P_WPlus, P_WMinus, P_ghZAnti, P_ghA, 8671, check)
      call createCurrent(P_Hl, P_WMinus, P_HPlus, P_A, 2863, check)
      call createCurrent(P_WMinus, P_Hl, P_WPlus, 4944, check)
      call createCurrent(P_GQ0, P_GMinus, P_GPlus, P_HaQ, 1869, check)
      call createCurrent(P_ghZAnti, P_Hl, P_ghWm, P_GPlus, 4363, check)
      call createCurrent(P_Hl, P_GPlus, P_HMinus, 3498, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_Hh, P_ghZ, 2751, check)
      call createCurrent(P_WPlus, P_ghWm, P_ghZAnti, P_A, 6017, check)
      call createCurrent(P_GQMinus, P_muPlus, P_nu_mu, 2079, check)
      call createCurrent(P_AQ, P_Ha, P_WMinus, P_HQPlus, 7327, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_Ha, P_HMinus, 6929, check)
      call createCurrent(P_HQPlus, P_GPlus, P_GMinus, P_GQMinus, 6716, check)
      call createCurrent(P_Hl, P_eMinus, P_ePlus, 4183, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghWp, P_WMinus, 4524, check)
      call createCurrent(P_HlQ, P_Hh, P_Hl, P_HhQ, 4942, check)
      call createCurrent(P_HlQ, P_GPlus, P_Ha, P_GQMinus, 5228, check)
      call createCurrent(P_Hh, P_tauMinus, P_tauPlus, 3047, check)
      call createCurrent(P_GQPlus, P_GMinus, P_HPlus, P_GQMinus, 706, check)
      call createCurrent(P_Z, P_Ha, P_Hl, 5690, check)
      call createCurrent(P_Z, P_GPlus, P_WMinus, 5499, check)
      call createCurrent(P_WPlus, P_GMinus, P_G0, P_A, 8410, check)
      call createCurrent(P_AQ, P_HPlus, P_WQMinus, 7176, check)
      call createCurrent(P_Hl, P_WMinus, P_GPlus, P_A, 3729, check)
      call createCurrent(P_HlQ, P_HMinus, P_G0, P_GQPlus, 6474, check)
      call createCurrent(P_A, P_ghWpAnti, P_ghZ, P_WPlus, 900, check)
      call createCurrent(P_g, P_g, P_HPlus, P_GMinus, 10668, check)
      call createCurrent(P_ghAAnti, P_Hl, P_HPlus, P_ghWm, 1258, check)
      call createCurrent(P_WPlus, P_HMinus, P_Hh, 3896, check)
      call createCurrent(P_ghWp, P_Hl, P_ghWpAnti, P_HaQ, 7091, check)
      call createCurrent(P_Ha, P_Ha, P_Hl, 4775, check)
      call createCurrent(P_HMinus, P_ghWmAnti, P_ghA, P_Ha, 1153, check)
      call createCurrent(P_HaQ, P_HPlus, P_WQMinus, 5536, check)
      call createCurrent(P_WMinus, P_g, P_g, P_WPlus, 10648, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_Hh, P_ghZ, 3199, check)
      call createCurrent(P_tAnti, P_t, P_HlQ, 722, check)
      call createCurrent(P_Z, P_WMinus, P_ghWmAnti, P_ghZ, 3070, check)
      call createCurrent(P_sAnti, P_s, P_AQ, 3233, check)
      call createCurrent(P_HPlus, P_HMinus, P_Z, 6035, check)
      call createCurrent(P_Z, P_HPlus, P_HMinus, P_Z, 4706, check)
      call createCurrent(P_G0, P_A, P_HPlus, P_WMinus, 9265, check)
      call createCurrent(P_GMinus, P_Hh, P_HPlus, P_Hl, 3351, check)
      call createCurrent(P_ghWp, P_A, P_ghZAnti, P_WMinus, 6432, check)
      call createCurrent(P_GQ0, P_G0, P_GMinus, P_HQPlus, 3558, check)
      call createCurrent(P_GPlus, P_ghWmAnti, P_ghWm, P_HMinus, 9571, check)
      call createCurrent(P_Hl, P_A, P_Hl, P_Z, 9377, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_G0, P_G0, 5682, check)
      call createCurrent(P_GPlus, P_GMinus, P_Hh, 8477, check)
      call createCurrent(P_Hh, P_HMinus, P_ghWmAnti, P_ghZ, 7762, check)
      call createCurrent(P_A, P_Hh, P_HMinus, P_WPlus, 8638, check)
      call createCurrent(P_HaQ, P_Hl, P_ghWpAnti, P_ghWp, 543, check)
      call createCurrent(P_Z, P_HMinus, P_Z, P_HPlus, 2730, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_Hl, 3132, check)
      call createCurrent(P_ZQ, P_Ha, P_WMinus, P_HQPlus, 228, check)
      call createCurrent(P_HMinus, P_ghA, P_ghWmAnti, P_Hh, 565, check)
      call createCurrent(P_ghWmAnti, P_HMinus, P_ghA, P_Ha, 2266, check)
      call createCurrent(P_nu_e, P_ePlus, P_GQMinus, 7789, check)
      call createCurrent(P_G0, P_GPlus, P_ghWpAnti, P_ghA, 4514, check)
      call createCurrent(P_Z, P_A, P_A, P_Z, 10555, check)
      call createCurrent(P_Ha, P_Hl, P_Hl, P_Hl, 10505, check)
      call createCurrent(P_HMinus, P_HPlus, P_ghAAnti, P_ghZ, 6404, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_HPlus, P_HaQ, 4538, check)
      call createCurrent(P_G0, P_GPlus, P_GMinus, P_G0, 3834, check)
      call createCurrent(P_WMinus, P_A, P_HPlus, P_Hl, 3041, check)
      call createCurrent(P_HQPlus, P_Z, P_HMinus, P_ZQ, 5524, check)
      call createCurrent(P_Ha, P_A, P_HPlus, P_WMinus, 6898, check)
      call createCurrent(P_Ha, P_Hl, P_HMinus, P_HPlus, 9229, check)
      call createCurrent(P_A, P_GMinus, P_HPlus, P_Z, 8972, check)
      call createCurrent(P_HQPlus, P_HMinus, P_HMinus, P_HQPlus, 5036, check)
      call createCurrent(P_ghA, P_HPlus, P_ghAAnti, P_HQMinus, 7997, check)
      call createCurrent(P_ghWmAnti, P_Hh, P_ghZ, P_GMinus, 108, check)
      call createCurrent(P_GMinus, P_G0, P_ghZAnti, P_ghWp, 7883, check)
      call createCurrent(P_G0, P_WMinus, P_GPlus, 8613, check)
      call createCurrent(P_HPlus, P_Hh, P_HMinus, P_Hh, 8329, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_G0, P_GQMinus, 4761, check)
      call createCurrent(P_HlQ, P_HMinus, P_ghWp, P_ghAAnti, 4940, check)
      call createCurrent(P_HMinus, P_WPlus, P_G0, 10214, check)
      call createCurrent(P_WQMinus, P_WPlus, P_G0, P_HlQ, 4855, check)
      call createCurrent(P_WMinus, P_WPlus, P_Z, P_A, 3617, check)
      call createCurrent(P_G0, P_Z, 9441, check)
      call createCurrent(P_ghZ, P_HPlus, P_Ha, P_ghWpAnti, 8609, check)
      call createCurrent(P_A, P_G0, P_GPlus, P_WMinus, 5194, check)
      call createCurrent(P_GQMinus, P_HPlus, P_Hh, P_HlQ, 2788, check)
      call createCurrent(P_bAnti, P_b, 9678, check)
      call createCurrent(P_G0, P_HPlus, P_Hh, P_HMinus, 10486, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_ghA, P_WQMinus, 264, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_Z, P_ghA, 2365, check)
      call createCurrent(P_GQ0, P_GMinus, P_HPlus, P_HaQ, 3578, check)
      call createCurrent(P_Z, P_Ha, P_A, P_G0, 10754, check)
      call createCurrent(P_GQ0, P_G0, P_HhQ, 2757, check)
      call createCurrent(P_WMinus, P_A, P_ghWp, P_ghAAnti, 866, check)
      call createCurrent(P_nu_tauAnti, P_tauMinus, P_WQPlus, 2989, check)
      call createCurrent(P_HMinus, P_ghZ, P_GPlus, P_ghZAnti, 9773, check)
      call createCurrent(P_GQMinus, P_WPlus, P_G0, P_ZQ, 6081, check)
      call createCurrent(P_ghAAnti, P_Hh, P_ghWm, P_GPlus, 8373, check)
      call createCurrent(P_GQMinus, P_HPlus, P_Ha, P_HhQ, 6298, check)
      call createCurrent(P_ghWp, P_WPlus, P_ghWpAnti, P_WMinus, 3701, check)
      call createCurrent(P_WPlus, P_HMinus, P_Ha, P_Z, 1717, check)
      call createCurrent(P_HQPlus, P_Hh, P_GMinus, P_HhQ, 1946, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_Z, P_WMinus, 5939, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_HPlus, P_GMinus, 10100, check)
      call createCurrent(P_GPlus, P_GMinus, P_G0, P_Hl, 9014, check)
      call createCurrent(P_HlQ, P_GPlus, P_Ha, P_HQMinus, 7461, check)
      call createCurrent(P_HMinus, P_g, P_g, P_GPlus, 10594, check)
      call createCurrent(P_Hl, P_GPlus, P_WMinus, P_A, 5592, check)
      call createCurrent(P_ZQ, P_WPlus, P_ghWm, P_ghAAnti, 173, check)
      call createCurrent(P_A, P_ghWp, P_A, P_ghWpAnti, 7359, check)
      call createCurrent(P_ZQ, P_nu_eAnti, P_nu_e, 7999, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_G0, P_HMinus, 9901, check)
      call createCurrent(P_WMinus, P_A, P_Hl, P_HPlus, 3678, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Z, P_A, 671, check)
      call createCurrent(P_Hl, P_ghA, P_HMinus, P_ghWmAnti, 1926, check)
      call createCurrent(P_HPlus, P_ghWm, P_Hl, P_ghZAnti, 4424, check)
      call createCurrent(P_WQMinus, P_GPlus, P_Z, P_HhQ, 2920, check)
      call createCurrent(P_GMinus, P_Hh, P_Ha, P_GPlus, 9129, check)
      call createCurrent(P_ghWpAnti, P_Hl, P_ghWp, 5193, check)
      call createCurrent(P_GPlus, P_ghAAnti, P_ghA, P_HMinus, 9707, check)
      call createCurrent(P_ZQ, P_Hl, P_GMinus, P_WQPlus, 3031, check)
      call createCurrent(P_HMinus, P_Ha, P_G0, P_HPlus, 5773, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_Hl, P_Hl, 7171, check)
      call createCurrent(P_WMinus, P_ghAAnti, P_A, P_ghWp, 3409, check)
      call createCurrent(P_Ha, P_ghZAnti, P_ghZ, P_Ha, 6700, check)
      call createCurrent(P_nu_e, P_ePlus, P_HQMinus, 5006, check)
      call createCurrent(P_WQPlus, P_Hh, P_HQMinus, 6496, check)
      call createCurrent(P_ghWmAnti, P_Hh, P_Hl, P_ghWm, 9718, check)
      call createCurrent(P_GPlus, P_WMinus, P_Ha, 9632, check)
      call createCurrent(P_b, P_bAnti, P_GQ0, 7969, check)
      call createCurrent(P_Z, P_ghWm, P_WPlus, P_ghAAnti, 6896, check)
      call createCurrent(P_A, P_Z, P_GMinus, P_GPlus, 1507, check)
      call createCurrent(P_WPlus, P_A, P_GMinus, P_Ha, 9665, check)
      call createCurrent(P_GMinus, P_ghZ, P_ghWmAnti, 3805, check)
      call createCurrent(P_d, P_dAnti, P_HaQ, 6665, check)
      call createCurrent(P_GQPlus, P_GMinus, P_A, P_AQ, 5772, check)
      call createCurrent(P_Hl, P_GPlus, P_Hl, P_HMinus, 8447, check)
      call createCurrent(P_ghZAnti, P_HMinus, P_G0, P_ghWp, 10061, check)
      call createCurrent(P_Ha, P_HPlus, P_HMinus, P_Hh, 10326, check)
      call createCurrent(P_GQPlus, P_Hh, P_G0, P_HQMinus, 682, check)
      call createCurrent(P_Ha, P_HMinus, P_Z, P_WPlus, 2593, check)
      call createCurrent(P_HQPlus, P_tauMinus, P_nu_tauAnti, 5443, check)
      call createCurrent(P_HPlus, P_HMinus, P_WPlus, P_WMinus, 2197, check)
      call createCurrent(P_HPlus, P_HMinus, P_ghZAnti, P_ghA, 4560, check)
      call createCurrent(P_ghWp, P_Ha, P_ghWpAnti, P_HhQ, 4450, check)
      call createCurrent(P_GQ0, P_GPlus, P_GMinus, P_GQ0, 187, check)
      call createCurrent(P_HaQ, P_WPlus, P_Hl, P_WQMinus, 3365, check)
      call createCurrent(P_WPlus, P_WMinus, P_HPlus, P_HMinus, 2661, check)
      call createCurrent(P_WQMinus, P_WPlus, P_G0, P_HhQ, 4346, check)
      call createCurrent(P_HaQ, P_GPlus, P_HMinus, P_HhQ, 7006, check)
      call createCurrent(P_nu_e, P_ePlus, P_GMinus, 2823, check)
      call createCurrent(P_HhQ, P_G0, P_ZQ, 8788, check)
      call createCurrent(P_HhQ, P_HMinus, P_HPlus, P_HlQ, 3754, check)
      call createCurrent(P_Ha, P_GPlus, P_ghWm, P_ghAAnti, 9984, check)
      call createCurrent(P_A, P_GMinus, P_Ha, P_WPlus, 9952, check)
      call createCurrent(P_WQPlus, P_ghWm, P_WMinus, P_ghWmAnti, 312, check)
      call createCurrent(P_sAnti, P_Ha, P_s, 2943, check)
      call createCurrent(P_Hl, P_HMinus, P_WPlus, 6179, check)
      call createCurrent(P_Ha, P_HMinus, P_ghWmAnti, P_ghA, 3053, check)
      call createCurrent(P_ghWpAnti, P_HPlus, P_Hh, P_ghZ, 4972, check)
      call createCurrent(P_g, P_g, P_Ha, P_Ha, 10708, check)
      call createCurrent(P_g, P_Z, P_A, P_g, 10530, check)
      call createCurrent(P_ghWp, P_Hh, P_ghZAnti, P_GMinus, 6015, check)
      call createCurrent(P_GMinus, P_ghWp, P_Ha, P_ghZAnti, 8883, check)
      call createCurrent(P_tauPlus, P_nu_tau, P_GMinus, 3475, check)
      call createCurrent(P_Hh, P_HPlus, P_ghWm, P_ghAAnti, 1816, check)
      call createCurrent(P_b, P_g, P_bAnti, 7363, check)
      call createCurrent(P_HPlus, P_Hl, P_Hh, P_GMinus, 5964, check)
      call createCurrent(P_ghA, P_GPlus, P_Hh, P_ghWpAnti, 5659, check)
      call createCurrent(P_WQMinus, P_Z, P_WPlus, P_AQ, 1824, check)
      call createCurrent(P_HPlus, P_ghWpAnti, P_ghA, P_Hh, 3152, check)
      call createCurrent(P_ghG, P_g, P_ghGAnti, P_gQ, 236, check)
      call createCurrent(P_ePlus, P_G0, P_eMinus, 5728, check)
      call createCurrent(P_HPlus, P_HMinus, P_G0, P_Hl, 8976, check)
      call createCurrent(P_Ha, P_ghAAnti, P_GPlus, P_ghWm, 10422, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_ghWp, P_Hh, 3065, check)
      call createCurrent(P_WMinus, P_WPlus, P_Hh, 2125, check)
      call createCurrent(P_GQPlus, P_GMinus, P_Hh, P_GQ0, 3130, check)
      call createCurrent(P_GQMinus, P_GPlus, P_Hl, P_HlQ, 4945, check)
      call createCurrent(P_ZQ, P_WMinus, P_Hh, P_HQPlus, 4104, check)
      call createCurrent(P_g, P_Hh, P_Hl, P_g, 10543, check)
      call createCurrent(P_G0, P_GMinus, P_HPlus, 1146, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghZ, P_Hh, 443, check)
      call createCurrent(P_G0, P_HPlus, P_ghWpAnti, P_ghA, 10379, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_Ha, P_ghWm, 8872, check)
      call createCurrent(P_HMinus, P_G0, P_GPlus, P_Hl, 5183, check)
      call createCurrent(P_HQMinus, P_WPlus, P_AQ, 5784, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Hh, P_Hl, 10359, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghAAnti, P_Hl, 7714, check)
      call createCurrent(P_Hl, P_g, P_g, P_Hl, 10537, check)
      call createCurrent(P_ghWpAnti, P_HPlus, P_Ha, P_ghZ, 2669, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_HMinus, P_G0, 9206, check)
      call createCurrent(P_ZQ, P_WPlus, P_WQMinus, 209, check)
      call createCurrent(P_WPlus, P_WMinus, P_HMinus, P_HPlus, 7545, check)
      call createCurrent(P_WQPlus, P_uAnti, P_d, 4211, check)
      call createCurrent(P_A, P_Hh, P_Hl, P_Z, 10500, check)
      call createCurrent(P_WPlus, P_Z, P_ghWm, P_ghAAnti, 881, check)
      call createCurrent(P_HQPlus, P_ghA, P_Ha, P_ghWpAnti, 8041, check)
      call createCurrent(P_GQMinus, P_HPlus, P_Hh, P_HhQ, 3791, check)
      call createCurrent(P_G0, P_Hl, P_HMinus, P_GPlus, 2971, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_G0, P_GQ0, 1233, check)
      call createCurrent(P_GQMinus, P_GPlus, P_ghWpAnti, P_ghWp, 8122, check)
      call createCurrent(P_HaQ, P_Hl, P_Hl, P_GQ0, 7627, check)
      call createCurrent(P_Z, P_WMinus, P_Ha, P_HPlus, 8325, check)
      call createCurrent(P_WMinus, P_GPlus, P_Ha, P_Z, 9107, check)
      call createCurrent(P_ZQ, P_ghAAnti, P_WMinus, P_ghWp, 7514, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_WPlus, P_WQMinus, 2753, check)
      call createCurrent(P_AQ, P_WPlus, P_GQMinus, 5883, check)
      call createCurrent(P_WMinus, P_ghWpAnti, P_WPlus, P_ghWp, 3195, check)
      call createCurrent(P_WPlus, P_HMinus, P_G0, 9404, check)
      call createCurrent(P_GMinus, P_g, P_GPlus, P_g, 10762, check)
      call createCurrent(P_GQPlus, P_GMinus, P_ghZ, P_ghAAnti, 3208, check)
      call createCurrent(P_HaQ, P_b, P_bAnti, 7152, check)
      call createCurrent(P_Hh, P_GPlus, P_ghWm, P_ghZAnti, 2643, check)
      call createCurrent(P_ghZ, P_HPlus, P_HMinus, P_ghZAnti, 1776, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghA, P_GQMinus, 5384, check)
      call createCurrent(P_HhQ, P_ghWmAnti, P_G0, P_ghWm, 3539, check)
      call createCurrent(P_WPlus, P_ghWmAnti, P_ghWm, P_WMinus, 1188, check)
      call createCurrent(P_WQPlus, P_tauMinus, P_nu_tauAnti, 1750, check)
      call createCurrent(P_Hl, P_HPlus, P_GMinus, P_Hl, 3852, check)
      call createCurrent(P_HlQ, P_ghZ, P_Hl, P_ghZAnti, 3394, check)
      call createCurrent(P_GMinus, P_t, P_bAnti, 2683, check)
      call createCurrent(P_HhQ, P_b, P_bAnti, 7392, check)
      call createCurrent(P_WQPlus, P_HMinus, P_A, P_HlQ, 2280, check)
      call createCurrent(P_GQPlus, P_Hh, P_Ha, P_HQMinus, 8811, check)
      call createCurrent(P_HhQ, P_GPlus, P_G0, P_GQMinus, 1991, check)
      call createCurrent(P_HQMinus, P_ghA, P_HPlus, P_ghZAnti, 3760, check)
      call createCurrent(P_HQPlus, P_HMinus, P_Ha, P_HhQ, 7990, check)
      call createCurrent(P_A, P_ghZ, P_WPlus, P_ghWpAnti, 7103, check)
      call createCurrent(P_HMinus, P_ghAAnti, P_ghWp, P_Hh, 8090, check)
      call createCurrent(P_HlQ, P_HPlus, P_Ha, P_HQMinus, 4386, check)
      call createCurrent(P_HlQ, P_ghWm, P_G0, P_ghWmAnti, 8154, check)
      call createCurrent(P_WQPlus, P_Ha, P_WMinus, P_HhQ, 7955, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Hl, P_GQ0, 4501, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_A, P_A, 1161, check)
      call createCurrent(P_A, P_ghWp, P_ghWpAnti, P_A, 1077, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_G0, P_G0, 3894, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_WMinus, P_A, 4904, check)
      call createCurrent(P_HlQ, P_ghZ, P_HMinus, P_ghWmAnti, 3015, check)
      call createCurrent(P_ghWpAnti, P_Hh, P_ghWp, P_HhQ, 5563, check)
      call createCurrent(P_G0, P_GPlus, P_ghWm, P_ghAAnti, 4762, check)
      call createCurrent(P_Z, P_Z, P_A, P_A, 10501, check)
      call createCurrent(P_GQ0, P_Z, P_GPlus, P_WQMinus, 4953, check)
      call createCurrent(P_WMinus, P_GPlus, P_G0, 1116, check)
      call createCurrent(P_HQMinus, P_A, P_WPlus, P_HaQ, 77, check)
      call createCurrent(P_HaQ, P_G0, P_GMinus, P_GQPlus, 7775, check)
      call createCurrent(P_WPlus, P_WMinus, P_ghZ, P_ghZAnti, 5901, check)
      call createCurrent(P_HQPlus, P_Hh, P_WMinus, P_ZQ, 6763, check)
      call createCurrent(P_GPlus, P_Ha, P_HMinus, P_Hh, 846, check)
      call createCurrent(P_HMinus, P_GPlus, P_ghA, P_ghAAnti, 10415, check)
      call createCurrent(P_GQPlus, P_GMinus, P_ghWmAnti, P_ghWm, 4608, check)
      call createCurrent(P_GMinus, P_HPlus, P_Hl, 6080, check)
      call createCurrent(P_WMinus, P_G0, P_GPlus, P_Z, 1580, check)
      call createCurrent(P_GMinus, P_Hh, P_A, P_WPlus, 1061, check)
      call createCurrent(P_AQ, P_WPlus, P_Hl, P_HQMinus, 2450, check)
      call createCurrent(P_A, P_HMinus, P_HPlus, P_A, 1831, check)
      call createCurrent(P_GPlus, P_HMinus, P_A, 9536, check)
      call createCurrent(P_Hh, P_ghA, P_HPlus, P_ghWpAnti, 3544, check)
      call createCurrent(P_GQPlus, P_WMinus, P_AQ, 4107, check)
      call createCurrent(P_ghA, P_ghAAnti, P_GMinus, P_GQPlus, 4777, check)
      call createCurrent(P_g, P_ghGAnti, P_ghG, 3646, check)
      call createCurrent(P_G0, P_G0, P_g, P_g, 10559, check)
      call createCurrent(P_Hh, P_A, P_GPlus, P_WMinus, 1524, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_G0, P_ghWp, 7033, check)
      call createCurrent(P_Hh, P_muPlus, P_muMinus, 7544, check)
      call createCurrent(P_ghAAnti, P_Ha, P_ghWp, P_HMinus, 1404, check)
      call createCurrent(P_HPlus, P_GMinus, P_A, P_Z, 10164, check)
      call createCurrent(P_HlQ, P_GPlus, P_WMinus, P_ZQ, 4946, check)
      call createCurrent(P_Hh, P_WMinus, P_A, P_HPlus, 3497, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_HPlus, P_HlQ, 4237, check)
      call createCurrent(P_ghWp, P_WMinus, P_WPlus, P_ghWpAnti, 7185, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_GMinus, P_G0, 6791, check)
      call createCurrent(P_Hh, P_t, P_tAnti, 7056, check)
      call createCurrent(P_cAnti, P_G0, P_c, 7207, check)
      call createCurrent(P_ZQ, P_A, P_GPlus, P_GQMinus, 3682, check)
      call createCurrent(P_ghZAnti, P_HMinus, P_ghWp, P_Hh, 6308, check)
      call createCurrent(P_ePlus, P_nu_e, P_GQMinus, 8422, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_Z, P_ghWp, 6235, check)
      call createCurrent(P_GQMinus, P_G0, P_HPlus, P_GQ0, 8437, check)
      call createCurrent(P_HMinus, P_Hh, P_ghAAnti, P_ghWp, 5974, check)
      call createCurrent(P_ghZ, P_HMinus, P_Ha, P_ghWmAnti, 8783, check)
      call createCurrent(P_Hl, P_HMinus, P_HPlus, P_G0, 10396, check)
      call createCurrent(P_HQPlus, P_ghZ, P_Hh, P_ghWpAnti, 6489, check)
      call createCurrent(P_WMinus, P_ghWp, P_ghAAnti, P_Z, 3371, check)
      call createCurrent(P_HaQ, P_Hh, P_GQ0, 3356, check)
      call createCurrent(P_u, P_uAnti, P_A, 351, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_A, P_ghWp, 4117, check)
      call createCurrent(P_GMinus, P_ghWp, P_Hl, P_ghAAnti, 8593, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Hh, P_HaQ, 7320, check)
      call createCurrent(P_ghWmAnti, P_G0, P_ghA, P_GQMinus, 2375, check)
      call createCurrent(P_ghWm, P_GPlus, P_Ha, P_ghAAnti, 9604, check)
      call createCurrent(P_Z, P_ghWpAnti, P_WPlus, P_ghA, 7467, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghWp, P_WQMinus, 6946, check)
      call createCurrent(P_WQMinus, P_Z, P_HPlus, P_HhQ, 3850, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_ghWm, P_Ha, 9009, check)
      call createCurrent(P_GMinus, P_ghWm, P_GPlus, P_ghWmAnti, 4724, check)
      call createCurrent(P_ghA, P_WMinus, P_Z, P_ghWmAnti, 2468, check)
      call createCurrent(P_AQ, P_WPlus, P_ghWm, P_ghZAnti, 1184, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_G0, P_HlQ, 8392, check)
      call createCurrent(P_ghWmAnti, P_Z, P_ghA, P_WQMinus, 7796, check)
      call createCurrent(P_GPlus, P_ghAAnti, P_ghWm, 7296, check)
      call createCurrent(P_Ha, P_ghA, P_GMinus, P_ghWmAnti, 9252, check)
      call createCurrent(P_sAnti, P_s, P_GQ0, 7311, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_HMinus, P_HaQ, 6292, check)
      call createCurrent(P_HQPlus, P_ghWpAnti, P_Ha, P_ghA, 3936, check)
      call createCurrent(P_GMinus, P_Hl, P_Hl, P_HPlus, 4225, check)
      call createCurrent(P_GQMinus, P_Hl, P_ghZ, P_ghWmAnti, 2554, check)
      call createCurrent(P_GQPlus, P_GMinus, P_ghAAnti, P_ghZ, 2048, check)
      call createCurrent(P_ghWmAnti, P_A, P_ghWm, P_ZQ, 1377, check)
      call createCurrent(P_GQMinus, P_HPlus, P_HaQ, 5154, check)
      call createCurrent(P_Hl, P_ghZ, P_ghWmAnti, P_HMinus, 3423, check)
      call createCurrent(P_GPlus, P_GMinus, P_Hl, P_Hl, 7085, check)
      call createCurrent(P_HPlus, P_ghWm, P_Ha, P_ghAAnti, 2758, check)
      call createCurrent(P_HPlus, P_Hh, P_ghAAnti, P_ghWm, 6666, check)
      call createCurrent(P_ghZ, P_Hh, P_ghWpAnti, P_GQPlus, 229, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_ghZ, P_GMinus, 4563, check)
      call createCurrent(P_HQPlus, P_Ha, P_G0, P_HQMinus, 3589, check)
      call createCurrent(P_HQMinus, P_Hh, P_Hh, P_HQPlus, 7738, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Ha, P_Ha, 4013, check)
      call createCurrent(P_Ha, P_ghWpAnti, P_ghWp, P_G0, 9644, check)
      call createCurrent(P_WMinus, P_WPlus, P_GMinus, P_GPlus, 6622, check)
      call createCurrent(P_HQPlus, P_Hh, P_Hh, P_HQMinus, 6252, check)
      call createCurrent(P_ghWpAnti, P_HPlus, P_ghZ, P_Hh, 6103, check)
      call createCurrent(P_WPlus, P_GPlus, P_GMinus, P_WMinus, 6167, check)
      call createCurrent(P_AQ, P_Hh, P_HPlus, P_WQMinus, 6348, check)
      call createCurrent(P_GQ0, P_ghWmAnti, P_Hl, P_ghWm, 5486, check)
      call createCurrent(P_ghZ, P_Hl, P_ghWpAnti, P_HQPlus, 4001, check)
      call createCurrent(P_WMinus, P_Z, P_Hl, P_HPlus, 1010, check)
      call createCurrent(P_Z, P_GPlus, P_HMinus, 8882, check)
      call createCurrent(P_ghA, P_ghAAnti, P_WMinus, P_WQPlus, 5442, check)
      call createCurrent(P_ghA, P_Hl, P_ghWpAnti, P_GQPlus, 357, check)
      call createCurrent(P_GPlus, P_Hl, P_GMinus, 2791, check)
      call createCurrent(P_HQPlus, P_Hl, P_Z, P_WQMinus, 2819, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_ghZ, P_HPlus, 9034, check)
      call createCurrent(P_Hl, P_WMinus, P_A, P_GPlus, 4508, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_GMinus, P_Hh, 3906, check)
      call createCurrent(P_WQMinus, P_HMinus, P_WPlus, P_HQPlus, 4479, check)
      call createCurrent(P_HQPlus, P_Z, P_WMinus, P_HaQ, 644, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_A, P_WPlus, 640, check)
      call createCurrent(P_Z, P_Z, P_GPlus, P_HMinus, 9592, check)
      call createCurrent(P_AQ, P_WPlus, P_WMinus, P_AQ, 3242, check)
      call createCurrent(P_WMinus, P_A, P_GPlus, P_Ha, 9109, check)
      call createCurrent(P_ghZ, P_G0, P_ghWpAnti, P_GPlus, 1297, check)
      call createCurrent(P_HPlus, P_G0, P_Ha, P_GMinus, 2373, check)
      call createCurrent(P_ghAAnti, P_ghA, P_WPlus, P_WMinus, 128, check)
      call createCurrent(P_G0, P_ghWpAnti, P_Ha, P_ghWp, 10260, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_GPlus, P_Hh, 5753, check)
      call createCurrent(P_HPlus, P_GMinus, P_GPlus, P_HMinus, 6034, check)
      call createCurrent(P_HlQ, P_Ha, P_GMinus, P_HQPlus, 3068, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_Ha, P_HaQ, 3720, check)
      call createCurrent(P_GMinus, P_ghWp, P_G0, P_ghAAnti, 3490, check)
      call createCurrent(P_ghWp, P_G0, P_HMinus, P_ghZAnti, 9627, check)
      call createCurrent(P_HPlus, P_GMinus, P_Hh, P_Hh, 3700, check)
      call createCurrent(P_GQ0, P_WMinus, P_WPlus, P_GQ0, 444, check)
      call createCurrent(P_HaQ, P_HPlus, P_GMinus, P_HlQ, 103, check)
      call createCurrent(P_GPlus, P_Z, P_Hl, P_WMinus, 6209, check)
      call createCurrent(P_Hl, P_G0, P_G0, P_Hh, 3149, check)
      call createCurrent(P_Hh, P_ghWpAnti, P_ghZ, P_HPlus, 2221, check)
      call createCurrent(P_d, P_g, P_dAnti, 5601, check)
      call createCurrent(P_muPlus, P_muMinus, P_HhQ, 5936, check)
      call createCurrent(P_sAnti, P_g, P_s, 8393, check)
      call createCurrent(P_GQ0, P_ghWpAnti, P_Hh, P_ghWp, 3259, check)
      call createCurrent(P_A, P_ePlus, P_eMinus, 7572, check)
      call createCurrent(P_A, P_G0, P_Z, P_G0, 10418, check)
      call createCurrent(P_HMinus, P_G0, P_Ha, P_GPlus, 2922, check)
      call createCurrent(P_HPlus, P_ghZAnti, P_HMinus, P_ghA, 4253, check)
      call createCurrent(P_A, P_GMinus, P_A, P_HPlus, 10136, check)
      call createCurrent(P_ZQ, P_GPlus, P_WMinus, P_HhQ, 7850, check)
      call createCurrent(P_ghWm, P_ghWpAnti, P_WPlus, P_WQPlus, 470, check)
      call createCurrent(P_AQ, P_HMinus, P_HQPlus, 5031, check)
      call createCurrent(P_GQMinus, P_Ha, P_GPlus, P_HhQ, 1666, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_HMinus, P_ghA, 9703, check)
      call createCurrent(P_ghWmAnti, P_HMinus, P_ghA, P_G0, 10344, check)
      call createCurrent(P_ghWp, P_G0, P_ghWpAnti, P_HlQ, 1444, check)
      call createCurrent(P_GPlus, P_HMinus, P_HMinus, P_HPlus, 62, check)
      call createCurrent(P_ZQ, P_s, P_sAnti, 5630, check)
      call createCurrent(P_GPlus, P_HMinus, P_GMinus, P_GPlus, 605, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_ghZ, P_GQMinus, 4120, check)
      call createCurrent(P_WPlus, P_HMinus, P_GPlus, P_WMinus, 10373, check)
      call createCurrent(P_ghWmAnti, P_WPlus, P_WMinus, P_ghWm, 8113, check)
      call createCurrent(P_WMinus, P_dAnti, P_u, 4462, check)
      call createCurrent(P_G0, P_G0, 10143, check)
      call createCurrent(P_ghWm, P_Ha, P_ghWmAnti, P_G0, 10062, check)
      call createCurrent(P_ghZ, P_Ha, P_HMinus, P_ghWmAnti, 8346, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghA, 1224, check)
      call createCurrent(P_HPlus, P_ghWp, P_GMinus, P_ghWpAnti, 10295, check)
      call createCurrent(P_Z, P_WPlus, P_A, P_WMinus, 6970, check)
      call createCurrent(P_GQPlus, P_ghZAnti, P_ghWm, 5355, check)
      call createCurrent(P_nu_muAnti, P_muMinus, P_GQPlus, 5397, check)
      call createCurrent(P_GQPlus, P_ghA, P_ghWpAnti, 4148, check)
      call createCurrent(P_Z, P_Hh, P_WPlus, P_GMinus, 521, check)
      call createCurrent(P_HlQ, P_Ha, P_G0, P_HlQ, 1316, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_WPlus, P_A, 5570, check)
      call createCurrent(P_GMinus, P_Hh, P_WPlus, 6880, check)
      call createCurrent(P_nu_muAnti, P_nu_mu, P_A, 9231, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_GMinus, P_GPlus, 6902, check)
      call createCurrent(P_HPlus, P_ghAAnti, P_ghZ, P_GMinus, 10082, check)
      call createCurrent(P_G0, P_G0, P_GMinus, P_HPlus, 856, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_WMinus, P_Z, 7203, check)
      call createCurrent(P_ghWmAnti, P_HMinus, P_ghZ, P_G0, 10059, check)
      call createCurrent(P_ghWpAnti, P_HPlus, P_ghA, P_Hh, 549, check)
      call createCurrent(P_HPlus, P_Hl, P_Hl, P_GMinus, 419, check)
      call createCurrent(P_Hl, P_ghZAnti, P_ghWm, P_GPlus, 6553, check)
      call createCurrent(P_ghWpAnti, P_HPlus, P_ghA, P_G0, 10095, check)
      call createCurrent(P_HlQ, P_ghWmAnti, P_HMinus, P_ghZ, 3011, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_GMinus, P_HPlus, 9631, check)
      call createCurrent(P_HQMinus, P_Ha, P_ghWmAnti, P_ghA, 2517, check)
      call createCurrent(P_s, P_cAnti, P_HPlus, 3486, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_HPlus, P_HQMinus, 8662, check)
      call createCurrent(P_Hl, P_HMinus, P_Ha, P_HPlus, 9553, check)
      call createCurrent(P_dAnti, P_d, P_Hl, 5512, check)
      call createCurrent(P_HMinus, P_HPlus, P_ghWmAnti, P_ghWm, 7028, check)
      call createCurrent(P_HaQ, P_G0, P_GPlus, P_GQMinus, 552, check)
      call createCurrent(P_GPlus, P_Hh, P_Hl, P_GMinus, 5647, check)
      call createCurrent(P_HMinus, P_Ha, P_HPlus, P_Hh, 10434, check)
      call createCurrent(P_HQMinus, P_ghA, P_ghWmAnti, 4745, check)
      call createCurrent(P_uAnti, P_u, P_Hl, 383, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghAAnti, P_GMinus, 7928, check)
      call createCurrent(P_HlQ, P_Z, P_HaQ, 8497, check)
      call createCurrent(P_A, P_tauPlus, P_tauMinus, 2810, check)
      call createCurrent(P_Ha, P_Z, P_Z, P_Ha, 3668, check)
      call createCurrent(P_HPlus, P_ghWm, P_ghZAnti, P_Hl, 5660, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_Hl, P_HMinus, 2941, check)
      call createCurrent(P_A, P_Hh, P_A, 10493, check)
      call createCurrent(P_Z, P_WPlus, P_WMinus, P_Z, 4817, check)
      call createCurrent(P_HQMinus, P_GPlus, P_HMinus, P_HQPlus, 4623, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghZAnti, P_G0, 8809, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_GPlus, P_HlQ, 6909, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghWp, 5574, check)
      call createCurrent(P_GPlus, P_Hl, P_A, P_WMinus, 4458, check)
      call createCurrent(P_HaQ, P_ghZAnti, P_Ha, P_ghZ, 1320, check)
      call createCurrent(P_GMinus, P_G0, P_GPlus, P_Hh, 10044, check)
      call createCurrent(P_GQMinus, P_G0, P_Hl, P_HQPlus, 3833, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_ghA, P_WQPlus, 3752, check)
      call createCurrent(P_A, P_Ha, P_Ha, P_A, 10541, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_WMinus, P_AQ, 3137, check)
      call createCurrent(P_GMinus, P_ghWp, P_ghWpAnti, P_HPlus, 9686, check)
      call createCurrent(P_WQPlus, P_A, P_WMinus, P_ZQ, 2634, check)
      call createCurrent(P_WQMinus, P_Hl, P_Hl, P_WQPlus, 2843, check)
      call createCurrent(P_GQ0, P_Ha, P_GMinus, P_GQPlus, 4548, check)
      call createCurrent(P_Hh, P_GPlus, P_HMinus, 2153, check)
      call createCurrent(P_GQMinus, P_GPlus, P_HaQ, 2459, check)
      call createCurrent(P_HQMinus, P_Hl, P_GPlus, P_HhQ, 3802, check)
      call createCurrent(P_Ha, P_G0, P_ghZAnti, P_ghZ, 10296, check)
      call createCurrent(P_t, P_Hl, P_tAnti, 8649, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_A, P_WQPlus, 8710, check)
      call createCurrent(P_HMinus, P_ghZ, P_Ha, P_ghWmAnti, 2386, check)
      call createCurrent(P_G0, P_HPlus, P_GMinus, P_G0, 7998, check)
      call createCurrent(P_WMinus, P_GMinus, P_GPlus, P_WPlus, 3955, check)
      call createCurrent(P_Z, P_ghWp, P_WMinus, P_ghAAnti, 4698, check)
      call createCurrent(P_WQPlus, P_ghWpAnti, P_ghZ, 769, check)
      call createCurrent(P_HlQ, P_G0, P_ZQ, 1547, check)
      call createCurrent(P_HhQ, P_Hl, P_GPlus, P_GQMinus, 3507, check)
      call createCurrent(P_GQ0, P_HMinus, P_GPlus, P_HaQ, 7049, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_Hl, P_GQPlus, 1120, check)
      call createCurrent(P_GQMinus, P_Hh, P_HPlus, P_HaQ, 7381, check)
      call createCurrent(P_HMinus, P_Z, P_HPlus, 7834, check)
      call createCurrent(P_ghA, P_GPlus, P_ghAAnti, P_HMinus, 10049, check)
      call createCurrent(P_Hh, P_Hl, P_Hl, P_Hl, 6450, check)
      call createCurrent(P_GMinus, P_HPlus, P_ghZAnti, P_ghZ, 10063, check)
      call createCurrent(P_Z, P_GMinus, P_HPlus, P_A, 10262, check)
      call createCurrent(P_HlQ, P_HPlus, P_Hh, P_HQMinus, 931, check)
      call createCurrent(P_HlQ, P_Hl, P_HPlus, P_HQMinus, 613, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghA, 8130, check)
      call createCurrent(P_HPlus, P_Hh, P_GMinus, P_G0, 8581, check)
      call createCurrent(P_HhQ, P_GPlus, P_Ha, P_GQMinus, 2518, check)
      call createCurrent(P_GQMinus, P_HPlus, P_GMinus, P_GQPlus, 700, check)
      call createCurrent(P_HMinus, P_WPlus, P_Hh, 1698, check)
      call createCurrent(P_Z, P_WMinus, P_GPlus, P_Hh, 4287, check)
      call createCurrent(P_A, P_G0, P_Hh, 9859, check)
      call createCurrent(P_GMinus, P_GPlus, P_ghA, P_ghAAnti, 6181, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_WPlus, P_A, 6433, check)
      call createCurrent(P_WQPlus, P_ghWm, P_WPlus, P_ghWpAnti, 6163, check)
      call createCurrent(P_HhQ, P_G0, P_Ha, P_HlQ, 915, check)
      call createCurrent(P_HQMinus, P_Hl, P_ghWmAnti, P_ghA, 6271, check)
      call createCurrent(P_HPlus, P_HMinus, P_GPlus, P_GMinus, 7026, check)
      call createCurrent(P_GMinus, P_ghZ, P_Hh, P_ghWmAnti, 7154, check)
      call createCurrent(P_Hh, P_ghA, P_ghWpAnti, P_HPlus, 7608, check)
      call createCurrent(P_WQMinus, P_Z, P_ghWmAnti, P_ghA, 660, check)
      call createCurrent(P_ghA, P_GMinus, P_ghWmAnti, P_Ha, 9348, check)
      call createCurrent(P_Z, P_ghZ, P_ghWpAnti, P_WPlus, 5290, check)
      call createCurrent(P_Z, P_uAnti, P_u, 3993, check)
      call createCurrent(P_GPlus, P_GMinus, P_A, P_Z, 6463, check)
      call createCurrent(P_ghWm, P_A, P_ghAAnti, P_WPlus, 4900, check)
      call createCurrent(P_Ha, P_GMinus, P_GPlus, P_Ha, 1498, check)
      call createCurrent(P_GQMinus, P_GMinus, P_HPlus, P_HQPlus, 1179, check)
      call createCurrent(P_muMinus, P_GPlus, P_nu_muAnti, 4859, check)
      call createCurrent(P_HMinus, P_ghZAnti, P_Hh, P_ghWp, 2265, check)
      call createCurrent(P_Ha, P_ghZ, P_ghZAnti, P_G0, 8892, check)
      call createCurrent(P_ZQ, P_GMinus, P_GPlus, P_ZQ, 2561, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghZ, P_Ha, 9805, check)
      call createCurrent(P_HlQ, P_Hh, P_GPlus, P_HQMinus, 3121, check)
      call createCurrent(P_Ha, P_dAnti, P_d, 6358, check)
      call createCurrent(P_Hl, P_ghAAnti, P_HMinus, P_ghWp, 381, check)
      call createCurrent(P_HPlus, P_nu_tauAnti, P_tauMinus, 3302, check)
      call createCurrent(P_WPlus, P_ghAAnti, P_A, P_ghWm, 2351, check)
      call createCurrent(P_HhQ, P_Ha, P_ghWpAnti, P_ghWp, 6265, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_HMinus, P_HlQ, 4791, check)
      call createCurrent(P_ghAAnti, P_ghA, P_GPlus, P_GQMinus, 2428, check)
      call createCurrent(P_ghA, P_G0, P_ghWpAnti, P_HPlus, 9450, check)
      call createCurrent(P_Hl, P_HPlus, P_Z, P_WMinus, 7862, check)
      call createCurrent(P_HQPlus, P_Hh, P_WQMinus, 1593, check)
      call createCurrent(P_G0, P_A, P_Hh, 9194, check)
      call createCurrent(P_WPlus, P_Hl, P_Hl, P_WMinus, 2988, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_GPlus, P_HhQ, 2549, check)
      call createCurrent(P_GMinus, P_HMinus, P_GPlus, P_GPlus, 7924, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_ZQ, 5878, check)
      call createCurrent(P_nu_mu, P_HMinus, P_muPlus, 4509, check)
      call createCurrent(P_Z, P_HPlus, P_Ha, P_WMinus, 1844, check)
      call createCurrent(P_HQMinus, P_GPlus, P_HPlus, P_GQMinus, 1897, check)
      call createCurrent(P_ghAAnti, P_HPlus, P_GMinus, P_ghA, 10461, check)
      call createCurrent(P_GQMinus, P_HPlus, P_GMinus, P_HQPlus, 5748, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghZAnti, P_AQ, 874, check)
      call createCurrent(P_HMinus, P_Ha, P_Hh, P_HPlus, 9139, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_GPlus, 1212, check)
      call createCurrent(P_HPlus, P_Hh, P_A, P_WMinus, 7015, check)
      call createCurrent(P_HhQ, P_Hh, P_HlQ, 6710, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_ghWm, P_A, 5977, check)
      call createCurrent(P_WPlus, P_HPlus, P_HMinus, P_WMinus, 2041, check)
      call createCurrent(P_Ha, P_Hl, P_HMinus, P_GPlus, 6173, check)
      call createCurrent(P_HlQ, P_Ha, P_GMinus, P_GQPlus, 7430, check)
      call createCurrent(P_GMinus, P_HPlus, P_Hl, P_Hh, 1308, check)
      call createCurrent(P_GQMinus, P_Ha, P_HPlus, P_HhQ, 8005, check)
      call createCurrent(P_GMinus, P_Hh, P_ghWmAnti, P_ghA, 5292, check)
      call createCurrent(P_HQPlus, P_WMinus, P_Z, P_HhQ, 8, check)
      call createCurrent(P_GPlus, P_ghZ, P_ghZAnti, P_GMinus, 6824, check)
      call createCurrent(P_GQ0, P_d, P_dAnti, 3325, check)
      call createCurrent(P_GPlus, P_HMinus, P_HPlus, P_HMinus, 5407, check)
      call createCurrent(P_HMinus, P_WMinus, P_GPlus, P_WPlus, 10234, check)
      call createCurrent(P_Hl, P_Z, P_G0, 4150, check)
      call createCurrent(P_Hl, P_GPlus, P_WMinus, P_Z, 3322, check)
      call createCurrent(P_HMinus, P_A, P_HPlus, P_A, 5496, check)
      call createCurrent(P_Hh, P_GMinus, P_HPlus, P_Hh, 5404, check)
      call createCurrent(P_WQMinus, P_WPlus, P_A, P_AQ, 2148, check)
      call createCurrent(P_GQPlus, P_WMinus, P_WPlus, P_GQMinus, 1207, check)
      call createCurrent(P_Hh, P_GMinus, P_Hh, P_HPlus, 8162, check)
      call createCurrent(P_ghA, P_HPlus, P_Hl, P_ghWpAnti, 6644, check)
      call createCurrent(P_HMinus, P_Z, P_GPlus, 10378, check)
      call createCurrent(P_WPlus, P_A, P_ghWm, P_ghAAnti, 8190, check)
      call createCurrent(P_sAnti, P_A, P_s, 6788, check)
      call createCurrent(P_Ha, P_GMinus, P_Hl, P_HPlus, 4141, check)
      call createCurrent(P_HMinus, P_GPlus, P_A, P_A, 9615, check)
      call createCurrent(P_WMinus, P_GPlus, P_WPlus, P_GMinus, 5314, check)
      call createCurrent(P_A, P_ghWmAnti, P_Z, P_ghWm, 4867, check)
      call createCurrent(P_WQMinus, P_Z, P_WQPlus, 4579, check)
      call createCurrent(P_HQPlus, P_G0, P_HMinus, P_HhQ, 610, check)
      call createCurrent(P_HaQ, P_GMinus, P_G0, P_GQPlus, 8042, check)
      call createCurrent(P_GPlus, P_Ha, P_ghAAnti, P_ghWm, 10021, check)
      call createCurrent(P_HaQ, P_ghWpAnti, P_ghWp, 512, check)
      call createCurrent(P_GMinus, P_WPlus, P_A, P_Hh, 6750, check)
      call createCurrent(P_ghZ, P_HMinus, P_ghWmAnti, P_Ha, 1166, check)
      call createCurrent(P_AQ, P_G0, P_WMinus, P_GQPlus, 8560, check)
      call createCurrent(P_G0, P_A, P_A, P_G0, 10521, check)
      call createCurrent(P_WQPlus, P_WMinus, P_Ha, P_HlQ, 66, check)
      call createCurrent(P_GMinus, P_Z, P_WPlus, P_Ha, 10081, check)
      call createCurrent(P_ghWp, P_HMinus, P_ghAAnti, P_HhQ, 2115, check)
      call createCurrent(P_ghWmAnti, P_Hh, P_ghZ, P_GQMinus, 4830, check)
      call createCurrent(P_HlQ, P_ghWmAnti, P_G0, P_ghWm, 7947, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_ghWp, 8080, check)
      call createCurrent(P_Ha, P_Hh, P_Hl, P_Ha, 2831, check)
      call createCurrent(P_GMinus, P_ghWpAnti, P_ghWp, P_GPlus, 4657, check)
      call createCurrent(P_HaQ, P_Hh, P_Hl, P_GQ0, 4290, check)
      call createCurrent(P_HMinus, P_ghA, P_Hh, P_ghWmAnti, 7445, check)
      call createCurrent(P_uAnti, P_u, P_g, 2220, check)
      call createCurrent(P_WMinus, P_Hh, P_HPlus, P_A, 7488, check)
      call createCurrent(P_HQMinus, P_G0, P_HPlus, P_HhQ, 2083, check)
      call createCurrent(P_ghWmAnti, P_G0, P_ghWm, P_G0, 216, check)
      call createCurrent(P_A, P_Ha, P_G0, P_Z, 10525, check)
      call createCurrent(P_g, P_ghG, P_g, P_ghGAnti, 2171, check)
      call createCurrent(P_Hh, P_Hh, P_GPlus, P_HMinus, 3931, check)
      call createCurrent(P_ZQ, P_GMinus, P_GPlus, P_AQ, 4656, check)
      call createCurrent(P_HMinus, P_WPlus, P_Ha, 5428, check)
      call createCurrent(P_HhQ, P_GMinus, P_G0, P_GQPlus, 5523, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_HMinus, P_HQPlus, 631, check)
      call createCurrent(P_HMinus, P_ghWmAnti, P_ghA, P_Hl, 5900, check)
      call createCurrent(P_HQMinus, P_GPlus, P_HPlus, P_HQMinus, 2579, check)
      call createCurrent(P_GPlus, P_Hl, P_HMinus, P_G0, 3469, check)
      call createCurrent(P_A, P_A, P_GPlus, P_HMinus, 10037, check)
      call createCurrent(P_HMinus, P_ghZ, P_ghZAnti, P_GPlus, 9931, check)
      call createCurrent(P_A, P_WPlus, P_ghWm, P_ghAAnti, 5722, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_Hl, P_ghWp, 1410, check)
      call createCurrent(P_Ha, P_GMinus, P_Z, P_WPlus, 9488, check)
      call createCurrent(P_HlQ, P_G0, P_HMinus, P_HQPlus, 2836, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_Z, P_WMinus, 2174, check)
      call createCurrent(P_Hh, P_ghWmAnti, P_GMinus, P_ghA, 5863, check)
      call createCurrent(P_AQ, P_A, P_WMinus, P_WQPlus, 2227, check)
      call createCurrent(P_WPlus, P_ghWm, P_A, P_ghAAnti, 3493, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_GMinus, P_HlQ, 3162, check)
      call createCurrent(P_Hl, P_A, P_Hh, P_Z, 10615, check)
      call createCurrent(P_HMinus, P_GPlus, P_Ha, 5756, check)
      call createCurrent(P_HhQ, P_ghWm, P_GPlus, P_ghAAnti, 5472, check)
      call createCurrent(P_Ha, P_GPlus, P_GMinus, P_Hh, 9060, check)
      call createCurrent(P_Ha, P_ghWmAnti, P_ghZ, P_HMinus, 4951, check)
      call createCurrent(P_ZQ, P_HMinus, P_WQPlus, 1605, check)
      call createCurrent(P_GPlus, P_HMinus, P_G0, P_G0, 695, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_GPlus, P_Hh, 333, check)
      call createCurrent(P_Hl, P_Ha, P_GMinus, P_HPlus, 3692, check)
      call createCurrent(P_HQMinus, P_Z, P_Hh, P_WQPlus, 8027, check)
      call createCurrent(P_GQMinus, P_HPlus, P_Hl, P_HaQ, 664, check)
      call createCurrent(P_Hh, P_Hh, P_ghZAnti, P_ghZ, 133, check)
      call createCurrent(P_ZQ, P_WMinus, P_HPlus, P_HlQ, 7041, check)
      call createCurrent(P_Ha, P_ghWm, P_GPlus, P_ghZAnti, 9116, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_HlQ, 6155, check)
      call createCurrent(P_Z, P_Hl, P_Z, P_Hh, 10155, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_ghA, P_WMinus, 2473, check)
      call createCurrent(P_GMinus, P_HPlus, P_Ha, P_G0, 8292, check)
      call createCurrent(P_WMinus, P_A, P_HPlus, P_Ha, 1596, check)
      call createCurrent(P_G0, P_ghA, P_ghWmAnti, P_GMinus, 2811, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_GMinus, P_Hh, 5993, check)
      call createCurrent(P_HaQ, P_Ha, P_Hh, P_HlQ, 4055, check)
      call createCurrent(P_HPlus, P_WMinus, P_Hh, 8631, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_A, P_AQ, 4973, check)
      call createCurrent(P_HMinus, P_ghZ, P_ghWmAnti, 4443, check)
      call createCurrent(P_Hh, P_ghZAnti, P_ghZ, 7581, check)
      call createCurrent(P_HPlus, P_ghZ, P_Hh, P_ghWpAnti, 7007, check)
      call createCurrent(P_Hh, P_Hh, P_WPlus, P_WMinus, 4194, check)
      call createCurrent(P_G0, P_Z, P_WPlus, P_GMinus, 2163, check)
      call createCurrent(P_GMinus, P_G0, P_HPlus, P_Hl, 7945, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghWpAnti, P_Hl, 4476, check)
      call createCurrent(P_HPlus, P_ghWpAnti, P_Ha, P_ghZ, 6637, check)
      call createCurrent(P_HlQ, P_HMinus, P_ghZ, P_ghWmAnti, 8022, check)
      call createCurrent(P_HlQ, P_Z, P_HPlus, P_WQMinus, 5978, check)
      call createCurrent(P_HQPlus, P_Ha, P_ghWpAnti, P_ghA, 699, check)
      call createCurrent(P_Hl, P_ghWmAnti, P_ghZ, P_HMinus, 4396, check)
      call createCurrent(P_GQMinus, P_Hl, P_GPlus, P_HhQ, 8812, check)
      call createCurrent(P_WMinus, P_Z, P_ghA, P_ghWmAnti, 1697, check)
      call createCurrent(P_WQPlus, P_WMinus, P_WMinus, P_WQPlus, 3261, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_G0, P_HMinus, 8924, check)
      call createCurrent(P_WPlus, P_Z, P_HMinus, P_Hl, 1386, check)
      call createCurrent(P_HQPlus, P_G0, P_HMinus, P_HlQ, 7147, check)
      call createCurrent(P_ghZ, P_HPlus, P_ghWpAnti, P_Hh, 4486, check)
      call createCurrent(P_Z, P_Hh, P_Hl, P_A, 10644, check)
      call createCurrent(P_HPlus, P_HMinus, P_ghWm, P_ghWmAnti, 4281, check)
      call createCurrent(P_ghWp, P_Z, P_ghZAnti, P_WMinus, 1748, check)
      call createCurrent(P_Hl, P_Z, P_GMinus, P_WPlus, 3724, check)
      call createCurrent(P_ghWp, P_Hh, P_GMinus, P_ghZAnti, 7722, check)
      call createCurrent(P_HQMinus, P_HPlus, P_Hl, P_HaQ, 25, check)
      call createCurrent(P_HaQ, P_Hl, P_GPlus, P_GQMinus, 1420, check)
      call createCurrent(P_WMinus, P_G0, P_A, P_GPlus, 6565, check)
      call createCurrent(P_A, P_ghA, P_WPlus, P_ghWpAnti, 5920, check)
      call createCurrent(P_HQMinus, P_HPlus, P_G0, P_HaQ, 980, check)
      call createCurrent(P_sAnti, P_s, P_Z, 3968, check)
      call createCurrent(P_GQMinus, P_G0, P_ghZ, P_ghWmAnti, 1727, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghZAnti, P_Z, 5966, check)
      call createCurrent(P_ghWpAnti, P_Z, P_ghZ, P_WQPlus, 3516, check)
      call createCurrent(P_Hh, P_A, P_WPlus, P_HMinus, 3721, check)
      call createCurrent(P_HQMinus, P_Z, P_WPlus, P_HhQ, 4113, check)
      call createCurrent(P_ZQ, P_A, P_ghWpAnti, P_ghWp, 2935, check)
      call createCurrent(P_HPlus, P_Z, P_Z, P_GMinus, 9447, check)
      call createCurrent(P_HlQ, P_GMinus, P_Z, P_WQPlus, 3418, check)
      call createCurrent(P_uAnti, P_GPlus, P_d, 7972, check)
      call createCurrent(P_HlQ, P_Hh, P_GMinus, P_HQPlus, 3864, check)
      call createCurrent(P_HaQ, P_G0, P_HPlus, P_HQMinus, 5430, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_HQPlus, 1142, check)
      call createCurrent(P_GMinus, P_Hl, P_Z, P_WPlus, 3581, check)
      call createCurrent(P_Ha, P_Ha, P_GPlus, P_HMinus, 4313, check)
      call createCurrent(P_Hh, P_Hl, P_A, P_A, 10735, check)
      call createCurrent(P_GQMinus, P_Z, P_GPlus, P_AQ, 5842, check)
      call createCurrent(P_WQMinus, P_HPlus, P_A, P_HlQ, 298, check)
      call createCurrent(P_HMinus, P_GPlus, P_Ha, P_Ha, 6117, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_ZQ, 3594, check)
      call createCurrent(P_HaQ, P_HMinus, P_GPlus, P_HhQ, 283, check)
      call createCurrent(P_HhQ, P_Hh, P_WPlus, P_WQMinus, 3659, check)
      call createCurrent(P_nu_muAnti, P_muMinus, P_HQPlus, 1672, check)
      call createCurrent(P_GQ0, P_Ha, P_HhQ, 1016, check)
      call createCurrent(P_HhQ, P_ghZ, P_Hh, P_ghZAnti, 6399, check)
      call createCurrent(P_G0, P_GPlus, P_Ha, P_HMinus, 3186, check)
      call createCurrent(P_Hl, P_Z, P_Z, P_Hh, 8916, check)
      call createCurrent(P_Hh, P_ghWp, P_ghWpAnti, P_Hh, 238, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_HhQ, 7847, check)
      call createCurrent(P_A, P_Ha, P_GPlus, P_WMinus, 10325, check)
      call createCurrent(P_Z, P_nu_e, P_nu_eAnti, 2203, check)
      call createCurrent(P_ghWmAnti, P_Z, P_WMinus, P_ghA, 1266, check)
      call createCurrent(P_ghWp, P_Ha, P_ghWpAnti, P_HlQ, 8731, check)
      call createCurrent(P_HlQ, P_Hh, P_GPlus, P_GQMinus, 3308, check)
      call createCurrent(P_GQ0, P_G0, P_ghWp, P_ghWpAnti, 1315, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghWp, P_WMinus, 2052, check)
      call createCurrent(P_Ha, P_Z, P_G0, P_Z, 9689, check)
      call createCurrent(P_GQ0, P_GMinus, P_HPlus, P_HlQ, 4994, check)
      call createCurrent(P_GPlus, P_Ha, P_GMinus, 9205, check)
      call createCurrent(P_ZQ, P_Ha, P_HhQ, 7660, check)
      call createCurrent(P_Ha, P_HPlus, P_G0, P_GMinus, 4886, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghWm, P_Hh, 21, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_GMinus, P_ghA, 1296, check)
      call createCurrent(P_HaQ, P_WMinus, P_Ha, P_WQPlus, 8394, check)
      call createCurrent(P_Hl, P_HMinus, P_A, P_WPlus, 124, check)
      call createCurrent(P_muMinus, P_nu_muAnti, P_HQPlus, 1118, check)
      call createCurrent(P_WQPlus, P_HPlus, P_WMinus, P_HQMinus, 302, check)
      call createCurrent(P_ghZ, P_HPlus, P_GMinus, P_ghAAnti, 9655, check)
      call createCurrent(P_HaQ, P_HMinus, P_ghZ, P_ghWmAnti, 4350, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_G0, P_GPlus, 5474, check)
      call createCurrent(P_ghWmAnti, P_GPlus, P_HMinus, P_ghWm, 9017, check)
      call createCurrent(P_HlQ, P_ghWp, P_GMinus, P_ghZAnti, 1555, check)
      call createCurrent(P_GQMinus, P_GPlus, P_ghA, P_ghZAnti, 8821, check)
      call createCurrent(P_A, P_Z, P_Hl, P_Hl, 8932, check)
      call createCurrent(P_HQMinus, P_GPlus, P_Ha, P_HlQ, 5178, check)
      call createCurrent(P_Z, P_GMinus, P_Hh, P_WPlus, 2306, check)
      call createCurrent(P_Hh, P_ghWm, P_Hh, P_ghWmAnti, 8169, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghAAnti, P_G0, 8496, check)
      call createCurrent(P_A, P_ghWmAnti, P_ghWm, P_A, 4368, check)
      call createCurrent(P_Hh, P_Ha, P_Ha, P_Hl, 4843, check)
      call createCurrent(P_cAnti, P_s, P_WQPlus, 6188, check)
      call createCurrent(P_ghWm, P_GMinus, P_ghWmAnti, P_GQPlus, 7004, check)
      call createCurrent(P_WPlus, P_G0, P_WMinus, P_Ha, 8993, check)
      call createCurrent(P_ghG, P_ghGAnti, P_gQ, 7054, check)
      call createCurrent(P_HMinus, P_WPlus, 10331, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_HQMinus, 3734, check)
      call createCurrent(P_ghWpAnti, P_HPlus, P_ghZ, P_HlQ, 3346, check)
      call createCurrent(P_ghWpAnti, P_HMinus, P_ghWp, P_HPlus, 6003, check)
      call createCurrent(P_WQMinus, P_A, P_WQPlus, 7723, check)
      call createCurrent(P_GQMinus, P_WPlus, P_ZQ, 2245, check)
      call createCurrent(P_GQMinus, P_G0, P_ghWmAnti, P_ghA, 5765, check)
      call createCurrent(P_GPlus, P_G0, P_GMinus, P_Hl, 9547, check)
      call createCurrent(P_HlQ, P_G0, P_Hh, P_HaQ, 7247, check)
      call createCurrent(P_HPlus, P_HMinus, P_Hh, P_Hh, 6051, check)
      call createCurrent(P_g, P_GPlus, P_g, P_HMinus, 10596, check)
      call createCurrent(P_Ha, P_G0, P_GPlus, P_HMinus, 8616, check)
      call createCurrent(P_HlQ, P_GMinus, P_A, P_WQPlus, 1143, check)
      call createCurrent(P_G0, P_Hl, P_GPlus, P_GMinus, 10261, check)
      call createCurrent(P_G0, P_G0, P_ghWp, P_ghWpAnti, 4682, check)
      call createCurrent(P_WPlus, P_WMinus, 10087, check)
      call createCurrent(P_GQPlus, P_Ha, P_HMinus, P_GQ0, 8498, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghZAnti, P_HhQ, 1006, check)
      call createCurrent(P_G0, P_GPlus, P_GMinus, P_Hh, 9296, check)
      call createCurrent(P_HQPlus, P_G0, P_HMinus, P_HaQ, 8746, check)
      call createCurrent(P_HhQ, P_Hh, P_G0, P_GQ0, 1968, check)
      call createCurrent(P_muPlus, P_Hh, P_muMinus, 277, check)
      call createCurrent(P_c, P_cAnti, P_HaQ, 3393, check)
      call createCurrent(P_GMinus, P_Hl, P_Ha, P_HPlus, 5352, check)
      call createCurrent(P_G0, P_WPlus, P_HMinus, P_Z, 9117, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_WMinus, P_ZQ, 5963, check)
      call createCurrent(P_WPlus, P_Z, P_A, P_WMinus, 8442, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_WMinus, P_AQ, 6769, check)
      call createCurrent(P_Ha, P_ghWm, P_Ha, P_ghWmAnti, 656, check)
      call createCurrent(P_G0, P_Ha, P_ghWmAnti, P_ghWm, 8915, check)
      call createCurrent(P_WQPlus, P_Hl, P_HMinus, P_AQ, 926, check)
      call createCurrent(P_HlQ, P_HMinus, P_WPlus, P_ZQ, 8277, check)
      call createCurrent(P_HhQ, P_Ha, P_ghWp, P_ghWpAnti, 5813, check)
      call createCurrent(P_d, P_G0, P_dAnti, 3643, check)
      call createCurrent(P_HMinus, P_GPlus, P_WMinus, P_WPlus, 9070, check)
      call createCurrent(P_s, P_WPlus, P_cAnti, 7167, check)
      call createCurrent(P_WQPlus, P_WMinus, P_Hl, P_HlQ, 8418, check)
      call createCurrent(P_ghZAnti, P_ghA, P_HPlus, P_HQMinus, 467, check)
      call createCurrent(P_HPlus, P_Hh, P_Hh, P_HMinus, 7023, check)
      call createCurrent(P_GPlus, P_Z, P_WMinus, P_Hl, 803, check)
      call createCurrent(P_WPlus, P_G0, P_G0, P_WMinus, 2777, check)
      call createCurrent(P_Hh, P_g, P_g, P_Hh, 10722, check)
      call createCurrent(P_HMinus, P_GPlus, P_ghZ, P_ghAAnti, 8847, check)
      call createCurrent(P_Hl, P_WPlus, P_GMinus, P_Z, 1424, check)
      call createCurrent(P_Hh, P_GMinus, P_ghA, P_ghWmAnti, 8123, check)
      call createCurrent(P_ghZ, P_HMinus, P_HPlus, P_ghAAnti, 4268, check)
      call createCurrent(P_G0, P_ghWpAnti, P_ghA, P_GPlus, 7376, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_Hh, P_HMinus, 6917, check)
      call createCurrent(P_GQ0, P_ePlus, P_eMinus, 1621, check)
      call createCurrent(P_Ha, P_A, P_A, P_Ha, 10533, check)
      call createCurrent(P_HQPlus, P_Hl, P_ghA, P_ghWpAnti, 841, check)
      call createCurrent(P_GQPlus, P_Ha, P_GMinus, P_HaQ, 7492, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Ha, P_HaQ, 5213, check)
      call createCurrent(P_Ha, P_Ha, 9038, check)
      call createCurrent(P_Ha, P_G0, 10241, check)
      call createCurrent(P_GPlus, P_ghAAnti, P_ghWm, P_Hh, 1647, check)
      call createCurrent(P_WMinus, P_Hl, P_Z, P_HPlus, 2249, check)
      call createCurrent(P_sAnti, P_s, P_gQ, 784, check)
      call createCurrent(P_Ha, P_GMinus, P_Hh, P_GPlus, 9753, check)
      call createCurrent(P_G0, P_A, P_HMinus, P_WPlus, 8981, check)
      call createCurrent(P_HMinus, P_Hh, P_HPlus, P_Hh, 1431, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_HPlus, P_Hh, 6136, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_Hl, P_ghA, 97, check)
      call createCurrent(P_WQPlus, P_ghWpAnti, P_ghA, 5628, check)
      call createCurrent(P_WPlus, P_G0, P_Ha, P_WMinus, 10399, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghA, P_HPlus, 10073, check)
      call createCurrent(P_HQMinus, P_WMinus, P_HPlus, P_WQPlus, 6572, check)
      call createCurrent(P_Hh, P_Z, P_GPlus, P_WMinus, 1768, check)
      call createCurrent(P_Hh, P_GMinus, P_G0, P_HPlus, 310, check)
      call createCurrent(P_WMinus, P_HPlus, P_G0, 9780, check)
      call createCurrent(P_HQPlus, P_WMinus, P_Z, P_HaQ, 5012, check)
      call createCurrent(P_AQ, P_WMinus, P_Hl, P_GQPlus, 1013, check)
      call createCurrent(P_WQPlus, P_Hh, P_Z, P_HQMinus, 7123, check)
      call createCurrent(P_HQMinus, P_HPlus, P_G0, P_GQ0, 7546, check)
      call createCurrent(P_A, P_Z, P_WMinus, P_WPlus, 5084, check)
      call createCurrent(P_Hl, P_Ha, P_Hh, P_Ha, 7918, check)
      call createCurrent(P_GQPlus, P_HMinus, P_Hh, P_HlQ, 8536, check)
      call createCurrent(P_WQMinus, P_HPlus, P_HlQ, 4178, check)
      call createCurrent(P_HQMinus, P_GPlus, P_Ha, P_HhQ, 951, check)
      call createCurrent(P_Ha, P_HPlus, P_ghAAnti, P_ghWm, 5522, check)
      call createCurrent(P_Ha, P_Hl, P_Hh, P_G0, 64, check)
      call createCurrent(P_HMinus, P_HPlus, P_A, P_A, 6263, check)
      call createCurrent(P_Hl, P_G0, P_GPlus, P_HMinus, 6369, check)
      call createCurrent(P_GQMinus, P_WPlus, P_A, P_HlQ, 8221, check)
      call createCurrent(P_GQPlus, P_Hh, P_Hl, P_GQMinus, 2107, check)
      call createCurrent(P_A, P_WMinus, P_Z, P_WPlus, 4337, check)
      call createCurrent(P_HQMinus, P_GMinus, P_GPlus, P_HQPlus, 2002, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_GQPlus, 6473, check)
      call createCurrent(P_G0, P_Z, P_G0, P_Z, 5967, check)
      call createCurrent(P_Ha, P_Ha, P_g, P_g, 10761, check)
      call createCurrent(P_G0, P_HPlus, P_GMinus, P_Hh, 3590, check)
      call createCurrent(P_HQMinus, P_HMinus, P_GPlus, P_HQPlus, 6322, check)
      call createCurrent(P_Hh, P_Hl, P_Hh, P_Hl, 5294, check)
      call createCurrent(P_HhQ, P_d, P_dAnti, 7818, check)
      call createCurrent(P_nu_mu, P_nu_muAnti, 10080, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghAAnti, P_Hh, 4026, check)
      call createCurrent(P_GMinus, P_A, P_WPlus, 8429, check)
      call createCurrent(P_GMinus, P_WMinus, P_WPlus, P_HPlus, 9029, check)
      call createCurrent(P_g, P_Z, P_g, P_g, 10574, check)
      call createCurrent(P_Hl, P_GMinus, P_ghWmAnti, P_ghA, 1719, check)
      call createCurrent(P_u, P_uAnti, P_Z, 5972, check)
      call createCurrent(P_GPlus, P_GMinus, P_Hh, P_G0, 9083, check)
      call createCurrent(P_ghZ, P_Ha, P_G0, P_ghZAnti, 9388, check)
      call createCurrent(P_HPlus, P_WMinus, P_A, 6393, check)
      call createCurrent(P_GQPlus, P_HPlus, P_HMinus, P_GQMinus, 1688, check)
      call createCurrent(P_nu_eAnti, P_nu_e, P_Z, 5530, check)
      call createCurrent(P_WQPlus, P_ghA, P_WMinus, P_ghZAnti, 8695, check)
      call createCurrent(P_GQPlus, P_cAnti, P_s, 1408, check)
      call createCurrent(P_HMinus, P_ghWmAnti, P_G0, P_ghZ, 9320, check)
      call createCurrent(P_Hh, P_c, P_cAnti, 8567, check)
      call createCurrent(P_GQ0, P_GMinus, P_ghZAnti, P_ghWp, 7451, check)
      call createCurrent(P_GPlus, P_G0, P_ghZ, P_ghWpAnti, 5769, check)
      call createCurrent(P_A, P_b, P_bAnti, 8188, check)
      call createCurrent(P_WMinus, P_ghWp, P_Z, P_ghZAnti, 8212, check)
      call createCurrent(P_G0, P_HMinus, P_GPlus, 649, check)
      call createCurrent(P_HQMinus, P_HPlus, P_Z, P_ZQ, 6329, check)
      call createCurrent(P_HMinus, P_ghA, P_ghWmAnti, 1893, check)
      call createCurrent(P_Z, P_Hl, P_Ha, 7202, check)
      call createCurrent(P_Hl, P_ghWmAnti, P_ghA, P_GMinus, 4971, check)
      call createCurrent(P_HPlus, P_GMinus, P_G0, P_G0, 4286, check)
      call createCurrent(P_cAnti, P_c, 9533, check)
      call createCurrent(P_HaQ, P_GMinus, P_HQPlus, 8790, check)
      call createCurrent(P_ghWpAnti, P_Z, P_Z, P_ghWp, 7557, check)
      call createCurrent(P_Ha, P_HPlus, P_HMinus, P_Ha, 8139, check)
      call createCurrent(P_WQPlus, P_ghZ, P_WMinus, P_ghZAnti, 1615, check)
      call createCurrent(P_HhQ, P_GMinus, P_Hh, P_GQPlus, 2223, check)
      call createCurrent(P_ZQ, P_Hh, P_WMinus, P_GQPlus, 1053, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_GPlus, P_G0, 4251, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_Hh, P_HPlus, 7568, check)
      call createCurrent(P_HPlus, P_ghWm, P_ghAAnti, P_G0, 10033, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_Ha, P_GPlus, 9375, check)
      call createCurrent(P_u, P_uAnti, P_ZQ, 7941, check)
      call createCurrent(P_g, P_GPlus, P_GMinus, P_g, 10688, check)
      call createCurrent(P_WQPlus, P_s, P_cAnti, 2967, check)
      call createCurrent(P_A, P_HMinus, P_Ha, P_WPlus, 2840, check)
      call createCurrent(P_Hh, P_ghWpAnti, P_Hh, P_ghWp, 5899, check)
      call createCurrent(P_HPlus, P_A, P_GMinus, P_Z, 9178, check)
      call createCurrent(P_Ha, P_Hh, P_HMinus, P_HPlus, 9033, check)
      call createCurrent(P_GMinus, P_ghA, P_ghWmAnti, P_G0, 2399, check)
      call createCurrent(P_HPlus, P_WMinus, P_Z, P_Hh, 402, check)
      call createCurrent(P_A, P_Z, P_ghWpAnti, P_ghWp, 6786, check)
      call createCurrent(P_WQMinus, P_ghA, P_WPlus, P_ghZAnti, 821, check)
      call createCurrent(P_HPlus, P_WMinus, P_Hl, P_A, 1808, check)
      call createCurrent(P_HMinus, P_HMinus, P_HPlus, P_HPlus, 2893, check)
      call createCurrent(P_WPlus, P_A, P_Ha, P_HMinus, 4043, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghWpAnti, P_G0, 3827, check)
      call createCurrent(P_AQ, P_Z, P_ghWp, P_ghWpAnti, 3270, check)
      call createCurrent(P_Hl, P_ghWm, P_Hh, P_ghWmAnti, 9435, check)
      call createCurrent(P_G0, P_G0, P_HPlus, P_GMinus, 4159, check)
      call createCurrent(P_G0, P_HMinus, P_Hl, P_HPlus, 9046, check)
      call createCurrent(P_ghWm, P_Hl, P_ghZAnti, P_HQPlus, 7970, check)
      call createCurrent(P_HQMinus, P_Hl, P_GPlus, P_HaQ, 239, check)
      call createCurrent(P_A, P_G0, P_G0, P_Z, 10123, check)
      call createCurrent(P_WPlus, P_WMinus, P_ghWp, P_ghWpAnti, 3875, check)
      call createCurrent(P_WQPlus, P_Ha, P_HMinus, P_AQ, 7975, check)
      call createCurrent(P_HMinus, P_ghWpAnti, P_GPlus, P_ghWp, 10299, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Hh, P_Hh, 3496, check)
      call createCurrent(P_ghZAnti, P_Ha, P_G0, P_ghZ, 10278, check)
      call createCurrent(P_WQPlus, P_G0, P_GMinus, P_AQ, 6091, check)
      call createCurrent(P_HlQ, P_Ha, P_WMinus, P_WQPlus, 5301, check)
      call createCurrent(P_ghWp, P_A, P_ghWpAnti, P_Z, 4851, check)
      call createCurrent(P_ghWpAnti, P_A, P_WPlus, P_ghZ, 2350, check)
      call createCurrent(P_Hh, P_A, P_Hh, P_Z, 9242, check)
      call createCurrent(P_A, P_HMinus, P_WPlus, P_Hh, 1364, check)
      call createCurrent(P_HMinus, P_Hh, P_WPlus, 4239, check)
      call createCurrent(P_Hh, P_WMinus, P_HPlus, P_Z, 6362, check)
      call createCurrent(P_g, P_g, P_GMinus, P_HPlus, 10695, check)
      call createCurrent(P_GQMinus, P_HPlus, P_HMinus, P_HQPlus, 2289, check)
      call createCurrent(P_HMinus, P_nu_e, P_ePlus, 3010, check)
      call createCurrent(P_Ha, P_G0, P_Z, P_Z, 10076, check)
      call createCurrent(P_GPlus, P_G0, P_Hh, P_GMinus, 9864, check)
      call createCurrent(P_HQPlus, P_Ha, P_WMinus, P_AQ, 8676, check)
      call createCurrent(P_GMinus, P_Hh, P_G0, P_HPlus, 702, check)
      call createCurrent(P_HQPlus, P_Hl, P_HQMinus, 1276, check)
      call createCurrent(P_GQPlus, P_ghZAnti, P_GMinus, P_ghA, 6150, check)
      call createCurrent(P_HMinus, P_u, P_dAnti, 2182, check)
      call createCurrent(P_A, P_A, P_ghWmAnti, P_ghWm, 7129, check)
      call createCurrent(P_G0, P_Hh, P_Hl, P_Ha, 1272, check)
      call createCurrent(P_d, P_GPlus, P_uAnti, 858, check)
      call createCurrent(P_WQPlus, P_GMinus, P_ZQ, 954, check)
      call createCurrent(P_HaQ, P_A, P_WPlus, P_HQMinus, 40, check)
      call createCurrent(P_ghAAnti, P_Hl, P_ghWp, P_HMinus, 6286, check)
      call createCurrent(P_Z, P_GMinus, P_Z, P_GPlus, 8025, check)
      call createCurrent(P_ZQ, P_ghWmAnti, P_Z, P_ghWm, 5162, check)
      call createCurrent(P_d, P_dAnti, P_G0, 3215, check)
      call createCurrent(P_WMinus, P_Z, P_ghZ, P_ghWmAnti, 7751, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_Z, P_ghZ, 7328, check)
      call createCurrent(P_HQMinus, P_GPlus, P_Hh, P_HhQ, 541, check)
      call createCurrent(P_Hl, P_HMinus, P_G0, P_HPlus, 8863, check)
      call createCurrent(P_HaQ, P_HPlus, P_GMinus, P_HhQ, 3673, check)
      call createCurrent(P_WQMinus, P_WPlus, P_Hh, P_GQ0, 2151, check)
      call createCurrent(P_HPlus, P_Ha, P_GMinus, 5840, check)
      call createCurrent(P_Z, P_HMinus, P_Hl, P_WPlus, 8007, check)
      call createCurrent(P_HPlus, P_Hh, P_WMinus, P_A, 4300, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_ghWp, 5446, check)
      call createCurrent(P_WQMinus, P_Z, P_WPlus, P_ZQ, 6874, check)
      call createCurrent(P_HPlus, P_HMinus, P_G0, 9140, check)
      call createCurrent(P_HQPlus, P_GMinus, P_HaQ, 1577, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_HMinus, P_HhQ, 7341, check)
      call createCurrent(P_Hl, P_HPlus, P_ghZ, P_ghWpAnti, 6214, check)
      call createCurrent(P_GPlus, P_Hl, P_ghA, P_ghWpAnti, 5414, check)
      call createCurrent(P_Z, P_eMinus, P_ePlus, 5609, check)
      call createCurrent(P_AQ, P_WMinus, P_WQPlus, 2017, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_WPlus, P_WMinus, 2773, check)
      call createCurrent(P_ghWm, P_Z, P_WPlus, P_ghZAnti, 5251, check)
      call createCurrent(P_WQMinus, P_A, P_ghWmAnti, P_ghZ, 6334, check)
      call createCurrent(P_HMinus, P_Z, P_GPlus, P_Z, 10427, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_Z, P_WQMinus, 248, check)
      call createCurrent(P_Hh, P_Ha, P_HMinus, P_GPlus, 6102, check)
      call createCurrent(P_G0, P_GPlus, P_WMinus, P_Z, 5767, check)
      call createCurrent(P_GQMinus, P_Ha, P_GPlus, P_HlQ, 2702, check)
      call createCurrent(P_WMinus, P_Hh, P_Hh, P_WPlus, 998, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_ghZ, P_GQPlus, 7885, check)
      call createCurrent(P_ghZ, P_WMinus, P_ghAAnti, P_WPlus, 2748, check)
      call createCurrent(P_HhQ, P_WPlus, P_G0, P_WQMinus, 6192, check)
      call createCurrent(P_Z, P_A, P_Z, P_Z, 10638, check)
      call createCurrent(P_Hh, P_GPlus, P_G0, P_HMinus, 6567, check)
      call createCurrent(P_GQ0, P_WMinus, P_Hh, P_WQPlus, 1624, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghA, P_G0, 5764, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_Hh, P_HPlus, 2444, check)
      call createCurrent(P_Hh, P_Hh, P_Hl, P_Hl, 5417, check)
      call createCurrent(P_HPlus, P_ghZAnti, P_ghZ, P_HMinus, 5752, check)
      call createCurrent(P_GPlus, P_ghAAnti, P_HMinus, P_ghZ, 9863, check)
      call createCurrent(P_HQPlus, P_Ha, P_ghWpAnti, P_ghZ, 8718, check)
      call createCurrent(P_GMinus, P_WPlus, P_A, 3134, check)
      call createCurrent(P_ghGAnti, P_g, P_ghG, P_g, 946, check)
      call createCurrent(P_nu_tau, P_tauPlus, P_HQMinus, 675, check)
      call createCurrent(P_Hh, P_HMinus, P_HPlus, 6544, check)
      call createCurrent(P_ghWm, P_Z, P_A, P_ghWmAnti, 3120, check)
      call createCurrent(P_tauMinus, P_nu_tauAnti, P_GQPlus, 5015, check)
      call createCurrent(P_AQ, P_A, P_GMinus, P_GQPlus, 8317, check)
      call createCurrent(P_GPlus, P_cAnti, P_s, 4522, check)
      call createCurrent(P_A, P_Hl, P_Hl, P_A, 10670, check)
      call createCurrent(P_Ha, P_Z, P_WMinus, P_GPlus, 9817, check)
      call createCurrent(P_GPlus, P_A, P_WMinus, P_Ha, 8930, check)
      call createCurrent(P_HPlus, P_G0, P_Ha, P_HMinus, 241, check)
      call createCurrent(P_t, P_tAnti, P_gQ, 6055, check)
      call createCurrent(P_GQ0, P_Hl, P_ghWm, P_ghWmAnti, 2856, check)
      call createCurrent(P_HQMinus, P_Hh, P_WPlus, P_AQ, 3623, check)
      call createCurrent(P_Hh, P_ghZ, P_ghWpAnti, P_GPlus, 1923, check)
      call createCurrent(P_GPlus, P_GMinus, P_Ha, 9313, check)
      call createCurrent(P_WMinus, P_ghZ, P_ghWmAnti, 6905, check)
      call createCurrent(P_Hh, P_Hl, P_ghWp, P_ghWpAnti, 9440, check)
      call createCurrent(P_GPlus, P_Ha, P_ghWpAnti, P_ghZ, 9969, check)
      call createCurrent(P_HQPlus, P_GMinus, P_Hl, P_GQ0, 3427, check)
      call createCurrent(P_HlQ, P_WPlus, P_A, P_GQMinus, 4464, check)
      call createCurrent(P_WPlus, P_Ha, P_GMinus, P_A, 9731, check)
      call createCurrent(P_ghA, P_ghZAnti, P_GPlus, P_GQMinus, 6633, check)
      call createCurrent(P_nu_muAnti, P_nu_mu, P_ZQ, 256, check)
      call createCurrent(P_GQPlus, P_ghWpAnti, P_G0, P_ghZ, 8576, check)
      call createCurrent(P_WPlus, P_ghA, P_ghWpAnti, 109, check)
      call createCurrent(P_HMinus, P_HPlus, P_GMinus, P_GPlus, 3606, check)
      call createCurrent(P_GQMinus, P_G0, P_Ha, P_HQPlus, 1369, check)
      call createCurrent(P_Z, P_WPlus, P_ghAAnti, P_ghWm, 6515, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_A, P_AQ, 8720, check)
      call createCurrent(P_GQMinus, P_Hh, P_G0, P_HQPlus, 2132, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_HPlus, P_Hh, 5991, check)
      call createCurrent(P_WQMinus, P_Z, P_HQPlus, 8577, check)
      call createCurrent(P_HQMinus, P_Ha, P_HPlus, P_GQ0, 7310, check)
      call createCurrent(P_HQPlus, P_WMinus, P_HaQ, 4876, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghWm, P_WPlus, 7037, check)
      call createCurrent(P_HaQ, P_HMinus, P_A, P_WQPlus, 3599, check)
      call createCurrent(P_GPlus, P_ghWm, P_Ha, P_ghAAnti, 9498, check)
      call createCurrent(P_ghWm, P_Ha, P_ghWmAnti, P_HaQ, 4045, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_WPlus, P_ghZ, 1735, check)
      call createCurrent(P_Hh, P_ghWm, P_GPlus, P_ghAAnti, 8802, check)
      call createCurrent(P_HPlus, P_HMinus, P_Hl, P_G0, 10156, check)
      call createCurrent(P_GQ0, P_Hl, P_HaQ, 5128, check)
      call createCurrent(P_HQMinus, P_HPlus, P_A, P_ZQ, 2887, check)
      call createCurrent(P_GMinus, P_GMinus, P_GPlus, P_HPlus, 8621, check)
      call createCurrent(P_HQPlus, P_WMinus, P_Ha, P_ZQ, 698, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghWp, P_GQ0, 2729, check)
      call createCurrent(P_GQPlus, P_GMinus, P_ghZAnti, P_ghZ, 410, check)
      call createCurrent(P_Hl, P_HPlus, P_HMinus, P_G0, 9597, check)
      call createCurrent(P_Hh, P_g, P_g, 10570, check)
      call createCurrent(P_HPlus, P_GMinus, P_Hl, 3304, check)
      call createCurrent(P_Hl, P_GPlus, P_Ha, P_GMinus, 9900, check)
      call createCurrent(P_GQMinus, P_Hh, P_Hl, P_GQPlus, 5279, check)
      call createCurrent(P_Z, P_Ha, P_GMinus, P_WPlus, 9766, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_G0, P_HMinus, 9645, check)
      call createCurrent(P_ghA, P_ghAAnti, P_HPlus, P_GMinus, 9213, check)
      call createCurrent(P_HaQ, P_Hl, P_HMinus, P_GQPlus, 1358, check)
      call createCurrent(P_Hl, P_G0, P_G0, 2353, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_GPlus, 7645, check)
      call createCurrent(P_HMinus, P_Hl, P_ghZ, P_ghWmAnti, 6625, check)
      call createCurrent(P_Z, P_WMinus, P_Hh, P_HPlus, 2600, check)
      call createCurrent(P_ghWpAnti, P_Z, P_ghWp, P_ZQ, 5919, check)
      call createCurrent(P_Hl, P_GMinus, P_GPlus, P_Hl, 8450, check)
      call createCurrent(P_Ha, P_ghWmAnti, P_GMinus, P_ghZ, 9824, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_HMinus, P_HPlus, 5531, check)
      call createCurrent(P_HhQ, P_dAnti, P_d, 4752, check)
      call createCurrent(P_ghWp, P_G0, P_ghWpAnti, P_Ha, 9209, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghWmAnti, P_Ha, 9739, check)
      call createCurrent(P_HQMinus, P_HPlus, P_HaQ, 3158, check)
      call createCurrent(P_WQMinus, P_Ha, P_WPlus, P_HhQ, 7418, check)
      call createCurrent(P_Ha, P_Hh, P_HPlus, P_HMinus, 10200, check)
      call createCurrent(P_HPlus, P_G0, P_GMinus, P_Hh, 5689, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_G0, P_HhQ, 6242, check)
      call createCurrent(P_WPlus, P_G0, P_GMinus, 2275, check)
      call createCurrent(P_GQPlus, P_Hh, P_WQMinus, 5039, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_HMinus, P_HaQ, 6857, check)
      call createCurrent(P_ZQ, P_Ha, P_WPlus, P_HQMinus, 3142, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_Hh, P_GMinus, 1732, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_HMinus, 3741, check)
      call createCurrent(P_GPlus, P_A, P_Hl, P_WMinus, 1642, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_Hl, P_HMinus, 7772, check)
      call createCurrent(P_HPlus, P_G0, P_ghWm, P_ghAAnti, 9186, check)
      call createCurrent(P_A, P_ghWm, P_Z, P_ghWmAnti, 3749, check)
      call createCurrent(P_HMinus, P_Z, P_WPlus, P_G0, 9049, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_G0, P_ghA, 6278, check)
      call createCurrent(P_HaQ, P_HMinus, P_G0, P_GQPlus, 1094, check)
      call createCurrent(P_HPlus, P_Ha, P_A, P_WMinus, 8719, check)
      call createCurrent(P_A, P_nu_mu, P_nu_muAnti, 9422, check)
      call createCurrent(P_GMinus, P_ghZ, P_ghAAnti, P_HPlus, 9603, check)
      call createCurrent(P_ghWm, P_HPlus, P_G0, P_ghAAnti, 9641, check)
      call createCurrent(P_WMinus, P_GPlus, P_A, P_Hh, 151, check)
      call createCurrent(P_HhQ, P_Ha, P_GMinus, P_GQPlus, 6838, check)
      call createCurrent(P_GPlus, P_A, P_GMinus, P_A, 6194, check)
      call createCurrent(P_G0, P_G0, P_ghWmAnti, P_ghWm, 274, check)
      call createCurrent(P_HaQ, P_GPlus, P_HQMinus, 5040, check)
      call createCurrent(P_HMinus, P_ghZAnti, P_ghWp, P_G0, 10041, check)
      call createCurrent(P_Hl, P_HPlus, P_G0, P_GMinus, 3618, check)
      call createCurrent(P_Z, P_A, P_Hl, P_Hl, 10171, check)
      call createCurrent(P_ghZ, P_HMinus, P_ghAAnti, P_HQPlus, 1486, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_GMinus, P_ghZ, 6599, check)
      call createCurrent(P_GPlus, P_Z, P_Z, P_GMinus, 2312, check)
      call createCurrent(P_HPlus, P_GMinus, P_g, P_g, 10658, check)
      call createCurrent(P_Ha, P_Ha, P_GMinus, P_GPlus, 468, check)
      call createCurrent(P_WQPlus, P_WMinus, P_HaQ, 6196, check)
      call createCurrent(P_HhQ, P_Hh, P_HMinus, P_HQPlus, 3331, check)
      call createCurrent(P_Hl, P_HPlus, P_GMinus, P_G0, 4088, check)
      call createCurrent(P_ZQ, P_sAnti, P_s, 1019, check)
      call createCurrent(P_GMinus, P_ghAAnti, P_GPlus, P_ghZ, 4087, check)
      call createCurrent(P_muMinus, P_Hh, P_muPlus, 6927, check)
      call createCurrent(P_GPlus, P_Hl, P_G0, P_GMinus, 10425, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_GMinus, P_GQ0, 7779, check)
      call createCurrent(P_GMinus, P_WPlus, P_G0, P_Z, 7160, check)
      call createCurrent(P_b, P_bAnti, P_HlQ, 6098, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_Hh, P_HQPlus, 510, check)
      call createCurrent(P_ghZ, P_HPlus, P_ghAAnti, P_HQMinus, 1686, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghWp, P_HMinus, 9550, check)
      call createCurrent(P_HhQ, P_ghWmAnti, P_GMinus, P_ghZ, 6490, check)
      call createCurrent(P_HPlus, P_G0, P_HMinus, P_Hh, 9253, check)
      call createCurrent(P_Ha, P_ghAAnti, P_ghWp, P_GMinus, 10281, check)
      call createCurrent(P_G0, P_eMinus, P_ePlus, 2547, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghZ, P_Hl, 7351, check)
      call createCurrent(P_Z, P_GMinus, P_Z, P_HPlus, 8846, check)
      call createCurrent(P_Ha, P_Hl, P_GPlus, P_HMinus, 1589, check)
      call createCurrent(P_GQ0, P_GMinus, P_A, P_WQPlus, 6189, check)
      call createCurrent(P_WPlus, P_G0, P_HMinus, 9871, check)
      call createCurrent(P_HhQ, P_GPlus, P_Hh, P_HQMinus, 6615, check)
      call createCurrent(P_A, P_WMinus, P_G0, P_HPlus, 9803, check)
      call createCurrent(P_WPlus, P_Hh, P_Hh, P_WMinus, 246, check)
      call createCurrent(P_G0, P_GMinus, P_GPlus, P_Ha, 6206, check)
      call createCurrent(P_WPlus, P_HMinus, P_Hl, P_A, 4931, check)
      call createCurrent(P_ghZAnti, P_Z, P_ghWm, P_WPlus, 2718, check)
      call createCurrent(P_G0, P_A, P_G0, P_A, 10746, check)
      call createCurrent(P_Hl, P_ghZ, P_GPlus, P_ghWpAnti, 6822, check)
      call createCurrent(P_HhQ, P_Ha, P_Hl, P_GQ0, 1393, check)
      call createCurrent(P_GMinus, P_HPlus, P_ghWmAnti, P_ghWm, 9438, check)
      call createCurrent(P_ZQ, P_A, P_ghWm, P_ghWmAnti, 3383, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_WQPlus, 428, check)
      call createCurrent(P_WQMinus, P_Ha, P_Z, P_HQPlus, 225, check)
      call createCurrent(P_HMinus, P_GPlus, P_WPlus, P_WMinus, 10339, check)
      call createCurrent(P_GQMinus, P_ghZ, P_GPlus, P_ghZAnti, 4772, check)
      call createCurrent(P_Hl, P_s, P_sAnti, 7825, check)
      call createCurrent(P_ghWpAnti, P_A, P_ghWp, P_Z, 594, check)
      call createCurrent(P_A, P_WPlus, P_GMinus, P_Hl, 1916, check)
      call createCurrent(P_Z, P_A, P_A, P_A, 10597, check)
      call createCurrent(P_G0, P_Z, P_HMinus, P_WPlus, 9648, check)
      call createCurrent(P_GPlus, P_HMinus, P_Hl, P_Hl, 3718, check)
      call createCurrent(P_ghWmAnti, P_HMinus, P_HPlus, P_ghWm, 3990, check)
      call createCurrent(P_Hl, P_A, P_Z, 9749, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_Hl, P_ghA, 2448, check)
      call createCurrent(P_HPlus, P_ghA, P_ghWpAnti, P_Hh, 8205, check)
      call createCurrent(P_ZQ, P_WPlus, P_Z, P_WQMinus, 2190, check)
      call createCurrent(P_WQMinus, P_Hl, P_Z, P_HQPlus, 5161, check)
      call createCurrent(P_dAnti, P_d, P_ZQ, 842, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghZAnti, 3574, check)
      call createCurrent(P_Hh, P_ghWm, P_ghZAnti, P_GPlus, 7839, check)
      call createCurrent(P_Hh, P_HMinus, P_Ha, P_GPlus, 955, check)
      call createCurrent(P_WQPlus, P_A, P_ghWpAnti, P_ghZ, 8121, check)
      call createCurrent(P_HMinus, P_g, P_g, P_HPlus, 10545, check)
      call createCurrent(P_WQMinus, P_Z, P_Ha, P_HQPlus, 4176, check)
      call createCurrent(P_Z, P_A, P_G0, P_G0, 9578, check)
      call createCurrent(P_GMinus, P_A, P_A, P_HPlus, 9286, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_HPlus, P_HaQ, 1299, check)
      call createCurrent(P_Hh, P_Hl, P_G0, P_Ha, 2580, check)
      call createCurrent(P_GQMinus, P_ghWp, P_GPlus, P_ghWpAnti, 8482, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghZ, P_Ha, 9319, check)
      call createCurrent(P_HPlus, P_Z, P_GMinus, P_A, 8971, check)
      call createCurrent(P_WQMinus, P_Hl, P_GPlus, P_ZQ, 2660, check)
      call createCurrent(P_Hl, P_ghWm, P_ghWmAnti, P_Hl, 7950, check)
      call createCurrent(P_WPlus, P_Ha, P_A, P_HMinus, 4196, check)
      call createCurrent(P_HlQ, P_HPlus, P_ghWm, P_ghAAnti, 325, check)
      call createCurrent(P_WQPlus, P_HMinus, P_Z, P_HlQ, 1792, check)
      call createCurrent(P_tauMinus, P_WPlus, P_nu_tauAnti, 558, check)
      call createCurrent(P_nu_mu, P_muPlus, P_GQMinus, 5744, check)
      call createCurrent(P_AQ, P_ePlus, P_eMinus, 2222, check)
      call createCurrent(P_g, P_g, P_Hl, 10731, check)
      call createCurrent(P_nu_e, P_nu_eAnti, P_Z, 7212, check)
      call createCurrent(P_HlQ, P_Hh, P_G0, P_GQ0, 3237, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_Hl, P_GMinus, 6624, check)
      call createCurrent(P_GPlus, P_ghAAnti, P_ghWm, P_G0, 1687, check)
      call createCurrent(P_HPlus, P_Ha, P_ghWpAnti, P_ghZ, 3073, check)
      call createCurrent(P_HlQ, P_Hl, P_HlQ, 5908, check)
      call createCurrent(P_ghZAnti, P_ghA, P_HPlus, P_HMinus, 7250, check)
      call createCurrent(P_AQ, P_HPlus, P_HMinus, P_AQ, 343, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_GPlus, P_Ha, 8874, check)
      call createCurrent(P_ghA, P_ghAAnti, P_HMinus, P_HPlus, 303, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_G0, P_GPlus, 8140, check)
      call createCurrent(P_Z, P_nu_tau, P_nu_tauAnti, 162, check)
      call createCurrent(P_Hl, P_GMinus, P_G0, P_GPlus, 9927, check)
      call createCurrent(P_Hh, P_HMinus, P_ghA, P_ghWmAnti, 658, check)
      call createCurrent(P_muMinus, P_muPlus, P_A, 1793, check)
      call createCurrent(P_ghZ, P_HMinus, P_ghWmAnti, P_Hl, 7466, check)
      call createCurrent(P_GQPlus, P_HMinus, P_Hl, P_HlQ, 1247, check)
      call createCurrent(P_Z, P_WMinus, P_Hl, P_GPlus, 2577, check)
      call createCurrent(P_WQPlus, P_nu_tauAnti, P_tauMinus, 2454, check)
      call createCurrent(P_WQPlus, P_WMinus, P_ghZAnti, P_ghA, 8081, check)
      call createCurrent(P_HaQ, P_HPlus, P_HMinus, P_GQ0, 5255, check)
      call createCurrent(P_Ha, P_ghWpAnti, P_ghA, P_HPlus, 6149, check)
      call createCurrent(P_HhQ, P_muMinus, P_muPlus, 7700, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghAAnti, P_HPlus, 9728, check)
      call createCurrent(P_GMinus, P_GPlus, P_HPlus, P_GMinus, 413, check)
      call createCurrent(P_ghWm, P_Hl, P_ghWmAnti, P_HaQ, 1387, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_Ha, P_G0, 9509, check)
      call createCurrent(P_ghWm, P_HPlus, P_ghZAnti, P_HaQ, 242, check)
      call createCurrent(P_WPlus, P_Hh, P_WMinus, 5948, check)
      call createCurrent(P_HMinus, P_G0, P_ghZAnti, P_ghWp, 10459, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_Hl, 477, check)
      call createCurrent(P_G0, P_A, P_WMinus, P_GPlus, 7355, check)
      call createCurrent(P_ghZ, P_HMinus, P_ghZAnti, P_HPlus, 2449, check)
      call createCurrent(P_GQMinus, P_nu_e, P_ePlus, 7205, check)
      call createCurrent(P_HQMinus, P_Ha, P_G0, P_HQPlus, 2406, check)
      call createCurrent(P_GPlus, P_Hh, P_Hh, P_GMinus, 2551, check)
      call createCurrent(P_HMinus, P_Ha, P_ghAAnti, P_ghWp, 1493, check)
      call createCurrent(P_HhQ, P_sAnti, P_s, 3483, check)
      call createCurrent(P_GQMinus, P_ghZAnti, P_ghWp, 5749, check)
      call createCurrent(P_HQPlus, P_HMinus, P_Hl, P_HlQ, 6978, check)
      call createCurrent(P_G0, P_GPlus, P_HMinus, P_Ha, 1148, check)
      call createCurrent(P_Ha, P_Hh, P_A, 9776, check)
      call createCurrent(P_HhQ, P_GMinus, P_ghWmAnti, P_ghZ, 8432, check)
      call createCurrent(P_HMinus, P_Hl, P_GPlus, P_G0, 883, check)
      call createCurrent(P_GQMinus, P_GPlus, P_ghA, P_ghAAnti, 4566, check)
      call createCurrent(P_HaQ, P_HPlus, P_Hl, P_HQMinus, 4852, check)
      call createCurrent(P_GQ0, P_c, P_cAnti, 5733, check)
      call createCurrent(P_ghWm, P_Hh, P_ghZAnti, P_HQPlus, 5795, check)
      call createCurrent(P_Z, P_HPlus, P_WMinus, P_G0, 9590, check)
      call createCurrent(P_Hl, P_ghWpAnti, P_ghWp, P_Hl, 2998, check)
      call createCurrent(P_WQMinus, P_dAnti, P_u, 1096, check)
      call createCurrent(P_A, P_GMinus, P_WPlus, P_G0, 8142, check)
      call createCurrent(P_WPlus, P_WMinus, P_Ha, P_Ha, 8438, check)
      call createCurrent(P_ZQ, P_eMinus, P_ePlus, 4187, check)
      call createCurrent(P_ghWm, P_Ha, P_GPlus, P_ghAAnti, 9914, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_HQPlus, 3431, check)
      call createCurrent(P_G0, P_HPlus, P_Hh, P_GMinus, 6878, check)
      call createCurrent(P_ghWmAnti, P_G0, P_ghA, P_HMinus, 9158, check)
      call createCurrent(P_HaQ, P_WMinus, P_WQPlus, 3449, check)
      call createCurrent(P_Ha, P_HMinus, P_Hl, P_GPlus, 355, check)
      call createCurrent(P_Ha, P_Hh, P_Hh, P_G0, 5725, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_HMinus, P_Hl, 7001, check)
      call createCurrent(P_ghWm, P_Hh, P_GPlus, P_ghZAnti, 8075, check)
      call createCurrent(P_WPlus, P_b, P_tAnti, 6894, check)
      call createCurrent(P_HaQ, P_ghWp, P_Hl, P_ghWpAnti, 3397, check)
      call createCurrent(P_Hh, P_Hl, P_HMinus, P_HPlus, 1988, check)
      call createCurrent(P_ghA, P_GPlus, P_ghWpAnti, 912, check)
      call createCurrent(P_GQMinus, P_sAnti, P_c, 7072, check)
      call createCurrent(P_GMinus, P_A, P_WPlus, P_Ha, 9102, check)
      call createCurrent(P_G0, P_WMinus, P_HPlus, P_Z, 9683, check)
      call createCurrent(P_HPlus, P_GMinus, P_ghA, P_ghAAnti, 10085, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_GMinus, P_HPlus, 9948, check)
      call createCurrent(P_Z, P_A, P_G0, P_Ha, 10495, check)
      call createCurrent(P_GPlus, P_Ha, P_GMinus, P_Ha, 1150, check)
      call createCurrent(P_WQPlus, P_Z, P_ghA, P_ghWpAnti, 252, check)
      call createCurrent(P_GMinus, P_WMinus, P_HPlus, P_WPlus, 10072, check)
      call createCurrent(P_nu_muAnti, P_A, P_nu_mu, 9256, check)
      call createCurrent(P_HaQ, P_HPlus, P_HMinus, P_HaQ, 1726, check)
      call createCurrent(P_GQMinus, P_Hl, P_WQPlus, 5465, check)
      call createCurrent(P_WMinus, P_WPlus, P_G0, P_Ha, 9820, check)
      call createCurrent(P_GMinus, P_ghAAnti, P_ghA, P_HPlus, 9493, check)
      call createCurrent(P_ZQ, P_WPlus, P_WMinus, P_ZQ, 5539, check)
      call createCurrent(P_HaQ, P_GMinus, P_HPlus, P_HlQ, 1285, check)
      call createCurrent(P_GQMinus, P_HPlus, P_Ha, P_HaQ, 8544, check)
      call createCurrent(P_GPlus, P_WMinus, P_Hl, 3307, check)
      call createCurrent(P_HPlus, P_WMinus, P_HMinus, P_WPlus, 3774, check)
      call createCurrent(P_GQ0, P_ghWp, P_Hl, P_ghWpAnti, 862, check)
      call createCurrent(P_Z, P_g, P_g, P_Z, 10741, check)
      call createCurrent(P_Z, P_ghZ, P_ghWmAnti, P_WMinus, 5902, check)
      call createCurrent(P_HQMinus, P_Hl, P_G0, P_GQPlus, 2158, check)
      call createCurrent(P_GPlus, P_g, P_HMinus, P_g, 10518, check)
      call createCurrent(P_Z, P_GMinus, P_WPlus, P_G0, 5186, check)
      call createCurrent(P_Ha, P_GPlus, P_ghA, P_ghWpAnti, 10335, check)
      call createCurrent(P_HMinus, P_GPlus, P_HMinus, P_GPlus, 760, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Z, P_ZQ, 1108, check)
      call createCurrent(P_HMinus, P_WPlus, P_Hh, P_A, 170, check)
      call createCurrent(P_GQ0, P_G0, P_HMinus, P_GQPlus, 1138, check)
      call createCurrent(P_Hl, P_WPlus, P_HMinus, 8663, check)
      call createCurrent(P_HlQ, P_Hl, P_Hh, P_HlQ, 5750, check)
      call createCurrent(P_ghWp, P_A, P_A, P_ghWpAnti, 7774, check)
      call createCurrent(P_WQPlus, P_ghZ, P_Z, P_ghWpAnti, 1992, check)
      call createCurrent(P_HhQ, P_GPlus, P_GQMinus, 7680, check)
      call createCurrent(P_HlQ, P_A, P_WMinus, P_HQPlus, 756, check)
      call createCurrent(P_HlQ, P_Ha, P_ghWp, P_ghWpAnti, 5315, check)
      call createCurrent(P_cAnti, P_c, P_HaQ, 4217, check)
      call createCurrent(P_GPlus, P_ghZ, P_GMinus, P_ghZAnti, 6510, check)
      call createCurrent(P_WMinus, P_WPlus, P_ghWm, P_ghWmAnti, 6968, check)
      call createCurrent(P_G0, P_Ha, P_WPlus, P_WMinus, 9415, check)
      call createCurrent(P_HMinus, P_A, P_WPlus, P_Hh, 7696, check)
      call createCurrent(P_Hl, P_GMinus, P_WPlus, 2031, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghWp, P_Hl, 3436, check)
      call createCurrent(P_ghZAnti, P_ghA, P_GPlus, P_HMinus, 10276, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghZAnti, P_HMinus, 9395, check)
      call createCurrent(P_GMinus, P_HMinus, P_HPlus, P_GPlus, 294, check)
      call createCurrent(P_nu_muAnti, P_HPlus, P_muMinus, 348, check)
      call createCurrent(P_ghZ, P_WMinus, P_A, P_ghWmAnti, 6674, check)
      call createCurrent(P_WMinus, P_Hh, P_WPlus, 4744, check)
      call createCurrent(P_WPlus, P_WMinus, P_A, P_Z, 7390, check)
      call createCurrent(P_G0, P_muPlus, P_muMinus, 5762, check)
      call createCurrent(P_Z, P_Z, P_ghWpAnti, P_ghWp, 1899, check)
      call createCurrent(P_WMinus, P_HPlus, P_GMinus, P_WPlus, 10319, check)
      call createCurrent(P_gQ, P_t, P_tAnti, 7216, check)
      call createCurrent(P_HaQ, P_HMinus, P_Ha, P_HQPlus, 7425, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_WMinus, P_A, 4340, check)
      call createCurrent(P_GQ0, P_ghZ, P_G0, P_ghZAnti, 2159, check)
      call createCurrent(P_HMinus, P_nu_mu, P_muPlus, 2521, check)
      call createCurrent(P_A, P_GMinus, P_G0, P_WPlus, 1287, check)
      call createCurrent(P_ghA, P_HPlus, P_ghWpAnti, P_Hh, 2755, check)
      call createCurrent(P_Hh, P_Hh, P_WMinus, P_WPlus, 4525, check)
      call createCurrent(P_ghWm, P_Hl, P_ghZAnti, P_HPlus, 6350, check)
      call createCurrent(P_G0, P_GMinus, P_Hh, P_HPlus, 7549, check)
      call createCurrent(P_HlQ, P_Ha, P_ghWm, P_ghWmAnti, 5718, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_HPlus, P_HQMinus, 5734, check)
      call createCurrent(P_Ha, P_GPlus, P_HMinus, P_Ha, 4881, check)
      call createCurrent(P_HaQ, P_u, P_uAnti, 7726, check)
      call createCurrent(P_G0, P_GMinus, P_ghZ, P_ghWmAnti, 2067, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_GQ0, 1286, check)
      call createCurrent(P_eMinus, P_ePlus, P_GQ0, 7170, check)
      call createCurrent(P_A, P_WMinus, P_HPlus, P_Hl, 4213, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_Z, P_WMinus, 5477, check)
      call createCurrent(P_WQMinus, P_muPlus, P_nu_mu, 3363, check)
      call createCurrent(P_A, P_GPlus, P_WMinus, P_Hl, 4157, check)
      call createCurrent(P_nu_tauAnti, P_nu_tau, 8989, check)
      call createCurrent(P_GQPlus, P_WMinus, P_Hh, P_AQ, 8023, check)
      call createCurrent(P_Ha, P_ghWp, P_GMinus, P_ghAAnti, 9184, check)
      call createCurrent(P_WQPlus, P_Hh, P_GMinus, P_ZQ, 8204, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_WMinus, P_AQ, 5197, check)
      call createCurrent(P_nu_eAnti, P_WPlus, P_eMinus, 2120, check)
      call createCurrent(P_WQMinus, P_Hh, P_GPlus, P_AQ, 4000, check)
      call createCurrent(P_dAnti, P_u, P_HMinus, 8684, check)
      call createCurrent(P_Z, P_WMinus, P_Z, P_WPlus, 5987, check)
      call createCurrent(P_g, P_Ha, P_g, P_Ha, 10646, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_HPlus, P_HaQ, 199, check)
      call createCurrent(P_WPlus, P_WMinus, P_Hl, 7603, check)
      call createCurrent(P_Hl, P_WPlus, P_GMinus, 3596, check)
      call createCurrent(P_ZQ, P_bAnti, P_b, 5480, check)
      call createCurrent(P_WQMinus, P_Hh, P_WPlus, P_GQ0, 4206, check)
      call createCurrent(P_WPlus, P_HMinus, P_A, P_Hl, 4691, check)
      call createCurrent(P_ghWp, P_Hl, P_GMinus, P_ghAAnti, 7926, check)
      call createCurrent(P_WQMinus, P_Z, P_A, P_WQPlus, 3989, check)
      call createCurrent(P_G0, P_GMinus, P_ghWmAnti, P_ghA, 3647, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghZAnti, P_HlQ, 6065, check)
      call createCurrent(P_ghA, P_HMinus, P_HPlus, P_ghZAnti, 692, check)
      call createCurrent(P_Z, P_nu_mu, P_nu_muAnti, 5181, check)
      call createCurrent(P_ghWmAnti, P_HMinus, P_Hh, P_ghA, 7535, check)
      call createCurrent(P_G0, P_HPlus, P_Hl, P_GMinus, 2381, check)
      call createCurrent(P_HlQ, P_HPlus, P_ghWm, P_ghZAnti, 6971, check)
      call createCurrent(P_GMinus, P_Hh, P_HPlus, P_G0, 1228, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghWmAnti, P_GMinus, 8365, check)
      call createCurrent(P_ZQ, P_Hl, P_WPlus, P_HQMinus, 8218, check)
      call createCurrent(P_GQMinus, P_ghZAnti, P_Hh, P_ghWp, 8179, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghZAnti, 3540, check)
      call createCurrent(P_s, P_sAnti, P_GQ0, 7406, check)
      call createCurrent(P_GPlus, P_GMinus, P_Z, P_Z, 7880, check)
      call createCurrent(P_Hh, P_WMinus, P_HPlus, 8481, check)
      call createCurrent(P_WQMinus, P_Hl, P_WPlus, P_HlQ, 1810, check)
      call createCurrent(P_HQMinus, P_Hh, P_ghWmAnti, P_ghZ, 3944, check)
      call createCurrent(P_HPlus, P_ghZAnti, P_Ha, P_ghWm, 5478, check)
      call createCurrent(P_HPlus, P_ghWpAnti, P_G0, P_ghA, 9240, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_Hh, P_HQPlus, 70, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_ghWm, P_G0, 8032, check)
      call createCurrent(P_Ha, P_Ha, P_ghWmAnti, P_ghWm, 2050, check)
      call createCurrent(P_WMinus, P_Ha, P_GPlus, P_A, 9365, check)
      call createCurrent(P_HMinus, P_G0, P_Hh, P_HPlus, 9221, check)
      call createCurrent(P_ghAAnti, P_Hh, P_HPlus, P_ghWm, 8417, check)
      call createCurrent(P_GMinus, P_WPlus, P_HPlus, P_WMinus, 9071, check)
      call createCurrent(P_ghWpAnti, P_G0, P_ghZ, P_GPlus, 2113, check)
      call createCurrent(P_GQ0, P_Hh, P_GMinus, P_HQPlus, 3494, check)
      call createCurrent(P_GQPlus, P_ghWpAnti, P_ghZ, 3949, check)
      call createCurrent(P_HPlus, P_Hh, P_ghWm, P_ghZAnti, 3943, check)
      call createCurrent(P_WMinus, P_ghAAnti, P_WPlus, P_ghA, 4794, check)
      call createCurrent(P_Hl, P_GMinus, P_Ha, P_HPlus, 4544, check)
      call createCurrent(P_WMinus, P_ghAAnti, P_Z, P_ghWp, 6104, check)
      call createCurrent(P_GQPlus, P_GMinus, P_Hl, P_HlQ, 6964, check)
      call createCurrent(P_Z, P_WPlus, P_GMinus, P_Hh, 5329, check)
      call createCurrent(P_A, P_GMinus, P_GPlus, P_Z, 3769, check)
      call createCurrent(P_HMinus, P_c, P_sAnti, 2392, check)
      call createCurrent(P_WMinus, P_Z, P_GPlus, 791, check)
      call createCurrent(P_c, P_cAnti, P_Hl, 426, check)
      call createCurrent(P_GPlus, P_Z, P_WMinus, P_Ha, 9614, check)
      call createCurrent(P_HPlus, P_Z, P_WMinus, P_Ha, 4633, check)
      call createCurrent(P_HQPlus, P_GMinus, P_Hl, P_HaQ, 4097, check)
      call createCurrent(P_WPlus, P_Hh, P_GMinus, P_Z, 8040, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_GMinus, P_G0, 5911, check)
      call createCurrent(P_WQMinus, P_GPlus, P_A, P_GQ0, 6647, check)
      call createCurrent(P_WQMinus, P_ghA, P_Z, P_ghWmAnti, 5868, check)
      call createCurrent(P_HPlus, P_GMinus, P_HMinus, P_HPlus, 2033, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_ghWp, P_Hh, 8784, check)
      call createCurrent(P_ghZ, P_HPlus, P_G0, P_ghWpAnti, 9896, check)
      call createCurrent(P_Hh, P_Z, P_A, P_Hh, 9527, check)
      call createCurrent(P_G0, P_GMinus, P_ghWp, P_ghAAnti, 1578, check)
      call createCurrent(P_WPlus, P_A, P_GMinus, 2201, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_Hh, P_HPlus, 3829, check)
      call createCurrent(P_A, P_Z, P_HMinus, P_HPlus, 5253, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_WQPlus, 6851, check)
      call createCurrent(P_ZQ, P_ghWm, P_ghWmAnti, 29, check)
      call createCurrent(P_GQ0, P_ghZ, P_GMinus, P_ghWmAnti, 1874, check)
      call createCurrent(P_HMinus, P_ghZAnti, P_Ha, P_ghWp, 4119, check)
      call createCurrent(P_GMinus, P_GPlus, P_A, P_A, 1558, check)
      call createCurrent(P_d, P_uAnti, P_WPlus, 8571, check)
      call createCurrent(P_ghWp, P_GMinus, P_HPlus, P_ghWpAnti, 8933, check)
      call createCurrent(P_tauPlus, P_WMinus, P_nu_tau, 952, check)
      call createCurrent(P_b, P_tAnti, P_WPlus, 731, check)
      call createCurrent(P_Hl, P_ghWm, P_Hl, P_ghWmAnti, 5838, check)
      call createCurrent(P_Ha, P_GPlus, P_G0, P_GMinus, 3924, check)
      call createCurrent(P_G0, P_ghZAnti, P_Ha, P_ghZ, 9737, check)
      call createCurrent(P_u, P_HMinus, P_dAnti, 2659, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_WMinus, 8618, check)
      call createCurrent(P_HhQ, P_HPlus, P_GMinus, P_HaQ, 6059, check)
      call createCurrent(P_ZQ, P_A, P_ghWp, P_ghWpAnti, 2476, check)
      call createCurrent(P_GPlus, P_Hl, P_WMinus, P_Z, 2272, check)
      call createCurrent(P_WMinus, P_Z, P_Hh, P_HPlus, 1158, check)
      call createCurrent(P_ghWmAnti, P_Hl, P_GMinus, P_ghZ, 8634, check)
      call createCurrent(P_HMinus, P_WPlus, P_Hh, P_Z, 8227, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_WMinus, 5060, check)
      call createCurrent(P_Hh, P_A, P_GMinus, P_WPlus, 5199, check)
      call createCurrent(P_ghWp, P_A, P_ghAAnti, P_WMinus, 3706, check)
      call createCurrent(P_A, P_HPlus, P_Z, P_HMinus, 531, check)
      call createCurrent(P_A, P_G0, P_A, P_G0, 10631, check)
      call createCurrent(P_HQPlus, P_cAnti, P_s, 3985, check)
      call createCurrent(P_ghZ, P_GPlus, P_Hh, P_ghWpAnti, 6352, check)
      call createCurrent(P_nu_eAnti, P_eMinus, P_GQPlus, 7175, check)
      call createCurrent(P_Z, P_HMinus, P_GPlus, P_Z, 10269, check)
      call createCurrent(P_HQMinus, P_Z, P_Hl, P_WQPlus, 1966, check)
      call createCurrent(P_GMinus, P_ghWp, P_Hh, P_ghZAnti, 3583, check)
      call createCurrent(P_ghWpAnti, P_Ha, P_ghWp, P_G0, 9759, check)
      call createCurrent(P_HQMinus, P_Hh, P_ghWp, P_ghZAnti, 3714, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_Hl, P_GPlus, 5547, check)
      call createCurrent(P_HQMinus, P_ghAAnti, P_HPlus, P_ghZ, 4243, check)
      call createCurrent(P_Z, P_A, P_Ha, P_G0, 10659, check)
      call createCurrent(P_ZQ, P_Hl, P_HMinus, P_WQPlus, 2925, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghZAnti, P_Hh, 8757, check)
      call createCurrent(P_Hh, P_ghWmAnti, P_ghWm, 1978, check)
      call createCurrent(P_Hl, P_GPlus, P_ghWpAnti, P_ghA, 8078, check)
      call createCurrent(P_HQPlus, P_HMinus, P_ghZAnti, P_ghZ, 2553, check)
      call createCurrent(P_HMinus, P_ghZAnti, P_ghWp, P_Hh, 6191, check)
      call createCurrent(P_GQ0, P_GPlus, P_Hh, P_GQMinus, 2156, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_Ha, P_ghZ, 8934, check)
      call createCurrent(P_HMinus, P_WPlus, P_A, 1526, check)
      call createCurrent(P_Hl, P_ghWpAnti, P_ghWp, 4247, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_Hh, P_HMinus, 1506, check)
      call createCurrent(P_A, P_WPlus, P_G0, P_HMinus, 9457, check)
      call createCurrent(P_GQ0, P_WMinus, P_A, P_GQPlus, 5056, check)
      call createCurrent(P_WPlus, P_ghWm, P_ghAAnti, P_A, 837, check)
      call createCurrent(P_HhQ, P_HPlus, P_ghZAnti, P_ghWm, 8200, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Z, P_Z, 8270, check)
      call createCurrent(P_HPlus, P_G0, P_A, P_WMinus, 9991, check)
      call createCurrent(P_Hl, P_Z, P_Hl, P_Z, 7713, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_Z, P_WPlus, 6543, check)
      call createCurrent(P_Hh, P_GPlus, P_GMinus, P_Hl, 7939, check)
      call createCurrent(P_GQ0, P_tauMinus, P_tauPlus, 4299, check)
      call createCurrent(P_HPlus, P_ghWpAnti, P_G0, P_ghZ, 9513, check)
      call createCurrent(P_Ha, P_HPlus, P_Z, P_WMinus, 4082, check)
      call createCurrent(P_tauPlus, P_nu_tau, P_HQMinus, 5710, check)
      call createCurrent(P_Z, P_HPlus, P_GMinus, 9203, check)
      call createCurrent(P_WPlus, P_eMinus, P_nu_eAnti, 1510, check)
      call createCurrent(P_GQMinus, P_Hl, P_GQPlus, 6338, check)
      call createCurrent(P_Hl, P_HPlus, P_A, P_WMinus, 6446, check)
      call createCurrent(P_WMinus, P_ghAAnti, P_ghWp, 5333, check)
      call createCurrent(P_GPlus, P_HMinus, P_WMinus, P_WPlus, 9193, check)
      call createCurrent(P_Hl, P_ghWm, P_ghWmAnti, 3532, check)
      call createCurrent(P_HhQ, P_Hh, P_Z, P_ZQ, 1927, check)
      call createCurrent(P_GQPlus, P_ghWpAnti, P_Hh, P_ghA, 8692, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_GMinus, P_G0, 6416, check)
      call createCurrent(P_HQMinus, P_HPlus, P_GQ0, 5823, check)
      call createCurrent(P_ghWmAnti, P_HPlus, P_ghWm, P_HMinus, 804, check)
      call createCurrent(P_WMinus, P_WPlus, P_Ha, P_G0, 10247, check)
      call createCurrent(P_GQMinus, P_WPlus, P_Hh, P_AQ, 3321, check)
      call createCurrent(P_GPlus, P_Z, P_WMinus, P_G0, 431, check)
      call createCurrent(P_GPlus, P_G0, P_ghWpAnti, P_ghA, 3683, check)
      call createCurrent(P_ZQ, P_HMinus, P_WPlus, P_HlQ, 2160, check)
      call createCurrent(P_HMinus, P_HPlus, P_Z, 8660, check)
      call createCurrent(P_GQPlus, P_nu_muAnti, P_muMinus, 4379, check)
      call createCurrent(P_HMinus, P_G0, P_WPlus, 9755, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_WQMinus, 5195, check)
      call createCurrent(P_Hl, P_ghZ, P_Hl, P_ghZAnti, 3318, check)
      call createCurrent(P_HhQ, P_GMinus, P_Hl, P_GQPlus, 5955, check)
      call createCurrent(P_HPlus, P_Hh, P_G0, P_GMinus, 8468, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghWp, P_HlQ, 2608, check)
      call createCurrent(P_ghZ, P_HPlus, P_ghAAnti, P_HMinus, 8098, check)
      call createCurrent(P_GPlus, P_Hh, P_ghWpAnti, P_ghZ, 7412, check)
      call createCurrent(P_AQ, P_ghWm, P_ghWmAnti, 6638, check)
      call createCurrent(P_G0, P_G0, P_Hl, P_Hh, 3733, check)
      call createCurrent(P_HhQ, P_HPlus, P_HMinus, P_HlQ, 7960, check)
      call createCurrent(P_ghZAnti, P_Hh, P_ghZ, 1884, check)
      call createCurrent(P_HQPlus, P_HMinus, P_GMinus, P_GQPlus, 887, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Ha, P_Ha, 5617, check)
      call createCurrent(P_GQ0, P_HMinus, P_Hh, P_GQPlus, 8062, check)
      call createCurrent(P_Hh, P_Hl, P_HPlus, P_HMinus, 7292, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_GPlus, P_GQMinus, 3180, check)
      call createCurrent(P_Hh, P_ghZ, P_HMinus, P_ghWmAnti, 6691, check)
      call createCurrent(P_eMinus, P_ePlus, 8857, check)
      call createCurrent(P_GMinus, P_Z, P_WPlus, 1107, check)
      call createCurrent(P_Ha, P_HMinus, P_GPlus, P_Hh, 2597, check)
      call createCurrent(P_Z, P_HMinus, P_Ha, P_WPlus, 369, check)
      call createCurrent(P_Hh, P_HPlus, P_ghAAnti, P_ghWm, 3303, check)
      call createCurrent(P_Hl, P_HPlus, P_HMinus, P_Ha, 10453, check)
      call createCurrent(P_HQPlus, P_HMinus, P_HPlus, P_GQMinus, 6607, check)
      call createCurrent(P_Z, P_ghWmAnti, P_WMinus, P_ghA, 1600, check)
      call createCurrent(P_HPlus, P_ghWpAnti, P_HMinus, P_ghWp, 888, check)
      call createCurrent(P_G0, P_GMinus, P_Hh, P_GPlus, 9176, check)
      call createCurrent(P_A, P_WMinus, P_WPlus, P_Z, 5819, check)
      call createCurrent(P_HMinus, P_g, P_HPlus, P_g, 10571, check)
      call createCurrent(P_HMinus, P_G0, P_Hl, P_GPlus, 3290, check)
      call createCurrent(P_A, P_ghWp, P_ghAAnti, P_WMinus, 1072, check)
      call createCurrent(P_Ha, P_GPlus, P_ghZAnti, P_ghWm, 9690, check)
      call createCurrent(P_G0, P_HMinus, P_Hh, P_GPlus, 7105, check)
      call createCurrent(P_A, P_WMinus, P_Hh, P_GPlus, 8552, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghWp, P_WMinus, 7707, check)
      call createCurrent(P_HlQ, P_ghWm, P_ghWmAnti, 619, check)
      call createCurrent(P_GQMinus, P_GMinus, P_HPlus, P_GQPlus, 1078, check)
      call createCurrent(P_ghA, P_GMinus, P_ghZAnti, P_HPlus, 9789, check)
      call createCurrent(P_GQPlus, P_Hl, P_ghWm, P_ghZAnti, 1734, check)
      call createCurrent(P_ghZAnti, P_Hh, P_ghWm, P_HQPlus, 6378, check)
      call createCurrent(P_b, P_tAnti, P_GQPlus, 8210, check)
      call createCurrent(P_Ha, P_Ha, P_ghZAnti, P_ghZ, 5944, check)
      call createCurrent(P_ghZ, P_G0, P_ghWpAnti, P_GQPlus, 4856, check)
      call createCurrent(P_GPlus, P_Z, P_GMinus, P_A, 2638, check)
      call createCurrent(P_ZQ, P_Hl, P_Hl, P_ZQ, 2239, check)
      call createCurrent(P_HlQ, P_GPlus, P_Hl, P_GQMinus, 1331, check)
      call createCurrent(P_HPlus, P_Ha, P_ghAAnti, P_ghWm, 7724, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_Hh, P_HQPlus, 1365, check)
      call createCurrent(P_Ha, P_Z, 9463, check)
      call createCurrent(P_HQPlus, P_HMinus, P_G0, P_HaQ, 7524, check)
      call createCurrent(P_Hh, P_ghWp, P_ghAAnti, P_GMinus, 3268, check)
      call createCurrent(P_ghAAnti, P_HMinus, P_Hh, P_ghWp, 474, check)
      call createCurrent(P_HaQ, P_Ha, P_ghWpAnti, P_ghWp, 6067, check)
      call createCurrent(P_ghZAnti, P_HMinus, P_GPlus, P_ghZ, 9622, check)
      call createCurrent(P_ZQ, P_Z, P_HMinus, P_HQPlus, 5494, check)
      call createCurrent(P_HhQ, P_HPlus, P_GMinus, P_HlQ, 6631, check)
      call createCurrent(P_GQPlus, P_G0, P_GMinus, P_HhQ, 1001, check)
      call createCurrent(P_HMinus, P_WPlus, P_WMinus, P_HPlus, 6629, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_Ha, P_GPlus, 9977, check)
      call createCurrent(P_g, P_c, P_cAnti, 7734, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Hh, P_GQ0, 5103, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghAAnti, P_ZQ, 1843, check)
      call createCurrent(P_GMinus, P_ghZ, P_Ha, P_ghWmAnti, 9658, check)
      call createCurrent(P_GQPlus, P_Z, P_GMinus, P_AQ, 7283, check)
      call createCurrent(P_Z, P_WPlus, P_HMinus, P_Ha, 8311, check)
      call createCurrent(P_nu_mu, P_muPlus, P_HMinus, 4572, check)
      call createCurrent(P_Z, P_ghWp, P_Z, P_ghWpAnti, 6843, check)
      call createCurrent(P_Z, P_Z, P_Ha, P_Ha, 3930, check)
      call createCurrent(P_Hh, P_G0, P_GPlus, P_GMinus, 9990, check)
      call createCurrent(P_GPlus, P_Ha, P_G0, P_HMinus, 6465, check)
      call createCurrent(P_HhQ, P_GMinus, P_HPlus, P_GQ0, 6069, check)
      call createCurrent(P_ghZ, P_Z, P_ghWpAnti, P_WPlus, 6746, check)
      call createCurrent(P_HQPlus, P_GMinus, P_GQ0, 43, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_ghWp, P_A, 7802, check)
      call createCurrent(P_G0, P_GPlus, P_G0, P_GMinus, 495, check)
      call createCurrent(P_A, P_nu_tauAnti, P_nu_tau, 9130, check)
      call createCurrent(P_HlQ, P_G0, P_WPlus, P_WQMinus, 5221, check)
      call createCurrent(P_Z, P_GMinus, P_HPlus, P_Z, 9860, check)
      call createCurrent(P_WMinus, P_Z, P_GPlus, P_Ha, 8974, check)
      call createCurrent(P_WMinus, P_ghA, P_WPlus, P_ghAAnti, 3790, check)
      call createCurrent(P_HPlus, P_Z, P_HMinus, 1559, check)
      call createCurrent(P_ZQ, P_ghWpAnti, P_A, P_ghWp, 3725, check)
      call createCurrent(P_HaQ, P_HPlus, P_Hh, P_HQMinus, 1889, check)
      call createCurrent(P_WMinus, P_A, P_GPlus, 3502, check)
      call createCurrent(P_A, P_G0, P_Z, P_Ha, 10702, check)
      call createCurrent(P_A, P_GMinus, P_WPlus, P_Ha, 8970, check)
      call createCurrent(P_ghWpAnti, P_G0, P_ghA, P_GQPlus, 5860, check)
      call createCurrent(P_A, P_Ha, P_GMinus, P_WPlus, 9328, check)
      call createCurrent(P_Z, P_Hl, P_Hl, P_Z, 8753, check)
      call createCurrent(P_GQMinus, P_WPlus, P_A, P_GQ0, 7922, check)
      call createCurrent(P_Hh, P_WMinus, P_GPlus, P_Z, 7471, check)
      call createCurrent(P_ghZ, P_HMinus, P_ghWmAnti, P_HlQ, 7748, check)
      call createCurrent(P_WQMinus, P_Hh, P_Hh, P_WQPlus, 6854, check)
      call createCurrent(P_Z, P_s, P_sAnti, 2074, check)
      call createCurrent(P_ghWm, P_Hh, P_Hl, P_ghWmAnti, 8945, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_Hl, P_HMinus, 524, check)
      call createCurrent(P_Hl, P_Hh, P_GPlus, P_HMinus, 4581, check)
      call createCurrent(P_HQMinus, P_HPlus, P_Ha, P_HlQ, 7596, check)
      call createCurrent(P_ZQ, P_Hl, P_WMinus, P_GQPlus, 5598, check)
      call createCurrent(P_GPlus, P_Hl, P_ghAAnti, P_ghWm, 5724, check)
      call createCurrent(P_HMinus, P_ghAAnti, P_HPlus, P_ghA, 1156, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_HhQ, 6238, check)
      call createCurrent(P_G0, P_HPlus, P_Hl, P_HMinus, 9429, check)
      call createCurrent(P_ghWm, P_Z, P_ghWmAnti, 1701, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Hl, P_Hl, 4442, check)
      call createCurrent(P_HMinus, P_GPlus, P_ghAAnti, P_ghA, 9459, check)
      call createCurrent(P_HPlus, P_ghZ, P_ghWpAnti, P_Hh, 783, check)
      call createCurrent(P_HaQ, P_Hl, P_WMinus, P_WQPlus, 4057, check)
      call createCurrent(P_HhQ, P_ghZ, P_ghZAnti, 4979, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_ghWm, P_AQ, 1159, check)
      call createCurrent(P_WMinus, P_Hl, P_HPlus, P_Z, 93, check)
      call createCurrent(P_ghZAnti, P_Z, P_WMinus, P_ghWp, 2647, check)
      call createCurrent(P_GMinus, P_HPlus, P_A, 10119, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_GMinus, P_HhQ, 8682, check)
      call createCurrent(P_GMinus, P_A, P_HPlus, P_A, 9959, check)
      call createCurrent(P_HQPlus, P_Hl, P_HMinus, P_HhQ, 5420, check)
      call createCurrent(P_GQ0, P_GPlus, P_A, P_WQMinus, 7372, check)
      call createCurrent(P_HMinus, P_GPlus, P_Hh, P_Hh, 2315, check)
      call createCurrent(P_Ha, P_Hh, P_GMinus, P_HPlus, 7002, check)
      call createCurrent(P_t, P_tAnti, P_Hl, 4992, check)
      call createCurrent(P_AQ, P_GPlus, P_GMinus, P_AQ, 4595, check)
      call createCurrent(P_HhQ, P_WPlus, P_GQMinus, 599, check)
      call createCurrent(P_ghWpAnti, P_Hh, P_HPlus, P_ghA, 6972, check)
      call createCurrent(P_WPlus, P_A, P_ghWpAnti, P_ghZ, 2387, check)
      call createCurrent(P_GQ0, P_Ha, P_G0, P_HaQ, 6557, check)
      call createCurrent(P_HQMinus, P_HPlus, P_ghA, P_ghZAnti, 3662, check)
      call createCurrent(P_ghZ, P_HMinus, P_GPlus, P_ghZAnti, 8881, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_G0, P_G0, 761, check)
      call createCurrent(P_Ha, P_GPlus, P_GMinus, P_G0, 4376, check)
      call createCurrent(P_AQ, P_HPlus, P_HQMinus, 3627, check)
      call createCurrent(P_Hl, P_Hl, P_G0, P_Ha, 6475, check)
      call createCurrent(P_tAnti, P_b, P_HQPlus, 2519, check)
      call createCurrent(P_GMinus, P_ghWp, P_ghZAnti, P_Hh, 5080, check)
      call createCurrent(P_Hh, P_A, P_WMinus, P_GPlus, 7122, check)
      call createCurrent(P_Hh, P_ghWmAnti, P_HMinus, P_ghZ, 3843, check)
      call createCurrent(P_Hl, P_ghWm, P_HPlus, P_ghAAnti, 7673, check)
      call createCurrent(P_GQPlus, P_ghAAnti, P_GMinus, P_ghA, 4601, check)
      call createCurrent(P_Hl, P_Ha, P_HMinus, P_GPlus, 5077, check)
      call createCurrent(P_WQPlus, P_WMinus, P_Hl, P_GQ0, 1785, check)
      call createCurrent(P_G0, P_GPlus, P_ghAAnti, P_ghWm, 8445, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghZ, P_Ha, 9813, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_ghWm, P_ZQ, 6222, check)
      call createCurrent(P_ghAAnti, P_Z, P_ghWm, P_WPlus, 3406, check)
      call createCurrent(P_HQMinus, P_Hl, P_HPlus, P_HhQ, 5778, check)
      call createCurrent(P_ghA, P_HMinus, P_HPlus, P_ghAAnti, 5742, check)
      call createCurrent(P_ghAAnti, P_HPlus, P_ghA, P_GMinus, 9165, check)
      call createCurrent(P_Hh, P_ghWpAnti, P_ghZ, P_GPlus, 368, check)
      call createCurrent(P_HQMinus, P_G0, P_Hl, P_GQPlus, 6382, check)
      call createCurrent(P_HlQ, P_HPlus, P_GQMinus, 4976, check)
      call createCurrent(P_GPlus, P_HMinus, P_Hl, 992, check)
      call createCurrent(P_GQMinus, P_GPlus, P_Hh, P_HlQ, 8001, check)
      call createCurrent(P_Ha, P_Hl, P_G0, P_Hh, 8211, check)
      call createCurrent(P_ghZAnti, P_G0, P_ghZ, P_GQ0, 1835, check)
      call createCurrent(P_GQ0, P_WMinus, P_WQPlus, 8461, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghWmAnti, P_Hl, 8602, check)
      call createCurrent(P_HQPlus, P_Z, P_HMinus, P_AQ, 8303, check)
      call createCurrent(P_u, P_WMinus, P_dAnti, 4033, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghZ, P_HhQ, 4783, check)
      call createCurrent(P_GQPlus, P_ghWm, P_G0, P_ghZAnti, 7808, check)
      call createCurrent(P_HlQ, P_GPlus, P_HMinus, P_HhQ, 7404, check)
      call createCurrent(P_GQMinus, P_GPlus, P_GQ0, 914, check)
      call createCurrent(P_HlQ, P_GMinus, P_GQPlus, 5248, check)
      call createCurrent(P_HQPlus, P_G0, P_GMinus, P_HlQ, 4586, check)
      call createCurrent(P_ghWpAnti, P_A, P_ghWp, P_AQ, 4733, check)
      call createCurrent(P_HMinus, P_Hh, P_GPlus, P_G0, 1929, check)
      call createCurrent(P_sAnti, P_HMinus, P_c, 7459, check)
      call createCurrent(P_tauMinus, P_Z, P_tauPlus, 352, check)
      call createCurrent(P_ePlus, P_Hh, P_eMinus, 6070, check)
      call createCurrent(P_HaQ, P_ghWp, P_HMinus, P_ghZAnti, 3311, check)
      call createCurrent(P_A, P_ghA, P_ghWpAnti, P_WPlus, 5717, check)
      call createCurrent(P_HPlus, P_HMinus, P_Z, P_Z, 3837, check)
      call createCurrent(P_HhQ, P_HMinus, P_Ha, P_HQPlus, 6641, check)
      call createCurrent(P_HPlus, P_Hl, P_ghZ, P_ghWpAnti, 4371, check)
      call createCurrent(P_GPlus, P_GMinus, P_ghAAnti, P_ghA, 3848, check)
      call createCurrent(P_WQMinus, P_ghA, P_A, P_ghWmAnti, 5943, check)
      call createCurrent(P_ghZAnti, P_Z, P_WPlus, P_ghWm, 2380, check)
      call createCurrent(P_GPlus, P_GMinus, P_Hh, P_Hh, 4577, check)
      call createCurrent(P_ghA, P_GPlus, P_ghAAnti, P_GMinus, 8352, check)
      call createCurrent(P_WMinus, P_WPlus, P_GPlus, P_GMinus, 1149, check)
      call createCurrent(P_ZQ, P_HPlus, P_WMinus, P_HaQ, 3695, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_Ha, P_GMinus, 9497, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_G0, P_GQPlus, 7178, check)
      call createCurrent(P_HMinus, P_ghZAnti, P_ghA, P_HPlus, 2244, check)
      call createCurrent(P_ZQ, P_muPlus, P_muMinus, 4561, check)
      call createCurrent(P_Ha, P_GPlus, P_Z, P_WMinus, 9599, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_HQMinus, 5025, check)
      call createCurrent(P_WQPlus, P_HMinus, P_HhQ, 7452, check)
      call createCurrent(P_HhQ, P_HMinus, P_GPlus, P_HaQ, 8697, check)
      call createCurrent(P_Z, P_HMinus, P_GPlus, 8962, check)
      call createCurrent(P_ghWmAnti, P_A, P_ghA, P_WQMinus, 3000, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_ghWm, P_HhQ, 977, check)
      call createCurrent(P_GQMinus, P_Z, P_GPlus, P_ZQ, 6296, check)
      call createCurrent(P_Z, P_A, P_WPlus, P_WMinus, 746, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_WMinus, P_ghWp, 8814, check)
      call createCurrent(P_GMinus, P_A, P_WPlus, P_G0, 3021, check)
      call createCurrent(P_HPlus, P_Hl, P_A, P_WMinus, 5644, check)
      call createCurrent(P_WQPlus, P_Hh, P_WQMinus, 6549, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_G0, P_GQ0, 7219, check)
      call createCurrent(P_ghWm, P_HPlus, P_ghAAnti, P_HaQ, 1925, check)
      call createCurrent(P_GMinus, P_Hl, P_Hl, P_GPlus, 3593, check)
      call createCurrent(P_WQMinus, P_WPlus, P_HlQ, 3193, check)
      call createCurrent(P_ghWmAnti, P_Hh, P_ghA, P_HQMinus, 636, check)
      call createCurrent(P_HPlus, P_ghAAnti, P_ghWm, P_Hl, 194, check)
      call createCurrent(P_GQPlus, P_HMinus, P_Hl, P_GQ0, 2930, check)
      call createCurrent(P_ghWmAnti, P_A, P_WMinus, P_ghZ, 6317, check)
      call createCurrent(P_HlQ, P_HMinus, P_GQPlus, 7842, check)
      call createCurrent(P_HlQ, P_HPlus, P_HQMinus, 6807, check)
      call createCurrent(P_HhQ, P_GPlus, P_A, P_WQMinus, 5662, check)
      call createCurrent(P_Ha, P_Ha, P_GMinus, P_HPlus, 6945, check)
      call createCurrent(P_GMinus, P_G0, P_ghWp, P_ghZAnti, 6380, check)
      call createCurrent(P_Hl, P_G0, P_HMinus, P_GPlus, 1196, check)
      call createCurrent(P_ZQ, P_G0, P_Z, P_GQ0, 4077, check)
      call createCurrent(P_Hh, P_Hl, P_GMinus, P_HPlus, 4240, check)
      call createCurrent(P_HQMinus, P_GPlus, P_G0, P_HlQ, 8219, check)
      call createCurrent(P_G0, P_ghA, P_HPlus, P_ghWpAnti, 8937, check)
      call createCurrent(P_muPlus, P_HMinus, P_nu_mu, 573, check)
      call createCurrent(P_HPlus, P_HMinus, P_Hl, P_Hl, 6634, check)
      call createCurrent(P_GQPlus, P_HMinus, P_G0, P_GQ0, 5608, check)
      call createCurrent(P_tauPlus, P_nu_tau, P_WMinus, 6677, check)
      call createCurrent(P_GQMinus, P_GPlus, P_Hh, P_HaQ, 8504, check)
      call createCurrent(P_tAnti, P_t, P_G0, 4766, check)
      call createCurrent(P_HhQ, P_G0, P_GMinus, P_GQPlus, 6523, check)
      call createCurrent(P_AQ, P_A, P_ghWm, P_ghWmAnti, 5631, check)
      call createCurrent(P_WPlus, P_Hl, P_A, P_GMinus, 7186, check)
      call createCurrent(P_Hh, P_G0, P_G0, P_Hh, 2771, check)
      call createCurrent(P_GQMinus, P_GPlus, P_Hh, P_HhQ, 1397, check)
      call createCurrent(P_HaQ, P_HMinus, P_HPlus, P_GQ0, 6453, check)
      call createCurrent(P_GQMinus, P_WPlus, P_G0, P_AQ, 8353, check)
      call createCurrent(P_GQ0, P_Hl, P_G0, P_HhQ, 2388, check)
      call createCurrent(P_HQPlus, P_G0, P_HMinus, P_GQ0, 7966, check)
      call createCurrent(P_WPlus, P_A, P_HMinus, P_Ha, 1360, check)
      call createCurrent(P_A, P_ghWm, P_ghAAnti, P_WPlus, 5016, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_GMinus, P_GQ0, 2109, check)
      call createCurrent(P_GQ0, P_G0, P_Hh, P_HlQ, 8120, check)
      call createCurrent(P_GQ0, P_Hh, P_ZQ, 5110, check)
      call createCurrent(P_G0, P_Ha, P_GMinus, P_HPlus, 8534, check)
      call createCurrent(P_Hh, P_G0, P_Hl, P_G0, 76, check)
      call createCurrent(P_A, P_Z, P_GPlus, P_GMinus, 762, check)
      call createCurrent(P_ghZAnti, P_Ha, P_ghWp, P_HMinus, 546, check)
      call createCurrent(P_GQ0, P_WMinus, P_GQPlus, 2400, check)
      call createCurrent(P_HQMinus, P_Hl, P_Hh, P_HQPlus, 5081, check)
      call createCurrent(P_GQPlus, P_A, P_GMinus, P_ZQ, 7552, check)
      call createCurrent(P_HlQ, P_GPlus, P_HQMinus, 2367, check)
      call createCurrent(P_Ha, P_ghWp, P_ghWpAnti, P_G0, 8871, check)
      call createCurrent(P_G0, P_HPlus, P_ghZ, P_ghWpAnti, 9904, check)
      call createCurrent(P_ghWp, P_Hh, P_Hh, P_ghWpAnti, 970, check)
      call createCurrent(P_HMinus, P_HPlus, P_G0, 9217, check)
      call createCurrent(P_Z, P_G0, P_Z, P_Ha, 9515, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_Hl, P_GMinus, 8109, check)
      call createCurrent(P_Ha, P_ghZAnti, P_G0, P_ghZ, 9593, check)
      call createCurrent(P_ghAAnti, P_HMinus, P_ghWp, P_Ha, 4118, check)
      call createCurrent(P_GMinus, P_HPlus, P_Hl, P_G0, 4468, check)
      call createCurrent(P_GMinus, P_Ha, P_GPlus, P_Hh, 9358, check)
      call createCurrent(P_GQPlus, P_Hl, P_Ha, P_HQMinus, 2951, check)
      call createCurrent(P_ZQ, P_GPlus, P_G0, P_WQMinus, 7436, check)
      call createCurrent(P_GMinus, P_Ha, P_ghAAnti, P_ghWp, 9684, check)
      call createCurrent(P_WMinus, P_tauPlus, P_nu_tau, 8220, check)
      call createCurrent(P_ghWp, P_Z, P_Z, P_ghWpAnti, 3825, check)
      call createCurrent(P_HPlus, P_GMinus, P_A, P_A, 9881, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_HPlus, P_HlQ, 2743, check)
      call createCurrent(P_HMinus, P_Hh, P_GPlus, P_Ha, 7016, check)
      call createCurrent(P_HPlus, P_WPlus, P_WMinus, P_GMinus, 9938, check)
      call createCurrent(P_HaQ, P_dAnti, P_d, 7493, check)
      call createCurrent(P_ghWpAnti, P_Hh, P_ghZ, P_HPlus, 2332, check)
      call createCurrent(P_HPlus, P_cAnti, P_s, 1367, check)
      call createCurrent(P_WPlus, P_WMinus, P_GMinus, P_HPlus, 9748, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_Ha, P_ghWp, 9298, check)
      call createCurrent(P_HlQ, P_GPlus, P_G0, P_GQMinus, 7935, check)
      call createCurrent(P_Hh, P_Hh, P_HPlus, P_HMinus, 547, check)
      call createCurrent(P_d, P_Ha, P_dAnti, 6528, check)
      call createCurrent(P_HPlus, P_GMinus, P_ghZ, P_ghZAnti, 9202, check)
      call createCurrent(P_HaQ, P_HPlus, P_Hl, P_GQMinus, 1332, check)
      call createCurrent(P_Ha, P_s, P_sAnti, 4545, check)
      call createCurrent(P_ghWpAnti, P_Ha, P_ghWp, P_HaQ, 4551, check)
      call createCurrent(P_Z, P_A, P_ghWm, P_ghWmAnti, 5211, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_WPlus, P_A, 3285, check)
      call createCurrent(P_WMinus, P_Hh, P_Hl, P_WPlus, 9807, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_HMinus, P_Ha, 2610, check)
      call createCurrent(P_HMinus, P_Hl, P_HPlus, P_G0, 9191, check)
      call createCurrent(P_AQ, P_t, P_tAnti, 7012, check)
      call createCurrent(P_ghWm, P_HPlus, P_ghZAnti, P_G0, 10151, check)
      call createCurrent(P_G0, P_HMinus, P_ghWmAnti, P_ghA, 9887, check)
      call createCurrent(P_WPlus, P_Hh, P_A, P_GMinus, 6268, check)
      call createCurrent(P_Hh, P_Ha, P_Hh, P_G0, 6394, check)
      call createCurrent(P_tauMinus, P_nu_tauAnti, P_GPlus, 188, check)
      call createCurrent(P_G0, P_HMinus, P_ghA, P_ghWmAnti, 9119, check)
      call createCurrent(P_Ha, P_Hl, P_Z, 5979, check)
      call createCurrent(P_HQMinus, P_Hh, P_HPlus, P_HaQ, 6957, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_HMinus, P_ghA, 9554, check)
      call createCurrent(P_GQMinus, P_GPlus, P_AQ, 6831, check)
      call createCurrent(P_Ha, P_ghWmAnti, P_ghWm, P_Ha, 1414, check)
      call createCurrent(P_WMinus, P_HPlus, P_Z, 7495, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghA, P_Hl, 8758, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Hl, 2929, check)
      call createCurrent(P_bAnti, P_b, P_Z, 8246, check)
      call createCurrent(P_G0, P_Ha, P_A, P_A, 10689, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_Hh, P_GQPlus, 7823, check)
      call createCurrent(P_ghWm, P_G0, P_ghWmAnti, P_HlQ, 5916, check)
      call createCurrent(P_A, P_c, P_cAnti, 2049, check)
      call createCurrent(P_A, P_ghWpAnti, P_ghWp, P_A, 20, check)
      call createCurrent(P_HPlus, P_Hl, P_ghWm, P_ghZAnti, 4155, check)
      call createCurrent(P_HMinus, P_ghWmAnti, P_GPlus, P_ghWm, 9532, check)
      call createCurrent(P_GQPlus, P_GPlus, P_GMinus, P_GQMinus, 3350, check)
      call createCurrent(P_A, P_GPlus, P_GMinus, P_A, 4146, check)
      call createCurrent(P_GPlus, P_Z, P_GMinus, 4919, check)
      call createCurrent(P_GQMinus, P_WPlus, P_AQ, 3542, check)
      call createCurrent(P_HlQ, P_Ha, P_Hh, P_GQ0, 7274, check)
      call createCurrent(P_muPlus, P_muMinus, P_GQ0, 8021, check)
      call createCurrent(P_nu_eAnti, P_HPlus, P_eMinus, 3923, check)
      call createCurrent(P_GMinus, P_Z, P_GPlus, P_Z, 2301, check)
      call createCurrent(P_HaQ, P_A, P_HMinus, P_WQPlus, 5368, check)
      call createCurrent(P_Ha, P_Z, P_Ha, P_Z, 6548, check)
      call createCurrent(P_c, P_cAnti, P_HlQ, 2282, check)
      call createCurrent(P_ghWp, P_Hl, P_Hl, P_ghWpAnti, 2516, check)
      call createCurrent(P_GPlus, P_ghZ, P_Hh, P_ghWpAnti, 6249, check)
      call createCurrent(P_GQPlus, P_tAnti, P_b, 2725, check)
      call createCurrent(P_GMinus, P_Hh, P_GPlus, P_G0, 8956, check)
      call createCurrent(P_Hh, P_WMinus, P_WPlus, P_Hl, 9924, check)
      call createCurrent(P_ghWp, P_Ha, P_ghZAnti, P_GMinus, 10108, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_Hl, P_GMinus, 5945, check)
      call createCurrent(P_Hl, P_Ha, P_HMinus, P_HPlus, 8955, check)
      call createCurrent(P_HQMinus, P_ghZAnti, P_Ha, P_ghWp, 5961, check)
      call createCurrent(P_A, P_G0, P_WPlus, P_GMinus, 6056, check)
      call createCurrent(P_G0, P_Ha, P_HPlus, P_HMinus, 7399, check)
      call createCurrent(P_Hh, P_HPlus, P_GMinus, P_Ha, 3092, check)
      call createCurrent(P_Z, P_GMinus, P_WPlus, 337, check)
      call createCurrent(P_Z, P_Ha, P_WPlus, P_GMinus, 9712, check)
      call createCurrent(P_WMinus, P_GPlus, P_Ha, 9439, check)
      call createCurrent(P_G0, P_ghWm, P_ghWmAnti, P_Ha, 9958, check)
      call createCurrent(P_nu_e, P_GMinus, P_ePlus, 2091, check)
      call createCurrent(P_WQPlus, P_A, P_ghA, P_ghWpAnti, 1618, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_GPlus, P_Hh, 1565, check)
      call createCurrent(P_Hl, P_GMinus, P_GPlus, 3051, check)
      call createCurrent(P_A, P_Hl, P_HMinus, P_WPlus, 6132, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_Hh, P_HQMinus, 1022, check)
      call createCurrent(P_Hh, P_GPlus, P_HMinus, P_Hl, 4028, check)
      call createCurrent(P_GQ0, P_Hl, P_WPlus, P_WQMinus, 451, check)
      call createCurrent(P_WMinus, P_WPlus, P_HPlus, P_GMinus, 9064, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_GPlus, P_Ha, 10015, check)
      call createCurrent(P_GQ0, P_Hl, P_Ha, P_HlQ, 2570, check)
      call createCurrent(P_HQPlus, P_WMinus, P_A, P_HhQ, 522, check)
      call createCurrent(P_Hh, P_Ha, P_G0, 5723, check)
      call createCurrent(P_GQMinus, P_GPlus, P_Ha, P_HhQ, 8356, check)
      call createCurrent(P_A, P_ghZ, P_ghWpAnti, P_WPlus, 801, check)
      call createCurrent(P_GMinus, P_GPlus, P_ghZ, P_ghAAnti, 5976, check)
      call createCurrent(P_WQMinus, P_Z, P_GPlus, P_GQ0, 3009, check)
      call createCurrent(P_GMinus, P_Z, P_A, P_HPlus, 9834, check)
      call createCurrent(P_dAnti, P_d, 10450, check)
      call createCurrent(P_GQ0, P_WPlus, P_WQMinus, 1171, check)
      call createCurrent(P_GQ0, P_Ha, P_Hh, P_HlQ, 5797, check)
      call createCurrent(P_HaQ, P_HMinus, P_Hl, P_HQPlus, 7511, check)
      call createCurrent(P_HaQ, P_Ha, P_HlQ, 1574, check)
      call createCurrent(P_HPlus, P_HMinus, P_Hh, P_G0, 9520, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_HMinus, 1413, check)
      call createCurrent(P_Z, P_G0, P_Hl, 2797, check)
      call createCurrent(P_GMinus, P_Ha, P_HPlus, P_Hl, 4307, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_HMinus, P_G0, 9912, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_HQPlus, 5265, check)
      call createCurrent(P_WQPlus, P_Ha, P_HQMinus, 8648, check)
      call createCurrent(P_cAnti, P_g, P_c, 7675, check)
      call createCurrent(P_HaQ, P_Ha, P_GPlus, P_GQMinus, 7793, check)
      call createCurrent(P_HPlus, P_Hl, P_Ha, P_GMinus, 1454, check)
      call createCurrent(P_GQ0, P_HMinus, P_GPlus, P_GQ0, 7814, check)
      call createCurrent(P_GPlus, P_GPlus, P_HMinus, P_HMinus, 5483, check)
      call createCurrent(P_GMinus, P_Z, P_A, P_GPlus, 7731, check)
      call createCurrent(P_AQ, P_GPlus, P_Hl, P_WQMinus, 6901, check)
      call createCurrent(P_Ha, P_ghWmAnti, P_Ha, P_ghWm, 4539, check)
      call createCurrent(P_Ha, P_A, P_WMinus, P_HPlus, 6759, check)
      call createCurrent(P_AQ, P_HPlus, P_HMinus, P_ZQ, 5336, check)
      call createCurrent(P_WQMinus, P_WPlus, P_HMinus, P_HQPlus, 1939, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_GMinus, P_ghWp, 1522, check)
      call createCurrent(P_HMinus, P_Hl, P_ghWmAnti, P_ghA, 4966, check)
      call createCurrent(P_HlQ, P_WMinus, P_Hl, P_WQPlus, 164, check)
      call createCurrent(P_HhQ, P_WPlus, P_Ha, P_WQMinus, 4451, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Ha, P_HlQ, 4504, check)
      call createCurrent(P_ghWmAnti, P_HMinus, P_Hl, P_ghZ, 7057, check)
      call createCurrent(P_GQ0, P_ghWp, P_ghWpAnti, 1903, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_GQ0, 1090, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_HMinus, P_Hl, 8833, check)
      call createCurrent(P_ghWm, P_Hh, P_ghAAnti, P_GPlus, 8629, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghWm, P_HhQ, 2344, check)
      call createCurrent(P_Z, P_Hh, P_Hh, P_Z, 880, check)
      call createCurrent(P_ghWpAnti, P_G0, P_ghWp, P_HlQ, 210, check)
      call createCurrent(P_HaQ, P_ghZAnti, P_HPlus, P_ghWm, 3455, check)
      call createCurrent(P_Z, P_Z, P_Ha, P_G0, 9878, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghWpAnti, P_WPlus, 3055, check)
      call createCurrent(P_HPlus, P_ghAAnti, P_ghWm, P_G0, 9696, check)
      call createCurrent(P_ZQ, P_WMinus, P_ghAAnti, P_ghWp, 1749, check)
      call createCurrent(P_WPlus, P_ghAAnti, P_Z, P_ghWm, 7479, check)
      call createCurrent(P_G0, P_WPlus, P_Z, P_GMinus, 2230, check)
      call createCurrent(P_GPlus, P_A, P_HMinus, 8984, check)
      call createCurrent(P_Hl, P_A, P_Z, P_Hl, 9392, check)
      call createCurrent(P_HMinus, P_Hl, P_GPlus, 7705, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_HaQ, 839, check)
      call createCurrent(P_GQ0, P_Hl, P_GPlus, P_GQMinus, 8423, check)
      call createCurrent(P_Hl, P_d, P_dAnti, 7636, check)
      call createCurrent(P_ghZAnti, P_Hh, P_HMinus, P_ghWp, 4819, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghZAnti, P_Hl, 4908, check)
      call createCurrent(P_WQPlus, P_WMinus, P_G0, P_HhQ, 2299, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_A, 1341, check)
      call createCurrent(P_HQPlus, P_ghZAnti, P_HMinus, P_ghZ, 6119, check)
      call createCurrent(P_HlQ, P_G0, P_Hl, P_GQ0, 3115, check)
      call createCurrent(P_GMinus, P_Hh, P_Hl, P_GPlus, 7047, check)
      call createCurrent(P_Hh, P_ghWmAnti, P_ghWm, P_Hh, 3221, check)
      call createCurrent(P_G0, P_Ha, P_Hl, 4256, check)
      call createCurrent(P_Ha, P_Hh, P_Z, 7686, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghAAnti, P_Z, 2888, check)
      call createCurrent(P_A, P_A, P_GPlus, P_GMinus, 6886, check)
      call createCurrent(P_HaQ, P_GPlus, P_GMinus, P_HaQ, 7353, check)
      call createCurrent(P_HMinus, P_Z, P_Z, P_GPlus, 10220, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_HMinus, P_Ha, 5356, check)
      call createCurrent(P_GMinus, P_Hh, P_HPlus, P_Ha, 6324, check)
      call createCurrent(P_Hl, P_ghZAnti, P_ghZ, 2745, check)
      call createCurrent(P_Hl, P_ghZAnti, P_ghWm, P_HPlus, 1579, check)
      call createCurrent(P_d, P_Hl, P_dAnti, 499, check)
      call createCurrent(P_Hh, P_ghWpAnti, P_ghWp, P_Hh, 3153, check)
      call createCurrent(P_HQMinus, P_Hh, P_Ha, P_GQPlus, 8331, check)
      call createCurrent(P_uAnti, P_u, P_GQ0, 3991, check)
      call createCurrent(P_Hl, P_ghWp, P_ghWpAnti, 7141, check)
      call createCurrent(P_Hl, P_Z, P_HPlus, P_WMinus, 5837, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_Ha, P_G0, 10312, check)
      call createCurrent(P_GMinus, P_A, P_WPlus, P_Hh, 142, check)
      call createCurrent(P_HhQ, P_ghWm, P_HPlus, P_ghAAnti, 3161, check)
      call createCurrent(P_Z, P_b, P_bAnti, 2973, check)
      call createCurrent(P_GMinus, P_G0, P_WPlus, P_Z, 1113, check)
      call createCurrent(P_Ha, P_G0, P_ghWm, P_ghWmAnti, 9369, check)
      call createCurrent(P_Z, P_G0, P_WMinus, P_HPlus, 9001, check)
      call createCurrent(P_HlQ, P_HMinus, P_HPlus, P_HhQ, 4826, check)
      call createCurrent(P_ghA, P_GMinus, P_Ha, P_ghWmAnti, 9222, check)
      call createCurrent(P_HhQ, P_HMinus, P_ghZAnti, P_ghWp, 4221, check)
      call createCurrent(P_WMinus, P_nu_e, P_ePlus, 4478, check)
      call createCurrent(P_WMinus, P_GPlus, P_Hh, 3341, check)
      call createCurrent(P_HlQ, P_G0, P_ghWp, P_ghWpAnti, 569, check)
      call createCurrent(P_GQMinus, P_GMinus, P_GPlus, P_HQPlus, 1525, check)
      call createCurrent(P_AQ, P_GMinus, P_A, P_GQPlus, 4517, check)
      call createCurrent(P_G0, P_ghWm, P_Ha, P_ghWmAnti, 10414, check)
      call createCurrent(P_Hh, P_ghWp, P_ghAAnti, P_HMinus, 5382, check)
      call createCurrent(P_nu_tauAnti, P_Z, P_nu_tau, 781, check)
      call createCurrent(P_WQPlus, P_GMinus, P_HhQ, 3439, check)
      call createCurrent(P_Z, P_HMinus, P_WPlus, P_Hl, 6313, check)
      call createCurrent(P_Ha, P_WPlus, P_GMinus, P_A, 9291, check)
      call createCurrent(P_GPlus, P_GMinus, P_Z, 1162, check)
      call createCurrent(P_WQMinus, P_GPlus, P_Hh, P_ZQ, 1032, check)
      call createCurrent(P_g, P_Hl, P_g, P_Hl, 10547, check)
      call createCurrent(P_GMinus, P_G0, P_Z, P_WPlus, 7869, check)
      call createCurrent(P_HQMinus, P_Hh, P_GPlus, P_GQ0, 2070, check)
      call createCurrent(P_Z, P_Hh, P_Z, P_Hh, 868, check)
      call createCurrent(P_WQPlus, P_Z, P_Hl, P_GQMinus, 3291, check)
      call createCurrent(P_HlQ, P_HPlus, P_G0, P_HQMinus, 2494, check)
      call createCurrent(P_GQ0, P_Hh, P_Hh, P_HaQ, 3684, check)
      call createCurrent(P_u, P_uAnti, 8845, check)
      call createCurrent(P_HhQ, P_A, P_GMinus, P_WQPlus, 1144, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_Hl, P_HQMinus, 4930, check)
      call createCurrent(P_HMinus, P_ghWp, P_ghWpAnti, P_HPlus, 1846, check)
      call createCurrent(P_Hl, P_HPlus, P_WMinus, 8077, check)
      call createCurrent(P_ghAAnti, P_Hh, P_ghWp, P_HMinus, 8585, check)
      call createCurrent(P_AQ, P_HPlus, P_Hh, P_WQMinus, 8658, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_G0, P_ghA, 1400, check)
      call createCurrent(P_WPlus, P_GPlus, P_WMinus, P_GMinus, 855, check)
      call createCurrent(P_HQPlus, P_A, P_WMinus, P_HhQ, 4609, check)
      call createCurrent(P_Hh, P_Z, P_WMinus, P_HPlus, 243, check)
      call createCurrent(P_AQ, P_Hh, P_GPlus, P_WQMinus, 4031, check)
      call createCurrent(P_Ha, P_ghWm, P_ghWmAnti, P_G0, 10157, check)
      call createCurrent(P_WQPlus, P_A, P_GMinus, P_HhQ, 4907, check)
      call createCurrent(P_HaQ, P_ghWpAnti, P_Hl, P_ghWp, 6073, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_WPlus, 6753, check)
      call createCurrent(P_ePlus, P_Ha, P_eMinus, 3241, check)
      call createCurrent(P_A, P_A, P_Hh, P_Hh, 10523, check)
      call createCurrent(P_A, P_WPlus, P_ghWpAnti, P_ghA, 4473, check)
      call createCurrent(P_GPlus, P_Ha, P_WMinus, 9108, check)
      call createCurrent(P_ZQ, P_GMinus, P_G0, P_WQPlus, 440, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_HPlus, P_ghZ, 9925, check)
      call createCurrent(P_ghWp, P_Hl, P_ghWpAnti, P_HlQ, 8691, check)
      call createCurrent(P_HQMinus, P_ghZAnti, P_Hl, P_ghWp, 5519, check)
      call createCurrent(P_ghWmAnti, P_HMinus, P_Ha, P_ghA, 4342, check)
      call createCurrent(P_G0, P_Hl, P_Hl, P_Ha, 156, check)
      call createCurrent(P_ghZAnti, P_HPlus, P_ghZ, P_HMinus, 4041, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Z, P_ZQ, 2127, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_ghWp, P_HhQ, 3859, check)
      call createCurrent(P_HQPlus, P_HMinus, P_Hl, P_HhQ, 3361, check)
      call createCurrent(P_A, P_g, P_A, P_g, 10527, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_ghZ, P_HMinus, 10197, check)
      call createCurrent(P_HMinus, P_Ha, P_A, P_WPlus, 4616, check)
      call createCurrent(P_Hl, P_Hl, P_Hl, P_Ha, 10633, check)
      call createCurrent(P_GQPlus, P_Ha, P_Ha, P_GQMinus, 6318, check)
      call createCurrent(P_HPlus, P_WMinus, P_A, P_Hh, 1339, check)
      call createCurrent(P_G0, P_ghZ, P_ghZAnti, P_Ha, 9197, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_HMinus, P_HhQ, 2860, check)
      call createCurrent(P_ghZAnti, P_HPlus, P_ghWm, P_Hh, 6392, check)
      call createCurrent(P_WMinus, P_Ha, P_A, P_GPlus, 10067, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_Hh, P_ghA, 6355, check)
      call createCurrent(P_WQMinus, P_ghWmAnti, P_Z, P_ghA, 4421, check)
      call createCurrent(P_Ha, P_GPlus, P_HMinus, P_G0, 8024, check)
      call createCurrent(P_ghZAnti, P_Ha, P_ghWm, P_GPlus, 9134, check)
      call createCurrent(P_GQ0, P_G0, P_Ha, P_HaQ, 6524, check)
      call createCurrent(P_GPlus, P_ghA, P_GMinus, P_ghZAnti, 1314, check)
      call createCurrent(P_ZQ, P_Z, P_G0, P_GQ0, 6778, check)
      call createCurrent(P_GQ0, P_Hh, P_HMinus, P_GQPlus, 7460, check)
      call createCurrent(P_WQMinus, P_Z, P_GPlus, P_HhQ, 3057, check)
      call createCurrent(P_HQMinus, P_t, P_bAnti, 1236, check)
      call createCurrent(P_A, P_Z, P_ghWmAnti, P_ghWm, 5888, check)
      call createCurrent(P_GQPlus, P_GMinus, P_Hl, P_HaQ, 8550, check)
      call createCurrent(P_ghWp, P_A, P_Z, P_ghWpAnti, 7153, check)
      call createCurrent(P_WPlus, P_ghWm, P_ghAAnti, 987, check)
      call createCurrent(P_g, P_g, P_g, P_A, 10728, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_Hh, P_GQMinus, 4740, check)
      call createCurrent(P_A, P_Z, P_ghWp, P_ghWpAnti, 36, check)
      call createCurrent(P_GMinus, P_Hl, P_Ha, P_GPlus, 9333, check)
      call createCurrent(P_GQPlus, P_ghZAnti, P_Hl, P_ghWm, 1699, check)
      call createCurrent(P_HhQ, P_HPlus, P_G0, P_HQMinus, 2689, check)
      call createCurrent(P_GMinus, P_u, P_dAnti, 136, check)
      call createCurrent(P_ghWm, P_HPlus, P_ghAAnti, P_Ha, 2986, check)
      call createCurrent(P_HaQ, P_ghWmAnti, P_Hl, P_ghWm, 6734, check)
      call createCurrent(P_GMinus, P_Hh, P_GPlus, P_Ha, 10327, check)
      call createCurrent(P_WPlus, P_ghA, P_WMinus, P_ghAAnti, 5768, check)
      call createCurrent(P_Z, P_Ha, P_HPlus, P_WMinus, 7525, check)
      call createCurrent(P_Ha, P_A, P_WMinus, P_GPlus, 9626, check)
      call createCurrent(P_ZQ, P_Z, P_WMinus, P_WQPlus, 3750, check)
      call createCurrent(P_HMinus, P_Hl, P_HPlus, P_Ha, 9888, check)
      call createCurrent(P_WMinus, P_G0, P_WPlus, P_G0, 4355, check)
      call createCurrent(P_A, P_Z, P_Hl, 9918, check)
      call createCurrent(P_HPlus, P_ghWpAnti, P_ghWp, P_HMinus, 8826, check)
      call createCurrent(P_HPlus, P_HMinus, P_Ha, P_Hh, 9522, check)
      call createCurrent(P_sAnti, P_G0, P_s, 2438, check)
      call createCurrent(P_ghGAnti, P_ghG, P_g, 8383, check)
      call createCurrent(P_Hh, P_G0, P_Z, 2445, check)
      call createCurrent(P_GMinus, P_HPlus, P_Ha, P_Ha, 2412, check)
      call createCurrent(P_ghWpAnti, P_HMinus, P_ghWp, P_GPlus, 9895, check)
      call createCurrent(P_GQ0, P_HPlus, P_G0, P_GQMinus, 4786, check)
      call createCurrent(P_G0, P_G0, P_WMinus, P_WPlus, 772, check)
      call createCurrent(P_GMinus, P_Hh, P_WPlus, P_Z, 7299, check)
      call createCurrent(P_A, P_ghWmAnti, P_ghZ, P_WMinus, 4336, check)
      call createCurrent(P_ghWp, P_HMinus, P_Ha, P_ghAAnti, 2307, check)
      call createCurrent(P_AQ, P_ghWp, P_A, P_ghWpAnti, 5553, check)
      call createCurrent(P_A, P_G0, 9152, check)
      call createCurrent(P_ghWpAnti, P_Hh, P_GPlus, P_ghA, 3638, check)
      call createCurrent(P_Hh, P_ghWp, P_GMinus, P_ghAAnti, 1007, check)
      call createCurrent(P_HMinus, P_HPlus, P_ghZ, P_ghAAnti, 5423, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_ghZ, P_WQPlus, 4985, check)
      call createCurrent(P_AQ, P_WMinus, P_Hl, P_HQPlus, 1781, check)
      call createCurrent(P_Hl, P_WMinus, P_WPlus, P_Hh, 10365, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_WPlus, P_ghWm, 1319, check)
      call createCurrent(P_WPlus, P_ghZAnti, P_ghWm, 7306, check)
      call createCurrent(P_HMinus, P_Z, P_A, P_GPlus, 10178, check)
      call createCurrent(P_Hl, P_ghWp, P_GMinus, P_ghZAnti, 7729, check)
      call createCurrent(P_AQ, P_HPlus, P_A, P_HQMinus, 4780, check)
      call createCurrent(P_tAnti, P_b, P_WPlus, 3043, check)
      call createCurrent(P_G0, P_Hh, P_G0, P_Hl, 3878, check)
      call createCurrent(P_WMinus, P_HPlus, P_Hh, 4899, check)
      call createCurrent(P_HMinus, P_Hl, P_HPlus, 4319, check)
      call createCurrent(P_Hl, P_ghAAnti, P_ghWm, P_GPlus, 879, check)
      call createCurrent(P_HMinus, P_HPlus, P_ghAAnti, P_ghA, 7618, check)
      call createCurrent(P_GMinus, P_ghA, P_GPlus, P_ghAAnti, 5007, check)
      call createCurrent(P_Z, P_G0, P_HMinus, P_WPlus, 9430, check)
      call createCurrent(P_bAnti, P_b, P_Hh, 1398, check)
      call createCurrent(P_Hh, P_GPlus, P_HMinus, P_G0, 5761, check)
      call createCurrent(P_GQPlus, P_Hl, P_WQMinus, 1429, check)
      call createCurrent(P_GPlus, P_Ha, P_ghWm, P_ghZAnti, 8899, check)
      call createCurrent(P_GPlus, P_WMinus, P_Ha, P_A, 10386, check)
      call createCurrent(P_Hl, P_Hl, P_G0, P_G0, 2216, check)
      call createCurrent(P_ghWm, P_GPlus, P_G0, P_ghZAnti, 3545, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_G0, P_GMinus, 6761, check)
      call createCurrent(P_WQMinus, P_G0, P_G0, P_WQPlus, 7701, check)
      call createCurrent(P_t, P_WMinus, P_bAnti, 3138, check)
      call createCurrent(P_Hl, P_GPlus, P_GMinus, P_Hh, 4437, check)
      call createCurrent(P_Hl, P_c, P_cAnti, 736, check)
      call createCurrent(P_HMinus, P_Hh, P_Z, P_WPlus, 921, check)
      call createCurrent(P_HMinus, P_ghZAnti, P_ghA, P_GPlus, 8865, check)
      call createCurrent(P_HlQ, P_Z, P_WPlus, P_HQMinus, 7656, check)
      call createCurrent(P_A, P_GMinus, P_WPlus, P_Hl, 4323, check)
      call createCurrent(P_bAnti, P_b, P_HhQ, 4359, check)
      call createCurrent(P_GPlus, P_WPlus, P_HMinus, P_WMinus, 9077, check)
      call createCurrent(P_WMinus, P_ghWp, P_ghAAnti, 6454, check)
      call createCurrent(P_HaQ, P_WPlus, P_WMinus, P_HaQ, 2469, check)
      call createCurrent(P_HlQ, P_WMinus, P_HQPlus, 5343, check)
      call createCurrent(P_ghAAnti, P_HMinus, P_ghZ, P_HPlus, 6891, check)
      call createCurrent(P_Hh, P_ghZ, P_ghZAnti, P_Hh, 4969, check)
      call createCurrent(P_A, P_HPlus, P_Hl, P_WMinus, 3110, check)
      call createCurrent(P_HPlus, P_ghWp, P_ghWpAnti, P_GMinus, 10324, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghZAnti, P_GQMinus, 2999, check)
      call createCurrent(P_Hl, P_GPlus, P_Hh, P_HMinus, 4145, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_HMinus, P_Hl, 3207, check)
      call createCurrent(P_HPlus, P_G0, P_ghZAnti, P_ghWm, 9424, check)
      call createCurrent(P_WQPlus, P_WMinus, P_ghA, P_ghAAnti, 2506, check)
      call createCurrent(P_HMinus, P_GPlus, P_Ha, P_G0, 2540, check)
      call createCurrent(P_HQMinus, P_Hl, P_ghWp, P_ghZAnti, 603, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_G0, P_Ha, 10244, check)
      call createCurrent(P_G0, P_t, P_tAnti, 6959, check)
      call createCurrent(P_GMinus, P_GPlus, P_ghAAnti, P_ghA, 5013, check)
      call createCurrent(P_WQPlus, P_nu_eAnti, P_eMinus, 7053, check)
      call createCurrent(P_tAnti, P_Hl, P_t, 6084, check)
      call createCurrent(P_ghA, P_HPlus, P_ghWpAnti, P_G0, 9308, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Ha, P_HlQ, 4864, check)
      call createCurrent(P_bAnti, P_g, P_b, 5751, check)
      call createCurrent(P_ghA, P_WPlus, P_ghZAnti, P_WMinus, 2740, check)
      call createCurrent(P_sAnti, P_s, P_HlQ, 2619, check)
      call createCurrent(P_ghZ, P_A, P_ghWpAnti, P_WPlus, 7803, check)
      call createCurrent(P_HMinus, P_Ha, P_GPlus, P_Hh, 4640, check)
      call createCurrent(P_Hh, P_GPlus, P_Hl, P_GMinus, 6725, check)
      call createCurrent(P_HQPlus, P_HMinus, P_ghZ, P_ghZAnti, 3550, check)
      call createCurrent(P_Ha, P_HMinus, P_ghWp, P_ghAAnti, 5613, check)
      call createCurrent(P_HhQ, P_A, P_WPlus, P_HQMinus, 7832, check)
      call createCurrent(P_HPlus, P_ghA, P_ghWpAnti, P_G0, 8839, check)
      call createCurrent(P_tAnti, P_t, P_AQ, 3211, check)
      call createCurrent(P_HQMinus, P_Hl, P_HQPlus, 6742, check)
      call createCurrent(P_GQPlus, P_Hl, P_ghWpAnti, P_ghZ, 9, check)
      call createCurrent(P_GMinus, P_A, P_GPlus, P_A, 6090, check)
      call createCurrent(P_HPlus, P_ghWmAnti, P_GMinus, P_ghWm, 9818, check)
      call createCurrent(P_ghZAnti, P_Ha, P_ghWp, P_HQMinus, 1208, check)
      call createCurrent(P_GPlus, P_ghA, P_ghWpAnti, P_Hl, 1965, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_A, P_AQ, 3670, check)
      call createCurrent(P_Z, P_Hl, P_A, P_Hh, 10503, check)
      call createCurrent(P_HQPlus, P_HMinus, P_Ha, P_HaQ, 4226, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_Z, P_WPlus, 7637, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghA, 7068, check)
      call createCurrent(P_GPlus, P_Z, P_A, P_GMinus, 1000, check)
      call createCurrent(P_G0, P_ghWp, P_ghWpAnti, P_G0, 4902, check)
      call createCurrent(P_GQMinus, P_Hl, P_Z, P_WQPlus, 3354, check)
      call createCurrent(P_Ha, P_HPlus, P_HMinus, 10101, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghWm, P_GPlus, 1412, check)
      call createCurrent(P_muMinus, P_G0, P_muPlus, 1472, check)
      call createCurrent(P_HaQ, P_HPlus, P_ghWm, P_ghAAnti, 284, check)
      call createCurrent(P_GQ0, P_GMinus, P_ghZ, P_ghWmAnti, 4190, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_Ha, P_ghA, 10366, check)
      call createCurrent(P_HQPlus, P_WMinus, P_HlQ, 6043, check)
      call createCurrent(P_HMinus, P_Hl, P_WPlus, 4065, check)
      call createCurrent(P_G0, P_Ha, P_A, P_Z, 10507, check)
      call createCurrent(P_GPlus, P_WMinus, P_A, 8138, check)
      call createCurrent(P_gQ, P_c, P_cAnti, 7107, check)
      call createCurrent(P_Ha, P_HPlus, P_Hh, P_GMinus, 4131, check)
      call createCurrent(P_ghZ, P_Hl, P_ghWmAnti, P_HMinus, 4918, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_G0, 542, check)
      call createCurrent(P_HlQ, P_G0, P_G0, P_HlQ, 7863, check)
      call createCurrent(P_Hh, P_Hh, P_Z, P_A, 9124, check)
      call createCurrent(P_HMinus, P_WPlus, P_Ha, P_Z, 8414, check)
      call createCurrent(P_ghWm, P_A, P_WPlus, P_ghZAnti, 4391, check)
      call createCurrent(P_HPlus, P_ghWpAnti, P_ghZ, P_Ha, 7426, check)
      call createCurrent(P_HMinus, P_G0, P_ghWmAnti, P_ghA, 9880, check)
      call createCurrent(P_Hh, P_HMinus, P_WPlus, 6870, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_Ha, P_HPlus, 3501, check)
      call createCurrent(P_WQMinus, P_ghAAnti, P_WPlus, P_ghA, 4637, check)
      call createCurrent(P_Ha, P_uAnti, P_u, 5889, check)
      call createCurrent(P_GMinus, P_G0, P_ghA, P_ghWmAnti, 8388, check)
      call createCurrent(P_HaQ, P_GMinus, P_GPlus, P_HaQ, 3610, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Ha, P_HhQ, 205, check)
      call createCurrent(P_Hh, P_Hh, P_ghWmAnti, P_ghWm, 1637, check)
      call createCurrent(P_HlQ, P_Hl, P_Ha, P_GQ0, 5538, check)
      call createCurrent(P_HMinus, P_Hl, P_GPlus, P_Hh, 4448, check)
      call createCurrent(P_Hh, P_Hl, P_Ha, P_Ha, 6101, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_Hl, P_HQPlus, 8016, check)
      call createCurrent(P_A, P_ghA, P_ghWmAnti, P_WMinus, 2582, check)
      call createCurrent(P_g, P_g, P_WPlus, P_WMinus, 10714, check)
      call createCurrent(P_HQPlus, P_Hh, P_GQMinus, 1805, check)
      call createCurrent(P_GQPlus, P_HMinus, P_Hh, P_HhQ, 2617, check)
      call createCurrent(P_ZQ, P_cAnti, P_c, 6588, check)
      call createCurrent(P_ghWpAnti, P_Hh, P_ghZ, P_GPlus, 5392, check)
      call createCurrent(P_HhQ, P_Z, P_WMinus, P_HQPlus, 4764, check)
      call createCurrent(P_WMinus, P_HPlus, P_Ha, 1402, check)
      call createCurrent(P_GQMinus, P_GPlus, P_G0, P_HaQ, 7403, check)
      call createCurrent(P_HaQ, P_Z, P_HhQ, 5759, check)
      call createCurrent(P_Ha, P_GMinus, P_ghA, P_ghWmAnti, 9198, check)
      call createCurrent(P_bAnti, P_b, P_Ha, 4017, check)
      call createCurrent(P_HMinus, P_GPlus, P_Z, P_A, 10483, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_HPlus, P_HaQ, 7668, check)
      call createCurrent(P_Ha, P_ghWp, P_ghAAnti, P_HMinus, 1662, check)
      call createCurrent(P_Hh, P_WMinus, P_Hh, P_WPlus, 4685, check)
      call createCurrent(P_ghWm, P_HPlus, P_ghAAnti, P_HhQ, 7938, check)
      call createCurrent(P_A, P_WMinus, P_GPlus, 2360, check)
      call createCurrent(P_HPlus, P_HMinus, P_HMinus, P_GPlus, 4413, check)
      call createCurrent(P_Hl, P_GMinus, P_HPlus, 412, check)
      call createCurrent(P_ZQ, P_ghWp, P_A, P_ghWpAnti, 1594, check)
      call createCurrent(P_tauMinus, P_G0, P_tauPlus, 3796, check)
      call createCurrent(P_HPlus, P_GMinus, P_Ha, P_G0, 4130, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_GMinus, P_Hh, 6840, check)
      call createCurrent(P_WPlus, P_A, P_HMinus, P_G0, 10167, check)
      call createCurrent(P_ZQ, P_ghWm, P_WPlus, P_ghZAnti, 7225, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghA, P_G0, 6483, check)
      call createCurrent(P_GQ0, P_b, P_bAnti, 1851, check)
      call createCurrent(P_G0, P_ghAAnti, P_ghWp, P_GMinus, 3632, check)
      call createCurrent(P_G0, P_HPlus, P_ghWpAnti, P_ghZ, 10162, check)
      call createCurrent(P_G0, P_HMinus, P_GPlus, P_Hh, 5449, check)
      call createCurrent(P_Ha, P_ghZAnti, P_ghWp, P_GMinus, 10179, check)
      call createCurrent(P_Hl, P_Hh, P_Hl, P_Hh, 2303, check)
      call createCurrent(P_HQMinus, P_Ha, P_G0, P_GQPlus, 4506, check)
      call createCurrent(P_ghAAnti, P_Z, P_ghWp, P_WMinus, 3219, check)
      call createCurrent(P_ghWpAnti, P_ghWm, P_WPlus, P_WPlus, 5297, check)
      call createCurrent(P_GPlus, P_Ha, P_HMinus, P_Hl, 4378, check)
      call createCurrent(P_Hl, P_WMinus, P_HPlus, 1996, check)
      call createCurrent(P_WPlus, P_Hh, P_WMinus, P_Hh, 6007, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Hh, P_Hh, 6185, check)
      call createCurrent(P_HhQ, P_G0, P_GPlus, P_HQMinus, 5738, check)
      call createCurrent(P_g, P_g, P_GPlus, P_HMinus, 10721, check)
      call createCurrent(P_ghA, P_HPlus, P_ghZAnti, P_GMinus, 9670, check)
      call createCurrent(P_ghWpAnti, P_Ha, P_GPlus, P_ghA, 9695, check)
      call createCurrent(P_ghWm, P_A, P_ghWmAnti, P_Z, 6749, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_WPlus, P_WMinus, 8626, check)
      call createCurrent(P_GMinus, P_HPlus, P_ghA, P_ghZAnti, 9475, check)
      call createCurrent(P_HaQ, P_Ha, P_Ha, P_HaQ, 6075, check)
      call createCurrent(P_HhQ, P_GPlus, P_HQMinus, 8013, check)
      call createCurrent(P_Hh, P_GPlus, P_Hh, P_GMinus, 6556, check)
      call createCurrent(P_WQMinus, P_A, P_HPlus, P_HhQ, 1093, check)
      call createCurrent(P_HMinus, P_Hl, P_G0, P_GPlus, 7321, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_HhQ, 7648, check)
      call createCurrent(P_GPlus, P_ghWm, P_Hh, P_ghZAnti, 8659, check)
      call createCurrent(P_Z, P_A, P_HPlus, P_GMinus, 9929, check)
      call createCurrent(P_GQMinus, P_Hh, P_WQPlus, 6798, check)
      call createCurrent(P_GQMinus, P_G0, P_WPlus, P_ZQ, 7172, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_Hl, P_Hl, 4114, check)
      call createCurrent(P_Ha, P_Ha, P_WPlus, P_WMinus, 8469, check)
      call createCurrent(P_HlQ, P_HPlus, P_HMinus, P_HhQ, 7835, check)
      call createCurrent(P_HlQ, P_ghWp, P_GMinus, P_ghAAnti, 5127, check)
      call createCurrent(P_ghWmAnti, P_Hh, P_ghZ, P_HMinus, 4083, check)
      call createCurrent(P_HQMinus, P_ghA, P_Hh, P_ghWmAnti, 8146, check)
      call createCurrent(P_HQPlus, P_d, P_uAnti, 4465, check)
      call createCurrent(P_GQPlus, P_Hh, P_HMinus, P_HaQ, 3779, check)
      call createCurrent(P_ghWp, P_GMinus, P_Ha, P_ghAAnti, 9096, check)
      call createCurrent(P_Z, P_nu_eAnti, P_nu_e, 6918, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_HMinus, P_Hh, 7422, check)
      call createCurrent(P_WMinus, P_WPlus, P_Hh, P_Hh, 4751, check)
      call createCurrent(P_HlQ, P_ghZAnti, P_ghZ, 1852, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_GMinus, P_HlQ, 4245, check)
      call createCurrent(P_GQ0, P_G0, P_HMinus, P_HQPlus, 5898, check)
      call createCurrent(P_HMinus, P_Ha, P_ghA, P_ghWmAnti, 7799, check)
      call createCurrent(P_WMinus, P_u, P_dAnti, 6494, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_WQMinus, 4921, check)
      call createCurrent(P_GQMinus, P_Z, P_WQPlus, 5843, check)
      call createCurrent(P_ghWp, P_HMinus, P_Ha, P_ghZAnti, 4611, check)
      call createCurrent(P_GMinus, P_HPlus, P_HMinus, P_GPlus, 49, check)
      call createCurrent(P_Ha, P_HMinus, P_HPlus, P_Ha, 3126, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_HPlus, P_Hl, 28, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_WQPlus, 6406, check)
      call createCurrent(P_Hl, P_A, P_GPlus, P_WMinus, 1353, check)
      call createCurrent(P_HMinus, P_ghWp, P_ghAAnti, P_Hh, 834, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_A, P_ZQ, 2051, check)
      call createCurrent(P_AQ, P_HMinus, P_Z, P_HQPlus, 4354, check)
      call createCurrent(P_ZQ, P_Hl, P_HPlus, P_WQMinus, 8589, check)
      call createCurrent(P_ghZAnti, P_HPlus, P_ghA, P_GMinus, 8938, check)
      call createCurrent(P_HQMinus, P_G0, P_Ha, P_GQPlus, 4537, check)
      call createCurrent(P_HaQ, P_Hh, P_HPlus, P_HQMinus, 2453, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_G0, P_GMinus, 7962, check)
      call createCurrent(P_HQMinus, P_G0, P_GPlus, P_GQ0, 6768, check)
      call createCurrent(P_HMinus, P_ghWmAnti, P_ghZ, P_Hh, 1085, check)
      call createCurrent(P_A, P_ghZ, P_ghWmAnti, P_WMinus, 4890, check)
      call createCurrent(P_WQPlus, P_G0, P_Z, P_GQMinus, 5055, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_HaQ, 4125, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_WPlus, P_A, 6743, check)
      call createCurrent(P_AQ, P_Hh, P_WMinus, P_HQPlus, 8519, check)
      call createCurrent(P_HQMinus, P_Z, P_WPlus, P_HaQ, 595, check)
      call createCurrent(P_HaQ, P_tAnti, P_t, 1394, check)
      call createCurrent(P_WMinus, P_WMinus, P_ghWmAnti, P_ghWp, 3688, check)
      call createCurrent(P_Ha, P_g, P_g, P_Ha, 10669, check)
      call createCurrent(P_HlQ, P_HPlus, P_GMinus, P_HlQ, 3204, check)
      call createCurrent(P_HPlus, P_Z, P_WMinus, 481, check)
      call createCurrent(P_HhQ, P_HMinus, P_ghWp, P_ghZAnti, 5726, check)
      call createCurrent(P_HhQ, P_ghWpAnti, P_Hh, P_ghWp, 6643, check)
      call createCurrent(P_ghWp, P_Z, P_ghWpAnti, P_ZQ, 6969, check)
      call createCurrent(P_ZQ, P_ghWm, P_Z, P_ghWmAnti, 2701, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_ghA, P_GPlus, 2798, check)
      call createCurrent(P_AQ, P_tauMinus, P_tauPlus, 7801, check)
      call createCurrent(P_HaQ, P_HMinus, P_ghWmAnti, P_ghZ, 285, check)
      call createCurrent(P_Hh, P_A, P_WPlus, P_GMinus, 797, check)
      call createCurrent(P_HQMinus, P_Ha, P_HPlus, P_HlQ, 4757, check)
      call createCurrent(P_Hh, P_ghWmAnti, P_ghA, P_GMinus, 1949, check)
      call createCurrent(P_ghWpAnti, P_HPlus, P_G0, P_ghZ, 9744, check)
      call createCurrent(P_b, P_tAnti, P_HQPlus, 2097, check)
      call createCurrent(P_ghA, P_WMinus, P_ghAAnti, P_WQPlus, 7424, check)
      call createCurrent(P_HPlus, P_GMinus, P_Hh, 8316, check)
      call createCurrent(P_Hl, P_G0, P_A, 8867, check)
      call createCurrent(P_Z, P_WPlus, P_HMinus, 2089, check)
      call createCurrent(P_Z, P_tAnti, P_t, 4382, check)
      call createCurrent(P_ghZ, P_HMinus, P_ghAAnti, P_GPlus, 9338, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_GPlus, P_ghA, 8460, check)
      call createCurrent(P_HaQ, P_HPlus, P_ghZAnti, P_ghWm, 5323, check)
      call createCurrent(P_A, P_ghAAnti, P_WPlus, P_ghWm, 7611, check)
      call createCurrent(P_HQPlus, P_WMinus, P_AQ, 4694, check)
      call createCurrent(P_Z, P_G0, P_WPlus, P_GMinus, 2032, check)
      call createCurrent(P_Z, P_G0, P_Z, P_G0, 8463, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_ghA, P_HMinus, 9525, check)
      call createCurrent(P_Z, P_ghWmAnti, P_ghA, P_WMinus, 1311, check)
      call createCurrent(P_Ha, P_Ha, P_HMinus, P_HPlus, 4152, check)
      call createCurrent(P_Hh, P_ghWm, P_ghWmAnti, P_Hh, 6500, check)
      call createCurrent(P_ZQ, P_Hl, P_WMinus, P_HQPlus, 1668, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_Ha, P_ghWm, 9022, check)
      call createCurrent(P_HMinus, P_Z, P_Hl, P_WPlus, 1497, check)
      call createCurrent(P_ghWpAnti, P_G0, P_G0, P_ghWp, 4943, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_Ha, P_ghWm, 9187, check)
      call createCurrent(P_Ha, P_HPlus, P_A, P_WMinus, 72, check)
      call createCurrent(P_ghAAnti, P_Hl, P_ghWp, P_GMinus, 2681, check)
      call createCurrent(P_ZQ, P_G0, P_HlQ, 3218, check)
      call createCurrent(P_HQPlus, P_Hl, P_Hl, P_GQMinus, 4964, check)
      call createCurrent(P_WQMinus, P_GPlus, P_GMinus, P_WQPlus, 7831, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghWmAnti, P_HlQ, 3898, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_Z, P_WMinus, 7260, check)
      call createCurrent(P_g, P_G0, P_g, P_G0, 10744, check)
      call createCurrent(P_GPlus, P_ghA, P_GMinus, P_ghAAnti, 3572, check)
      call createCurrent(P_A, P_ghWm, P_WPlus, P_ghZAnti, 1067, check)
      call createCurrent(P_GQMinus, P_Ha, P_Ha, P_GQPlus, 3313, check)
      call createCurrent(P_GQ0, P_HMinus, P_Hl, P_GQPlus, 3552, check)
      call createCurrent(P_GQMinus, P_HPlus, P_Hl, P_HhQ, 8150, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_GQ0, 7073, check)
      call createCurrent(P_GQPlus, P_Hh, P_Hh, P_HQMinus, 4124, check)
      call createCurrent(P_WPlus, P_HMinus, P_A, 5640, check)
      call createCurrent(P_Ha, P_Ha, P_Hl, P_Hl, 478, check)
      call createCurrent(P_GQPlus, P_G0, P_GMinus, P_GQ0, 5746, check)
      call createCurrent(P_Ha, P_G0, P_Z, P_A, 10614, check)
      call createCurrent(P_GQPlus, P_WMinus, P_A, P_HlQ, 5341, check)
      call createCurrent(P_HPlus, P_ghWmAnti, P_ghWm, P_GMinus, 10420, check)
      call createCurrent(P_G0, P_HPlus, P_WMinus, P_Z, 10467, check)
      call createCurrent(P_ZQ, P_nu_muAnti, P_nu_mu, 1854, check)
      call createCurrent(P_GMinus, P_Ha, P_Hl, P_GPlus, 9971, check)
      call createCurrent(P_c, P_cAnti, P_g, 1152, check)
      call createCurrent(P_HPlus, P_A, P_WMinus, P_Hl, 602, check)
      call createCurrent(P_g, P_g, P_A, P_A, 10661, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_GQMinus, 7562, check)
      call createCurrent(P_WQPlus, P_Ha, P_Z, P_HQMinus, 2616, check)
      call createCurrent(P_ghWp, P_Hh, P_ghZAnti, P_HMinus, 1704, check)
      call createCurrent(P_ghA, P_Hh, P_GMinus, P_ghWmAnti, 230, check)
      call createCurrent(P_nu_tau, P_HMinus, P_tauPlus, 7010, check)
      call createCurrent(P_ghZ, P_Ha, P_ghWmAnti, P_HQMinus, 7235, check)
      call createCurrent(P_GMinus, P_GPlus, P_ghWpAnti, P_ghWp, 2676, check)
      call createCurrent(P_A, P_HPlus, P_Z, P_GMinus, 10395, check)
      call createCurrent(P_HlQ, P_G0, P_HMinus, P_GQPlus, 7907, check)
      call createCurrent(P_WMinus, P_HPlus, P_G0, P_A, 9772, check)
      call createCurrent(P_GMinus, P_Z, P_Hh, P_WPlus, 2938, check)
      call createCurrent(P_A, P_WMinus, P_ghWp, P_ghAAnti, 6141, check)
      call createCurrent(P_Hh, P_WMinus, P_Z, P_HPlus, 8617, check)
      call createCurrent(P_ghWmAnti, P_Ha, P_GMinus, P_ghZ, 9637, check)
      call createCurrent(P_WMinus, P_WPlus, P_A, 1981, check)
      call createCurrent(P_Z, P_G0, P_GMinus, P_WPlus, 8152, check)
      call createCurrent(P_GQPlus, P_GMinus, P_Ha, P_HhQ, 5066, check)
      call createCurrent(P_WQMinus, P_ghWmAnti, P_ghZ, 2841, check)
      call createCurrent(P_HlQ, P_HPlus, P_Hh, P_GQMinus, 4799, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_GMinus, P_ghA, 3254, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_Hl, P_GMinus, 6913, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_ghZ, P_WMinus, 2366, check)
      call createCurrent(P_HMinus, P_HPlus, P_ghZ, P_ghZAnti, 2536, check)
      call createCurrent(P_Hl, P_Z, P_WPlus, P_HMinus, 3335, check)
      call createCurrent(P_ZQ, P_nu_mu, P_nu_muAnti, 344, check)
      call createCurrent(P_Ha, P_GPlus, P_ghZ, P_ghWpAnti, 10407, check)
      call createCurrent(P_Hh, P_sAnti, P_s, 1346, check)
      call createCurrent(P_nu_muAnti, P_muMinus, P_WQPlus, 8071, check)
      call createCurrent(P_WQPlus, P_G0, P_WMinus, P_HhQ, 5367, check)
      call createCurrent(P_HQMinus, P_Ha, P_GPlus, P_HlQ, 4309, check)
      call createCurrent(P_GQMinus, P_G0, P_HQPlus, 1873, check)
      call createCurrent(P_GQMinus, P_dAnti, P_u, 3064, check)
      call createCurrent(P_Hl, P_HPlus, P_G0, P_HMinus, 9649, check)
      call createCurrent(P_GQMinus, P_ghAAnti, P_GPlus, P_ghZ, 2461, check)
      call createCurrent(P_GPlus, P_ghWm, P_ghZAnti, 4270, check)
      call createCurrent(P_ghZAnti, P_HPlus, P_Hl, P_ghWm, 6174, check)
      call createCurrent(P_G0, P_HMinus, P_HPlus, P_G0, 8338, check)
      call createCurrent(P_G0, P_Ha, P_ghWm, P_ghWmAnti, 9602, check)
      call createCurrent(P_GQ0, P_HMinus, P_Ha, P_GQPlus, 7480, check)
      call createCurrent(P_Hh, P_GMinus, P_GPlus, P_G0, 8965, check)
      call createCurrent(P_GQMinus, P_HPlus, P_HhQ, 320, check)
      call createCurrent(P_WMinus, P_WPlus, P_ghAAnti, P_ghZ, 4535, check)
      call createCurrent(P_G0, P_ghZ, P_ghWpAnti, P_HPlus, 9142, check)
      call createCurrent(P_Z, P_Hl, P_WMinus, P_HPlus, 2402, check)
      call createCurrent(P_ghWp, P_GPlus, P_GMinus, P_ghWpAnti, 8258, check)
      call createCurrent(P_ghZAnti, P_HPlus, P_ghZ, P_HQMinus, 6237, check)
      call createCurrent(P_Hh, P_HMinus, P_Hh, P_HPlus, 1035, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_Hh, P_GPlus, 1002, check)
      call createCurrent(P_muPlus, P_nu_mu, P_WQMinus, 2470, check)
      call createCurrent(P_GMinus, P_GPlus, P_HMinus, P_HPlus, 2813, check)
      call createCurrent(P_GQ0, P_G0, P_Hl, P_HhQ, 7559, check)
      call createCurrent(P_G0, P_ghWp, P_G0, P_ghWpAnti, 7316, check)
      call createCurrent(P_WQPlus, P_eMinus, P_nu_eAnti, 5078, check)
      call createCurrent(P_WMinus, P_muPlus, P_nu_mu, 7755, check)
      call createCurrent(P_HPlus, P_ghAAnti, P_ghZ, P_HMinus, 4432, check)
      call createCurrent(P_GQMinus, P_G0, P_GPlus, P_HhQ, 3818, check)
      call createCurrent(P_Hl, P_Hl, P_Hh, 7092, check)
      call createCurrent(P_WPlus, P_ghZAnti, P_WMinus, P_ghZ, 7496, check)
      call createCurrent(P_ghAAnti, P_Hh, P_GPlus, P_ghWm, 2006, check)
      call createCurrent(P_ghZAnti, P_HMinus, P_ghZ, P_HQPlus, 5877, check)
      call createCurrent(P_HMinus, P_Ha, P_GPlus, P_Hl, 1095, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_WPlus, 7797, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_GMinus, P_ghWp, 4223, check)
      call createCurrent(P_HQMinus, P_ghZAnti, P_Hh, P_ghWp, 5337, check)
      call createCurrent(P_ghAAnti, P_ghA, P_HPlus, P_HMinus, 4322, check)
      call createCurrent(P_ghWp, P_G0, P_ghWpAnti, P_HhQ, 4285, check)
      call createCurrent(P_ghWmAnti, P_Hl, P_ghA, P_GQMinus, 2807, check)
      call createCurrent(P_A, P_Z, P_HMinus, P_GPlus, 9982, check)
      call createCurrent(P_G0, P_G0, P_GPlus, P_GMinus, 4887, check)
      call createCurrent(P_WPlus, P_Ha, P_Z, P_HMinus, 5094, check)
      call createCurrent(P_ZQ, P_HMinus, P_Hl, P_WQPlus, 5687, check)
      call createCurrent(P_Hl, P_ghWmAnti, P_Hl, P_ghWm, 4997, check)
      call createCurrent(P_GMinus, P_muPlus, P_nu_mu, 1385, check)
      call createCurrent(P_GQ0, P_Hl, P_Ha, P_HhQ, 2487, check)
      call createCurrent(P_Z, P_WPlus, P_Hh, P_GMinus, 8673, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_GMinus, P_Hh, 3766, check)
      call createCurrent(P_HaQ, P_GPlus, P_Ha, P_GQMinus, 3442, check)
      call createCurrent(P_GMinus, P_Hl, P_WPlus, P_A, 5166, check)
      call createCurrent(P_ZQ, P_Hl, P_WPlus, P_GQMinus, 2997, check)
      call createCurrent(P_HlQ, P_Hh, P_GMinus, P_GQPlus, 6052, check)
      call createCurrent(P_Z, P_WPlus, P_ghA, P_ghWpAnti, 2754, check)
      call createCurrent(P_GQPlus, P_GMinus, P_GMinus, P_HQPlus, 2371, check)
      call createCurrent(P_eMinus, P_nu_eAnti, P_GQPlus, 7867, check)
      call createCurrent(P_HlQ, P_Hl, P_GMinus, P_HQPlus, 8412, check)
      call createCurrent(P_d, P_dAnti, P_GQ0, 5070, check)
      call createCurrent(P_GMinus, P_HPlus, P_GPlus, P_HMinus, 115, check)
      call createCurrent(P_ghWmAnti, P_Z, P_Z, P_ghWm, 7551, check)
      call createCurrent(P_GPlus, P_GMinus, P_ghAAnti, P_ghZ, 7110, check)
      call createCurrent(P_GQMinus, P_WPlus, P_Hl, P_ZQ, 6766, check)
      call createCurrent(P_HQMinus, P_Z, P_HQPlus, 1601, check)
      call createCurrent(P_HaQ, P_muMinus, P_muPlus, 2104, check)
      call createCurrent(P_Hl, P_A, P_Ha, 9557, check)
      call createCurrent(P_g, P_ghGAnti, P_ghG, P_g, 4024, check)
      call createCurrent(P_GMinus, P_Hh, P_Hh, P_HPlus, 288, check)
      call createCurrent(P_HhQ, P_HPlus, P_Z, P_WQMinus, 1987, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_WPlus, P_WMinus, 902, check)
      call createCurrent(P_WQPlus, P_WMinus, P_GPlus, P_GQMinus, 5635, check)
      call createCurrent(P_AQ, P_Hh, P_HMinus, P_WQPlus, 864, check)
      call createCurrent(P_g, P_GPlus, P_HMinus, P_g, 10492, check)
      call createCurrent(P_HhQ, P_ghWpAnti, P_HPlus, P_ghZ, 2114, check)
      call createCurrent(P_s, P_sAnti, P_g, 6621, check)
      call createCurrent(P_HlQ, P_ghZ, P_GMinus, P_ghWmAnti, 7996, check)
      call createCurrent(P_Ha, P_ghZAnti, P_GPlus, P_ghWm, 9954, check)
      call createCurrent(P_Ha, P_Hh, P_Ha, P_Hl, 5931, check)
      call createCurrent(P_WMinus, P_ghZ, P_ghZAnti, P_WPlus, 3266, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_GQMinus, 3511, check)
      call createCurrent(P_b, P_bAnti, 9115, check)
      call createCurrent(P_HPlus, P_GMinus, P_G0, P_Ha, 7282, check)
      call createCurrent(P_g, P_HPlus, P_g, P_GMinus, 10672, check)
      call createCurrent(P_HaQ, P_ghWmAnti, P_HMinus, P_ghZ, 1026, check)
      call createCurrent(P_GQMinus, P_HMinus, P_GPlus, P_HQPlus, 2842, check)
      call createCurrent(P_WQPlus, P_WMinus, P_ghAAnti, P_ghZ, 805, check)
      call createCurrent(P_G0, P_GPlus, P_A, P_WMinus, 1829, check)
      call createCurrent(P_uAnti, P_Z, P_u, 5656, check)
      call createCurrent(P_Z, P_G0, 8913, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_Z, P_WQPlus, 3615, check)
      call createCurrent(P_HaQ, P_HMinus, P_Hh, P_HQPlus, 421, check)
      call createCurrent(P_ghWmAnti, P_Z, P_ghZ, P_WQMinus, 1641, check)
      call createCurrent(P_tauMinus, P_A, P_tauPlus, 6387, check)
      call createCurrent(P_ghA, P_G0, P_ghWpAnti, P_GPlus, 4565, check)
      call createCurrent(P_HQMinus, P_HMinus, P_GPlus, P_GQPlus, 185, check)
      call createCurrent(P_WQPlus, P_Hl, P_Hl, P_WQMinus, 3107, check)
      call createCurrent(P_Z, P_WPlus, P_G0, P_HMinus, 9823, check)
      call createCurrent(P_ghWmAnti, P_HMinus, P_G0, P_ghZ, 9310, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Hl, 8714, check)
      call createCurrent(P_uAnti, P_g, P_u, 8343, check)
      call createCurrent(P_G0, P_ghWp, P_GMinus, P_ghZAnti, 5286, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_Z, P_WQPlus, 4862, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_Hl, P_HPlus, 5038, check)
      call createCurrent(P_WQPlus, P_ghA, P_ghWpAnti, 8535, check)
      call createCurrent(P_ghA, P_ghAAnti, P_HPlus, P_HQMinus, 1129, check)
      call createCurrent(P_GMinus, P_ghZ, P_ghWmAnti, P_Ha, 10424, check)
      call createCurrent(P_ghWpAnti, P_WMinus, P_WPlus, P_ghWp, 4084, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_Hh, P_GPlus, 7732, check)
      call createCurrent(P_HPlus, P_GPlus, P_GMinus, P_HMinus, 8276, check)
      call createCurrent(P_G0, P_HMinus, P_G0, P_HPlus, 7651, check)
      call createCurrent(P_Z, P_HPlus, P_A, P_HMinus, 2, check)
      call createCurrent(P_WQPlus, P_A, P_HMinus, P_HhQ, 6391, check)
      call createCurrent(P_WQPlus, P_WMinus, P_G0, P_HlQ, 826, check)
      call createCurrent(P_gQ, P_u, P_uAnti, 5947, check)
      call createCurrent(P_uAnti, P_Hl, P_u, 2896, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_HMinus, P_GPlus, 9433, check)
      call createCurrent(P_GPlus, P_Z, P_GMinus, P_Z, 6884, check)
      call createCurrent(P_ghWpAnti, P_Hl, P_ghWp, P_HaQ, 6234, check)
      call createCurrent(P_GPlus, P_WMinus, P_G0, P_A, 6836, check)
      call createCurrent(P_HQMinus, P_sAnti, P_c, 8156, check)
      call createCurrent(P_GPlus, P_G0, P_G0, P_HMinus, 7682, check)
      call createCurrent(P_HQMinus, P_GPlus, P_GMinus, P_GQPlus, 5172, check)
      call createCurrent(P_HlQ, P_ghZ, P_ghZAnti, 6168, check)
      call createCurrent(P_HPlus, P_Hl, P_GMinus, P_Hh, 5572, check)
      call createCurrent(P_HaQ, P_ghWm, P_Hl, P_ghWmAnti, 7913, check)
      call createCurrent(P_GMinus, P_ghWp, P_Ha, P_ghAAnti, 10240, check)
      call createCurrent(P_WQMinus, P_ghZ, P_WPlus, P_ghAAnti, 8216, check)
      call createCurrent(P_G0, P_G0, P_GMinus, P_GPlus, 155, check)
      call createCurrent(P_Ha, P_HMinus, P_ghZ, P_ghWmAnti, 4655, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_HhQ, 160, check)
      call createCurrent(P_GQ0, P_Z, P_HlQ, 7683, check)
      call createCurrent(P_ghZ, P_G0, P_GMinus, P_ghWmAnti, 3730, check)
      call createCurrent(P_GPlus, P_G0, P_Ha, P_HMinus, 6660, check)
      call createCurrent(P_WMinus, P_Hh, P_HPlus, 1529, check)
      call createCurrent(P_ZQ, P_GMinus, P_WQPlus, 3893, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_Hl, P_ghWm, 7632, check)
      call createCurrent(P_Z, P_WPlus, P_HMinus, P_G0, 10205, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_HMinus, P_GPlus, 9955, check)
      call createCurrent(P_GQ0, P_GPlus, P_GQMinus, 2218, check)
      call createCurrent(P_WPlus, P_HMinus, P_G0, P_Z, 9243, check)
      call createCurrent(P_Hl, P_WMinus, P_Z, P_GPlus, 6723, check)
      call createCurrent(P_HlQ, P_HMinus, P_HPlus, P_HlQ, 8646, check)
      call createCurrent(P_WMinus, P_Z, P_ghWp, P_ghZAnti, 4941, check)
      call createCurrent(P_Z, P_Ha, P_Hh, 4815, check)
      call createCurrent(P_ghA, P_GPlus, P_Ha, P_ghWpAnti, 9092, check)
      call createCurrent(P_Hl, P_G0, P_Hl, P_Hl, 10671, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_HMinus, P_Hl, 6855, check)
      call createCurrent(P_GQMinus, P_Hh, P_ghWp, P_ghZAnti, 2861, check)
      call createCurrent(P_Hl, P_GMinus, P_GPlus, P_G0, 9606, check)
      call createCurrent(P_Ha, P_ghA, P_ghWpAnti, P_HPlus, 5104, check)
      call createCurrent(P_nu_muAnti, P_muMinus, P_GPlus, 3867, check)
      call createCurrent(P_GQMinus, P_ghZAnti, P_GPlus, P_ghA, 6367, check)
      call createCurrent(P_ghZ, P_Z, P_ghWmAnti, P_WMinus, 2678, check)
      call createCurrent(P_c, P_cAnti, P_Ha, 1519, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_Hh, P_GMinus, 4191, check)
      call createCurrent(P_bAnti, P_b, P_gQ, 2008, check)
      call createCurrent(P_A, P_Hh, P_WMinus, P_HPlus, 7560, check)
      call createCurrent(P_HQPlus, P_Z, P_HQMinus, 8295, check)
      call createCurrent(P_Ha, P_Ha, P_Hh, 1058, check)
      call createCurrent(P_Hh, P_GPlus, P_ghWpAnti, P_ghZ, 5144, check)
      call createCurrent(P_WPlus, P_GMinus, P_Ha, P_Z, 9161, check)
      call createCurrent(P_ghA, P_Ha, P_ghWpAnti, P_GPlus, 9339, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_HQMinus, 1489, check)
      call createCurrent(P_HQMinus, P_Hh, P_ghZ, P_ghWmAnti, 6534, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_ghA, P_WMinus, 6651, check)
      call createCurrent(P_g, P_ghGAnti, P_g, P_ghG, 8006, check)
      call createCurrent(P_Ha, P_G0, P_g, P_g, 10673, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_GMinus, P_GQ0, 1008, check)
      call createCurrent(P_G0, P_ghZAnti, P_ghWm, P_HPlus, 9436, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_GPlus, P_GQ0, 7356, check)
      call createCurrent(P_GMinus, P_ghWp, P_Hh, P_ghAAnti, 4650, check)
      call createCurrent(P_G0, P_ghWm, P_HPlus, P_ghZAnti, 9786, check)
      call createCurrent(P_gQ, P_ghG, P_ghGAnti, 2726, check)
      call createCurrent(P_Hh, P_ghWm, P_Hl, P_ghWmAnti, 9376, check)
      call createCurrent(P_HlQ, P_ePlus, P_eMinus, 7710, check)
      call createCurrent(P_Hl, P_HMinus, P_GPlus, P_Hl, 723, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_HPlus, P_GMinus, 9324, check)
      call createCurrent(P_A, P_dAnti, P_d, 8528, check)
      call createCurrent(P_A, P_bAnti, P_b, 7325, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_GQPlus, 5918, check)
      call createCurrent(P_gQ, P_ghGAnti, P_ghG, 4189, check)
      call createCurrent(P_Hh, P_Hh, P_Hh, P_Hh, 4494, check)
      call createCurrent(P_sAnti, P_s, 9019, check)
      call createCurrent(P_HQMinus, P_GPlus, P_GPlus, P_GQMinus, 5076, check)
      call createCurrent(P_HPlus, P_ghA, P_ghWpAnti, 4901, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_A, P_WQPlus, 4518, check)
      call createCurrent(P_GPlus, P_GMinus, P_Hl, 4505, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghAAnti, P_HhQ, 536, check)
      call createCurrent(P_GQPlus, P_Hl, P_GMinus, P_GQ0, 8527, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_Hh, 8143, check)
      call createCurrent(P_WQPlus, P_ghWpAnti, P_Z, P_ghZ, 4423, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_GPlus, P_ghZ, 6276, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghZ, P_G0, 2609, check)
      call createCurrent(P_HQPlus, P_Z, P_WMinus, P_HlQ, 3814, check)
      call createCurrent(P_HaQ, P_uAnti, P_u, 1813, check)
      call createCurrent(P_ghWp, P_HMinus, P_ghZAnti, P_Hl, 5731, check)
      call createCurrent(P_Z, P_Z, P_Hl, 6803, check)
      call createCurrent(P_WQMinus, P_G0, P_WPlus, P_HhQ, 2532, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_HPlus, P_Hl, 1185, check)
      call createCurrent(P_G0, P_Ha, P_G0, P_Ha, 6834, check)
      call createCurrent(P_HPlus, P_Ha, P_Hh, P_GMinus, 3980, check)
      call createCurrent(P_HaQ, P_HMinus, P_ghAAnti, P_ghWp, 3066, check)
      call createCurrent(P_HMinus, P_A, P_A, P_GPlus, 9884, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghA, P_GQPlus, 1930, check)
      call createCurrent(P_dAnti, P_Hl, P_d, 6437, check)
      call createCurrent(P_HQPlus, P_Ha, P_Ha, P_HQMinus, 1645, check)
      call createCurrent(P_ZQ, P_GPlus, P_WQMinus, 2635, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_ghWp, P_HlQ, 6042, check)
      call createCurrent(P_HhQ, P_ghZ, P_HPlus, P_ghWpAnti, 4327, check)
      call createCurrent(P_ghWmAnti, P_Ha, P_ghZ, P_HQMinus, 4220, check)
      call createCurrent(P_ZQ, P_GPlus, P_GMinus, P_AQ, 6514, check)
      call createCurrent(P_Ha, P_HMinus, P_Ha, P_HPlus, 2850, check)
      call createCurrent(P_Hl, P_HPlus, P_Ha, P_HMinus, 8870, check)
      call createCurrent(P_ghWpAnti, P_HPlus, P_ghZ, P_G0, 9636, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_G0, P_G0, 4400, check)
      call createCurrent(P_WQPlus, P_WMinus, P_A, P_ZQ, 6948, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_WQMinus, 7872, check)
      call createCurrent(P_HPlus, P_Hl, P_HMinus, 3806, check)
      call createCurrent(P_Hl, P_Hl, P_g, P_g, 10758, check)
      call createCurrent(P_AQ, P_A, P_HPlus, P_HQMinus, 4832, check)
      call createCurrent(P_WPlus, P_Z, P_GMinus, P_Hh, 506, check)
      call createCurrent(P_Z, P_WPlus, P_Hl, P_GMinus, 455, check)
      call createCurrent(P_G0, P_Ha, 9065, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_ghWp, P_Z, 8579, check)
      call createCurrent(P_Hl, P_Hh, P_Hh, P_Hh, 6827, check)
      call createCurrent(P_Hl, P_HMinus, P_Hh, P_HPlus, 3046, check)
      call createCurrent(P_HMinus, P_ghWp, P_ghAAnti, P_Ha, 5093, check)
      call createCurrent(P_GPlus, P_G0, P_Hh, P_HMinus, 2543, check)
      call createCurrent(P_GMinus, P_GPlus, P_A, P_Z, 8176, check)
      call createCurrent(P_HMinus, P_ghAAnti, P_ghZ, P_HPlus, 7529, check)
      call createCurrent(P_HlQ, P_ghWpAnti, P_GPlus, P_ghZ, 6400, check)
      call createCurrent(P_ghZ, P_Hl, P_HMinus, P_ghWmAnti, 3795, check)
      call createCurrent(P_WQPlus, P_GMinus, P_Hh, P_AQ, 5776, check)
      call createCurrent(P_ghA, P_WMinus, P_ghZAnti, P_WPlus, 3125, check)
      call createCurrent(P_Hh, P_ghWp, P_GMinus, P_ghZAnti, 7653, check)
      call createCurrent(P_Hl, P_ghWpAnti, P_ghZ, P_HPlus, 5400, check)
      call createCurrent(P_GQPlus, P_Ha, P_GMinus, P_GQ0, 1539, check)
      call createCurrent(P_HQMinus, P_WPlus, P_A, P_HhQ, 7771, check)
      call createCurrent(P_GQ0, P_G0, P_ghZAnti, P_ghZ, 3669, check)
      call createCurrent(P_ghZAnti, P_Ha, P_ghZ, P_HaQ, 3182, check)
      call createCurrent(P_WMinus, P_WPlus, P_GMinus, P_HPlus, 9640, check)
      call createCurrent(P_Ha, P_WMinus, P_A, P_HPlus, 4214, check)
      call createCurrent(P_ghA, P_HMinus, P_ghWmAnti, 2232, check)
      call createCurrent(P_GPlus, P_G0, P_ghWm, P_ghAAnti, 1172, check)
      call createCurrent(P_ghZ, P_GMinus, P_Ha, P_ghWmAnti, 10466, check)
      call createCurrent(P_WPlus, P_Hl, P_WMinus, P_Hh, 9239, check)
      call createCurrent(P_HPlus, P_Hl, P_GMinus, P_G0, 8653, check)
      call createCurrent(P_Hl, P_WPlus, P_WMinus, P_Hl, 7227, check)
      call createCurrent(P_WPlus, P_A, P_GMinus, P_Hl, 7876, check)
      call createCurrent(P_Hl, P_GPlus, P_HMinus, P_Ha, 4995, check)
      call createCurrent(P_G0, P_WMinus, P_G0, P_WPlus, 7844, check)
      call createCurrent(P_HMinus, P_nu_tau, P_tauPlus, 6828, check)
      call createCurrent(P_ghA, P_GMinus, P_HPlus, P_ghZAnti, 10048, check)
      call createCurrent(P_GQPlus, P_G0, P_WMinus, P_AQ, 7519, check)
      call createCurrent(P_GQ0, P_ghWm, P_G0, P_ghWmAnti, 7058, check)
      call createCurrent(P_GPlus, P_GMinus, P_GPlus, P_HMinus, 2984, check)
      call createCurrent(P_bAnti, P_Hl, P_b, 8466, check)
      call createCurrent(P_Ha, P_GMinus, P_WPlus, P_A, 9961, check)
      call createCurrent(P_ghAAnti, P_HPlus, P_ghWm, P_Ha, 154, check)
      call createCurrent(P_GQ0, P_Hl, P_WMinus, P_WQPlus, 895, check)
      call createCurrent(P_GMinus, P_Hh, P_WPlus, P_A, 4526, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_A, P_WMinus, 5388, check)
      call createCurrent(P_GPlus, P_Hh, P_GMinus, P_Hh, 8186, check)
      call createCurrent(P_GMinus, P_GPlus, P_WPlus, P_WMinus, 4793, check)
      call createCurrent(P_muMinus, P_WPlus, P_nu_muAnti, 5304, check)
      call createCurrent(P_WQMinus, P_WPlus, P_ghAAnti, P_ghA, 1710, check)
      call createCurrent(P_Z, P_Hl, P_Hl, P_A, 9428, check)
      call createCurrent(P_HhQ, P_Ha, P_GQ0, 3220, check)
      call createCurrent(P_HQPlus, P_HMinus, P_Hl, P_HaQ, 8568, check)
      call createCurrent(P_GMinus, P_GPlus, P_G0, 9448, check)
      call createCurrent(P_WMinus, P_Z, P_WPlus, P_A, 2327, check)
      call createCurrent(P_HQPlus, P_Ha, P_GMinus, P_HlQ, 7921, check)
      call createCurrent(P_WMinus, P_GPlus, P_Hh, P_A, 4019, check)
      call createCurrent(P_nu_mu, P_muPlus, P_WMinus, 3012, check)
      call createCurrent(P_g, P_g, P_ghGAnti, P_ghG, 3541, check)
      call createCurrent(P_HaQ, P_Hl, P_Ha, P_HhQ, 3698, check)
      call createCurrent(P_ghA, P_Z, P_ghWpAnti, P_WPlus, 8732, check)
      call createCurrent(P_Ha, P_Ha, P_Z, P_A, 9996, check)
      call createCurrent(P_HQPlus, P_GMinus, P_G0, P_HhQ, 203, check)
      call createCurrent(P_GQMinus, P_Hl, P_GPlus, P_HlQ, 4975, check)
      call createCurrent(P_ghWp, P_G0, P_ghZAnti, P_GQMinus, 1595, check)
      call createCurrent(P_GQMinus, P_Hl, P_WPlus, P_ZQ, 3188, check)
      call createCurrent(P_GQMinus, P_Hh, P_WPlus, P_AQ, 6142, check)
      call createCurrent(P_ghAAnti, P_Hh, P_GMinus, P_ghWp, 5954, check)
      call createCurrent(P_HMinus, P_WPlus, P_A, P_Ha, 7981, check)
      call createCurrent(P_WPlus, P_GMinus, P_Z, P_Hl, 3758, check)
      call createCurrent(P_Ha, P_ghZ, P_ghWpAnti, P_HPlus, 2688, check)
      call createCurrent(P_GQPlus, P_HMinus, P_Hh, P_HaQ, 8490, check)
      call createCurrent(P_HaQ, P_Ha, P_GMinus, P_GQPlus, 5683, check)
      call createCurrent(P_Hh, P_tauPlus, P_tauMinus, 2670, check)
      call createCurrent(P_Z, P_Hl, P_GMinus, P_WPlus, 592, check)
      call createCurrent(P_AQ, P_HMinus, P_WQPlus, 6223, check)
      call createCurrent(P_g, P_WMinus, P_g, P_WPlus, 10601, check)
      call createCurrent(P_GQMinus, P_A, P_GQPlus, 5126, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghA, P_Ha, 10034, check)
      call createCurrent(P_ghWpAnti, P_Z, P_WPlus, P_ghZ, 2267, check)
      call createCurrent(P_A, P_A, P_WPlus, P_WMinus, 7613, check)
      call createCurrent(P_Z, P_GMinus, P_GPlus, P_A, 135, check)
      call createCurrent(P_GQPlus, P_G0, P_Hl, P_HQMinus, 6591, check)
      call createCurrent(P_ghAAnti, P_Ha, P_ghWm, P_GPlus, 10367, check)
      call createCurrent(P_GPlus, P_muMinus, P_nu_muAnti, 2309, check)
      call createCurrent(P_muMinus, P_A, P_muPlus, 5049, check)
      call createCurrent(P_Ha, P_ghA, P_ghWmAnti, P_HMinus, 1046, check)
      call createCurrent(P_ghZ, P_Hh, P_ghWpAnti, P_HPlus, 7476, check)
      call createCurrent(P_WQPlus, P_GMinus, P_G0, P_ZQ, 1791, check)
      call createCurrent(P_Z, P_GMinus, P_HPlus, 10405, check)
      call createCurrent(P_WPlus, P_ghWm, P_Z, P_ghZAnti, 6203, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_GMinus, P_ghZ, 6538, check)
      call createCurrent(P_Hh, P_Hl, P_Z, P_Z, 9725, check)
      call createCurrent(P_G0, P_A, P_WMinus, P_HPlus, 9021, check)
      call createCurrent(P_HQMinus, P_HPlus, P_GMinus, P_GQPlus, 1631, check)
      call createCurrent(P_GQMinus, P_Hh, P_WPlus, P_ZQ, 3940, check)
      call createCurrent(P_WQMinus, P_GPlus, P_Hl, P_AQ, 2910, check)
      call createCurrent(P_Ha, P_ghAAnti, P_ghWm, P_HPlus, 6949, check)
      call createCurrent(P_Hh, P_ghA, P_HMinus, P_ghWmAnti, 6526, check)
      call createCurrent(P_g, P_A, P_g, P_A, 10739, check)
      call createCurrent(P_HMinus, P_A, P_HPlus, 2379, check)
      call createCurrent(P_HhQ, P_Hh, P_HPlus, P_GQMinus, 1614, check)
      call createCurrent(P_ZQ, P_GMinus, P_GQPlus, 2457, check)
      call createCurrent(P_GMinus, P_HMinus, P_GPlus, P_HPlus, 8707, check)
      call createCurrent(P_ZQ, P_WMinus, P_HPlus, P_HaQ, 5559, check)
      call createCurrent(P_ghZAnti, P_HMinus, P_HPlus, P_ghZ, 1039, check)
      call createCurrent(P_ghA, P_Hh, P_ghWmAnti, P_GQMinus, 4575, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_WMinus, P_ZQ, 291, check)
      call createCurrent(P_HPlus, P_HMinus, P_ghAAnti, P_ghA, 3460, check)
      call createCurrent(P_nu_tauAnti, P_HPlus, P_tauMinus, 4629, check)
      call createCurrent(P_GQMinus, P_Z, P_WPlus, P_HlQ, 2738, check)
      call createCurrent(P_WPlus, P_Hl, P_HMinus, P_A, 7230, check)
      call createCurrent(P_GQ0, P_HPlus, P_Ha, P_GQMinus, 6487, check)
      call createCurrent(P_GQPlus, P_WMinus, P_Hl, P_AQ, 2629, check)
      call createCurrent(P_G0, P_Ha, P_Hh, P_Hh, 8282, check)
      call createCurrent(P_HlQ, P_GMinus, P_Hl, P_GQPlus, 2721, check)
      call createCurrent(P_HQMinus, P_tauPlus, P_nu_tau, 5214, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_Z, P_WQMinus, 4742, check)
      call createCurrent(P_ghZ, P_ghAAnti, P_HMinus, P_HQPlus, 8674, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghA, 1418, check)
      call createCurrent(P_GPlus, P_WPlus, P_WMinus, P_GMinus, 2395, check)
      call createCurrent(P_HMinus, P_G0, P_HPlus, P_Ha, 8816, check)
      call createCurrent(P_ghWm, P_Hh, P_ghWmAnti, P_Hh, 1825, check)
      call createCurrent(P_G0, P_HMinus, P_ghWp, P_ghAAnti, 9861, check)
      call createCurrent(P_ghWmAnti, P_G0, P_GMinus, P_ghA, 8009, check)
      call createCurrent(P_ePlus, P_eMinus, P_Z, 1274, check)
      call createCurrent(P_ghWp, P_GMinus, P_G0, P_ghZAnti, 4135, check)
      call createCurrent(P_Hh, P_HMinus, P_ghAAnti, P_ghWp, 2131, check)
      call createCurrent(P_cAnti, P_Hh, P_c, 5897, check)
      call createCurrent(P_HlQ, P_GPlus, P_GMinus, P_HhQ, 4602, check)
      call createCurrent(P_GQMinus, P_WPlus, P_Z, P_GQ0, 6655, check)
      call createCurrent(P_ghZAnti, P_Hh, P_ghZ, P_Hl, 9811, check)
      call createCurrent(P_GPlus, P_HMinus, P_HPlus, P_GMinus, 4453, check)
      call createCurrent(P_A, P_Hl, P_GPlus, P_WMinus, 2656, check)
      call createCurrent(P_Z, P_ghWmAnti, P_ghZ, P_WMinus, 2809, check)
      call createCurrent(P_HaQ, P_G0, P_Hl, P_HlQ, 7567, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Z, P_ZQ, 2030, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_GMinus, P_HlQ, 1970, check)
      call createCurrent(P_HPlus, P_GPlus, P_GMinus, P_GMinus, 3097, check)
      call createCurrent(P_G0, P_ghA, P_HMinus, P_ghWmAnti, 10092, check)
      call createCurrent(P_c, P_cAnti, P_Z, 275, check)
      call createCurrent(P_G0, P_HPlus, P_ghWm, P_ghAAnti, 10182, check)
      call createCurrent(P_Hl, P_Hh, P_Ha, P_Ha, 7807, check)
      call createCurrent(P_GQ0, P_HPlus, P_Hh, P_HQMinus, 7647, check)
      call createCurrent(P_GPlus, P_Hl, P_GMinus, P_Hh, 2209, check)
      call createCurrent(P_HQPlus, P_Ha, P_GMinus, P_HaQ, 1898, check)
      call createCurrent(P_Ha, P_Ha, P_HPlus, P_HMinus, 927, check)
      call createCurrent(P_WQMinus, P_tauPlus, P_nu_tau, 6244, check)
      call createCurrent(P_ghWp, P_Hl, P_HMinus, P_ghZAnti, 7716, check)
      call createCurrent(P_HMinus, P_ghAAnti, P_ghWp, P_G0, 8878, check)
      call createCurrent(P_AQ, P_GMinus, P_WQPlus, 8366, check)
      call createCurrent(P_HMinus, P_Hl, P_G0, P_HPlus, 10028, check)
      call createCurrent(P_d, P_dAnti, P_HlQ, 7848, check)
      call createCurrent(P_WQMinus, P_HPlus, P_HMinus, P_WQPlus, 7473, check)
      call createCurrent(P_WQMinus, P_bAnti, P_t, 6344, check)
      call createCurrent(P_ghWpAnti, P_HPlus, P_Hh, P_ghA, 4991, check)
      call createCurrent(P_HlQ, P_Ha, P_GPlus, P_HQMinus, 6706, check)
      call createCurrent(P_A, P_GMinus, P_WPlus, 1177, check)
      call createCurrent(P_GQ0, P_Hl, P_HPlus, P_GQMinus, 2505, check)
      call createCurrent(P_ghA, P_G0, P_ghWmAnti, P_GMinus, 6240, check)
      call createCurrent(P_dAnti, P_d, P_AQ, 6833, check)
      call createCurrent(P_HlQ, P_Hh, P_Hl, P_HlQ, 2977, check)
      call createCurrent(P_WMinus, P_WPlus, P_ghWmAnti, P_ghWm, 985, check)
      call createCurrent(P_HQPlus, P_Z, P_Hl, P_WQMinus, 5834, check)
      call createCurrent(P_ghZAnti, P_HMinus, P_ghA, P_HQPlus, 1636, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghA, P_Ha, 9335, check)
      call createCurrent(P_HaQ, P_GPlus, P_G0, P_HQMinus, 4649, check)
      call createCurrent(P_HlQ, P_ghZ, P_GPlus, P_ghWpAnti, 2945, check)
      call createCurrent(P_Z, P_ghWmAnti, P_A, P_ghWm, 5912, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Z, P_A, 4570, check)
      call createCurrent(P_HaQ, P_ghWp, P_Ha, P_ghWpAnti, 4409, check)
      call createCurrent(P_GQMinus, P_Hh, P_Hh, P_HQPlus, 2578, check)
      call createCurrent(P_HhQ, P_Ha, P_ghWmAnti, P_ghWm, 2822, check)
      call createCurrent(P_HQMinus, P_ghZ, P_Hh, P_ghWmAnti, 7120, check)
      call createCurrent(P_ghAAnti, P_ghA, P_HPlus, P_HQMinus, 4380, check)
      call createCurrent(P_WQPlus, P_Ha, P_HMinus, P_ZQ, 8455, check)
      call createCurrent(P_Hl, P_b, P_bAnti, 1765, check)
      call createCurrent(P_Ha, P_GMinus, P_WPlus, P_Z, 9224, check)
      call createCurrent(P_HlQ, P_ghWm, P_GPlus, P_ghZAnti, 4735, check)
      call createCurrent(P_WQMinus, P_GPlus, P_HlQ, 5835, check)
      call createCurrent(P_Hl, P_ghWp, P_ghWpAnti, P_Hh, 8891, check)
      call createCurrent(P_WPlus, P_ghZ, P_ghAAnti, P_WMinus, 2672, check)
      call createCurrent(P_HlQ, P_Hl, P_ghZ, P_ghZAnti, 2314, check)
      call createCurrent(P_Ha, P_G0, P_ghZ, P_ghZAnti, 9267, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_G0, P_GQ0, 6868, check)
      call createCurrent(P_WMinus, P_WPlus, P_ghA, P_ghZAnti, 3840, check)
      call createCurrent(P_Hl, P_A, P_Hh, P_A, 10704, check)
      call createCurrent(P_HhQ, P_ghWpAnti, P_GPlus, P_ghZ, 5854, check)
      call createCurrent(P_HPlus, P_GMinus, P_ghZAnti, P_ghZ, 9381, check)
      call createCurrent(P_g, P_g, P_A, P_Z, 10701, check)
      call createCurrent(P_G0, P_ghWpAnti, P_HPlus, P_ghZ, 10102, check)
      call createCurrent(P_HhQ, P_HMinus, P_Ha, P_GQPlus, 6178, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_GMinus, P_HhQ, 2146, check)
      call createCurrent(P_GQMinus, P_ghA, P_GPlus, P_ghZAnti, 1484, check)
      call createCurrent(P_ghZ, P_HMinus, P_GPlus, P_ghAAnti, 9133, check)
      call createCurrent(P_Hl, P_GMinus, P_Hh, P_HPlus, 6942, check)
      call createCurrent(P_HQPlus, P_ghZ, P_HMinus, P_ghAAnti, 4879, check)
      call createCurrent(P_WQMinus, P_A, P_GPlus, P_GQ0, 4753, check)
      call createCurrent(P_ghWmAnti, P_Hl, P_ghZ, P_HMinus, 2801, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_GPlus, P_HlQ, 6895, check)
      call createCurrent(P_ghAAnti, P_HMinus, P_ghWp, P_HhQ, 1654, check)
      call createCurrent(P_HaQ, P_HPlus, P_ghAAnti, P_ghWm, 6984, check)
      call createCurrent(P_Hh, P_Ha, P_Hl, P_G0, 7764, check)
      call createCurrent(P_G0, P_Z, P_WPlus, P_HMinus, 8837, check)
      call createCurrent(P_HMinus, P_HMinus, P_HPlus, P_GPlus, 8563, check)
      call createCurrent(P_Hh, P_ghWpAnti, P_Hl, P_ghWp, 10460, check)
      call createCurrent(P_Z, P_HMinus, P_A, P_HPlus, 3214, check)
      call createCurrent(P_Z, P_Hh, P_WPlus, P_HMinus, 4049, check)
      call createCurrent(P_ghWmAnti, P_HMinus, P_ghZ, P_Hh, 918, check)
      call createCurrent(P_HPlus, P_G0, P_Hl, P_GMinus, 8181, check)
      call createCurrent(P_HlQ, P_HPlus, P_ghAAnti, P_ghWm, 1830, check)
      call createCurrent(P_WPlus, P_Ha, P_GMinus, P_Z, 9237, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_Hl, P_ghA, 8166, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_Hl, P_GMinus, 4836, check)
      call createCurrent(P_t, P_bAnti, P_HQMinus, 1896, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghWp, P_HhQ, 4696, check)
      call createCurrent(P_HaQ, P_WPlus, P_A, P_HQMinus, 8635, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_Ha, P_HPlus, 1858, check)
      call createCurrent(P_HMinus, P_WPlus, P_Ha, P_A, 7634, check)
      call createCurrent(P_Z, P_G0, P_HPlus, P_WMinus, 9413, check)
      call createCurrent(P_ghWp, P_GPlus, P_ghWpAnti, P_HMinus, 9697, check)
      call createCurrent(P_GQPlus, P_Hl, P_Hh, P_GQMinus, 1679, check)
      call createCurrent(P_HlQ, P_Hl, P_Z, P_ZQ, 6617, check)
      call createCurrent(P_GPlus, P_ghA, P_Hl, P_ghWpAnti, 799, check)
      call createCurrent(P_ghZ, P_WPlus, P_ghZAnti, P_WMinus, 446, check)
      call createCurrent(P_HQMinus, P_Ha, P_HPlus, P_HhQ, 7884, check)
      call createCurrent(P_GPlus, P_HMinus, P_Z, 10173, check)
      call createCurrent(P_ghA, P_GPlus, P_ghWpAnti, P_Hl, 5470, check)
      call createCurrent(P_g, P_Z, P_g, P_Z, 10490, check)
      call createCurrent(P_A, P_ghWp, P_ghWpAnti, 4242, check)
      call createCurrent(P_WQPlus, P_GMinus, P_A, P_HhQ, 3691, check)
      call createCurrent(P_GQPlus, P_A, P_GQMinus, 3810, check)
      call createCurrent(P_HQMinus, P_Ha, P_Z, P_WQPlus, 4249, check)
      call createCurrent(P_Hl, P_GMinus, P_Hh, P_GPlus, 4712, check)
      call createCurrent(P_WMinus, P_ghWp, P_WMinus, P_ghWmAnti, 6576, check)
      call createCurrent(P_cAnti, P_c, P_HhQ, 8164, check)
      call createCurrent(P_GMinus, P_Ha, P_G0, P_GPlus, 7509, check)
      call createCurrent(P_ghWp, P_Z, P_A, P_ghWpAnti, 7670, check)
      call createCurrent(P_GQPlus, P_Ha, P_G0, P_HQMinus, 896, check)
      call createCurrent(P_HPlus, P_tauMinus, P_nu_tauAnti, 8191, check)
      call createCurrent(P_A, P_ghWm, P_ghWmAnti, P_Z, 8543, check)
      call createCurrent(P_ghAAnti, P_HPlus, P_ghA, P_HMinus, 245, check)
      call createCurrent(P_Ha, P_WMinus, P_HPlus, P_A, 4440, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_WPlus, P_Z, 4454, check)
      call createCurrent(P_GQ0, P_GPlus, P_ghWpAnti, P_ghZ, 3917, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_HMinus, P_G0, 9090, check)
      call createCurrent(P_HPlus, P_ghAAnti, P_HMinus, P_ghA, 7396, check)
      call createCurrent(P_GMinus, P_A, P_Ha, P_WPlus, 10216, check)
      call createCurrent(P_HPlus, P_tAnti, P_b, 479, check)
      call createCurrent(P_Hh, P_ghZAnti, P_ghZ, P_Hl, 10337, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghZAnti, P_AQ, 4824, check)
      call createCurrent(P_GMinus, P_WPlus, P_Z, P_Hl, 8288, check)
      call createCurrent(P_Hl, P_Hh, P_ghWmAnti, P_ghWm, 9584, check)
      call createCurrent(P_HMinus, P_G0, P_Z, P_WPlus, 10357, check)
      call createCurrent(P_Hl, P_G0, P_Ha, P_Hl, 4343, check)
      call createCurrent(P_nu_tauAnti, P_A, P_nu_tau, 10137, check)
      call createCurrent(P_A, P_Hh, P_WPlus, P_GMinus, 1303, check)
      call createCurrent(P_HlQ, P_Hl, P_ghWp, P_ghWpAnti, 101, check)
      call createCurrent(P_HlQ, P_HMinus, P_GPlus, P_HhQ, 2781, check)
      call createCurrent(P_HPlus, P_ghWpAnti, P_ghA, P_G0, 10002, check)
      call createCurrent(P_GQ0, P_Hl, P_ghWp, P_ghWpAnti, 6089, check)
      call createCurrent(P_GPlus, P_GPlus, P_GMinus, P_HMinus, 6146, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_WPlus, P_AQ, 191, check)
      call createCurrent(P_HMinus, P_ghZAnti, P_GPlus, P_ghZ, 10078, check)
      call createCurrent(P_Hl, P_ghA, P_ghWmAnti, P_HMinus, 5216, check)
      call createCurrent(P_c, P_GMinus, P_sAnti, 5714, check)
      call createCurrent(P_Hh, P_WPlus, P_HMinus, P_A, 1695, check)
      call createCurrent(P_Hh, P_GPlus, P_Z, P_WMinus, 3832, check)
      call createCurrent(P_WPlus, P_s, P_cAnti, 2919, check)
      call createCurrent(P_HhQ, P_WPlus, P_GMinus, P_ZQ, 8420, check)
      call createCurrent(P_Hh, P_ghWmAnti, P_ghA, P_HMinus, 7393, check)
      call createCurrent(P_Hh, P_ghZ, P_Hl, P_ghZAnti, 8985, check)
      call createCurrent(P_Z, P_Hh, P_HPlus, P_WMinus, 4678, check)
      call createCurrent(P_GQMinus, P_ghZ, P_Hh, P_ghWmAnti, 773, check)
      call createCurrent(P_GMinus, P_G0, P_WPlus, 2559, check)
      call createCurrent(P_A, P_HPlus, P_WMinus, P_Hh, 7043, check)
      call createCurrent(P_ghAAnti, P_HPlus, P_ghZ, P_HQMinus, 2205, check)
      call createCurrent(P_HPlus, P_uAnti, P_d, 7698, check)
      call createCurrent(P_WPlus, P_HPlus, P_GMinus, P_WMinus, 8975, check)
      call createCurrent(P_Ha, P_G0, P_GPlus, P_GMinus, 3140, check)
      call createCurrent(P_HQPlus, P_HMinus, P_HaQ, 6648, check)
      call createCurrent(P_ghWp, P_GMinus, P_G0, P_ghAAnti, 607, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghAAnti, P_AQ, 387, check)
      call createCurrent(P_GQMinus, P_WPlus, P_Z, P_HhQ, 6899, check)
      call createCurrent(P_g, P_s, P_sAnti, 568, check)
      call createCurrent(P_Ha, P_G0, P_WMinus, P_WPlus, 10304, check)
      call createCurrent(P_HPlus, P_G0, P_WMinus, P_Z, 8952, check)
      call createCurrent(P_WMinus, P_ghZAnti, P_ghZ, P_WPlus, 1853, check)
      call createCurrent(P_ghWm, P_GPlus, P_HMinus, P_ghWmAnti, 9989, check)
      call createCurrent(P_ghZ, P_GMinus, P_G0, P_ghWmAnti, 2991, check)
      call createCurrent(P_ghWmAnti, P_Ha, P_HMinus, P_ghZ, 4882, check)
      call createCurrent(P_ghWm, P_Hl, P_ghAAnti, P_GPlus, 2963, check)
      call createCurrent(P_HQMinus, P_ghZAnti, P_HPlus, P_ghA, 5074, check)
      call createCurrent(P_A, P_WPlus, P_ghA, P_ghWpAnti, 813, check)
      call createCurrent(P_G0, P_WPlus, P_G0, P_WMinus, 3738, check)
      call createCurrent(P_Z, P_Hh, P_Hl, P_Z, 10035, check)
      call createCurrent(P_ghWmAnti, P_A, P_ghWm, 3020, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_Hh, P_ghA, 8396, check)
      call createCurrent(P_ZQ, P_GPlus, P_Hh, P_WQMinus, 3477, check)
      call createCurrent(P_WQPlus, P_G0, P_WMinus, P_HlQ, 179, check)
      call createCurrent(P_ghWpAnti, P_G0, P_GPlus, P_ghA, 6083, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_A, P_WPlus, 7210, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_G0, P_ghZ, 8017, check)
      call createCurrent(P_Z, P_WMinus, P_HPlus, P_Hh, 986, check)
      call createCurrent(P_Z, P_WMinus, P_A, P_WPlus, 6033, check)
      call createCurrent(P_Hh, P_g, P_Hh, P_g, 10491, check)
      call createCurrent(P_g, P_g, P_g, 2014, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_GPlus, 1027, check)
      call createCurrent(P_GQPlus, P_A, P_WMinus, P_HhQ, 3019, check)
      call createCurrent(P_GMinus, P_g, P_g, P_GPlus, 10589, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghWm, P_GQPlus, 4697, check)
      call createCurrent(P_GQ0, P_bAnti, P_b, 3088, check)
      call createCurrent(P_HhQ, P_HMinus, P_G0, P_HQPlus, 3555, check)
      call createCurrent(P_cAnti, P_c, P_GQ0, 6076, check)
      call createCurrent(P_Hh, P_HMinus, P_WPlus, P_Z, 3375, check)
      call createCurrent(P_Hl, P_WMinus, P_A, P_HPlus, 5831, check)
      call createCurrent(P_A, P_A, P_Ha, P_G0, 10636, check)
      call createCurrent(P_HQPlus, P_ghZAnti, P_Hh, P_ghWm, 7769, check)
      call createCurrent(P_A, P_G0, P_HMinus, P_WPlus, 9549, check)
      call createCurrent(P_HQPlus, P_HMinus, P_A, P_AQ, 4959, check)
      call createCurrent(P_HPlus, P_ghWm, P_ghZAnti, P_Ha, 4605, check)
      call createCurrent(P_HQPlus, P_Hh, P_ghWm, P_ghZAnti, 7550, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_A, P_WQMinus, 1200, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_Hh, P_HhQ, 3407, check)
      call createCurrent(P_Hl, P_Hh, P_ghWp, P_ghWpAnti, 9420, check)
      call createCurrent(P_Hh, P_ghZ, P_ghWpAnti, P_HPlus, 8566, check)
      call createCurrent(P_tAnti, P_Hh, P_t, 5891, check)
      call createCurrent(P_GQPlus, P_G0, P_HMinus, P_GQ0, 2952, check)
      call createCurrent(P_HQPlus, P_Hl, P_WMinus, P_AQ, 7267, check)
      call createCurrent(P_g, P_g, P_HMinus, P_HPlus, 10747, check)
      call createCurrent(P_ghWp, P_Hl, P_GMinus, P_ghZAnti, 4169, check)
      call createCurrent(P_GMinus, P_WMinus, P_GPlus, P_WPlus, 6256, check)
      call createCurrent(P_HhQ, P_ghWp, P_ghWpAnti, 106, check)
      call createCurrent(P_ePlus, P_eMinus, P_AQ, 886, check)
      call createCurrent(P_GPlus, P_Hl, P_ghWpAnti, P_ghA, 269, check)
      call createCurrent(P_HMinus, P_ghWp, P_GPlus, P_ghWpAnti, 9680, check)
      call createCurrent(P_Hh, P_A, P_A, P_Hl, 10655, check)
      call createCurrent(P_GQ0, P_GPlus, P_HMinus, P_HlQ, 1123, check)
      call createCurrent(P_ZQ, P_b, P_bAnti, 5815, check)
      call createCurrent(P_WMinus, P_WPlus, P_ghWpAnti, P_ghWp, 3855, check)
      call createCurrent(P_Z, P_WPlus, P_Ha, P_GMinus, 10354, check)
      call createCurrent(P_GQ0, P_Hh, P_Ha, P_HhQ, 2962, check)
      call createCurrent(P_ghWmAnti, P_G0, P_ghA, P_GMinus, 5986, check)
      call createCurrent(P_Z, P_WPlus, P_ghWpAnti, P_ghA, 6351, check)
      call createCurrent(P_ePlus, P_Z, P_eMinus, 4042, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_ghZ, P_GMinus, 7042, check)
      call createCurrent(P_HhQ, P_GPlus, P_ghWm, P_ghAAnti, 2296, check)
      call createCurrent(P_Hh, P_G0, P_Hh, P_Ha, 2015, check)
      call createCurrent(P_ghZ, P_G0, P_ghWmAnti, P_GQMinus, 6940, check)
      call createCurrent(P_ghZAnti, P_Hl, P_Hh, P_ghZ, 10190, check)
      call createCurrent(P_HQMinus, P_Z, P_WPlus, P_HlQ, 3472, check)
      call createCurrent(P_G0, P_ghWm, P_ghWmAnti, P_G0, 2325, check)
      call createCurrent(P_ghWp, P_HMinus, P_ghZAnti, P_Hh, 2126, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_GPlus, P_ghZ, 5403, check)
      call createCurrent(P_Ha, P_Z, P_HPlus, P_WMinus, 8440, check)
      call createCurrent(P_HhQ, P_WMinus, P_Z, P_GQPlus, 8561, check)
      call createCurrent(P_G0, P_GPlus, P_G0, P_HMinus, 4027, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_GPlus, P_Hl, 439, check)
      call createCurrent(P_nu_e, P_Z, P_nu_eAnti, 2846, check)
      call createCurrent(P_G0, P_Hh, P_A, 10398, check)
      call createCurrent(P_A, P_ghAAnti, P_WMinus, P_ghWp, 639, check)
      call createCurrent(P_GMinus, P_A, P_WPlus, P_Hl, 5150, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_Hh, P_HPlus, 4110, check)
      call createCurrent(P_A, P_G0, P_Hl, 10069, check)
      call createCurrent(P_uAnti, P_d, P_GPlus, 2001, check)
      call createCurrent(P_A, P_ghWm, P_A, P_ghWmAnti, 7570, check)
      call createCurrent(P_Hl, P_Z, P_GPlus, P_WMinus, 6218, check)
      call createCurrent(P_HhQ, P_GMinus, P_ghAAnti, P_ghWp, 7740, check)
      call createCurrent(P_ghWp, P_Z, P_ghWpAnti, 6281, check)
      call createCurrent(P_ZQ, P_Ha, P_HPlus, P_WQMinus, 8236, check)
      call createCurrent(P_WMinus, P_GMinus, P_WPlus, P_HPlus, 9664, check)
      call createCurrent(P_ghWm, P_Z, P_ghWmAnti, P_Z, 1289, check)
      call createCurrent(P_WQMinus, P_WPlus, P_ghZAnti, P_ghA, 2839, check)
      call createCurrent(P_GQMinus, P_ghWmAnti, P_G0, P_ghA, 5125, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghA, P_Hh, 4137, check)
      call createCurrent(P_Hh, P_Ha, P_GMinus, P_GPlus, 9254, check)
      call createCurrent(P_HMinus, P_HPlus, P_Hl, P_Ha, 9195, check)
      call createCurrent(P_GPlus, P_G0, P_ghWm, P_ghZAnti, 4718, check)
      call createCurrent(P_HMinus, P_Hl, P_Ha, P_HPlus, 9468, check)
      call createCurrent(P_HaQ, P_sAnti, P_s, 1163, check)
      call createCurrent(P_ZQ, P_Hh, P_HaQ, 4261, check)
      call createCurrent(P_HaQ, P_HMinus, P_Z, P_WQPlus, 8819, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Hl, P_HaQ, 4823, check)
      call createCurrent(P_Z, P_Z, P_ghWm, P_ghWmAnti, 3224, check)
      call createCurrent(P_Hl, P_Hh, 10016, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_Ha, P_ghA, 10416, check)
      call createCurrent(P_GPlus, P_GMinus, P_ghWmAnti, P_ghWm, 7139, check)
      call createCurrent(P_HhQ, P_Hh, P_Ha, P_HaQ, 2409, check)
      call createCurrent(P_GQ0, P_Hh, P_HMinus, P_HQPlus, 6516, check)
      call createCurrent(P_G0, P_A, P_Hl, 8995, check)
      call createCurrent(P_Ha, P_HMinus, P_G0, P_GPlus, 1523, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_Z, P_WPlus, 5739, check)
      call createCurrent(P_HlQ, P_G0, P_HaQ, 8667, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_ghWm, P_HlQ, 6658, check)
      call createCurrent(P_gQ, P_g, P_ghG, P_ghGAnti, 3491, check)
      call createCurrent(P_GQ0, P_A, P_GMinus, P_WQPlus, 4330, check)
      call createCurrent(P_ZQ, P_HPlus, P_HMinus, P_ZQ, 7566, check)
      call createCurrent(P_GMinus, P_Hl, P_ghZAnti, P_ghWp, 7215, check)
      call createCurrent(P_GQ0, P_GPlus, P_Hh, P_HQMinus, 7200, check)
      call createCurrent(P_GPlus, P_HMinus, P_Z, P_Z, 9501, check)
      call createCurrent(P_ghWp, P_HMinus, P_ghAAnti, P_Hl, 8226, check)
      call createCurrent(P_GQPlus, P_ghWpAnti, P_Hh, P_ghZ, 4873, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Hl, P_HaQ, 6044, check)
      call createCurrent(P_HPlus, P_Hh, P_HMinus, P_Ha, 8928, check)
      call createCurrent(P_WPlus, P_Ha, P_HMinus, P_Z, 6243, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghAAnti, P_Hh, 8344, check)
      call createCurrent(P_G0, P_ghWm, P_GPlus, P_ghZAnti, 5177, check)
      call createCurrent(P_WPlus, P_nu_tauAnti, P_tauMinus, 5316, check)
      call createCurrent(P_ZQ, P_WMinus, P_GQPlus, 8184, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_Hh, P_ghWp, 7377, check)
      call createCurrent(P_GQPlus, P_Z, P_Hh, P_WQMinus, 651, check)
      call createCurrent(P_Hh, P_HMinus, P_GPlus, P_Hl, 742, check)
      call createCurrent(P_Hl, P_Hl, P_WPlus, P_WMinus, 7457, check)
      call createCurrent(P_t, P_HMinus, P_bAnti, 5271, check)
      call createCurrent(P_GMinus, P_A, P_Z, P_GPlus, 7625, check)
      call createCurrent(P_ghWp, P_Hh, P_GMinus, P_ghAAnti, 4004, check)
      call createCurrent(P_WQMinus, P_Ha, P_WPlus, P_HlQ, 877, check)
      call createCurrent(P_GMinus, P_ghZ, P_ghWmAnti, P_Hl, 8803, check)
      call createCurrent(P_GQMinus, P_Hh, P_GQPlus, 3838, check)
      call createCurrent(P_ZQ, P_ePlus, P_eMinus, 3232, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghZ, 5160, check)
      call createCurrent(P_GMinus, P_HPlus, P_Hh, P_Hh, 8533, check)
      call createCurrent(P_HhQ, P_Hh, P_Hl, P_HhQ, 8764, check)
      call createCurrent(P_WQMinus, P_ghZAnti, P_WPlus, P_ghA, 3524, check)
      call createCurrent(P_G0, P_HPlus, P_ghWm, P_ghZAnti, 10189, check)
      call createCurrent(P_WQMinus, P_HPlus, P_ZQ, 1754, check)
      call createCurrent(P_HMinus, P_WPlus, P_Z, P_Ha, 2739, check)
      call createCurrent(P_HMinus, P_WPlus, P_A, P_G0, 9349, check)
      call createCurrent(P_ghWm, P_G0, P_ghWmAnti, P_GQ0, 4869, check)
      call createCurrent(P_Z, P_HPlus, P_Hh, P_WMinus, 8363, check)
      call createCurrent(P_AQ, P_A, P_GPlus, P_GQMinus, 271, check)
      call createCurrent(P_GQMinus, P_GPlus, P_ZQ, 4111, check)
      call createCurrent(P_A, P_A, P_HPlus, P_HMinus, 6730, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_HPlus, P_HaQ, 1438, check)
      call createCurrent(P_ghZ, P_Hl, P_ghWmAnti, P_GMinus, 2795, check)
      call createCurrent(P_HaQ, P_G0, P_HlQ, 4234, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_ghWm, P_Ha, 9846, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_Hl, P_Hh, 10413, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_ghWm, P_Hh, 4073, check)
      call createCurrent(P_A, P_WMinus, P_HPlus, 824, check)
      call createCurrent(P_HPlus, P_GMinus, P_ghWpAnti, P_ghWp, 9037, check)
      call createCurrent(P_Ha, P_HMinus, P_G0, P_HPlus, 8137, check)
      call createCurrent(P_Ha, P_HPlus, P_ghA, P_ghWpAnti, 5732, check)
      call createCurrent(P_Z, P_Z, P_Hl, P_Hh, 9471, check)
      call createCurrent(P_Z, P_Ha, P_WPlus, P_HMinus, 6888, check)
      call createCurrent(P_HPlus, P_Ha, P_ghZAnti, P_ghWm, 4011, check)
      call createCurrent(P_WPlus, P_WMinus, P_ghWm, P_ghWmAnti, 2915, check)
      call createCurrent(P_ghWm, P_HPlus, P_Ha, P_ghAAnti, 8446, check)
      call createCurrent(P_HMinus, P_GPlus, P_ghZ, P_ghZAnti, 8903, check)
      call createCurrent(P_GMinus, P_GPlus, P_ghZAnti, P_ghZ, 1366, check)
      call createCurrent(P_HQPlus, P_A, P_HQMinus, 65, check)
      call createCurrent(P_g, P_dAnti, P_d, 78, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_GQ0, 4193, check)
      call createCurrent(P_uAnti, P_d, P_WQPlus, 3799, check)
      call createCurrent(P_G0, P_Ha, P_Ha, P_G0, 2073, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_Hh, P_HQMinus, 578, check)
      call createCurrent(P_ghAAnti, P_Hl, P_ghWm, P_GPlus, 2108, check)
      call createCurrent(P_HPlus, P_ghZAnti, P_ghWm, P_G0, 9906, check)
      call createCurrent(P_ghZAnti, P_HPlus, P_ghWm, P_HaQ, 1730, check)
      call createCurrent(P_HaQ, P_Hh, P_GPlus, P_HQMinus, 3652, check)
      call createCurrent(P_GQPlus, P_Ha, P_HMinus, P_HhQ, 2586, check)
      call createCurrent(P_ghWp, P_G0, P_GMinus, P_ghZAnti, 8046, check)
      call createCurrent(P_Ha, P_ghWmAnti, P_HMinus, P_ghA, 2304, check)
      call createCurrent(P_G0, P_Z, P_G0, P_A, 10254, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_HMinus, P_Ha, 47, check)
      call createCurrent(P_GPlus, P_WPlus, P_WMinus, P_HMinus, 9821, check)
      call createCurrent(P_ghWp, P_Hl, P_ghWpAnti, P_Hl, 2396, check)
      call createCurrent(P_GMinus, P_Hl, P_G0, P_HPlus, 6202, check)
      call createCurrent(P_WPlus, P_Z, P_GMinus, P_Hl, 4037, check)
      call createCurrent(P_Hl, P_Hh, P_Hh, P_Hl, 2037, check)
      call createCurrent(P_A, P_tauMinus, P_tauPlus, 2443, check)
      call createCurrent(P_GQ0, P_GPlus, P_GMinus, P_HaQ, 4167, check)
      call createCurrent(P_HhQ, P_GMinus, P_WPlus, P_ZQ, 3751, check)
      call createCurrent(P_HhQ, P_ghWm, P_GPlus, P_ghZAnti, 2786, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghAAnti, P_HlQ, 1540, check)
      call createCurrent(P_GPlus, P_ghAAnti, P_ghA, P_GMinus, 250, check)
      call createCurrent(P_WMinus, P_GPlus, P_Z, P_G0, 2318, check)
      call createCurrent(P_HaQ, P_HPlus, P_GMinus, P_HaQ, 7336, check)
      call createCurrent(P_ghAAnti, P_ghZ, P_GPlus, P_HMinus, 9839, check)
      call createCurrent(P_HhQ, P_HMinus, P_GQPlus, 3556, check)
      call createCurrent(P_A, P_HMinus, P_G0, P_WPlus, 9257, check)
      call createCurrent(P_ghZ, P_Hh, P_ghWmAnti, P_HQMinus, 2939, check)
      call createCurrent(P_GQPlus, P_GMinus, P_ghWm, P_ghWmAnti, 6108, check)
      call createCurrent(P_HaQ, P_Hl, P_HPlus, P_GQMinus, 8035, check)
      call createCurrent(P_HPlus, P_Ha, P_GMinus, P_Hl, 141, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghA, P_HMinus, 9005, check)
      call createCurrent(P_GPlus, P_WMinus, P_WPlus, P_HMinus, 10447, check)
      call createCurrent(P_G0, P_HMinus, P_Ha, P_HPlus, 1739, check)
      call createCurrent(P_Hl, P_Hh, P_GMinus, P_GPlus, 7691, check)
      call createCurrent(P_Z, P_GPlus, P_A, P_GMinus, 6048, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghWm, P_WQPlus, 733, check)
      call createCurrent(P_ghZAnti, P_Hh, P_GPlus, P_ghWm, 5791, check)
      call createCurrent(P_GQMinus, P_ghZ, P_G0, P_ghWmAnti, 7344, check)
      call createCurrent(P_HMinus, P_ghZ, P_GPlus, P_ghAAnti, 10054, check)
      call createCurrent(P_GQPlus, P_b, P_tAnti, 2749, check)
      call createCurrent(P_Hl, P_Hl, P_HMinus, P_HPlus, 4583, check)
      call createCurrent(P_HMinus, P_ghZ, P_ghWmAnti, P_Hl, 1379, check)
      call createCurrent(P_GPlus, P_HMinus, P_ghZ, P_ghZAnti, 10432, check)
      call createCurrent(P_HMinus, P_G0, P_HPlus, P_G0, 4981, check)
      call createCurrent(P_ghZ, P_GMinus, P_HPlus, P_ghAAnti, 9588, check)
      call createCurrent(P_ghZAnti, P_HMinus, P_ghWp, P_Hl, 2707, check)
      call createCurrent(P_HhQ, P_ghAAnti, P_HPlus, P_ghWm, 1915, check)
      call createCurrent(P_Ha, P_ghWm, P_ghWmAnti, P_Ha, 2794, check)
      call createCurrent(P_ZQ, P_G0, P_WPlus, P_GQMinus, 7987, check)
      call createCurrent(P_G0, P_G0, P_HMinus, P_HPlus, 3879, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_HPlus, P_Ha, 8547, check)
      call createCurrent(P_ghAAnti, P_Z, P_WMinus, P_ghWp, 1154, check)
      call createCurrent(P_ghA, P_HMinus, P_ghWmAnti, P_Hh, 8050, check)
      call createCurrent(P_HQMinus, P_HPlus, P_ghZAnti, P_ghA, 7612, check)
      call createCurrent(P_Hh, P_G0, P_HPlus, P_HMinus, 10256, check)
      call createCurrent(P_HlQ, P_Z, P_Z, P_HlQ, 7532, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_WQMinus, 267, check)
      call createCurrent(P_ZQ, P_HPlus, P_WQMinus, 4431, check)
      call createCurrent(P_HaQ, P_GMinus, P_G0, P_HQPlus, 2878, check)
      call createCurrent(P_WQPlus, P_WMinus, P_ghZ, P_ghZAnti, 7413, check)
      call createCurrent(P_Hl, P_ghWpAnti, P_ghZ, P_GPlus, 6156, check)
      call createCurrent(P_WMinus, P_WMinus, P_WPlus, P_WPlus, 8704, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_WPlus, P_WQMinus, 8286, check)
      call createCurrent(P_b, P_bAnti, P_ZQ, 4304, check)
      call createCurrent(P_tAnti, P_t, P_Hh, 2595, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Hh, P_Hl, 8926, check)
      call createCurrent(P_c, P_WMinus, P_sAnti, 7983, check)
      call createCurrent(P_HaQ, P_G0, P_Hh, P_HlQ, 6251, check)
      call createCurrent(P_GPlus, P_Ha, P_ghZ, P_ghWpAnti, 9798, check)
      call createCurrent(P_GMinus, P_GPlus, P_Hh, P_Hh, 4260, check)
      call createCurrent(P_ghZAnti, P_HMinus, P_ghA, P_HPlus, 3858, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_Hl, P_ghZ, 5095, check)
      call createCurrent(P_GPlus, P_GMinus, P_Z, P_A, 3432, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_Z, P_ghA, 2557, check)
      call createCurrent(P_Ha, P_Ha, P_A, P_Z, 9200, check)
      call createCurrent(P_A, P_ghWpAnti, P_ghWp, P_Z, 4273, check)
      call createCurrent(P_GQ0, P_G0, P_ghWmAnti, P_ghWm, 1189, check)
      call createCurrent(P_HlQ, P_Ha, P_Hh, P_HaQ, 2633, check)
      call createCurrent(P_Hh, P_Hl, P_G0, P_G0, 961, check)
      call createCurrent(P_g, P_Hl, P_Hl, P_g, 10660, check)
      call createCurrent(P_G0, P_Hl, P_GPlus, P_HMinus, 4463, check)
      call createCurrent(P_GMinus, P_G0, P_ghAAnti, P_ghWp, 4439, check)
      call createCurrent(P_Z, P_GPlus, P_A, P_HMinus, 9742, check)
      call createCurrent(P_HQPlus, P_Ha, P_Z, P_WQMinus, 2710, check)
      call createCurrent(P_GQMinus, P_HPlus, P_GPlus, P_GQMinus, 6796, check)
      call createCurrent(P_G0, P_HMinus, P_ghWmAnti, P_ghZ, 9611, check)
      call createCurrent(P_WQMinus, P_Z, P_Hl, P_HQPlus, 3119, check)
      call createCurrent(P_HQPlus, P_GPlus, P_HMinus, P_HQMinus, 7733, check)
      call createCurrent(P_HQPlus, P_GMinus, P_Hl, P_HlQ, 6445, check)
      call createCurrent(P_GQMinus, P_GMinus, P_GPlus, P_GQPlus, 6584, check)
      call createCurrent(P_ghAAnti, P_G0, P_HMinus, P_ghWp, 10410, check)
      call createCurrent(P_G0, P_ePlus, P_eMinus, 2173, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_A, P_ghWm, 7758, check)
      call createCurrent(P_HPlus, P_ghZ, P_ghAAnti, P_GMinus, 8946, check)
      call createCurrent(P_HlQ, P_Ha, P_ghWmAnti, P_ghWm, 4659, check)
      call createCurrent(P_HPlus, P_Ha, P_HMinus, P_Hl, 9284, check)
      call createCurrent(P_GPlus, P_Z, P_HMinus, P_Z, 8896, check)
      call createCurrent(P_ghA, P_Hh, P_ghWpAnti, P_HPlus, 4924, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_Hh, P_GQMinus, 80, check)
      call createCurrent(P_ghZ, P_Hh, P_ghZAnti, P_Hl, 10176, check)
      call createCurrent(P_AQ, P_GMinus, P_GPlus, P_AQ, 771, check)
      call createCurrent(P_g, P_HMinus, P_GPlus, P_g, 10752, check)
      call createCurrent(P_WQMinus, P_ghZAnti, P_ghWp, 8360, check)
      call createCurrent(P_Ha, P_WPlus, P_HMinus, P_A, 3482, check)
      call createCurrent(P_ghWmAnti, P_Hl, P_ghZ, P_HQMinus, 2101, check)
      call createCurrent(P_HaQ, P_cAnti, P_c, 6885, check)
      call createCurrent(P_ghG, P_g, P_g, P_ghGAnti, 2990, check)
      call createCurrent(P_t, P_tAnti, P_g, 2013, check)
      call createCurrent(P_Hh, P_HPlus, P_Hh, P_GMinus, 6058, check)
      call createCurrent(P_ghWmAnti, P_A, P_ghWm, P_AQ, 3962, check)
      call createCurrent(P_G0, P_WMinus, P_WPlus, P_G0, 1043, check)
      call createCurrent(P_Z, P_Hl, P_GPlus, P_WMinus, 8202, check)
      call createCurrent(P_ghA, P_ghAAnti, P_GMinus, P_HPlus, 10079, check)
      call createCurrent(P_GQMinus, P_Hl, P_Hl, P_GQPlus, 3178, check)
      call createCurrent(P_GMinus, P_G0, P_G0, P_HPlus, 3727, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_A, P_WPlus, 7589, check)
      call createCurrent(P_ghWmAnti, P_HPlus, P_ghWm, P_GMinus, 10126, check)
      call createCurrent(P_Hh, P_G0, P_Ha, 8778, check)
      call createCurrent(P_Hh, P_cAnti, P_c, 7465, check)
      call createCurrent(P_GPlus, P_Hh, P_WMinus, P_Z, 643, check)
      call createCurrent(P_ghAAnti, P_ghA, P_HMinus, P_GPlus, 9489, check)
      call createCurrent(P_ghA, P_ghAAnti, P_GPlus, P_GMinus, 1820, check)
      call createCurrent(P_GPlus, P_GMinus, P_ghZAnti, P_ghZ, 7374, check)
      call createCurrent(P_GQ0, P_Ha, P_Ha, P_GQ0, 380, check)
      call createCurrent(P_HlQ, P_HPlus, P_GMinus, P_GQ0, 6435, check)
      call createCurrent(P_G0, P_GMinus, P_HPlus, P_Hl, 3792, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_HPlus, P_Ha, 1546, check)
      call createCurrent(P_Hl, P_Z, P_Z, 8754, check)
      call createCurrent(P_ghAAnti, P_HPlus, P_ghWm, P_Hl, 18, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghWm, P_HlQ, 2534, check)
      call createCurrent(P_Z, P_WMinus, P_WPlus, 7838, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_G0, P_HMinus, 9505, check)
      call createCurrent(P_HQPlus, P_ghWpAnti, P_Hl, P_ghZ, 748, check)
      call createCurrent(P_WQMinus, P_u, P_dAnti, 1731, check)
      call createCurrent(P_ghWp, P_Hh, P_ghWpAnti, 6908, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_WPlus, P_ghWm, 5237, check)
      call createCurrent(P_A, P_Z, P_G0, P_Ha, 10569, check)
      call createCurrent(P_Hl, P_GMinus, P_ghZAnti, P_ghWp, 7100, check)
      call createCurrent(P_HMinus, P_Ha, P_ghWmAnti, P_ghA, 7773, check)
      call createCurrent(P_GQ0, P_G0, P_G0, P_GQ0, 6551, check)
      call createCurrent(P_ghWm, P_Z, P_WPlus, P_ghAAnti, 1676, check)
      call createCurrent(P_HMinus, P_ghZAnti, P_HPlus, P_ghZ, 6587, check)
      call createCurrent(P_ghAAnti, P_HPlus, P_ghA, P_HQMinus, 5196, check)
      call createCurrent(P_HPlus, P_Hh, P_ghWpAnti, P_ghA, 7075, check)
      call createCurrent(P_A, P_Ha, P_G0, P_A, 10706, check)
      call createCurrent(P_HMinus, P_ghAAnti, P_GPlus, P_ghZ, 9050, check)
      call createCurrent(P_HQMinus, P_G0, P_HPlus, P_GQ0, 4936, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Hl, P_GQ0, 7810, check)
      call createCurrent(P_A, P_HMinus, P_HPlus, P_Z, 2514, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_ghWp, P_ZQ, 5915, check)
      call createCurrent(P_Hh, P_ghWp, P_Hh, P_ghWpAnti, 6679, check)
      call createCurrent(P_HlQ, P_GPlus, P_Hl, P_HQMinus, 650, check)
      call createCurrent(P_HhQ, P_GMinus, P_GPlus, P_HlQ, 2019, check)
      call createCurrent(P_Hl, P_ghA, P_GMinus, P_ghWmAnti, 8209, check)
      call createCurrent(P_GQ0, P_Hh, P_Hl, P_HaQ, 5069, check)
      call createCurrent(P_WMinus, P_Z, P_Ha, P_GPlus, 9581, check)
      call createCurrent(P_HMinus, P_Hh, P_G0, P_HPlus, 9251, check)
      call createCurrent(P_AQ, P_G0, P_WPlus, P_GQMinus, 193, check)
      call createCurrent(P_WQPlus, P_cAnti, P_s, 1508, check)
      call createCurrent(P_HhQ, P_G0, P_HPlus, P_GQMinus, 6112, check)
      call createCurrent(P_ghWpAnti, P_Hh, P_Hh, P_ghWp, 1064, check)
      call createCurrent(P_d, P_uAnti, P_WQPlus, 7428, check)
      call createCurrent(P_ghAAnti, P_ghA, P_WMinus, P_WPlus, 7858, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_GMinus, P_Hl, 2770, check)
      call createCurrent(P_A, P_HMinus, P_WPlus, P_G0, 9768, check)
      call createCurrent(P_WMinus, P_A, P_HPlus, 861, check)
      call createCurrent(P_Hl, P_HPlus, P_Hl, P_GMinus, 3060, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_Ha, P_ghZ, 9801, check)
      call createCurrent(P_WPlus, P_GMinus, P_A, P_Hl, 4207, check)
      call createCurrent(P_GQMinus, P_ghWp, P_G0, P_ghZAnti, 8132, check)
      call createCurrent(P_ghWm, P_Hl, P_ghWmAnti, 686, check)
      call createCurrent(P_GQMinus, P_ghZ, P_GPlus, P_ghAAnti, 5569, check)
      call createCurrent(P_Z, P_WPlus, P_Z, P_WMinus, 4209, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_GPlus, P_Hh, 4297, check)
      call createCurrent(P_GQPlus, P_HMinus, P_Ha, P_HlQ, 5215, check)
      call createCurrent(P_A, P_GPlus, P_Z, P_HMinus, 10052, check)
      call createCurrent(P_G0, P_HPlus, P_GMinus, 5544, check)
      call createCurrent(P_A, P_Hl, P_Hh, P_Z, 10751, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_G0, P_GMinus, 1407, check)
      call createCurrent(P_A, P_WMinus, P_ghWp, P_ghZAnti, 2515, check)
      call createCurrent(P_HMinus, P_HPlus, P_Hh, P_G0, 9412, check)
      call createCurrent(P_HaQ, P_HMinus, P_ghWp, P_ghAAnti, 2480, check)
      call createCurrent(P_HPlus, P_G0, P_GMinus, P_G0, 5637, check)
      call createCurrent(P_WMinus, P_HPlus, P_A, P_Ha, 6799, check)
      call createCurrent(P_GQPlus, P_GMinus, P_Ha, P_GQ0, 5111, check)
      call createCurrent(P_bAnti, P_b, P_g, 6321, check)
      call createCurrent(P_GQMinus, P_Ha, P_HPlus, P_GQ0, 8051, check)
      call createCurrent(P_Ha, P_G0, P_Hh, 7518, check)
      call createCurrent(P_HhQ, P_ghWm, P_HPlus, P_ghZAnti, 6770, check)
      call createCurrent(P_GPlus, P_GMinus, P_WPlus, P_WMinus, 1838, check)
      call createCurrent(P_HlQ, P_tauPlus, P_tauMinus, 3908, check)
      call createCurrent(P_ghA, P_ghZAnti, P_WPlus, P_WMinus, 5487, check)
      call createCurrent(P_WQMinus, P_Hl, P_WQPlus, 340, check)
      call createCurrent(P_HMinus, P_G0, P_ghAAnti, P_ghWp, 10389, check)
      call createCurrent(P_GMinus, P_HPlus, P_A, P_A, 9682, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Ha, P_G0, 9716, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_WMinus, P_WQPlus, 6697, check)
      call createCurrent(P_t, P_Z, P_tAnti, 738, check)
      call createCurrent(P_HQPlus, P_ghAAnti, P_HMinus, P_ghA, 3295, check)
      call createCurrent(P_G0, P_dAnti, P_d, 7937, check)
      call createCurrent(P_HaQ, P_ghWmAnti, P_ghWm, 8106, check)
      call createCurrent(P_Ha, P_GPlus, P_GMinus, 9089, check)
      call createCurrent(P_Hl, P_Ha, P_Ha, P_Hl, 4818, check)
      call createCurrent(P_ghA, P_WPlus, P_Z, P_ghWpAnti, 5555, check)
      call createCurrent(P_s, P_Z, P_sAnti, 1252, check)
      call createCurrent(P_GMinus, P_A, P_GPlus, P_Z, 8060, check)
      call createCurrent(P_Hl, P_muMinus, P_muPlus, 669, check)
      call createCurrent(P_HMinus, P_HPlus, P_GPlus, P_GMinus, 6571, check)
      call createCurrent(P_nu_e, P_WMinus, P_ePlus, 5965, check)
      call createCurrent(P_HaQ, P_Hl, P_G0, P_HhQ, 845, check)
      call createCurrent(P_GPlus, P_ghZ, P_Hl, P_ghWpAnti, 6983, check)
      call createCurrent(P_Hl, P_GMinus, P_Hl, P_GPlus, 3531, check)
      call createCurrent(P_eMinus, P_Hh, P_ePlus, 3078, check)
      call createCurrent(P_Hh, P_Z, P_HPlus, P_WMinus, 2263, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_Hh, P_Hh, 2789, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_GMinus, P_Hh, 5867, check)
      call createCurrent(P_GQPlus, P_ghZ, P_ghWpAnti, 2007, check)
      call createCurrent(P_GPlus, P_Hh, P_G0, P_HMinus, 1089, check)
      call createCurrent(P_s, P_sAnti, P_HhQ, 693, check)
      call createCurrent(P_HlQ, P_A, P_GMinus, P_WQPlus, 7599, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_Hh, P_HMinus, 1136, check)
      call createCurrent(P_GQMinus, P_Ha, P_Hl, P_HQPlus, 2996, check)
      call createCurrent(P_HQMinus, P_ghA, P_Ha, P_ghWmAnti, 6122, check)
      call createCurrent(P_A, P_WMinus, P_HPlus, P_G0, 9598, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_Hl, P_HPlus, 6950, check)
      call createCurrent(P_Hh, P_Hh, P_Hl, 392, check)
      call createCurrent(P_HaQ, P_HPlus, P_WMinus, P_ZQ, 168, check)
      call createCurrent(P_G0, P_c, P_cAnti, 3358, check)
      call createCurrent(P_WMinus, P_ghZ, P_Z, P_ghWmAnti, 3515, check)
      call createCurrent(P_G0, P_GMinus, P_ghWmAnti, P_ghZ, 441, check)
      call createCurrent(P_GQ0, P_HMinus, P_GPlus, P_HlQ, 5567, check)
      call createCurrent(P_HQPlus, P_HMinus, P_HMinus, P_GQPlus, 1463, check)
      call createCurrent(P_t, P_tAnti, P_HlQ, 6928, check)
      call createCurrent(P_HlQ, P_Hl, P_Ha, P_HaQ, 7784, check)
      call createCurrent(P_ghWm, P_HPlus, P_ghWmAnti, P_HMinus, 7786, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghZAnti, P_G0, 7954, check)
      call createCurrent(P_Ha, P_b, P_bAnti, 4713, check)
      call createCurrent(P_Ha, P_Ha, P_Ha, P_G0, 462, check)
      call createCurrent(P_Ha, P_g, P_G0, P_g, 10693, check)
      call createCurrent(P_nu_tau, P_nu_tauAnti, P_A, 8960, check)
      call createCurrent(P_HMinus, P_Z, P_WPlus, 1012, check)
      call createCurrent(P_ghAAnti, P_HMinus, P_Ha, P_ghWp, 999, check)
      call createCurrent(P_GMinus, P_GMinus, P_GPlus, P_GPlus, 6426, check)
      call createCurrent(P_HaQ, P_Hl, P_HaQ, 6635, check)
      call createCurrent(P_HlQ, P_HMinus, P_A, P_WQPlus, 937, check)
      call createCurrent(P_HPlus, P_G0, P_ghWm, P_ghZAnti, 9464, check)
      call createCurrent(P_AQ, P_HPlus, P_Z, P_HQMinus, 7849, check)
      call createCurrent(P_WQMinus, P_WPlus, P_HhQ, 570, check)
      call createCurrent(P_HQMinus, P_Z, P_HPlus, P_AQ, 3023, check)
      call createCurrent(P_WQPlus, P_GMinus, P_Hh, P_ZQ, 3609, check)
      call createCurrent(P_GMinus, P_Ha, P_ghWp, P_ghZAnti, 10343, check)
      call createCurrent(P_Ha, P_HMinus, P_Ha, P_GPlus, 714, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_Ha, P_HMinus, 5209, check)
      call createCurrent(P_GQPlus, P_eMinus, P_nu_eAnti, 22, check)
      call createCurrent(P_HQMinus, P_GPlus, P_HlQ, 8033, check)
      call createCurrent(P_muMinus, P_muPlus, P_AQ, 6844, check)
      call createCurrent(P_tAnti, P_t, P_Ha, 5236, check)
      call createCurrent(P_WPlus, P_HMinus, P_G0, P_A, 9809, check)
      call createCurrent(P_HhQ, P_ghZ, P_GMinus, P_ghWmAnti, 6656, check)
      call createCurrent(P_Ha, P_GMinus, P_GPlus, 9831, check)
      call createCurrent(P_G0, P_HMinus, P_HPlus, P_Hh, 8978, check)
      call createCurrent(P_Ha, P_ghWm, P_ghAAnti, P_HPlus, 1756, check)
      call createCurrent(P_ghWm, P_A, P_ghWmAnti, P_A, 4533, check)
      call createCurrent(P_HPlus, P_GMinus, P_ghZ, P_ghAAnti, 8947, check)
      call createCurrent(P_HMinus, P_Ha, P_Hh, P_GPlus, 7432, check)
      call createCurrent(P_GMinus, P_G0, P_HPlus, 4658, check)
      call createCurrent(P_Ha, P_HPlus, P_GMinus, P_Hl, 8304, check)
      call createCurrent(P_ghWpAnti, P_A, P_ghWp, P_A, 4958, check)
      call createCurrent(P_HhQ, P_HMinus, P_Hh, P_HQPlus, 4151, check)
      call createCurrent(P_WMinus, P_HPlus, P_HMinus, P_WPlus, 708, check)
      call createCurrent(P_GQMinus, P_Ha, P_HPlus, P_HaQ, 4238, check)
      call createCurrent(P_HMinus, P_HPlus, P_Hh, P_Ha, 9747, check)
      call createCurrent(P_HPlus, P_GMinus, P_Ha, P_Ha, 4205, check)
      call createCurrent(P_HMinus, P_GPlus, P_Hl, 6881, check)
      call createCurrent(P_HMinus, P_ghWp, P_G0, P_ghAAnti, 9848, check)
      call createCurrent(P_dAnti, P_d, P_HhQ, 2531, check)
      call createCurrent(P_WPlus, P_g, P_WMinus, P_g, 10663, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_Hl, P_HlQ, 3903, check)
      call createCurrent(P_WQMinus, P_Hh, P_WPlus, P_HaQ, 1466, check)
      call createCurrent(P_tauMinus, P_nu_tauAnti, P_WQPlus, 265, check)
      call createCurrent(P_Z, P_GPlus, P_Ha, P_WMinus, 10385, check)
      call createCurrent(P_Z, P_Ha, P_GPlus, P_WMinus, 8920, check)
      call createCurrent(P_ZQ, P_Z, P_WPlus, P_WQMinus, 2592, check)
      call createCurrent(P_Z, P_ghZAnti, P_WPlus, P_ghWm, 1262, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_GPlus, P_HhQ, 3499, check)
      call createCurrent(P_ghA, P_ghAAnti, P_GMinus, P_GPlus, 5515, check)
      call createCurrent(P_Hl, P_Z, P_A, P_Hl, 9135, check)
      call createCurrent(P_HhQ, P_Ha, P_HMinus, P_HQPlus, 5890, check)
      call createCurrent(P_ghWp, P_Hh, P_ghWpAnti, P_HaQ, 448, check)
      call createCurrent(P_ghWpAnti, P_Z, P_ghWp, P_A, 1217, check)
      call createCurrent(P_Ha, P_HMinus, P_ghAAnti, P_ghWp, 6688, check)
      call createCurrent(P_ZQ, P_WMinus, P_WQPlus, 4099, check)
      call createCurrent(P_ghWpAnti, P_Hh, P_Hl, P_ghWp, 10440, check)
      call createCurrent(P_HaQ, P_Ha, P_Hh, P_HhQ, 3075, check)
      call createCurrent(P_HlQ, P_GMinus, P_HPlus, P_HhQ, 833, check)
      call createCurrent(P_WMinus, P_Hl, P_WPlus, P_Hl, 5755, check)
      call createCurrent(P_GQ0, P_GMinus, P_GPlus, P_GQ0, 5362, check)
      call createCurrent(P_HPlus, P_GMinus, P_ghAAnti, P_ghZ, 10132, check)
      call createCurrent(P_ghZ, P_HMinus, P_HPlus, P_ghZAnti, 741, check)
      call createCurrent(P_WQMinus, P_HMinus, P_HPlus, P_WQPlus, 2504, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_HPlus, 7032, check)
      call createCurrent(P_GQPlus, P_HMinus, P_Ha, P_HaQ, 5259, check)
      call createCurrent(P_HaQ, P_HMinus, P_HPlus, P_HaQ, 2900, check)
      call createCurrent(P_HMinus, P_ghA, P_Ha, P_ghWmAnti, 4617, check)
      call createCurrent(P_GMinus, P_ghAAnti, P_ghWp, P_Ha, 9828, check)
      call createCurrent(P_GQ0, P_Hl, P_HMinus, P_GQPlus, 7640, check)
      call createCurrent(P_HPlus, P_A, P_HMinus, P_A, 1005, check)
      call createCurrent(P_c, P_cAnti, P_gQ, 4222, check)
      call createCurrent(P_ghAAnti, P_Ha, P_GPlus, P_ghWm, 9923, check)
      call createCurrent(P_Z, P_G0, P_WMinus, P_GPlus, 5484, check)
      call createCurrent(P_ghWmAnti, P_Hh, P_ghA, P_GQMinus, 5360, check)
      call createCurrent(P_HaQ, P_ghWm, P_Hh, P_ghWmAnti, 2340, check)
      call createCurrent(P_HMinus, P_Ha, P_ghZAnti, P_ghWp, 4349, check)
      call createCurrent(P_AQ, P_eMinus, P_ePlus, 6938, check)
      call createCurrent(P_GQ0, P_GPlus, P_HMinus, P_GQ0, 8225, check)
      call createCurrent(P_Hl, P_Ha, P_Z, 3198, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_Hh, P_GQMinus, 6032, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_GPlus, P_HMinus, 9149, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_HlQ, 2467, check)
      call createCurrent(P_Hl, P_G0, P_Ha, 8500, check)
      call createCurrent(P_GPlus, P_GMinus, P_G0, P_Hh, 9926, check)
      call createCurrent(P_Hl, P_G0, P_G0, P_Hl, 8619, check)
      call createCurrent(P_Hh, P_Hl, P_WPlus, P_WMinus, 10168, check)
      call createCurrent(P_Hl, P_HMinus, P_ghAAnti, P_ghWp, 5839, check)
      call createCurrent(P_GQ0, P_G0, P_WMinus, P_WQPlus, 907, check)
      call createCurrent(P_GPlus, P_Hh, P_GMinus, 5260, check)
      call createCurrent(P_WQPlus, P_ghZAnti, P_ghWm, 3665, check)
      call createCurrent(P_Hh, P_Hl, 9531, check)
      call createCurrent(P_WQMinus, P_nu_tau, P_tauPlus, 6550, check)
      call createCurrent(P_GQPlus, P_nu_eAnti, P_eMinus, 6364, check)
      call createCurrent(P_Z, P_WPlus, P_ghZ, P_ghWpAnti, 1742, check)
      call createCurrent(P_HPlus, P_HMinus, P_Hl, 7830, check)
      call createCurrent(P_A, P_G0, P_HPlus, P_WMinus, 9802, check)
      call createCurrent(P_HPlus, P_ghZAnti, P_ghWm, P_Hh, 5817, check)
      call createCurrent(P_Hl, P_Hl, P_Hl, P_G0, 10639, check)
      call createCurrent(P_GPlus, P_A, P_A, P_HMinus, 9028, check)
      call createCurrent(P_Hh, P_Z, P_WPlus, P_HMinus, 6570, check)
      call createCurrent(P_ghZAnti, P_Ha, P_ghZ, P_G0, 9613, check)
      call createCurrent(P_WMinus, P_ghZ, P_WPlus, P_ghAAnti, 6924, check)
      call createCurrent(P_Ha, P_HPlus, P_WMinus, P_A, 626, check)
      call createCurrent(P_WQMinus, P_HPlus, P_A, P_HhQ, 6777, check)
      call createCurrent(P_HaQ, P_Ha, P_HMinus, P_GQPlus, 4401, check)
      call createCurrent(P_HMinus, P_GPlus, P_G0, P_Ha, 6805, check)
      call createCurrent(P_ghAAnti, P_ghZ, P_HMinus, P_HPlus, 3965, check)
      call createCurrent(P_g, P_HPlus, P_HMinus, P_g, 10565, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_G0, P_GQ0, 514, check)
      call createCurrent(P_HMinus, P_Hl, P_Z, P_WPlus, 1744, check)
      call createCurrent(P_G0, P_ghWp, P_ghAAnti, P_HMinus, 8889, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_Hh, P_HMinus, 1249, check)
      call createCurrent(P_HPlus, P_G0, P_ghAAnti, P_ghWm, 9356, check)
      call createCurrent(P_Ha, P_ghWp, P_ghAAnti, P_GMinus, 9407, check)
      call createCurrent(P_ghZAnti, P_G0, P_ghWm, P_GQPlus, 3373, check)
      call createCurrent(P_GMinus, P_Hl, P_G0, P_GPlus, 10001, check)
      call createCurrent(P_HlQ, P_WPlus, P_GMinus, P_ZQ, 849, check)
      call createCurrent(P_ZQ, P_Hl, P_GPlus, P_WQMinus, 290, check)
      call createCurrent(P_GQMinus, P_WPlus, P_Hh, P_ZQ, 1165, check)
      call createCurrent(P_Z, P_A, P_HMinus, P_GPlus, 10094, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_HhQ, 1673, check)
      call createCurrent(P_GQMinus, P_ghZAnti, P_Hl, P_ghWp, 4433, check)
      call createCurrent(P_HPlus, P_G0, P_ghWpAnti, P_ghA, 10026, check)
      call createCurrent(P_HQMinus, P_Hh, P_Hl, P_GQPlus, 8799, check)
      call createCurrent(P_GQMinus, P_G0, P_HPlus, P_HaQ, 3279, check)
      call createCurrent(P_Z, P_GPlus, P_GMinus, P_Z, 8526, check)
      call createCurrent(P_A, P_HPlus, P_A, P_GMinus, 10077, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Ha, P_HaQ, 8508, check)
      call createCurrent(P_ghWpAnti, P_Ha, P_HPlus, P_ghA, 411, check)
      call createCurrent(P_GPlus, P_ghZ, P_HMinus, P_ghZAnti, 9162, check)
      call createCurrent(P_Hl, P_ghWp, P_ghZAnti, P_HMinus, 6198, check)
      call createCurrent(P_Hl, P_HMinus, P_HPlus, P_Ha, 9612, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Ha, P_G0, 9579, check)
      call createCurrent(P_WPlus, P_A, P_Ha, P_GMinus, 9000, check)
      call createCurrent(P_GPlus, P_A, P_WMinus, P_Hl, 1747, check)
      call createCurrent(P_WQMinus, P_GPlus, P_ZQ, 6773, check)
      call createCurrent(P_HlQ, P_Ha, P_HaQ, 4347, check)
      call createCurrent(P_AQ, P_Hl, P_WMinus, P_GQPlus, 4811, check)
      call createCurrent(P_WMinus, P_G0, P_Z, P_GPlus, 1894, check)
      call createCurrent(P_HlQ, P_Ha, P_HMinus, P_HQPlus, 5712, check)
      call createCurrent(P_ghWmAnti, P_Z, P_ghWm, 4296, check)
      call createCurrent(P_HQMinus, P_HPlus, P_A, P_AQ, 2235, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghZ, P_A, 8069, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_HPlus, P_Hh, 3728, check)
      call createCurrent(P_WQMinus, P_WPlus, P_Hl, P_HlQ, 1292, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghA, P_Hh, 4759, check)
      call createCurrent(P_g, P_Z, P_Z, P_g, 10680, check)
      call createCurrent(P_A, P_WPlus, P_HMinus, 2782, check)
      call createCurrent(P_GQPlus, P_A, P_WMinus, P_HlQ, 6640, check)
      call createCurrent(P_tauMinus, P_nu_tauAnti, P_HPlus, 6182, check)
      call createCurrent(P_HQPlus, P_GMinus, P_Hh, P_HaQ, 7077, check)
      call createCurrent(P_HPlus, P_ghWpAnti, P_ghA, P_Hl, 5551, check)
      call createCurrent(P_HaQ, P_G0, P_G0, P_HaQ, 5620, check)
      call createCurrent(P_WMinus, P_Hl, P_Hh, P_WPlus, 9255, check)
      call createCurrent(P_HPlus, P_HMinus, P_G0, P_Hh, 9763, check)
      call createCurrent(P_Z, P_Z, P_GMinus, P_GPlus, 7959, check)
      call createCurrent(P_ghWm, P_A, P_WPlus, P_ghAAnti, 121, check)
      call createCurrent(P_Z, P_A, P_ghWp, P_ghWpAnti, 8744, check)
      call createCurrent(P_GQMinus, P_ghA, P_Hl, P_ghWmAnti, 30, check)
      call createCurrent(P_ghZ, P_ghAAnti, P_WPlus, P_WQMinus, 561, check)
      call createCurrent(P_WQMinus, P_ghA, P_WPlus, P_ghAAnti, 5520, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_ghWp, P_AQ, 611, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_ghZ, P_WQMinus, 2932, check)
      call createCurrent(P_Hh, P_GMinus, P_Ha, P_HPlus, 6783, check)
      call createCurrent(P_ghA, P_HMinus, P_Ha, P_ghWmAnti, 2912, check)
      call createCurrent(P_G0, P_tAnti, P_t, 2238, check)
      call createCurrent(P_AQ, P_WPlus, P_ghWm, P_ghAAnti, 2348, check)
      call createCurrent(P_HPlus, P_Z, P_Z, P_HMinus, 1713, check)
      call createCurrent(P_WMinus, P_Z, P_ghWp, P_ghAAnti, 8419, check)
      call createCurrent(P_uAnti, P_u, P_HhQ, 6026, check)
      call createCurrent(P_s, P_GPlus, P_cAnti, 6273, check)
      call createCurrent(P_HMinus, P_G0, P_GPlus, P_Hh, 1619, check)
      call createCurrent(P_Hh, P_Hl, P_ghZ, P_ghZAnti, 10017, check)
      call createCurrent(P_WMinus, P_GPlus, P_Z, P_Hl, 5894, check)
      call createCurrent(P_HPlus, P_ghAAnti, P_G0, P_ghWm, 9917, check)
      call createCurrent(P_GQPlus, P_G0, P_GMinus, P_HlQ, 1610, check)
      call createCurrent(P_c, P_sAnti, P_HQMinus, 7891, check)
      call createCurrent(P_ghZ, P_GMinus, P_GPlus, P_ghZAnti, 423, check)
      call createCurrent(P_WQMinus, P_ghZ, P_ghWmAnti, 5227, check)
      call createCurrent(P_c, P_cAnti, 8840, check)
      call createCurrent(P_WMinus, P_WPlus, P_ghZAnti, P_ghA, 540, check)
      call createCurrent(P_WQMinus, P_ghWp, P_WPlus, P_ghWpAnti, 1738, check)
      call createCurrent(P_G0, P_ghWp, P_HMinus, P_ghAAnti, 10334, check)
      call createCurrent(P_A, P_Hh, P_Z, P_Hl, 10732, check)
      call createCurrent(P_ghZAnti, P_HMinus, P_GPlus, P_ghA, 9897, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_HPlus, P_ghWm, 9204, check)
      call createCurrent(P_Z, P_GPlus, P_Hl, P_WMinus, 606, check)
      call createCurrent(P_GPlus, P_s, P_cAnti, 5798, check)
      call createCurrent(P_GPlus, P_ghA, P_ghAAnti, P_GMinus, 6755, check)
      call createCurrent(P_HQMinus, P_ghWmAnti, P_Ha, P_ghA, 2411, check)
      call createCurrent(P_WPlus, P_ghAAnti, P_WMinus, P_ghA, 5106, check)
      call createCurrent(P_GMinus, P_Ha, P_GPlus, P_Ha, 6008, check)
      call createCurrent(P_ghAAnti, P_Hh, P_HMinus, P_ghWp, 5564, check)
      call createCurrent(P_GQMinus, P_WMinus, P_GPlus, P_WQPlus, 4781, check)
      call createCurrent(P_A, P_WMinus, P_ghWmAnti, P_ghA, 3868, check)
      call createCurrent(P_ghWmAnti, P_G0, P_ghWm, P_Ha, 10211, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_WPlus, 4594, check)
      call createCurrent(P_Ha, P_Z, P_GPlus, P_WMinus, 8900, check)
      call createCurrent(P_Hh, P_GPlus, P_GMinus, P_Ha, 10430, check)
      call createCurrent(P_GQPlus, P_Hl, P_HMinus, P_HaQ, 6421, check)
      call createCurrent(P_HMinus, P_HPlus, P_Z, P_Z, 3815, check)
      call createCurrent(P_WMinus, P_HPlus, P_WPlus, P_GMinus, 9894, check)
      call createCurrent(P_WQPlus, P_HMinus, P_AQ, 4085, check)
      call createCurrent(P_Hl, P_HPlus, P_GMinus, P_Hh, 7663, check)
      call createCurrent(P_WQMinus, P_A, P_HPlus, P_HlQ, 3252, check)
      call createCurrent(P_HMinus, P_Ha, P_ghZ, P_ghWmAnti, 4618, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_GMinus, P_GQ0, 315, check)
      call createCurrent(P_G0, P_Hh, P_Ha, P_Hl, 500, check)
      call createCurrent(P_WPlus, P_ghZAnti, P_ghZ, P_WMinus, 3570, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_G0, P_GPlus, 7790, check)
      call createCurrent(P_HPlus, P_ghWp, P_ghWpAnti, P_HMinus, 6598, check)
      call createCurrent(P_WMinus, P_WPlus, P_Hl, P_Hl, 7192, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_HaQ, 2872, check)
      call createCurrent(P_ghWpAnti, P_Ha, P_ghZ, P_HPlus, 149, check)
      call createCurrent(P_Hl, P_GMinus, P_ghA, P_ghWmAnti, 1743, check)
      call createCurrent(P_HaQ, P_G0, P_Hh, P_HhQ, 8556, check)
      call createCurrent(P_g, P_g, P_HPlus, P_HMinus, 10697, check)
      call createCurrent(P_HMinus, P_G0, P_ghZ, P_ghWmAnti, 8912, check)
      call createCurrent(P_WQPlus, P_WMinus, P_HPlus, P_HQMinus, 59, check)
      call createCurrent(P_WMinus, P_G0, P_HPlus, 10419, check)
      call createCurrent(P_ghAAnti, P_HMinus, P_ghA, P_HPlus, 5204, check)
      call createCurrent(P_Z, P_Z, P_HMinus, P_HPlus, 5806, check)
      call createCurrent(P_GQPlus, P_HMinus, P_Ha, P_GQ0, 899, check)
      call createCurrent(P_ghA, P_Hh, P_ghWpAnti, P_HQPlus, 1362, check)
      call createCurrent(P_WMinus, P_ghA, P_ghWmAnti, P_A, 2720, check)
      call createCurrent(P_Z, P_WPlus, P_HMinus, P_Hh, 3506, check)
      call createCurrent(P_HlQ, P_WPlus, P_HQMinus, 8693, check)
      call createCurrent(P_HMinus, P_ghWmAnti, P_ghA, P_G0, 9685, check)
      call createCurrent(P_WMinus, P_HPlus, P_Hh, P_Z, 7046, check)
      call createCurrent(P_G0, P_d, P_dAnti, 3001, check)
      call createCurrent(P_HPlus, P_Z, P_GMinus, 8877, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_GQMinus, 4820, check)
      call createCurrent(P_ghA, P_G0, P_HPlus, P_ghWpAnti, 9572, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Ha, P_G0, 10307, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_HMinus, P_HlQ, 5358, check)
      call createCurrent(P_ghA, P_Z, P_WPlus, P_ghWpAnti, 527, check)
      call createCurrent(P_Ha, P_Ha, P_ghWp, P_ghWpAnti, 6258, check)
      call createCurrent(P_A, P_Hh, P_G0, 10112, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_WMinus, P_Z, 3780, check)
      call createCurrent(P_Z, P_HMinus, P_HPlus, 1934, check)
      call createCurrent(P_HhQ, P_A, P_GPlus, P_WQMinus, 8250, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_HMinus, P_HQPlus, 4202, check)
      call createCurrent(P_HPlus, P_WMinus, P_Ha, P_Z, 469, check)
      call createCurrent(P_bAnti, P_Z, P_b, 4495, check)
      call createCurrent(P_Hl, P_ghZAnti, P_HPlus, P_ghWm, 1099, check)
      call createCurrent(P_Ha, P_G0, P_HPlus, P_HMinus, 2143, check)
      call createCurrent(P_d, P_dAnti, P_A, 5709, check)
      call createCurrent(P_Z, P_ghWp, P_ghWpAnti, P_Z, 8018, check)
      call createCurrent(P_WMinus, P_Z, P_Hl, P_GPlus, 1714, check)
      call createCurrent(P_GMinus, P_ghAAnti, P_Hh, P_ghWp, 3717, check)
      call createCurrent(P_ghZAnti, P_HPlus, P_ghWm, P_HlQ, 296, check)
      call createCurrent(P_HhQ, P_HPlus, P_ghWm, P_ghZAnti, 7395, check)
      call createCurrent(P_WQPlus, P_GMinus, P_HlQ, 6127, check)
      call createCurrent(P_GPlus, P_HMinus, P_Ha, P_Ha, 7470, check)
      call createCurrent(P_A, P_HPlus, P_HMinus, 8493, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_HMinus, P_HQPlus, 6028, check)
      call createCurrent(P_Ha, P_HPlus, P_GMinus, P_Hh, 8600, check)
      call createCurrent(P_GQ0, P_ghZAnti, P_G0, P_ghZ, 8521, check)
      call createCurrent(P_GPlus, P_Hl, P_ghZAnti, P_ghWm, 5922, check)
      call createCurrent(P_HQPlus, P_GMinus, P_HPlus, P_GQMinus, 3014, check)
      call createCurrent(P_HMinus, P_Z, P_Ha, P_WPlus, 4660, check)
      call createCurrent(P_Hl, P_G0, P_HMinus, P_HPlus, 9633, check)
      call createCurrent(P_GMinus, P_G0, P_Hl, P_GPlus, 9425, check)
      call createCurrent(P_ghA, P_Hh, P_ghWpAnti, P_GQPlus, 3777, check)
      call createCurrent(P_HPlus, P_Hh, P_HMinus, P_Hl, 3141, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_A, P_ghWm, 4224, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_GPlus, P_ghZ, 2264, check)
      call createCurrent(P_G0, P_ghWp, P_Ha, P_ghWpAnti, 10275, check)
      call createCurrent(P_Hl, P_t, P_tAnti, 1462, check)
      call createCurrent(P_Z, P_GPlus, P_WMinus, P_Ha, 10479, check)
      call createCurrent(P_HMinus, P_Hl, P_WPlus, P_Z, 3707, check)
      call createCurrent(P_HPlus, P_GMinus, P_Ha, 4358, check)
      call createCurrent(P_Hl, P_ghZ, P_ghZAnti, P_Hl, 2152, check)
      call createCurrent(P_muPlus, P_A, P_muMinus, 7798, check)
      call createCurrent(P_G0, P_GMinus, P_WPlus, P_A, 3226, check)
      call createCurrent(P_Ha, P_A, P_Z, P_G0, 10652, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghWm, P_GQ0, 360, check)
      call createCurrent(P_HaQ, P_Hh, P_GPlus, P_GQMinus, 1342, check)
      call createCurrent(P_HQPlus, P_HPlus, P_HMinus, P_GQMinus, 1554, check)
      call createCurrent(P_HPlus, P_nu_muAnti, P_muMinus, 1567, check)
      call createCurrent(P_AQ, P_WMinus, P_G0, P_GQPlus, 6963, check)
      call createCurrent(P_G0, P_Hh, P_Ha, 728, check)
      call createCurrent(P_ghWm, P_GMinus, P_ghWmAnti, P_GPlus, 1942, check)
      call createCurrent(P_HlQ, P_GPlus, P_HMinus, P_HlQ, 5210, check)
      call createCurrent(P_HlQ, P_d, P_dAnti, 7991, check)
      call createCurrent(P_GQMinus, P_HPlus, P_Hh, P_GQ0, 3231, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_GPlus, P_Hh, 5130, check)
      call createCurrent(P_HaQ, P_GMinus, P_Ha, P_GQPlus, 5447, check)
      call createCurrent(P_ghWmAnti, P_A, P_ghZ, P_WQMinus, 1872, check)
      call createCurrent(P_WQMinus, P_nu_e, P_ePlus, 3281, check)
      call createCurrent(P_Ha, P_G0, P_HMinus, P_HPlus, 8170, check)
      call createCurrent(P_HQPlus, P_Hl, P_GMinus, P_HaQ, 3537, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Ha, P_HaQ, 3444, check)
      call createCurrent(P_ghWpAnti, P_Hl, P_ghZ, P_HQPlus, 5846, check)
      call createCurrent(P_A, P_Ha, P_Hl, 10287, check)
      call createCurrent(P_Ha, P_G0, P_Hl, P_Hh, 5540, check)
      call createCurrent(P_HQPlus, P_G0, P_G0, P_GQMinus, 5222, check)
      call createCurrent(P_ghWm, P_A, P_ghZAnti, P_WPlus, 6562, check)
      call createCurrent(P_WPlus, P_HMinus, P_Z, P_Hh, 6115, check)
      call createCurrent(P_GPlus, P_Hh, P_HMinus, P_Ha, 8545, check)
      call createCurrent(P_Ha, P_GMinus, P_HPlus, P_Hl, 793, check)
      call createCurrent(P_HhQ, P_GPlus, P_HMinus, P_HhQ, 450, check)
      call createCurrent(P_GQMinus, P_G0, P_HPlus, P_HlQ, 4666, check)
      call createCurrent(P_HPlus, P_nu_eAnti, P_eMinus, 5411, check)
      call createCurrent(P_GQPlus, P_GMinus, P_G0, P_HaQ, 4436, check)
      call createCurrent(P_WQPlus, P_ghA, P_A, P_ghWpAnti, 4320, check)
      call createCurrent(P_HhQ, P_GMinus, P_Ha, P_GQPlus, 3543, check)
      call createCurrent(P_GPlus, P_ghWmAnti, P_ghWm, P_GMinus, 5413, check)
      call createCurrent(P_ghA, P_G0, P_GPlus, P_ghWpAnti, 7163, check)
      call createCurrent(P_ghWmAnti, P_Hl, P_ghWm, P_Hl, 4174, check)
      call createCurrent(P_AQ, P_Hh, P_WPlus, P_GQMinus, 3922, check)
      call createCurrent(P_ghZAnti, P_Ha, P_GMinus, P_ghWp, 9314, check)
      call createCurrent(P_GQMinus, P_ghWpAnti, P_GPlus, P_ghWp, 8265, check)
      call createCurrent(P_ghA, P_ghZAnti, P_HPlus, P_GMinus, 9396, check)
      call createCurrent(P_Ha, P_GPlus, P_ghWpAnti, P_ghA, 9157, check)
      call createCurrent(P_HQMinus, P_G0, P_G0, P_GQPlus, 6975, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_G0, P_GQMinus, 2803, check)
      call createCurrent(P_WPlus, P_Z, P_GMinus, P_Ha, 9902, check)
      call createCurrent(P_A, P_Ha, P_A, P_Ha, 10604, check)
      call createCurrent(P_HhQ, P_GMinus, P_ghZ, P_ghWmAnti, 6754, check)
      call createCurrent(P_G0, P_HMinus, P_WPlus, P_Z, 9777, check)
      call createCurrent(P_GQMinus, P_ePlus, P_nu_e, 1707, check)
      call createCurrent(P_Hl, P_ghAAnti, P_GPlus, P_ghWm, 6830, check)
      call createCurrent(P_ghWm, P_HPlus, P_ghZAnti, 8332, check)
      call createCurrent(P_G0, P_HPlus, P_HMinus, P_Ha, 2572, check)
      call createCurrent(P_s, P_sAnti, P_AQ, 6509, check)
      call createCurrent(P_c, P_cAnti, P_HhQ, 8431, check)
      call createCurrent(P_Z, P_WPlus, P_Hh, P_HMinus, 3437, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_Hl, P_HQPlus, 2451, check)
      call createCurrent(P_HQPlus, P_s, P_cAnti, 6133, check)
      call createCurrent(P_GQPlus, P_GMinus, P_Ha, P_HlQ, 424, check)
      call createCurrent(P_ZQ, P_GMinus, P_A, P_GQPlus, 8053, check)
      call createCurrent(P_GQPlus, P_ghZ, P_Hl, P_ghWpAnti, 4406, check)
      call createCurrent(P_WMinus, P_Z, P_Z, P_WPlus, 7135, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghZ, 2161, check)
      call createCurrent(P_WPlus, P_WMinus, P_Hl, P_Hh, 9342, check)
      call createCurrent(P_GQ0, P_WPlus, P_Z, P_GQMinus, 1670, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_GPlus, P_Hl, 711, check)
      call createCurrent(P_G0, P_ghAAnti, P_ghWm, P_HPlus, 9238, check)
      call createCurrent(P_nu_e, P_nu_eAnti, P_ZQ, 437, check)
      call createCurrent(P_HaQ, P_GPlus, P_HMinus, P_GQ0, 6962, check)
      call createCurrent(P_GQ0, P_GPlus, P_HQMinus, 8097, check)
      call createCurrent(P_HaQ, P_Hh, P_ZQ, 3857, check)
      call createCurrent(P_WMinus, P_Hh, P_A, P_GPlus, 5421, check)
      call createCurrent(P_G0, P_HPlus, P_A, P_WMinus, 9852, check)
      call createCurrent(P_ghWmAnti, P_Ha, P_ghWm, P_Ha, 2662, check)
      call createCurrent(P_u, P_G0, P_uAnti, 6794, check)
      call createCurrent(P_t, P_bAnti, P_WMinus, 740, check)
      call createCurrent(P_WQPlus, P_ghZ, P_WMinus, P_ghAAnti, 5930, check)
      call createCurrent(P_Hl, P_Hh, P_A, P_Z, 10730, check)
      call createCurrent(P_ghZ, P_WPlus, P_ghWpAnti, P_A, 5102, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_Ha, P_HPlus, 884, check)
      call createCurrent(P_GQ0, P_ghWmAnti, P_G0, P_ghWm, 859, check)
      call createCurrent(P_ghAAnti, P_HPlus, P_ghZ, P_HMinus, 4259, check)
      call createCurrent(P_WQPlus, P_ghAAnti, P_WMinus, P_ghZ, 586, check)
      call createCurrent(P_ghWmAnti, P_Ha, P_ghA, P_GMinus, 9815, check)
      call createCurrent(P_ghA, P_A, P_WMinus, P_ghWmAnti, 7584, check)
      call createCurrent(P_WPlus, P_ghA, P_ghWpAnti, P_A, 5896, check)
      call createCurrent(P_WPlus, P_WMinus, P_Z, 4957, check)
      call createCurrent(P_ghWp, P_WMinus, P_Z, P_ghAAnti, 2884, check)
      call createCurrent(P_bAnti, P_t, P_WQMinus, 2286, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_GPlus, P_Ha, 9100, check)
      call createCurrent(P_HlQ, P_WPlus, P_Z, P_HQMinus, 1300, check)
      call createCurrent(P_HaQ, P_Hh, P_WPlus, P_WQMinus, 7362, check)
      call createCurrent(P_WPlus, P_Z, P_HMinus, P_Hh, 3948, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_GQMinus, 4361, check)
      call createCurrent(P_Hh, P_ghWm, P_ghZAnti, P_HPlus, 7619, check)
      call createCurrent(P_GPlus, P_Ha, P_ghZAnti, P_ghWm, 9362, check)
      call createCurrent(P_ghWpAnti, P_A, P_Z, P_ghWp, 5796, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_GPlus, P_G0, 4269, check)
      call createCurrent(P_GPlus, P_ghAAnti, P_GMinus, P_ghA, 3169, check)
      call createCurrent(P_HQMinus, P_Ha, P_GPlus, P_GQ0, 4725, check)
      call createCurrent(P_A, P_WPlus, P_G0, P_GMinus, 4078, check)
      call createCurrent(P_Hl, P_GPlus, P_G0, P_GMinus, 9866, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_Hl, 5533, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_HMinus, P_Ha, 1157, check)
      call createCurrent(P_GQ0, P_HPlus, P_Hl, P_GQMinus, 8434, check)
      call createCurrent(P_HQPlus, P_HMinus, P_Hl, P_GQ0, 6260, check)
      call createCurrent(P_GQMinus, P_Hh, P_ghWmAnti, P_ghA, 8248, check)
      call createCurrent(P_WPlus, P_Ha, P_A, P_GMinus, 9057, check)
      call createCurrent(P_A, P_Ha, P_HMinus, P_WPlus, 2982, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_G0, P_HlQ, 4839, check)
      call createCurrent(P_gQ, P_ghGAnti, P_g, P_ghG, 6257, check)
      call createCurrent(P_G0, P_A, P_G0, P_Z, 9663, check)
      call createCurrent(P_AQ, P_muPlus, P_muMinus, 7780, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_ghZ, P_WMinus, 875, check)
      call createCurrent(P_HMinus, P_A, P_Hh, P_WPlus, 6001, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_Hh, P_GQMinus, 2697, check)
      call createCurrent(P_Hl, P_Hh, P_HPlus, P_HMinus, 8208, check)
      call createCurrent(P_HPlus, P_GMinus, P_ghAAnti, P_ghA, 9845, check)
      call createCurrent(P_HPlus, P_ghWm, P_Hh, P_ghAAnti, 6456, check)
      call createCurrent(P_ghWpAnti, P_HPlus, P_ghA, P_Hl, 4076, check)
      call createCurrent(P_HaQ, P_ghWpAnti, P_Hh, P_ghWp, 800, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_G0, P_GQPlus, 3817, check)
      call createCurrent(P_HhQ, P_ghWp, P_G0, P_ghWpAnti, 1435, check)
      call createCurrent(P_Hl, P_GMinus, P_Ha, P_GPlus, 10305, check)
      call createCurrent(P_Hh, P_ghZ, P_GPlus, P_ghWpAnti, 7644, check)
      call createCurrent(P_ghGAnti, P_ghG, P_gQ, 1471, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_Hh, P_HMinus, 4998, check)
      call createCurrent(P_GQPlus, P_G0, P_HQMinus, 1092, check)
      call createCurrent(P_ghZ, P_HPlus, P_ghWpAnti, P_HlQ, 7089, check)
      call createCurrent(P_gQ, P_tAnti, P_t, 6846, check)
      call createCurrent(P_AQ, P_WMinus, P_Hh, P_GQPlus, 5063, check)
      call createCurrent(P_G0, P_sAnti, P_s, 6529, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_Hl, P_ghZ, 5582, check)
      call createCurrent(P_WQPlus, P_HMinus, P_Hh, P_ZQ, 5643, check)
      call createCurrent(P_AQ, P_ghWm, P_WPlus, P_ghZAnti, 8610, check)
      call createCurrent(P_HMinus, P_ghA, P_GPlus, P_ghZAnti, 9258, check)
      call createCurrent(P_HhQ, P_WMinus, P_A, P_GQPlus, 5415, check)
      call createCurrent(P_AQ, P_WMinus, P_A, P_WQPlus, 1938, check)
      call createCurrent(P_ghWm, P_WPlus, P_A, P_ghAAnti, 6064, check)
      call createCurrent(P_ghWpAnti, P_Ha, P_Ha, P_ghWp, 138, check)
      call createCurrent(P_HQPlus, P_HMinus, P_Hh, P_HhQ, 1767, check)
      call createCurrent(P_HMinus, P_Ha, P_HPlus, P_Hl, 10148, check)
      call createCurrent(P_GPlus, P_Hh, P_Ha, P_GMinus, 9332, check)
      call createCurrent(P_HPlus, P_Ha, P_HMinus, P_Ha, 1221, check)
      call createCurrent(P_eMinus, P_ePlus, P_A, 3109, check)
      call createCurrent(P_Ha, P_Hh, P_Hh, P_Hh, 10753, check)
      call createCurrent(P_Ha, P_Hh, P_GMinus, P_GPlus, 9008, check)
      call createCurrent(P_HMinus, P_GPlus, P_ghWpAnti, P_ghWp, 9988, check)
      call createCurrent(P_muPlus, P_nu_mu, P_GQMinus, 7785, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_Hh, P_ghZ, 6961, check)
      call createCurrent(P_HaQ, P_tauMinus, P_tauPlus, 2573, check)
      call createCurrent(P_HMinus, P_GPlus, P_ghWp, P_ghWpAnti, 9974, check)
      call createCurrent(P_GPlus, P_ghWmAnti, P_GMinus, P_ghWm, 8182, check)
      call createCurrent(P_WQPlus, P_GPlus, P_WMinus, P_GQMinus, 7347, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_Hh, P_GQMinus, 6578, check)
      call createCurrent(P_G0, P_Z, P_Ha, P_Z, 8838, check)
      call createCurrent(P_Ha, P_Hl, P_GMinus, P_HPlus, 7521, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_GMinus, P_GPlus, 7933, check)
      call createCurrent(P_G0, P_HMinus, P_WPlus, P_A, 8977, check)
      call createCurrent(P_WPlus, P_WMinus, P_ghAAnti, P_ghA, 8198, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_GPlus, P_HlQ, 7132, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_GMinus, P_HhQ, 3607, check)
      call createCurrent(P_GMinus, P_GPlus, P_G0, P_Hh, 10098, check)
      call createCurrent(P_HaQ, P_Ha, P_HPlus, P_HQMinus, 1204, check)
      call createCurrent(P_Hl, P_WMinus, P_Z, P_HPlus, 6016, check)
      call createCurrent(P_Hh, P_GMinus, P_Hl, P_HPlus, 7985, check)
      call createCurrent(P_GQ0, P_Ha, P_HlQ, 3651, check)
      call createCurrent(P_ghWmAnti, P_GPlus, P_GMinus, P_ghWm, 6169, check)
      call createCurrent(P_WMinus, P_WPlus, P_WMinus, P_WPlus, 1952, check)
      call createCurrent(P_Ha, P_HPlus, P_WMinus, P_Z, 7137, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_GMinus, P_Hh, 6320, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_ghA, P_GQPlus, 4619, check)
      call createCurrent(P_GPlus, P_ghAAnti, P_ghZ, P_HMinus, 10273, check)
      call createCurrent(P_G0, P_HPlus, P_Ha, P_GMinus, 1977, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_GMinus, 1531, check)
      call createCurrent(P_Ha, P_WMinus, P_Z, P_GPlus, 10036, check)
      call createCurrent(P_Hh, P_uAnti, P_u, 1940, check)
      call createCurrent(P_Hl, P_Hh, P_g, P_g, 10529, check)
      call createCurrent(P_HaQ, P_HPlus, P_Ha, P_GQMinus, 3122, check)
      call createCurrent(P_WQPlus, P_HMinus, P_Ha, P_ZQ, 7685, check)
      call createCurrent(P_Hh, P_GMinus, P_WPlus, P_Z, 1230, check)
      call createCurrent(P_HhQ, P_WPlus, P_Z, P_HQMinus, 1210, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_HPlus, P_HhQ, 6343, check)
      call createCurrent(P_Ha, P_g, P_Ha, P_g, 10506, check)
      call createCurrent(P_A, P_HMinus, P_HPlus, 1473, check)
      call createCurrent(P_Ha, P_ghWmAnti, P_ghA, P_HMinus, 3374, check)
      call createCurrent(P_HlQ, P_GPlus, P_Hh, P_GQMinus, 6148, check)
      call createCurrent(P_GQPlus, P_ghA, P_Hh, P_ghWpAnti, 991, check)
      call createCurrent(P_Z, P_Hl, P_A, 10257, check)
      call createCurrent(P_HPlus, P_GMinus, 9411, check)
      call createCurrent(P_WPlus, P_Hl, P_WMinus, 5562, check)
      call createCurrent(P_Z, P_WPlus, P_G0, P_GMinus, 3362, check)
      call createCurrent(P_ghA, P_GPlus, P_G0, P_ghWpAnti, 612, check)
      call createCurrent(P_ghA, P_ghAAnti, P_WPlus, P_WQMinus, 2055, check)
      call createCurrent(P_Hh, P_GMinus, P_ghWmAnti, P_ghZ, 8340, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_GMinus, 665, check)
      call createCurrent(P_HQPlus, P_HMinus, P_Hh, P_HaQ, 6077, check)
      call createCurrent(P_Hh, P_Hl, P_Hl, P_Hh, 2849, check)
      call createCurrent(P_G0, P_GPlus, P_Hh, P_GMinus, 9259, check)
      call createCurrent(P_HhQ, P_A, P_WMinus, P_HQPlus, 1038, check)
      call createCurrent(P_Z, P_WMinus, P_GPlus, P_Hl, 755, check)
      call createCurrent(P_Ha, P_d, P_dAnti, 3286, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_HPlus, P_Ha, 7717, check)
      call createCurrent(P_GMinus, P_A, P_G0, P_WPlus, 5427, check)
      call createCurrent(P_WMinus, P_Z, P_HPlus, P_Ha, 2076, check)
      call createCurrent(P_WQMinus, P_WPlus, P_ghWpAnti, P_ghWp, 4255, check)
      call createCurrent(P_WQMinus, P_GPlus, P_GQ0, 5359, check)
      call createCurrent(P_WPlus, P_Z, P_Hh, P_HMinus, 2931, check)
      call createCurrent(P_Z, P_tauPlus, P_tauMinus, 7246, check)
      call createCurrent(P_HPlus, P_G0, P_ghWpAnti, P_ghZ, 10330, check)
      call createCurrent(P_ghZAnti, P_Hh, P_ghWp, P_GMinus, 2589, check)
      call createCurrent(P_gQ, P_g, P_g, P_gQ, 5799, check)
      call createCurrent(P_ZQ, P_A, P_HPlus, P_HQMinus, 2117, check)
      call createCurrent(P_G0, P_ghWmAnti, P_GMinus, P_ghA, 3264, check)
      call createCurrent(P_GMinus, P_Hh, P_ghWp, P_ghZAnti, 7586, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_G0, P_GMinus, 6853, check)
      call createCurrent(P_ghWp, P_Hh, P_ghWpAnti, P_Hl, 9241, check)
      call createCurrent(P_GMinus, P_ghZ, P_GPlus, P_ghZAnti, 2065, check)
      call createCurrent(P_HhQ, P_Ha, P_GMinus, P_HQPlus, 2045, check)
      call createCurrent(P_ghAAnti, P_G0, P_ghWm, P_HPlus, 9594, check)
      call createCurrent(P_WPlus, P_nu_eAnti, P_eMinus, 8797, check)
      call createCurrent(P_WQPlus, P_WMinus, P_Z, P_ZQ, 2035, check)
      call createCurrent(P_HMinus, P_Hl, P_ghA, P_ghWmAnti, 3745, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_ghZ, P_GPlus, 7936, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_AQ, 7489, check)
      call createCurrent(P_Hh, P_GMinus, P_WPlus, 8073, check)
      call createCurrent(P_ghA, P_ghZAnti, P_HMinus, P_GPlus, 9754, check)
      call createCurrent(P_HhQ, P_ghZAnti, P_Hh, P_ghZ, 2422, check)
      call createCurrent(P_G0, P_GMinus, P_ghWp, P_ghZAnti, 422, check)
      call createCurrent(P_GQMinus, P_Hl, P_GPlus, P_GQ0, 8755, check)
      call createCurrent(P_c, P_cAnti, P_Hh, 4121, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_GMinus, P_GQPlus, 7156, check)
      call createCurrent(P_A, P_Hl, P_GMinus, P_WPlus, 6639, check)
      call createCurrent(P_Hl, P_HMinus, P_ghWp, P_ghAAnti, 8310, check)
      call createCurrent(P_Z, P_ghWp, P_ghWpAnti, P_A, 2061, check)
      call createCurrent(P_HMinus, P_Hl, P_ghWmAnti, P_ghZ, 3756, check)
      call createCurrent(P_HhQ, P_HMinus, P_HQPlus, 905, check)
      call createCurrent(P_ghAAnti, P_Hl, P_GMinus, P_ghWp, 2346, check)
      call createCurrent(P_WPlus, P_Hh, P_HMinus, 8026, check)
      call createCurrent(P_WMinus, P_Hh, P_Z, P_HPlus, 6819, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_HMinus, 5509, check)
      call createCurrent(P_HPlus, P_Hh, P_Z, P_WMinus, 7576, check)
      call createCurrent(P_HaQ, P_GPlus, P_GQMinus, 2418, check)
      call createCurrent(P_nu_tauAnti, P_tauMinus, P_HPlus, 4567, check)
      call createCurrent(P_ghWmAnti, P_A, P_ghZ, P_WMinus, 3831, check)
      call createCurrent(P_u, P_g, P_uAnti, 1606, check)
      call createCurrent(P_GPlus, P_G0, P_Z, P_WMinus, 8791, check)
      call createCurrent(P_ghWm, P_HPlus, P_Ha, P_ghZAnti, 4638, check)
      call createCurrent(P_GMinus, P_WPlus, P_Ha, P_Z, 9297, check)
      call createCurrent(P_ghWm, P_Hl, P_ghZAnti, P_GPlus, 4147, check)
      call createCurrent(P_Z, P_WMinus, P_HPlus, P_G0, 10249, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Hl, P_Hl, 5650, check)
      call createCurrent(P_nu_mu, P_muPlus, P_WQMinus, 5674, check)
      call createCurrent(P_ghWpAnti, P_Hh, P_ghA, P_HQPlus, 92, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_WPlus, P_ghWm, 3435, check)
      call createCurrent(P_ghWm, P_Ha, P_ghWmAnti, P_Ha, 7297, check)
      call createCurrent(P_Hh, P_GMinus, P_ghWmAnti, P_ghA, 7354, check)
      call createCurrent(P_HQPlus, P_Hl, P_ghWm, P_ghZAnti, 1375, check)
      call createCurrent(P_ePlus, P_eMinus, P_A, 8760, check)
      call createCurrent(P_WMinus, P_ghWp, P_WPlus, P_ghWpAnti, 4700, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghZ, P_GQPlus, 7982, check)
      call createCurrent(P_GMinus, P_G0, P_GPlus, P_Hl, 9455, check)
      call createCurrent(P_GQMinus, P_Hh, P_ghA, P_ghWmAnti, 3568, check)
      call createCurrent(P_HPlus, P_ghWm, P_ghAAnti, P_Ha, 6883, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_HPlus, P_G0, 9575, check)
      call createCurrent(P_HPlus, P_Hl, P_ghWpAnti, P_ghZ, 3928, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_Hh, P_GQPlus, 3872, check)
      call createCurrent(P_HPlus, P_ghWm, P_ghAAnti, P_Hh, 390, check)
      call createCurrent(P_Hh, P_GMinus, P_HPlus, P_Hl, 198, check)
      call createCurrent(P_GQ0, P_GMinus, P_HQPlus, 3388, check)
      call createCurrent(P_AQ, P_WPlus, P_A, P_WQMinus, 4153, check)
      call createCurrent(P_ghWmAnti, P_GPlus, P_ghWm, P_HMinus, 10006, check)
      call createCurrent(P_dAnti, P_HMinus, P_u, 7009, check)
      call createCurrent(P_Z, P_WMinus, P_ghZAnti, P_ghWp, 6675, check)
      call createCurrent(P_GPlus, P_Ha, P_ghWpAnti, P_ghA, 9304, check)
      call createCurrent(P_HPlus, P_Z, P_Hh, P_WMinus, 2665, check)
      call createCurrent(P_ZQ, P_ghWmAnti, P_A, P_ghWm, 4541, check)
      call createCurrent(P_ZQ, P_tAnti, P_t, 5391, check)
      call createCurrent(P_HlQ, P_HPlus, P_ghZAnti, P_ghWm, 223, check)
      call createCurrent(P_GPlus, P_ghWm, P_ghAAnti, P_Hh, 2277, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_Hh, P_Hl, 10146, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghZ, P_GMinus, 7443, check)
      call createCurrent(P_Hh, P_ghWpAnti, P_HPlus, P_ghZ, 1190, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_GMinus, P_Hl, 817, check)
      call createCurrent(P_Hh, P_Z, P_WPlus, P_GMinus, 556, check)
      call createCurrent(P_HMinus, P_WPlus, P_G0, P_A, 9379, check)
      call createCurrent(P_G0, P_Ha, P_ghZAnti, P_ghZ, 9586, check)
      call createCurrent(P_GMinus, P_WPlus, P_A, P_Hl, 7688, check)
      call createCurrent(P_HMinus, P_G0, P_ghWp, P_ghZAnti, 9372, check)
      call createCurrent(P_GQPlus, P_ghWpAnti, P_Hl, P_ghA, 2927, check)
      call createCurrent(P_HPlus, P_HMinus, P_HMinus, P_HPlus, 4796, check)
      call createCurrent(P_G0, P_Ha, P_GPlus, P_GMinus, 3209, check)
      call createCurrent(P_GQPlus, P_A, P_A, P_GQMinus, 8095, check)
      call createCurrent(P_ghA, P_HMinus, P_GPlus, P_ghAAnti, 10060, check)
      call createCurrent(P_HaQ, P_ghWm, P_HPlus, P_ghZAnti, 7116, check)
      call createCurrent(P_sAnti, P_s, P_Hh, 4449, check)
      call createCurrent(P_Hh, P_ghZAnti, P_Hh, P_ghZ, 4686, check)
      call createCurrent(P_Hh, P_HPlus, P_HMinus, P_Hh, 3619, check)
      call createCurrent(P_GQMinus, P_Ha, P_Hh, P_HQPlus, 7124, check)
      call createCurrent(P_HhQ, P_Z, P_HPlus, P_WQMinus, 1847, check)
      call createCurrent(P_ghA, P_GMinus, P_ghZAnti, P_GQPlus, 5471, check)
      call createCurrent(P_Z, P_ghWm, P_ghWmAnti, P_Z, 2368, check)
      call createCurrent(P_ghWpAnti, P_HPlus, P_ghZ, P_HhQ, 4133, check)
      call createCurrent(P_HlQ, P_WMinus, P_Ha, P_WQPlus, 1203, check)
      call createCurrent(P_HhQ, P_WPlus, P_A, P_GQMinus, 1031, check)
      call createCurrent(P_ghWm, P_Hh, P_ghWmAnti, P_HhQ, 744, check)
      call createCurrent(P_dAnti, P_u, P_GMinus, 5859, check)
      call createCurrent(P_GQ0, P_G0, P_HPlus, P_GQMinus, 6386, check)
      call createCurrent(P_GQPlus, P_HMinus, P_Hl, P_HhQ, 4803, check)
      call createCurrent(P_Hh, P_WPlus, P_Hl, P_WMinus, 9957, check)
      call createCurrent(P_HPlus, P_ghA, P_Ha, P_ghWpAnti, 286, check)
      call createCurrent(P_Hl, P_cAnti, P_c, 372, check)
      call createCurrent(P_GQPlus, P_uAnti, P_d, 4154, check)
      call createCurrent(P_ghAAnti, P_G0, P_ghWp, P_HMinus, 10239, check)
      call createCurrent(P_Hl, P_A, P_HMinus, P_WPlus, 4407, check)
      call createCurrent(P_HlQ, P_Ha, P_WPlus, P_WQMinus, 581, check)
      call createCurrent(P_ghWpAnti, P_Hl, P_ghA, P_HQPlus, 1496, check)
      call createCurrent(P_HPlus, P_ghWpAnti, P_Hh, P_ghA, 347, check)
      call createCurrent(P_HQMinus, P_A, P_HQPlus, 2699, check)
      call createCurrent(P_gQ, P_sAnti, P_s, 3746, check)
      call createCurrent(P_WPlus, P_Z, P_ghWpAnti, P_ghZ, 7099, check)
      call createCurrent(P_ghWmAnti, P_G0, P_HMinus, P_ghA, 9370, check)
      call createCurrent(P_A, P_HMinus, P_WPlus, 8675, check)
      call createCurrent(P_HhQ, P_HPlus, P_HMinus, P_HhQ, 2802, check)
      call createCurrent(P_WMinus, P_A, P_ghAAnti, P_ghWp, 38, check)
      call createCurrent(P_Hh, P_ghZ, P_Hh, P_ghZAnti, 8698, check)
      call createCurrent(P_HMinus, P_t, P_bAnti, 3653, check)
      call createCurrent(P_GQMinus, P_Z, P_Hl, P_WQPlus, 2775, check)
      call createCurrent(P_GMinus, P_ghA, P_ghZAnti, P_GPlus, 2852, check)
      call createCurrent(P_GQPlus, P_Hl, P_Hl, P_HQMinus, 2622, check)
      call createCurrent(P_GQ0, P_Hl, P_ZQ, 6431, check)
      call createCurrent(P_bAnti, P_b, P_HlQ, 5770, check)
      call createCurrent(P_Ha, P_GPlus, P_GMinus, P_Hl, 10438, check)
      call createCurrent(P_ghA, P_Hl, P_ghWpAnti, P_GPlus, 8436, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_GPlus, P_Hl, 782, check)
      call createCurrent(P_HMinus, P_HPlus, P_Hh, P_Hl, 5050, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghA, P_A, 7184, check)
      call createCurrent(P_G0, P_Hl, P_G0, 3982, check)
      call createCurrent(P_ghWmAnti, P_Hl, P_Hl, P_ghWm, 4831, check)
      call createCurrent(P_HPlus, P_Ha, P_WMinus, 6347, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Hl, P_Hl, 6850, check)
      call createCurrent(P_GQPlus, P_Ha, P_G0, P_GQMinus, 809, check)
      call createCurrent(P_g, P_g, P_G0, P_Ha, 10520, check)
      call createCurrent(P_s, P_A, P_sAnti, 2862, check)
      call createCurrent(P_HQMinus, P_ghWmAnti, P_ghA, 5632, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_GPlus, P_GQ0, 7391, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_Hh, P_GPlus, 6010, check)
      call createCurrent(P_HaQ, P_Hh, P_ghWpAnti, P_ghWp, 6687, check)
      call createCurrent(P_muPlus, P_muMinus, P_G0, 7165, check)
      call createCurrent(P_HPlus, P_Hl, P_HMinus, P_Ha, 9551, check)
      call createCurrent(P_ZQ, P_ghWp, P_WMinus, P_ghZAnti, 1047, check)
      call createCurrent(P_GPlus, P_HMinus, P_G0, P_Ha, 7174, check)
      call createCurrent(P_WMinus, P_ghZAnti, P_WPlus, P_ghA, 4574, check)
      call createCurrent(P_ghAAnti, P_HMinus, P_ghWp, P_Hl, 8612, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_Ha, P_HQPlus, 4374, check)
      call createCurrent(P_GQMinus, P_Ha, P_G0, P_HQPlus, 7870, check)
      call createCurrent(P_ghWp, P_A, P_ghWpAnti, P_ZQ, 7882, check)
      call createCurrent(P_Ha, P_ghWmAnti, P_G0, P_ghWm, 9800, check)
      call createCurrent(P_Hl, P_HPlus, P_HMinus, P_Hl, 8251, check)
      call createCurrent(P_HQPlus, P_Ha, P_WMinus, P_ZQ, 3530, check)
      call createCurrent(P_Z, P_HPlus, P_WMinus, P_Ha, 6619, check)
      call createCurrent(P_ghA, P_GPlus, P_GMinus, P_ghAAnti, 7208, check)
      call createCurrent(P_HMinus, P_Hh, P_GPlus, P_Hl, 5445, check)
      call createCurrent(P_ghWmAnti, P_Ha, P_ghZ, P_GMinus, 9876, check)
      call createCurrent(P_Hl, P_Hh, P_G0, P_G0, 7583, check)
      call createCurrent(P_WQPlus, P_WMinus, P_Hh, P_HhQ, 3206, check)
      call createCurrent(P_A, P_Hh, P_Hl, P_A, 10685, check)
      call createCurrent(P_ghWp, P_G0, P_Ha, P_ghWpAnti, 10463, check)
      call createCurrent(P_tauPlus, P_G0, P_tauMinus, 270, check)
      call createCurrent(P_WQMinus, P_Z, P_GPlus, P_HlQ, 5176, check)
      call createCurrent(P_A, P_Hl, P_WPlus, P_GMinus, 5052, check)
      call createCurrent(P_ghWmAnti, P_Hh, P_ghA, P_GMinus, 567, check)
      call createCurrent(P_HMinus, P_Ha, P_HPlus, P_G0, 1291, check)
      call createCurrent(P_ZQ, P_Hh, P_WMinus, P_HQPlus, 3203, check)
      call createCurrent(P_WMinus, P_ghZAnti, P_ghWp, 588, check)
      call createCurrent(P_AQ, P_s, P_sAnti, 4760, check)
      call createCurrent(P_G0, P_WMinus, P_GPlus, P_Z, 4321, check)
      call createCurrent(P_HlQ, P_ghZAnti, P_Hl, P_ghZ, 4635, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghZAnti, P_HPlus, 9131, check)
      call createCurrent(P_HlQ, P_GMinus, P_HQPlus, 407, check)
      call createCurrent(P_ghWpAnti, P_Hh, P_ghWp, P_Hh, 3422, check)
      call createCurrent(P_ghWmAnti, P_Z, P_ghWm, P_Z, 7630, check)
      call createCurrent(P_HMinus, P_Hh, P_Hl, P_HPlus, 7895, check)
      call createCurrent(P_GPlus, P_WMinus, P_Z, P_Hh, 8689, check)
      call createCurrent(P_HPlus, P_ghA, P_ghZAnti, P_HMinus, 1550, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_HMinus, P_Hl, 4022, check)
      call createCurrent(P_WMinus, P_ghA, P_Z, P_ghWmAnti, 7239, check)
      call createCurrent(P_HQMinus, P_HPlus, P_HMinus, P_HQPlus, 7633, check)
      call createCurrent(P_GQMinus, P_GPlus, P_HMinus, P_GQPlus, 559, check)
      call createCurrent(P_g, P_GMinus, P_GPlus, P_g, 10498, check)
      call createCurrent(P_WPlus, P_GMinus, P_WMinus, P_HPlus, 9094, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghZ, 3124, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_ghZ, P_HPlus, 10022, check)
      call createCurrent(P_bAnti, P_b, P_AQ, 2027, check)
      call createCurrent(P_HMinus, P_Z, P_G0, P_WPlus, 10271, check)
      call createCurrent(P_WQPlus, P_G0, P_GMinus, P_ZQ, 3887, check)
      call createCurrent(P_Hl, P_ghZ, P_ghWpAnti, P_GPlus, 6511, check)
      call createCurrent(P_G0, P_Hh, P_Hl, P_G0, 3784, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_HPlus, P_HhQ, 5542, check)
      call createCurrent(P_sAnti, P_s, P_Ha, 7198, check)
      call createCurrent(P_Ha, P_GPlus, P_WMinus, P_A, 9106, check)
      call createCurrent(P_A, P_Z, 9514, check)
      call createCurrent(P_ghWmAnti, P_HMinus, P_ghA, 1640, check)
      call createCurrent(P_ghWmAnti, P_A, P_ghA, P_WMinus, 6860, check)
      call createCurrent(P_Ha, P_Ha, P_WMinus, P_WPlus, 4948, check)
      call createCurrent(P_Hh, P_Hl, P_Z, P_A, 10572, check)
      call createCurrent(P_GQMinus, P_GPlus, P_GMinus, P_GQPlus, 3616, check)
      call createCurrent(P_A, P_A, P_G0, P_Ha, 10743, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghWm, P_Hl, 4398, check)
      call createCurrent(P_ZQ, P_Z, P_ghWp, P_ghWpAnti, 3387, check)
      call createCurrent(P_ghZ, P_GMinus, P_Hl, P_ghWmAnti, 978, check)
      call createCurrent(P_WMinus, P_G0, P_HPlus, P_Z, 9851, check)
      call createCurrent(P_Z, P_ghA, P_WMinus, P_ghWmAnti, 7045, check)
      call createCurrent(P_ghAAnti, P_ghZ, P_GPlus, P_GMinus, 1041, check)
      call createCurrent(P_GQPlus, P_G0, P_ghA, P_ghWpAnti, 3947, check)
      call createCurrent(P_WMinus, P_Hl, P_Z, P_GPlus, 2960, check)
      call createCurrent(P_HaQ, P_Z, P_HlQ, 3094, check)
      call createCurrent(P_GMinus, P_Z, P_GPlus, P_A, 3004, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_WQPlus, 6812, check)
      call createCurrent(P_HQPlus, P_Ha, P_ghA, P_ghWpAnti, 6512, check)
      call createCurrent(P_Ha, P_Hl, P_GPlus, P_GMinus, 9123, check)
      call createCurrent(P_Hl, P_ghWp, P_Hh, P_ghWpAnti, 9067, check)
      call createCurrent(P_ghWpAnti, P_A, P_ghWp, P_ZQ, 6958, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_G0, P_GQ0, 2985, check)
      call createCurrent(P_HhQ, P_HPlus, P_HQMinus, 7029, check)
      call createCurrent(P_HhQ, P_ghZAnti, P_HPlus, P_ghWm, 5488, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_GMinus, P_HlQ, 5713, check)
      call createCurrent(P_ghA, P_HMinus, P_GPlus, P_ghZAnti, 10371, check)
      call createCurrent(P_WQMinus, P_Z, P_HPlus, P_HaQ, 292, check)
      call createCurrent(P_WQMinus, P_GPlus, P_AQ, 789, check)
      call createCurrent(P_HQPlus, P_eMinus, P_nu_eAnti, 1434, check)
      call createCurrent(P_A, P_Ha, P_Z, P_Ha, 10236, check)
      call createCurrent(P_ghGAnti, P_g, P_ghG, 4198, check)
      call createCurrent(P_Hh, P_Ha, P_Ha, P_Hh, 2987, check)
      call createCurrent(P_Z, P_Ha, P_WMinus, P_HPlus, 8389, check)
      call createCurrent(P_s, P_cAnti, P_WPlus, 2100, check)
      call createCurrent(P_ghWp, P_HPlus, P_ghWpAnti, P_HQMinus, 3839, check)
      call createCurrent(P_WMinus, P_Hh, P_HPlus, P_Z, 5745, check)
      call createCurrent(P_HlQ, P_ghAAnti, P_HPlus, P_ghWm, 3693, check)
      call createCurrent(P_ghZ, P_HMinus, P_ghWmAnti, P_HaQ, 7055, check)
      call createCurrent(P_HaQ, P_Hl, P_HMinus, P_HQPlus, 956, check)
      call createCurrent(P_HQMinus, P_G0, P_GPlus, P_HaQ, 1769, check)
      call createCurrent(P_ghZ, P_HPlus, P_GMinus, P_ghZAnti, 9027, check)
      call createCurrent(P_HQPlus, P_Hh, P_ghZAnti, P_ghWm, 1989, check)
      call createCurrent(P_ghWmAnti, P_Hl, P_ghA, P_GMinus, 1380, check)
      call createCurrent(P_HPlus, P_Hh, P_Hh, P_GMinus, 1962, check)
      call createCurrent(P_GQMinus, P_Hl, P_Hh, P_HQPlus, 5157, check)
      call createCurrent(P_GQPlus, P_Hh, P_Hl, P_HQMinus, 4054, check)
      call createCurrent(P_Hl, P_Z, P_WMinus, P_GPlus, 8765, check)
      call createCurrent(P_ZQ, P_c, P_cAnti, 743, check)
      call createCurrent(P_ghWp, P_HMinus, P_ghZAnti, P_HlQ, 6290, check)
      call createCurrent(P_HaQ, P_t, P_tAnti, 2914, check)
      call createCurrent(P_Hh, P_Z, P_Hh, P_Z, 2372, check)
      call createCurrent(P_Hl, P_HMinus, P_Hl, P_HPlus, 2879, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghZAnti, P_GQ0, 1395, check)
      call createCurrent(P_G0, P_HMinus, P_ghZAnti, P_ghWp, 8958, check)
      call createCurrent(P_Ha, P_A, P_Ha, P_A, 10691, check)
      call createCurrent(P_Hh, P_ghWm, P_ghAAnti, P_HPlus, 1244, check)
      call createCurrent(P_GPlus, P_ghZ, P_ghZAnti, P_HMinus, 8936, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_A, P_ghA, 8665, check)
      call createCurrent(P_GQPlus, P_WMinus, P_Z, P_GQ0, 6533, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_ghA, P_WPlus, 8604, check)
      call createCurrent(P_HhQ, P_G0, P_HaQ, 1678, check)
      call createCurrent(P_ghWm, P_GPlus, P_Ha, P_ghZAnti, 9855, check)
      call createCurrent(P_ghWpAnti, P_Hl, P_GPlus, P_ghZ, 8403, check)
      call createCurrent(P_WMinus, P_Z, P_A, P_WPlus, 2270, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Hl, P_Hl, 7019, check)
      call createCurrent(P_ePlus, P_eMinus, P_HlQ, 2576, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_HMinus, P_Ha, 5782, check)
      call createCurrent(P_ghZAnti, P_ghA, P_WPlus, P_WMinus, 1778, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_Ha, P_HMinus, 5849, check)
      call createCurrent(P_Hl, P_GPlus, P_GMinus, 7322, check)
      call createCurrent(P_ZQ, P_ghWpAnti, P_Z, P_ghWp, 7571, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_WPlus, P_ZQ, 5361, check)
      call createCurrent(P_nu_mu, P_A, P_nu_muAnti, 9732, check)
      call createCurrent(P_Hl, P_Hl, P_Hh, P_Hh, 3957, check)
      call createCurrent(P_HlQ, P_b, P_bAnti, 6395, check)
      call createCurrent(P_GPlus, P_HMinus, P_Hh, 5880, check)
      call createCurrent(P_WPlus, P_ghZAnti, P_ghA, P_WMinus, 1971, check)
      call createCurrent(P_Ha, P_GMinus, P_ghZ, P_ghWmAnti, 9143, check)
      call createCurrent(P_G0, P_ghAAnti, P_GPlus, P_ghWm, 7400, check)
      call createCurrent(P_GQ0, P_muPlus, P_muMinus, 7115, check)
      call createCurrent(P_HlQ, P_Hh, P_HPlus, P_GQMinus, 7930, check)
      call createCurrent(P_G0, P_bAnti, P_b, 2039, check)
      call createCurrent(P_GMinus, P_ghA, P_Hl, P_ghWmAnti, 1106, check)
      call createCurrent(P_ZQ, P_nu_tauAnti, P_nu_tau, 4978, check)
      call createCurrent(P_Z, P_Z, P_Hl, P_Hl, 1034, check)
      call createCurrent(P_ghWmAnti, P_HMinus, P_Hl, P_ghA, 4708, check)
      call createCurrent(P_Z, P_WPlus, P_WMinus, P_A, 5882, check)
      call createCurrent(P_HQMinus, P_A, P_WPlus, P_HhQ, 5079, check)
      call createCurrent(P_GQ0, P_HPlus, P_GMinus, P_HhQ, 1895, check)
      call createCurrent(P_ghWp, P_Hh, P_ghWpAnti, P_HhQ, 4668, check)
      call createCurrent(P_ghWpAnti, P_Hl, P_ghWp, P_Hl, 5872, check)
      call createCurrent(P_HaQ, P_Hh, P_G0, P_HhQ, 6650, check)
      call createCurrent(P_AQ, P_ghWm, P_A, P_ghWmAnti, 501, check)
      call createCurrent(P_GPlus, P_ghAAnti, P_ghWm, P_Hl, 5218, check)
      call createCurrent(P_GMinus, P_tauPlus, P_nu_tau, 2825, check)
      call createCurrent(P_HPlus, P_Z, P_Ha, P_WMinus, 1630, check)
      call createCurrent(P_muPlus, P_Ha, P_muMinus, 5680, check)
      call createCurrent(P_HQPlus, P_GMinus, P_HMinus, P_GQPlus, 6873, check)
      call createCurrent(P_G0, P_ghA, P_GPlus, P_ghWpAnti, 5514, check)
      call createCurrent(P_A, P_ghWpAnti, P_WPlus, P_ghZ, 1575, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_HPlus, P_Hl, 1065, check)
      call createCurrent(P_HlQ, P_Hh, P_Ha, P_HaQ, 2499, check)
      call createCurrent(P_HlQ, P_WPlus, P_A, P_HQMinus, 5191, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_Hh, P_GQPlus, 6408, check)
      call createCurrent(P_HQMinus, P_Hl, P_ghZ, P_ghWmAnti, 7261, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Z, P_AQ, 2431, check)
      call createCurrent(P_HhQ, P_G0, P_G0, P_HhQ, 528, check)
      call createCurrent(P_ghWp, P_GMinus, P_Hh, P_ghZAnti, 3111, check)
      call createCurrent(P_GPlus, P_ghWmAnti, P_HMinus, P_ghWm, 10105, check)
      call createCurrent(P_WPlus, P_WMinus, P_Z, P_A, 3854, check)
      call createCurrent(P_GQMinus, P_Hl, P_HPlus, P_HhQ, 8255, check)
      call createCurrent(P_ghWpAnti, P_Hh, P_ghWp, P_GQ0, 5454, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_Hl, P_HQPlus, 525, check)
      call createCurrent(P_HMinus, P_ghAAnti, P_ghWp, P_Ha, 4459, check)
      call createCurrent(P_WPlus, P_tAnti, P_b, 3535, check)
      call createCurrent(P_GPlus, P_G0, P_Hl, P_HMinus, 4106, check)
      call createCurrent(P_ghWpAnti, P_Ha, P_ghWp, P_Ha, 8299, check)
      call createCurrent(P_GQ0, P_Hh, P_ghWp, P_ghWpAnti, 6485, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghWmAnti, P_G0, 4730, check)
      call createCurrent(P_HhQ, P_G0, P_ghWmAnti, P_ghWm, 1036, check)
      call createCurrent(P_WQMinus, P_WPlus, P_Hl, P_GQ0, 2009, check)
      call createCurrent(P_WPlus, P_G0, P_HMinus, P_Z, 9714, check)
      call createCurrent(P_GMinus, P_G0, P_Ha, P_GPlus, 435, check)
      call createCurrent(P_Z, P_Hl, P_HPlus, P_WMinus, 8261, check)
      call createCurrent(P_HhQ, P_Ha, P_ghWm, P_ghWmAnti, 929, check)
      call createCurrent(P_Hh, P_Hh, P_HMinus, P_GPlus, 2735, check)
      call createCurrent(P_HlQ, P_G0, P_Ha, P_HhQ, 5374, check)
      call createCurrent(P_GMinus, P_Hl, P_HPlus, P_Hh, 7221, check)
      call createCurrent(P_ePlus, P_eMinus, P_HaQ, 1464, check)
      call createCurrent(P_HQMinus, P_c, P_sAnti, 1440, check)
      call createCurrent(P_GQPlus, P_WMinus, P_A, P_HhQ, 7179, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_HPlus, P_HhQ, 6704, check)
      call createCurrent(P_A, P_A, P_HMinus, P_GPlus, 9196, check)
      call createCurrent(P_ZQ, P_ghWm, P_A, P_ghWmAnti, 4415, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_A, 7196, check)
      call createCurrent(P_GMinus, P_G0, P_WPlus, P_A, 2501, check)
      call createCurrent(P_Z, P_u, P_uAnti, 8108, check)
      call createCurrent(P_WMinus, P_ghA, P_WPlus, P_ghZAnti, 7468, check)
      call createCurrent(P_ghZ, P_Hl, P_GMinus, P_ghWmAnti, 8467, check)
      call createCurrent(P_ZQ, P_WPlus, P_Hl, P_HQMinus, 434, check)
      call createCurrent(P_Ha, P_HPlus, P_ghWm, P_ghZAnti, 6190, check)
      call createCurrent(P_Hh, P_A, P_Z, 8856, check)
      call createCurrent(P_HQPlus, P_Ha, P_Hl, P_GQMinus, 3378, check)
      call createCurrent(P_GQPlus, P_WPlus, P_WMinus, P_GQMinus, 8244, check)
      call createCurrent(P_WPlus, P_ghAAnti, P_ghZ, P_WMinus, 7961, check)
      call createCurrent(P_HQMinus, P_Ha, P_GPlus, P_HaQ, 2913, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_G0, P_HhQ, 6389, check)
      call createCurrent(P_Z, P_HMinus, P_WPlus, P_Ha, 7233, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Z, 8328, check)
      call createCurrent(P_Hl, P_Z, P_Hh, P_A, 10584, check)
      call createCurrent(P_Z, P_g, P_g, P_A, 10627, check)
      call createCurrent(P_GQPlus, P_WMinus, P_G0, P_AQ, 8743, check)
      call createCurrent(P_ZQ, P_Z, P_HPlus, P_HQMinus, 1261, check)
      call createCurrent(P_ghA, P_WPlus, P_ghWpAnti, P_A, 4303, check)
      call createCurrent(P_ghWm, P_Ha, P_ghWmAnti, P_HhQ, 511, check)
      call createCurrent(P_GQPlus, P_Hh, P_ghZ, P_ghWpAnti, 6419, check)
      call createCurrent(P_g, P_ghG, P_ghGAnti, P_g, 1941, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_G0, P_G0, 5064, check)
      call createCurrent(P_GQPlus, P_HMinus, P_GMinus, P_HQPlus, 5159, check)
      call createCurrent(P_Hh, P_HMinus, P_ghWmAnti, P_ghA, 7255, check)
      call createCurrent(P_G0, P_G0, P_Hl, 2094, check)
      call createCurrent(P_sAnti, P_c, P_WQMinus, 5780, check)
      call createCurrent(P_ghZAnti, P_HPlus, P_ghWm, 2921, check)
      call createCurrent(P_HhQ, P_HMinus, P_Z, P_WQPlus, 8430, check)
      call createCurrent(P_WPlus, P_A, P_Z, P_WMinus, 7753, check)
      call createCurrent(P_WQPlus, P_WPlus, P_WMinus, P_WQMinus, 7249, check)
      call createCurrent(P_GMinus, P_A, P_HPlus, P_Z, 9705, check)
      call createCurrent(P_ghZAnti, P_Hl, P_ghZ, 4435, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_HMinus, 8509, check)
      call createCurrent(P_HMinus, P_ghAAnti, P_G0, P_ghWp, 10446, check)
      call createCurrent(P_WQPlus, P_Z, P_WMinus, P_ZQ, 79, check)
      call createCurrent(P_g, P_g, P_A, P_g, 10696, check)
      call createCurrent(P_WPlus, P_Ha, P_Ha, P_WMinus, 963, check)
      call createCurrent(P_HPlus, P_WMinus, P_Z, P_Hl, 5395, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_GPlus, P_Ha, 9405, check)
      call createCurrent(P_bAnti, P_b, P_ZQ, 4615, check)
      call createCurrent(P_b, P_bAnti, P_HhQ, 1192, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_A, P_ZQ, 7333, check)
      call createCurrent(P_HlQ, P_GPlus, P_Z, P_WQMinus, 3978, check)
      call createCurrent(P_ghA, P_Ha, P_ghWpAnti, P_HPlus, 1517, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_ghWp, P_G0, 8685, check)
      call createCurrent(P_GMinus, P_Hh, P_ghWmAnti, P_ghZ, 71, check)
      call createCurrent(P_GQPlus, P_ghWm, P_GMinus, P_ghWmAnti, 1703, check)
      call createCurrent(P_nu_e, P_nu_eAnti, 10111, check)
      call createCurrent(P_Hl, P_ghWp, P_GMinus, P_ghAAnti, 4007, check)
      call createCurrent(P_GQMinus, P_GPlus, P_Hl, P_GQ0, 2824, check)
      call createCurrent(P_HPlus, P_eMinus, P_nu_eAnti, 6744, check)
      call createCurrent(P_G0, P_A, P_Z, P_Ha, 10716, check)
      call createCurrent(P_Ha, P_WMinus, P_GPlus, P_A, 9872, check)
      call createCurrent(P_Hl, P_Hh, P_ghWm, P_ghWmAnti, 9360, check)
      call createCurrent(P_GQPlus, P_WMinus, P_Z, P_HlQ, 87, check)
      call createCurrent(P_ghAAnti, P_G0, P_GMinus, P_ghWp, 4911, check)
      call createCurrent(P_WQPlus, P_Z, P_Hh, P_GQMinus, 6461, check)
      call createCurrent(P_GPlus, P_Ha, P_ghWm, P_ghAAnti, 8893, check)
      call createCurrent(P_ghWm, P_HPlus, P_ghAAnti, 3316, check)
      call createCurrent(P_HaQ, P_Ha, P_Hl, P_HlQ, 7214, check)
      call createCurrent(P_HQMinus, P_Ha, P_Hh, P_GQPlus, 966, check)
      call createCurrent(P_HMinus, P_Hh, P_ghWmAnti, P_ghZ, 6495, check)
      call createCurrent(P_A, P_Z, P_HPlus, P_GMinus, 9220, check)
      call createCurrent(P_Hl, P_GPlus, P_GMinus, P_Ha, 10251, check)
      call createCurrent(P_HaQ, P_ghZ, P_Ha, P_ghZAnti, 5667, check)
      call createCurrent(P_ghWp, P_GMinus, P_GPlus, P_ghWpAnti, 6082, check)
      call createCurrent(P_GPlus, P_WPlus, P_GMinus, P_WMinus, 7828, check)
      call createCurrent(P_GPlus, P_Ha, P_Hh, P_HMinus, 8370, check)
      call createCurrent(P_HhQ, P_G0, P_Hl, P_HaQ, 3245, check)
      call createCurrent(P_ghZAnti, P_Hh, P_ghWp, P_HQMinus, 2630, check)
      call createCurrent(P_Hh, P_HPlus, P_Ha, P_HMinus, 10057, check)
      call createCurrent(P_Z, P_ghWm, P_WPlus, P_ghZAnti, 1840, check)
      call createCurrent(P_ZQ, P_nu_tau, P_nu_tauAnti, 1063, check)
      call createCurrent(P_HlQ, P_ghWm, P_GPlus, P_ghAAnti, 7194, check)
      call createCurrent(P_uAnti, P_d, P_HQPlus, 8570, check)
      call createCurrent(P_G0, P_ghWpAnti, P_ghWp, P_G0, 8127, check)
      call createCurrent(P_ghZ, P_GMinus, P_HPlus, P_ghZAnti, 10302, check)
      call createCurrent(P_WPlus, P_HPlus, P_WMinus, P_GMinus, 9826, check)
      call createCurrent(P_ghWm, P_Ha, P_ghAAnti, P_GPlus, 9006, check)
      call createCurrent(P_Hl, P_Z, P_WPlus, P_GMinus, 5452, check)
      call createCurrent(P_GQPlus, P_HMinus, P_G0, P_HlQ, 596, check)
      call createCurrent(P_AQ, P_ghWmAnti, P_A, P_ghWm, 498, check)
      call createCurrent(P_HQPlus, P_G0, P_Hl, P_GQMinus, 3305, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghAAnti, P_HMinus, 10217, check)
      call createCurrent(P_eMinus, P_ePlus, P_Ha, 7064, check)
      call createCurrent(P_GPlus, P_ghWm, P_ghAAnti, P_G0, 2323, check)
      call createCurrent(P_Hl, P_ghAAnti, P_GMinus, P_ghWp, 6390, check)
      call createCurrent(P_A, P_ghWpAnti, P_A, P_ghWp, 7427, check)
      call createCurrent(P_ZQ, P_Z, P_GPlus, P_GQMinus, 1537, check)
      call createCurrent(P_HQPlus, P_HMinus, P_HhQ, 1760, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_ghWp, P_A, 1582, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_WPlus, P_Z, 3519, check)
      call createCurrent(P_HPlus, P_ghWpAnti, P_ghZ, 3465, check)
      call createCurrent(P_WMinus, P_A, P_GPlus, P_Hh, 5832, check)
      call createCurrent(P_AQ, P_ghWpAnti, P_A, P_ghWp, 4809, check)
      call createCurrent(P_WQMinus, P_G0, P_GPlus, P_AQ, 2612, check)
      call createCurrent(P_HaQ, P_Hl, P_Hh, P_HaQ, 1751, check)
      call createCurrent(P_GQPlus, P_HMinus, P_HaQ, 4175, check)
      call createCurrent(P_HPlus, P_Hl, P_GMinus, 6477, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_WPlus, 4816, check)
      call createCurrent(P_HMinus, P_ghAAnti, P_ghWp, 8620, check)
      call createCurrent(P_WPlus, P_WMinus, P_WPlus, P_WMinus, 6592, check)
      call createCurrent(P_ghA, P_HPlus, P_Hh, P_ghWpAnti, 2700, check)
      call createCurrent(P_HQPlus, P_HMinus, P_Ha, P_GQ0, 4949, check)
      call createCurrent(P_GQ0, P_GPlus, P_WMinus, P_ZQ, 4142, check)
      call createCurrent(P_WMinus, P_GPlus, P_Hl, P_Z, 694, check)
      call createCurrent(P_G0, P_ghZAnti, P_GPlus, P_ghWm, 7169, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_GPlus, P_HlQ, 8110, check)
      call createCurrent(P_WQPlus, P_ghZAnti, P_WMinus, P_ghA, 490, check)
      call createCurrent(P_HQPlus, P_Ha, P_ghWm, P_ghZAnti, 7929, check)
      call createCurrent(P_Z, P_Hh, P_WMinus, P_HPlus, 276, check)
      call createCurrent(P_WMinus, P_ghZAnti, P_ghWp, P_Z, 3164, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Ha, P_Ha, 2224, check)
      call createCurrent(P_Z, P_HMinus, P_WPlus, P_G0, 9745, check)
      call createCurrent(P_GPlus, P_Ha, P_WMinus, P_A, 9336, check)
      call createCurrent(P_HQPlus, P_WPlus, P_WMinus, P_HQMinus, 2407, check)
      call createCurrent(P_GQMinus, P_HPlus, P_HMinus, P_GQPlus, 4389, check)
      call createCurrent(P_HMinus, P_Hh, P_Ha, P_GPlus, 6401, check)
      call createCurrent(P_GMinus, P_G0, P_Hh, P_HPlus, 7875, check)
      call createCurrent(P_WQPlus, P_Hl, P_WQMinus, 3803, check)
      call createCurrent(P_GMinus, P_Hl, P_HPlus, P_Hl, 7533, check)
      call createCurrent(P_Hl, P_ghWpAnti, P_GPlus, P_ghZ, 5998, check)
      call createCurrent(P_HMinus, P_G0, P_A, P_WPlus, 10297, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_Z, P_ghA, 6183, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_G0, P_HhQ, 1284, check)
      call createCurrent(P_HhQ, P_Hh, P_Hh, P_HlQ, 4717, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_HQPlus, 5087, check)
      call createCurrent(P_ghA, P_G0, P_ghWpAnti, P_GQPlus, 3856, check)
      call createCurrent(P_WQMinus, P_Hh, P_WPlus, P_HhQ, 3284, check)
      call createCurrent(P_tauPlus, P_GMinus, P_nu_tau, 224, check)
      call createCurrent(P_WQPlus, P_ghWpAnti, P_A, P_ghA, 8172, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_WMinus, 7289, check)
      call createCurrent(P_HQMinus, P_HPlus, P_HhQ, 8161, check)
      call createCurrent(P_HQPlus, P_Ha, P_Ha, P_GQMinus, 3775, check)
      call createCurrent(P_ZQ, P_HPlus, P_WMinus, P_HhQ, 7360, check)
      call createCurrent(P_Ha, P_HMinus, P_ghWmAnti, P_ghZ, 1878, check)
      call createCurrent(P_GPlus, P_ghAAnti, P_Hh, P_ghWm, 1475, check)
      call createCurrent(P_Hh, P_HPlus, P_GMinus, 1226, check)
      call createCurrent(P_ghA, P_WPlus, P_ghZAnti, P_WQMinus, 2010, check)
      call createCurrent(P_Hh, P_GPlus, P_HMinus, P_Ha, 3563, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_HMinus, P_HPlus, 827, check)
      call createCurrent(P_HQMinus, P_A, P_HPlus, P_ZQ, 7149, check)
      call createCurrent(P_HQPlus, P_HMinus, P_G0, P_HlQ, 6011, check)
      call createCurrent(P_A, P_GPlus, P_HMinus, P_A, 9932, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_Hl, P_HPlus, 4933, check)
      call createCurrent(P_G0, P_Hh, P_HPlus, P_HMinus, 10223, check)
      call createCurrent(P_nu_tauAnti, P_tauMinus, P_GPlus, 1974, check)
      call createCurrent(P_A, P_HMinus, P_GPlus, 9942, check)
      call createCurrent(P_GQ0, P_ghWm, P_GPlus, P_ghZAnti, 3635, check)
      call createCurrent(P_ghWpAnti, P_HPlus, P_ghA, P_Ha, 5556, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghAAnti, 8630, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_HPlus, P_Hl, 2383, check)
      call createCurrent(P_HQMinus, P_HPlus, P_ghAAnti, P_ghA, 7816, check)
      call createCurrent(P_muMinus, P_muPlus, P_GQ0, 6934, check)
      call createCurrent(P_HlQ, P_GMinus, P_Hh, P_HQPlus, 46, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Z, P_Z, 5820, check)
      call createCurrent(P_AQ, P_HMinus, P_Ha, P_WQPlus, 257, check)
      call createCurrent(P_ghWp, P_WPlus, P_ghWpAnti, P_WQMinus, 5651, check)
      call createCurrent(P_Hh, P_Hh, P_HPlus, P_GMinus, 7499, check)
      call createCurrent(P_GQPlus, P_Hh, P_GQMinus, 1576, check)
      call createCurrent(P_G0, P_ghZAnti, P_HMinus, P_ghWp, 9367, check)
      call createCurrent(P_Z, P_Ha, P_HMinus, P_WPlus, 5790, check)
      call createCurrent(P_ZQ, P_ghWp, P_Z, P_ghWpAnti, 6994, check)
      call createCurrent(P_G0, P_Hl, P_Hh, P_G0, 6219, check)
      call createCurrent(P_ghAAnti, P_ghA, P_HPlus, P_GMinus, 9104, check)
      call createCurrent(P_HPlus, P_WMinus, P_A, P_G0, 10138, check)
      call createCurrent(P_G0, P_G0, P_Hl, P_Hl, 6839, check)
      call createCurrent(P_HMinus, P_Ha, P_HPlus, P_Ha, 6336, check)
      call createCurrent(P_WPlus, P_G0, P_Z, P_HMinus, 9946, check)
      call createCurrent(P_G0, P_Ha, P_G0, P_G0, 2075, check)
      call createCurrent(P_GMinus, P_ghAAnti, P_G0, P_ghWp, 4182, check)
      call createCurrent(P_HQMinus, P_Ha, P_ghZ, P_ghWmAnti, 8268, check)
      call createCurrent(P_A, P_ghWm, P_ghZAnti, P_WPlus, 8354, check)
      call createCurrent(P_ghZAnti, P_G0, P_ghZ, P_Ha, 9916, check)
      call createCurrent(P_G0, P_Hh, P_HPlus, P_GMinus, 2976, check)
      call createCurrent(P_A, P_tAnti, P_t, 1260, check)
      call createCurrent(P_GPlus, P_ghA, P_ghWpAnti, P_Ha, 9559, check)
      call createCurrent(P_WQPlus, P_Z, P_GMinus, P_HlQ, 6595, check)
      call createCurrent(P_u, P_uAnti, P_GQ0, 2690, check)
      call createCurrent(P_Ha, P_Z, P_WMinus, P_HPlus, 6311, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_Hh, P_GMinus, 2969, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_G0, P_GQMinus, 5783, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghWp, P_GQMinus, 8400, check)
      call createCurrent(P_GMinus, P_G0, P_GPlus, P_Ha, 1127, check)
      call createCurrent(P_Hl, P_GMinus, P_GPlus, P_Hh, 2096, check)
      call createCurrent(P_ghA, P_ghAAnti, P_GPlus, P_GQMinus, 1237, check)
      call createCurrent(P_HMinus, P_G0, P_Hl, P_HPlus, 9225, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_HPlus, P_ghA, 9048, check)
      call createCurrent(P_HPlus, P_WMinus, P_Hl, 4636, check)
      call createCurrent(P_HQMinus, P_Hh, P_HPlus, P_HhQ, 1363, check)
      call createCurrent(P_HlQ, P_GMinus, P_ghWp, P_ghAAnti, 6430, check)
      call createCurrent(P_eMinus, P_ePlus, P_Hh, 1050, check)
      call createCurrent(P_Ha, P_Z, P_WPlus, P_GMinus, 9724, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_G0, P_ghWp, 4353, check)
      call createCurrent(P_ghA, P_WPlus, P_A, P_ghWpAnti, 7182, check)
      call createCurrent(P_b, P_A, P_bAnti, 6566, check)
      call createCurrent(P_WMinus, P_WPlus, P_WPlus, P_WMinus, 399, check)
      call createCurrent(P_HhQ, P_ghWpAnti, P_G0, P_ghWp, 8564, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghAAnti, P_HlQ, 4705, check)
      call createCurrent(P_A, P_WMinus, P_GPlus, P_Ha, 9605, check)
      call createCurrent(P_Ha, P_HMinus, P_Hl, P_HPlus, 9618, check)
      call createCurrent(P_HMinus, P_Hh, P_WPlus, P_Z, 1042, check)
      call createCurrent(P_Hl, P_Ha, P_Hl, P_Ha, 8678, check)
      call createCurrent(P_g, P_A, P_A, P_g, 10564, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghZ, P_Z, 2287, check)
      call createCurrent(P_GPlus, P_ghZ, P_ghWpAnti, P_G0, 2733, check)
      call createCurrent(P_HQPlus, P_Hh, P_ghA, P_ghWpAnti, 273, check)
      call createCurrent(P_WQMinus, P_ghAAnti, P_WPlus, P_ghZ, 8443, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_HaQ, 3793, check)
      call createCurrent(P_WMinus, P_GPlus, P_G0, P_A, 1430, check)
      call createCurrent(P_GQPlus, P_GMinus, P_Z, P_ZQ, 2895, check)
      call createCurrent(P_ghA, P_Hl, P_ghWpAnti, P_HPlus, 1801, check)
      call createCurrent(P_ZQ, P_GPlus, P_WMinus, P_GQ0, 8305, check)
      call createCurrent(P_s, P_Hh, P_sAnti, 5626, check)
      call createCurrent(P_HlQ, P_G0, P_HPlus, P_GQMinus, 2225, check)
      call createCurrent(P_eMinus, P_nu_eAnti, P_HQPlus, 5085, check)
      call createCurrent(P_Z, P_Hl, P_Hh, P_A, 10630, check)
      call createCurrent(P_HPlus, P_Hh, P_ghZ, P_ghWpAnti, 4628, check)
      call createCurrent(P_HMinus, P_HPlus, P_Hl, 6996, check)
      call createCurrent(P_nu_tauAnti, P_nu_tau, P_A, 10428, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_G0, P_GPlus, 4937, check)
      call createCurrent(P_HPlus, P_ghZAnti, P_G0, P_ghWm, 9567, check)
      call createCurrent(P_A, P_G0, P_Ha, P_Z, 10738, check)
      call createCurrent(P_HQPlus, P_A, P_WMinus, P_HaQ, 342, check)
      call createCurrent(P_A, P_HPlus, P_WMinus, P_G0, 9282, check)
      call createCurrent(P_ghWm, P_A, P_A, P_ghWmAnti, 3911, check)
      call createCurrent(P_HMinus, P_GPlus, P_ghA, P_ghZAnti, 9016, check)
      call createCurrent(P_GQMinus, P_Hl, P_Hl, P_HQPlus, 1033, check)
      call createCurrent(P_WMinus, P_GPlus, P_Hl, P_A, 853, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_WMinus, P_WPlus, 7145, check)
      call createCurrent(P_GQMinus, P_HPlus, P_Ha, P_GQ0, 820, check)
      call createCurrent(P_nu_tau, P_WMinus, P_tauPlus, 1325, check)
      call createCurrent(P_GPlus, P_HPlus, P_GMinus, P_GMinus, 2818, check)
      call createCurrent(P_GPlus, P_GMinus, P_GPlus, P_GMinus, 8740, check)
      call createCurrent(P_A, P_G0, P_WMinus, P_GPlus, 6307, check)
      call createCurrent(P_HMinus, P_HPlus, P_g, P_g, 10723, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_GMinus, 1839, check)
      call createCurrent(P_GQPlus, P_tauMinus, P_nu_tauAnti, 7383, check)
      call createCurrent(P_ghAAnti, P_HPlus, P_G0, P_ghWm, 9118, check)
      call createCurrent(P_GPlus, P_GMinus, P_A, P_A, 15, check)
      call createCurrent(P_GQPlus, P_HMinus, P_HPlus, P_GQMinus, 6775, check)
      call createCurrent(P_GQPlus, P_G0, P_ghWpAnti, P_ghZ, 1671, check)
      call createCurrent(P_WPlus, P_GMinus, 8860, check)
      call createCurrent(P_HaQ, P_GPlus, P_Hl, P_GQMinus, 1334, check)
      call createCurrent(P_ghA, P_Ha, P_ghWmAnti, P_HQMinus, 4367, check)
      call createCurrent(P_HMinus, P_Ha, P_Hl, P_GPlus, 3018, check)
      call createCurrent(P_WPlus, P_WPlus, P_WMinus, P_WMinus, 1068, check)
      call createCurrent(P_ghZ, P_GPlus, P_GMinus, P_ghZAnti, 6733, check)
      call createCurrent(P_ZQ, P_Hh, P_Z, P_HhQ, 836, check)
      call createCurrent(P_Hh, P_ghWm, P_HPlus, P_ghAAnti, 2237, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_ghZ, P_GPlus, 8532, check)
      call createCurrent(P_WQMinus, P_GPlus, P_HhQ, 3168, check)
      call createCurrent(P_ghAAnti, P_Hl, P_ghWm, P_HPlus, 280, check)
      call createCurrent(P_G0, P_Z, P_Z, P_Ha, 9269, check)
      call createCurrent(P_HQMinus, P_HMinus, P_HPlus, P_HQPlus, 341, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_HlQ, 4880, check)
      call createCurrent(P_WQMinus, P_A, P_GPlus, P_HlQ, 5481, check)
      call createCurrent(P_Z, P_ghAAnti, P_WMinus, P_ghWp, 8048, check)
      call createCurrent(P_GMinus, P_Hh, P_GPlus, 5558, check)
      call createCurrent(P_GQ0, P_Ha, P_GMinus, P_HQPlus, 3794, check)
      call createCurrent(P_WPlus, P_ghWm, P_WPlus, P_ghWpAnti, 1490, check)
      call createCurrent(P_GQMinus, P_ghWmAnti, P_Hl, P_ghZ, 3239, check)
      call createCurrent(P_ghWpAnti, P_Ha, P_GPlus, P_ghZ, 8925, check)
      call createCurrent(P_ghZ, P_WMinus, P_ghZAnti, P_WQPlus, 7066, check)
      call createCurrent(P_t, P_Ha, P_tAnti, 2632, check)
      call createCurrent(P_HPlus, P_ghA, P_ghWpAnti, P_Hl, 2251, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Z, P_AQ, 5348, check)
      call createCurrent(P_G0, P_ghZ, P_Ha, P_ghZAnti, 10252, check)
      call createCurrent(P_ghWmAnti, P_HMinus, P_ghWm, P_GPlus, 9558, check)
      call createCurrent(P_GQPlus, P_Hh, P_HMinus, P_HlQ, 6536, check)
      call createCurrent(P_ghWp, P_HPlus, P_ghWpAnti, P_HMinus, 7111, check)
      call createCurrent(P_GPlus, P_ghA, P_ghWpAnti, P_G0, 2437, check)
      call createCurrent(P_HMinus, P_ghAAnti, P_Ha, P_ghWp, 513, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_HPlus, P_HhQ, 5001, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_Z, P_WQPlus, 1536, check)
      call createCurrent(P_HQMinus, P_HPlus, P_Hh, P_HlQ, 287, check)
      call createCurrent(P_GMinus, P_HPlus, P_Hh, P_G0, 2236, check)
      call createCurrent(P_HQPlus, P_HMinus, P_ghWm, P_ghWmAnti, 6274, check)
      call createCurrent(P_HQMinus, P_Hl, P_HPlus, P_HaQ, 737, check)
      call createCurrent(P_uAnti, P_u, P_Z, 2427, check)
      call createCurrent(P_GMinus, P_G0, P_GPlus, P_G0, 3323, check)
      call createCurrent(P_HQPlus, P_nu_eAnti, P_eMinus, 1376, check)
      call createCurrent(P_Z, P_ghWp, P_ghZAnti, P_WMinus, 452, check)
      call createCurrent(P_ghWp, P_G0, P_ghZAnti, P_HMinus, 9947, check)
      call createCurrent(P_GMinus, P_HPlus, P_Hl, P_Ha, 5250, check)
      call createCurrent(P_GQ0, P_G0, P_Hh, P_HhQ, 5861, check)
      call createCurrent(P_HMinus, P_Ha, P_Ha, P_GPlus, 3071, check)
      call createCurrent(P_HhQ, P_HPlus, P_GMinus, P_GQ0, 88, check)
      call createCurrent(P_HhQ, P_Hh, P_HMinus, P_GQPlus, 8538, check)
      call createCurrent(P_Z, P_WMinus, P_WPlus, P_Z, 5876, check)
      call createCurrent(P_ZQ, P_WPlus, P_Hh, P_GQMinus, 5821, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghA, 4328, check)
      call createCurrent(P_WPlus, P_HMinus, 10019, check)
      call createCurrent(P_HaQ, P_Z, P_HMinus, P_WQPlus, 1298, check)
      call createCurrent(P_HPlus, P_Ha, P_HMinus, P_G0, 2408, check)
      call createCurrent(P_HaQ, P_Ha, P_ghZAnti, P_ghZ, 1975, check)
      call createCurrent(P_Hh, P_ghWmAnti, P_ghZ, P_GMinus, 366, check)
      call createCurrent(P_GPlus, P_GMinus, P_Hl, P_Ha, 10104, check)
      call createCurrent(P_GPlus, P_ghWm, P_ghWmAnti, P_HMinus, 10274, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_GMinus, P_HPlus, 9098, check)
      call createCurrent(P_G0, P_ghWmAnti, P_ghA, P_GMinus, 7988, check)
      call createCurrent(P_ghA, P_GPlus, P_ghZAnti, P_GQMinus, 6593, check)
      call createCurrent(P_AQ, P_HMinus, P_HPlus, P_AQ, 1994, check)
      call createCurrent(P_ghA, P_GMinus, P_HPlus, P_ghAAnti, 9767, check)
      call createCurrent(P_WQMinus, P_Hl, P_WPlus, P_GQ0, 2497, check)
      call createCurrent(P_GPlus, P_HMinus, P_ghZ, P_ghAAnti, 10131, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_Ha, P_HQMinus, 4499, check)
      call createCurrent(P_GQPlus, P_Hh, P_GMinus, P_HaQ, 7689, check)
      call createCurrent(P_ghWm, P_A, P_ghWmAnti, P_AQ, 2760, check)
      call createCurrent(P_cAnti, P_c, P_g, 2361, check)
      call createCurrent(P_ghWp, P_GPlus, P_HMinus, P_ghWpAnti, 9344, check)
      call createCurrent(P_ZQ, P_d, P_dAnti, 7639, check)
      call createCurrent(P_A, P_ghWm, P_ghWmAnti, P_A, 6418, check)
      call createCurrent(P_Z, P_ghWm, P_ghZAnti, P_WPlus, 6212, check)
      call createCurrent(P_HPlus, P_Hl, P_ghWm, P_ghAAnti, 3680, check)
      call createCurrent(P_HaQ, P_d, P_dAnti, 5622, check)
      call createCurrent(P_GMinus, P_nu_mu, P_muPlus, 6481, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_Hl, P_GPlus, 1705, check)
      call createCurrent(P_G0, P_G0, P_A, P_Z, 9702, check)
      call createCurrent(P_Hh, P_Z, P_Z, P_Hl, 9192, check)
      call createCurrent(P_ghZ, P_HMinus, P_ghWmAnti, P_Hh, 2356, check)
      call createCurrent(P_ePlus, P_eMinus, 9869, check)
      call createCurrent(P_nu_tau, P_nu_tauAnti, P_Z, 7547, check)
      call createCurrent(P_HMinus, P_GPlus, P_G0, 5, check)
      call createCurrent(P_ghWpAnti, P_HPlus, P_Ha, P_ghA, 7806, check)
      call createCurrent(P_HMinus, P_HPlus, P_GMinus, P_HPlus, 5775, check)
      call createCurrent(P_Ha, P_ghA, P_GPlus, P_ghWpAnti, 9506, check)
      call createCurrent(P_HlQ, P_HMinus, P_ghZAnti, P_ghWp, 6000, check)
      call createCurrent(P_A, P_Z, P_Hh, 10144, check)
      call createCurrent(P_HlQ, P_Hl, P_Hl, P_HhQ, 6632, check)
      call createCurrent(P_HQPlus, P_Hl, P_GMinus, P_GQ0, 2756, check)
      call createCurrent(P_HaQ, P_GMinus, P_Hh, P_GQPlus, 6513, check)
      call createCurrent(P_HhQ, P_Z, P_GMinus, P_WQPlus, 7481, check)
      call createCurrent(P_GPlus, P_G0, P_HMinus, P_Ha, 3880, check)
      call createCurrent(P_HMinus, P_Hl, P_ghZAnti, P_ghWp, 3052, check)
      call createCurrent(P_Z, P_tauMinus, P_tauPlus, 98, check)
      call createCurrent(P_G0, P_ghWmAnti, P_ghZ, P_HMinus, 9020, check)
      call createCurrent(P_WPlus, P_WMinus, P_ghZ, P_ghAAnti, 6690, check)
      call createCurrent(P_GQMinus, P_HMinus, P_GPlus, P_GQPlus, 4164, check)
      call createCurrent(P_ghZ, P_Hl, P_ghWmAnti, P_GQMinus, 3828, check)
      call createCurrent(P_GMinus, P_HMinus, P_HPlus, P_HPlus, 2423, check)
      call createCurrent(P_HlQ, P_Ha, P_ZQ, 2680, check)
      call createCurrent(P_ghZAnti, P_ghA, P_GPlus, P_GMinus, 4184, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghA, P_Z, 2533, check)
      call createCurrent(P_HaQ, P_Hh, P_Ha, P_HlQ, 2544, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_Hl, P_HPlus, 4051, check)
      call createCurrent(P_GQPlus, P_GMinus, P_GPlus, P_GQMinus, 8546, check)
      call createCurrent(P_WQMinus, P_WPlus, P_ZQ, 7554, check)
      call createCurrent(P_nu_muAnti, P_muMinus, P_HPlus, 176, check)
      call createCurrent(P_HlQ, P_A, P_WPlus, P_HQMinus, 7315, check)
      call createCurrent(P_GMinus, P_HPlus, P_Ha, P_Hl, 8055, check)
      call createCurrent(P_HQMinus, P_HPlus, P_ghWp, P_ghWpAnti, 7788, check)
      call createCurrent(P_WMinus, P_Hh, P_GPlus, P_A, 5044, check)
      call createCurrent(P_HQMinus, P_Z, P_Ha, P_WQPlus, 5188, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_WQPlus, 2498, check)
      call createCurrent(P_HPlus, P_Hl, P_Hh, P_HMinus, 903, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_Z, P_WMinus, 5611, check)
      call createCurrent(P_ghA, P_GPlus, P_ghZAnti, P_GMinus, 5269, check)
      call createCurrent(P_GPlus, P_HMinus, P_Hh, P_Hh, 1552, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_WPlus, P_WMinus, 3518, check)
      call createCurrent(P_WMinus, P_HPlus, P_Hl, 7067, check)
      call createCurrent(P_WQPlus, P_HPlus, P_HMinus, P_WQMinus, 6992, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_G0, P_ghA, 1542, check)
      call createCurrent(P_HQMinus, P_HPlus, P_ghZ, P_ghAAnti, 7555, check)
      call createCurrent(P_A, P_ghA, P_WMinus, P_ghWmAnti, 4316, check)
      call createCurrent(P_bAnti, P_b, P_Hl, 5142, check)
      call createCurrent(P_GQPlus, P_G0, P_G0, P_GQMinus, 2294, check)
      call createCurrent(P_ghA, P_GMinus, P_ghWmAnti, P_Hh, 8298, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_ghWm, 1521, check)
      call createCurrent(P_ghZAnti, P_Ha, P_ghWp, P_GMinus, 10401, check)
      call createCurrent(P_Ha, P_A, P_Hl, 9647, check)
      call createCurrent(P_GPlus, P_HMinus, P_ghWpAnti, P_ghWp, 9785, check)
      call createCurrent(P_HPlus, P_GPlus, P_HMinus, P_HMinus, 7811, check)
      call createCurrent(P_WMinus, P_WPlus, P_G0, P_G0, 5463, check)
      call createCurrent(P_ghWp, P_HMinus, P_ghWpAnti, P_GPlus, 9552, check)
      call createCurrent(P_muMinus, P_nu_muAnti, P_HPlus, 4845, check)
      call createCurrent(P_Hh, P_ghWpAnti, P_ghA, P_HPlus, 7866, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_GPlus, P_G0, 7258, check)
      call createCurrent(P_s, P_G0, P_sAnti, 4707, check)
      call createCurrent(P_Hl, P_A, P_Hl, P_A, 10598, check)
      call createCurrent(P_Z, P_A, P_ghWmAnti, P_ghWm, 6236, check)
      call createCurrent(P_Ha, P_GPlus, P_WMinus, 9150, check)
      call createCurrent(P_HMinus, P_Ha, P_Z, P_WPlus, 8454, check)
      call createCurrent(P_Z, P_Z, P_Hh, P_Hh, 3348, check)
      call createCurrent(P_A, P_GPlus, P_Ha, P_WMinus, 9387, check)
      call createCurrent(P_GPlus, P_WMinus, P_GMinus, P_WPlus, 4156, check)
      call createCurrent(P_sAnti, P_c, P_GQMinus, 5716, check)
      call createCurrent(P_HQMinus, P_G0, P_Hh, P_GQPlus, 1912, check)
      call createCurrent(P_nu_tauAnti, P_tauMinus, P_WPlus, 7980, check)
      call createCurrent(P_nu_e, P_nu_eAnti, P_A, 8902, check)
      call createCurrent(P_Hl, P_GMinus, P_ghWp, P_ghZAnti, 1459, check)
      call createCurrent(P_d, P_A, P_dAnti, 5096, check)
      call createCurrent(P_HPlus, P_WMinus, P_WPlus, P_HMinus, 5982, check)
      call createCurrent(P_Hl, P_ghWpAnti, P_Hl, P_ghWp, 3309, check)
      call createCurrent(P_HlQ, P_ghWpAnti, P_HPlus, P_ghZ, 1922, check)
      call createCurrent(P_HMinus, P_ghA, P_HPlus, P_ghAAnti, 183, check)
      call createCurrent(P_Ha, P_WPlus, P_A, P_HMinus, 1723, check)
      call createCurrent(P_HQPlus, P_WMinus, P_A, P_HlQ, 5527, check)
      call createCurrent(P_GQPlus, P_Z, P_WQMinus, 5309, check)
      call createCurrent(P_GQ0, P_HPlus, P_G0, P_HQMinus, 8654, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_HPlus, P_G0, 9479, check)
      call createCurrent(P_ghAAnti, P_Hh, P_ghWm, P_HPlus, 1073, check)
      call createCurrent(P_ghWm, P_WPlus, P_WPlus, P_ghWpAnti, 1322, check)
      call createCurrent(P_Hh, P_ghWm, P_HPlus, P_ghZAnti, 7343, check)
      call createCurrent(P_dAnti, P_d, P_g, 6936, check)
      call createCurrent(P_ZQ, P_Hh, P_WPlus, P_GQMinus, 7561, check)
      call createCurrent(P_GQPlus, P_GMinus, P_ghZ, P_ghZAnti, 8409, check)
      call createCurrent(P_Hh, P_ghWpAnti, P_GPlus, P_ghZ, 8428, check)
      call createCurrent(P_Hh, P_HMinus, P_Hl, P_HPlus, 4093, check)
      call createCurrent(P_G0, P_HMinus, P_GPlus, P_G0, 8257, check)
      call createCurrent(P_HaQ, P_Ha, P_WPlus, P_WQMinus, 7244, check)
      call createCurrent(P_ghA, P_Hl, P_ghWmAnti, P_GMinus, 5985, check)
      call createCurrent(P_GQ0, P_G0, P_G0, P_HaQ, 7287, check)
      call createCurrent(P_A, P_WPlus, P_WMinus, P_Z, 1215, check)
      call createCurrent(P_Hh, P_ghAAnti, P_ghWm, P_HPlus, 6166, check)
      call createCurrent(P_WQPlus, P_HMinus, P_Hl, P_ZQ, 4332, check)
      call createCurrent(P_A, P_WPlus, P_GMinus, 147, check)
      call createCurrent(P_Hh, P_GMinus, P_ghAAnti, P_ghWp, 3914, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghWp, P_Hh, 810, check)
      call createCurrent(P_HQPlus, P_Hl, P_Hh, P_HQMinus, 1017, check)
      call createCurrent(P_HQPlus, P_HMinus, P_GPlus, P_GQMinus, 1307, check)
      call createCurrent(P_A, P_A, P_ghWp, P_ghWpAnti, 6623, check)
      call createCurrent(P_HPlus, P_G0, P_ghA, P_ghWpAnti, 9873, check)
      call createCurrent(P_WMinus, P_A, P_Hl, P_GPlus, 5851, check)
      call createCurrent(P_Ha, P_ghZAnti, P_HMinus, P_ghWp, 7281, check)
      call createCurrent(P_GQPlus, P_A, P_GMinus, P_AQ, 5298, check)
      call createCurrent(P_sAnti, P_c, P_HQMinus, 3899, check)
      call createCurrent(P_HlQ, P_GMinus, P_Ha, P_GQPlus, 7104, check)
      call createCurrent(P_HMinus, P_GPlus, P_Ha, P_Hh, 6381, check)
      call createCurrent(P_ghA, P_Ha, P_ghWpAnti, P_HQPlus, 5824, check)
      call createCurrent(P_HMinus, P_ghWp, P_ghZAnti, P_Ha, 3554, check)
      call createCurrent(P_HPlus, P_ghA, P_Hh, P_ghWpAnti, 1239, check)
      call createCurrent(P_HMinus, P_ghWp, P_HPlus, P_ghWpAnti, 7538, check)
      call createCurrent(P_ghA, P_HPlus, P_ghWpAnti, P_Hl, 7911, check)
      call createCurrent(P_HMinus, P_G0, P_ghA, P_ghWmAnti, 8850, check)
      call createCurrent(P_Hl, P_HMinus, P_Z, P_WPlus, 4173, check)
      call createCurrent(P_Z, P_ghWpAnti, P_ghWp, P_A, 3569, check)
      call createCurrent(P_HlQ, P_GMinus, P_WQPlus, 3327, check)
      call createCurrent(P_Hh, P_ghAAnti, P_HMinus, P_ghWp, 2867, check)
      call createCurrent(P_A, P_WMinus, P_HPlus, P_Hh, 7971, check)
      call createCurrent(P_GQ0, P_GPlus, P_Z, P_WQMinus, 2090, check)
      call createCurrent(P_A, P_GPlus, P_WMinus, P_Hh, 632, check)
      call createCurrent(P_HPlus, P_ghAAnti, P_GMinus, P_ghZ, 9069, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghZAnti, P_ZQ, 8643, check)
      call createCurrent(P_GMinus, P_GPlus, P_ghA, P_ghZAnti, 1112, check)
      call createCurrent(P_HQPlus, P_GMinus, P_G0, P_GQ0, 8769, check)
      call createCurrent(P_Ha, P_Ha, P_Hh, P_Hh, 8327, check)
      call createCurrent(P_HMinus, P_Hh, P_Hl, P_GPlus, 2011, check)
      call createCurrent(P_WMinus, P_ghWm, P_WPlus, P_ghWmAnti, 1759, check)
      call createCurrent(P_GPlus, P_ghAAnti, P_HMinus, P_ghA, 9114, check)
      call createCurrent(P_ghZAnti, P_Ha, P_ghZ, P_Ha, 4210, check)
      call createCurrent(P_Z, P_Hh, P_G0, 4970, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_GMinus, P_GQPlus, 2964, check)
      call createCurrent(P_Hh, P_ghZ, P_GMinus, P_ghWmAnti, 8750, check)
      call createCurrent(P_AQ, P_Hl, P_HMinus, P_WQPlus, 5088, check)
      call createCurrent(P_g, P_G0, P_Ha, P_g, 10690, check)
      call createCurrent(P_HaQ, P_ghWm, P_ghWmAnti, 3287, check)
      call createCurrent(P_HPlus, P_G0, P_G0, P_GMinus, 5434, check)
      call createCurrent(P_HQMinus, P_Hh, P_ghZAnti, P_ghWp, 825, check)
      call createCurrent(P_HQPlus, P_ghZAnti, P_HMinus, P_ghA, 6388, check)
      call createCurrent(P_WPlus, P_HMinus, P_A, P_Hh, 8515, check)
      call createCurrent(P_G0, P_ghAAnti, P_ghWp, P_HMinus, 9366, check)
      call createCurrent(P_Hl, P_ghWpAnti, P_HPlus, P_ghZ, 6601, check)
      call createCurrent(P_WQPlus, P_ghWm, P_ghAAnti, 1535, check)
      call createCurrent(P_g, P_g, P_Hh, 10613, check)
      call createCurrent(P_GQMinus, P_ghAAnti, P_GPlus, P_ghA, 7582, check)
      call createCurrent(P_GPlus, P_ghZ, P_ghWpAnti, P_Ha, 9051, check)
      call createCurrent(P_Z, P_GMinus, P_Hl, P_WPlus, 709, check)
      call createCurrent(P_ghA, P_GMinus, P_ghWmAnti, P_Hl, 4513, check)
      call createCurrent(P_GPlus, P_ghWm, P_ghZAnti, P_Hh, 2137, check)
      call createCurrent(P_Z, P_HPlus, P_G0, P_WMinus, 10404, check)
      call createCurrent(P_HaQ, P_Ha, P_WMinus, P_WQPlus, 227, check)
      call createCurrent(P_WMinus, P_Ha, P_GPlus, 9172, check)
      call createCurrent(P_WMinus, P_Ha, P_Z, P_HPlus, 1263, check)
      call createCurrent(P_GQPlus, P_G0, P_Ha, P_HQMinus, 1186, check)
      call createCurrent(P_ghZ, P_HMinus, P_ghWmAnti, 5132, check)
      call createCurrent(P_HQPlus, P_GMinus, P_GMinus, P_HQPlus, 7942, check)
      call createCurrent(P_HPlus, P_Ha, P_G0, P_GMinus, 1736, check)
      call createCurrent(P_HhQ, P_HPlus, P_ghWpAnti, P_ghZ, 7661, check)
      call createCurrent(P_Hh, P_Z, P_Hh, P_A, 9260, check)
      call createCurrent(P_GMinus, P_G0, P_Hh, P_GPlus, 9565, check)
      call createCurrent(P_ghZAnti, P_G0, P_HMinus, P_ghWp, 10454, check)
      call createCurrent(P_Hh, P_GPlus, P_Hl, P_HMinus, 1388, check)
      call createCurrent(P_Hh, P_HPlus, P_ghWpAnti, P_ghZ, 463, check)
      call createCurrent(P_Hl, P_WPlus, P_HMinus, P_Z, 73, check)
      call createCurrent(P_ZQ, P_GMinus, P_Z, P_GQPlus, 5068, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_HMinus, P_Hl, 7265, check)
      call createCurrent(P_Z, P_WPlus, P_GMinus, P_Hl, 334, check)
      call createCurrent(P_ZQ, P_GPlus, P_Hl, P_WQMinus, 1862, check)
      call createCurrent(P_g, P_d, P_dAnti, 5990, check)
      call createCurrent(P_ghAAnti, P_A, P_ghWm, P_WPlus, 617, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghZ, P_A, 4598, check)
      call createCurrent(P_HhQ, P_WMinus, P_GPlus, P_ZQ, 2393, check)
      call createCurrent(P_WQMinus, P_Z, P_ghA, P_ghWmAnti, 4070, check)
      call createCurrent(P_HPlus, P_G0, P_Hh, P_HMinus, 10258, check)
      call createCurrent(P_A, P_cAnti, P_c, 2410, check)
      call createCurrent(P_Ha, P_ghZAnti, P_ghWm, P_GPlus, 10043, check)
      call createCurrent(P_ghZ, P_HMinus, P_ghWmAnti, P_G0, 9711, check)
      call createCurrent(P_u, P_dAnti, P_GQMinus, 3988, check)
      call createCurrent(P_WQPlus, P_GMinus, P_AQ, 3598, check)
      call createCurrent(P_Hh, P_ghZ, P_HPlus, P_ghWpAnti, 8522, check)
      call createCurrent(P_Ha, P_Hl, P_Ha, P_Hl, 3562, check)
      call createCurrent(P_WPlus, P_WMinus, P_ghZAnti, P_ghZ, 4849, check)
      call createCurrent(P_HhQ, P_Hh, P_ghZAnti, P_ghZ, 5895, check)
      call createCurrent(P_g, P_tAnti, P_t, 6890, check)
      call createCurrent(P_GQPlus, P_GMinus, P_ghA, P_ghZAnti, 3026, check)
      call createCurrent(P_GPlus, P_g, P_g, P_HMinus, 10582, check)
      call createCurrent(P_WPlus, P_Hl, P_HMinus, P_Z, 5002, check)
      call createCurrent(P_g, P_HMinus, P_HPlus, P_g, 10725, check)
      call createCurrent(P_Hh, P_A, P_Hh, P_A, 10748, check)
      call createCurrent(P_WPlus, P_WMinus, P_G0, P_G0, 2339, check)
      call createCurrent(P_HhQ, P_HMinus, P_ghWmAnti, P_ghZ, 1864, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_Ha, P_HaQ, 8749, check)
      call createCurrent(P_WQMinus, P_ghWmAnti, P_A, P_ghZ, 4341, check)
      call createCurrent(P_HQPlus, P_b, P_tAnti, 4072, check)
      call createCurrent(P_d, P_uAnti, P_GPlus, 6979, check)
      call createCurrent(P_HaQ, P_Hl, P_ghWmAnti, P_ghWm, 6025, check)
      call createCurrent(P_HaQ, P_G0, P_Hl, P_HhQ, 2442, check)
      call createCurrent(P_HQPlus, P_HMinus, P_ZQ, 4197, check)
      call createCurrent(P_Hh, P_WPlus, P_Hh, P_WMinus, 2077, check)
      call createCurrent(P_HQMinus, P_Hl, P_Ha, P_GQPlus, 944, check)
      call createCurrent(P_WQMinus, P_WPlus, P_Hl, P_HaQ, 7827, check)
      call createCurrent(P_ghA, P_ghZAnti, P_HPlus, P_HQMinus, 5844, check)
      call createCurrent(P_GQMinus, P_HMinus, P_HPlus, P_HQPlus, 4774, check)
      call createCurrent(P_GQ0, P_HPlus, P_GQMinus, 3686, check)
      call createCurrent(P_AQ, P_Z, P_ghWm, P_ghWmAnti, 8074, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_GMinus, 3699, check)
      call createCurrent(P_G0, P_G0, P_HPlus, P_HMinus, 634, check)
      call createCurrent(P_WPlus, P_WMinus, P_ghA, P_ghAAnti, 3853, check)
      call createCurrent(P_HhQ, P_Ha, P_G0, P_HlQ, 5811, check)
      call createCurrent(P_WPlus, P_Hl, P_GMinus, P_Z, 2673, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_A, P_ghZ, 3454, check)
      call createCurrent(P_HMinus, P_Hl, P_Ha, P_GPlus, 3155, check)
      call createCurrent(P_HQPlus, P_HMinus, P_ghAAnti, P_ghA, 4870, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_GMinus, P_GQ0, 19, check)
      call createCurrent(P_A, P_HMinus, P_A, P_GPlus, 9847, check)
      call createCurrent(P_WQPlus, P_A, P_A, P_WQMinus, 3167, check)
      call createCurrent(P_WMinus, P_HPlus, P_Hl, P_A, 8825, check)
      call createCurrent(P_ghAAnti, P_ghZ, P_HMinus, P_GPlus, 9302, check)
      call createCurrent(P_Z, P_ghWmAnti, P_ghWm, P_Z, 4283, check)
      call createCurrent(P_Ha, P_Z, P_Ha, P_A, 10024, check)
      call createCurrent(P_WMinus, P_Ha, P_HPlus, P_A, 6863, check)
      call createCurrent(P_HhQ, P_A, P_HMinus, P_WQPlus, 3478, check)
      call createCurrent(P_muPlus, P_muMinus, 10456, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_GPlus, P_GQ0, 4293, check)
      call createCurrent(P_Ha, P_G0, P_GMinus, P_GPlus, 3160, check)
      call createCurrent(P_GMinus, P_Z, P_WPlus, P_Hl, 7076, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_Hh, P_HQPlus, 117, check)
      call createCurrent(P_WPlus, P_WMinus, P_A, P_A, 7767, check)
      call createCurrent(P_A, P_HPlus, P_G0, P_WMinus, 9249, check)
      call createCurrent(P_Hh, P_WMinus, P_GPlus, P_A, 917, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_Hl, P_ghWp, 8294, check)
      call createCurrent(P_Z, P_A, P_Hh, P_Hl, 10755, check)
      call createCurrent(P_ZQ, P_GMinus, P_Hl, P_WQPlus, 7855, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_Hh, P_GPlus, 4578, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_HPlus, P_GMinus, 9573, check)
      call createCurrent(P_ghZ, P_WMinus, P_WPlus, P_ghAAnti, 1775, check)
      call createCurrent(P_HPlus, P_HMinus, P_ghWp, P_ghWpAnti, 3421, check)
      call createCurrent(P_Hl, P_Ha, P_G0, P_Hl, 6323, check)
      call createCurrent(P_GPlus, P_Hl, P_GMinus, P_G0, 10195, check)
      call createCurrent(P_WQPlus, P_WMinus, P_Ha, P_HhQ, 1321, check)
      call createCurrent(P_Ha, P_ghZAnti, P_ghWm, P_HPlus, 2682, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_Hl, P_HQMinus, 5870, check)
      call createCurrent(P_HMinus, P_G0, P_HPlus, 10411, check)
      call createCurrent(P_muMinus, P_Hl, P_muPlus, 289, check)
      call createCurrent(P_Z, P_GMinus, P_G0, P_WPlus, 1924, check)
      call createCurrent(P_HQMinus, P_Hh, P_Hh, P_GQPlus, 7148, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_G0, P_HPlus, 10310, check)
      call createCurrent(P_HhQ, P_Ha, P_GPlus, P_GQMinus, 6340, check)
      call createCurrent(P_ghZ, P_Hh, P_ghWpAnti, P_GPlus, 8241, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_WMinus, P_A, 1370, check)
      call createCurrent(P_ghWp, P_Z, P_ghWpAnti, P_AQ, 1914, check)
      call createCurrent(P_Hh, P_Hh, P_HMinus, P_HPlus, 7464, check)
      call createCurrent(P_ghAAnti, P_HPlus, P_ghZ, P_GMinus, 9619, check)
      call createCurrent(P_A, P_Hh, P_Hh, P_Z, 9494, check)
      call createCurrent(P_ghA, P_Hl, P_ghWpAnti, P_HQPlus, 5354, check)
      call createCurrent(P_A, P_HPlus, P_HMinus, P_A, 2253, check)
      call createCurrent(P_ghZ, P_Hl, P_ghWpAnti, P_GQPlus, 459, check)
      call createCurrent(P_WQPlus, P_Z, P_A, P_WQMinus, 3005, check)
      call createCurrent(P_WQPlus, P_Z, P_ghZ, P_ghWpAnti, 408, check)
      call createCurrent(P_WMinus, P_HMinus, P_GPlus, P_WPlus, 10375, check)
      call createCurrent(P_AQ, P_Hl, P_GMinus, P_WQPlus, 8716, check)
      call createCurrent(P_Hl, P_ghWm, P_HPlus, P_ghZAnti, 2546, check)
      call createCurrent(P_HPlus, P_GMinus, P_GMinus, P_HPlus, 5418, check)
      call createCurrent(P_HQPlus, P_Hh, P_WMinus, P_AQ, 1715, check)
      call createCurrent(P_ghZ, P_HPlus, P_ghZAnti, P_GMinus, 9400, check)
      call createCurrent(P_G0, P_ghWm, P_ghAAnti, P_HPlus, 8901, check)
      call createCurrent(P_HQMinus, P_A, P_Z, P_HQPlus, 7943, check)
      call createCurrent(P_ghA, P_ghAAnti, P_GPlus, P_HMinus, 10229, check)
      call createCurrent(P_sAnti, P_s, P_A, 2462, check)
      call createCurrent(P_ghZ, P_Hl, P_GPlus, P_ghWpAnti, 304, check)
      call createCurrent(P_WQMinus, P_WPlus, P_ghZ, P_ghZAnti, 5205, check)
      call createCurrent(P_GQMinus, P_Z, P_Hh, P_WQPlus, 5440, check)
      call createCurrent(P_WQPlus, P_A, P_ghWpAnti, P_ghA, 4344, check)
      call createCurrent(P_HlQ, P_A, P_GPlus, P_WQMinus, 3996, check)
      call createCurrent(P_HQPlus, P_Ha, P_ghZAnti, P_ghWm, 1164, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_HPlus, P_Hh, 6652, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_Hh, P_HPlus, 5862, check)
      call createCurrent(P_Z, P_WMinus, P_ghZ, P_ghWmAnti, 2599, check)
      call createCurrent(P_HQPlus, P_Z, P_Hh, P_WQMinus, 3129, check)
      call createCurrent(P_GMinus, P_G0, P_HPlus, P_Ha, 659, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_GQMinus, 5276, check)
      call createCurrent(P_A, P_HPlus, P_Hh, P_WMinus, 1499, check)
      call createCurrent(P_HMinus, P_GPlus, P_GMinus, P_GPlus, 5969, check)
      call createCurrent(P_GMinus, P_HPlus, P_HMinus, P_HPlus, 2185, check)
      call createCurrent(P_HlQ, P_ghWp, P_G0, P_ghWpAnti, 7579, check)
      call createCurrent(P_WQPlus, P_Hl, P_GQMinus, 52, check)
      call createCurrent(P_GMinus, P_ePlus, P_nu_e, 3353, check)
      call createCurrent(P_G0, P_A, P_GPlus, P_WMinus, 8531, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghZ, P_HPlus, 10353, check)
      call createCurrent(P_Ha, P_HMinus, P_GPlus, P_Hl, 2631, check)
      call createCurrent(P_GPlus, P_G0, P_GMinus, 9585, check)
      call createCurrent(P_HlQ, P_Hh, P_Hh, P_HhQ, 5794, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_HMinus, P_GPlus, 9273, check)
      call createCurrent(P_HMinus, P_ghWmAnti, P_ghA, P_Hh, 6172, check)
      call createCurrent(P_GPlus, P_ghWm, P_Hh, P_ghAAnti, 3386, check)
      call createCurrent(P_ZQ, P_GMinus, P_WPlus, P_GQ0, 2398, check)
      call createCurrent(P_HPlus, P_Hh, P_ghWm, P_ghAAnti, 7652, check)
      call createCurrent(P_GQMinus, P_Hh, P_HPlus, P_GQ0, 3755, check)
      call createCurrent(P_WQPlus, P_HMinus, P_ZQ, 6789, check)
      call createCurrent(P_HQPlus, P_GMinus, P_HlQ, 497, check)
      call createCurrent(P_WQPlus, P_WMinus, P_Hh, P_GQ0, 6120, check)
      call createCurrent(P_cAnti, P_Ha, P_c, 3069, check)
      call createCurrent(P_HQPlus, P_Z, P_Ha, P_WQMinus, 6341, check)
      call createCurrent(P_ghWm, P_G0, P_ghZAnti, P_GPlus, 1603, check)
      call createCurrent(P_t, P_tAnti, P_HhQ, 2046, check)
      call createCurrent(P_HPlus, P_ghWm, P_G0, P_ghZAnti, 8853, check)
      call createCurrent(P_Ha, P_eMinus, P_ePlus, 1583, check)
      call createCurrent(P_Z, P_Ha, 9710, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_GMinus, 7201, check)
      call createCurrent(P_HPlus, P_WMinus, 10376, check)
      call createCurrent(P_GQ0, P_uAnti, P_u, 1551, check)
      call createCurrent(P_GQPlus, P_ghZAnti, P_GMinus, P_ghZ, 1079, check)
      call createCurrent(P_ghWpAnti, P_G0, P_Ha, P_ghWp, 9331, check)
      call createCurrent(P_HlQ, P_GPlus, P_ghZAnti, P_ghWm, 3255, check)
      call createCurrent(P_Ha, P_ghA, P_ghWmAnti, P_GMinus, 8939, check)
      call createCurrent(P_ghWm, P_G0, P_ghZAnti, P_GQPlus, 3735, check)
      call createCurrent(P_ghWp, P_HMinus, P_GPlus, P_ghWpAnti, 9722, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_Z, P_WQPlus, 418, check)
      call createCurrent(P_ZQ, P_Hh, P_GQ0, 1544, check)
      call createCurrent(P_HQPlus, P_WPlus, P_HMinus, P_WQMinus, 5758, check)
      call createCurrent(P_HaQ, P_Hl, P_WPlus, P_WQMinus, 3661, check)
      call createCurrent(P_GMinus, P_Hl, P_HPlus, P_Ha, 1935, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_HaQ, 1357, check)
      call createCurrent(P_HlQ, P_WMinus, P_Z, P_HQPlus, 2837, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghAAnti, P_G0, 4061, check)
      call createCurrent(P_Z, P_Ha, P_G0, P_A, 10605, check)
      call createCurrent(P_dAnti, P_Ha, P_d, 8302, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_Ha, P_HQMinus, 3398, check)
      call createCurrent(P_ghA, P_WMinus, P_WPlus, P_ghZAnti, 4993, check)
      call createCurrent(P_HQMinus, P_WPlus, P_WMinus, P_HQPlus, 7342, check)
      call createCurrent(P_GPlus, P_GMinus, P_HPlus, P_HMinus, 2040, check)
      call createCurrent(P_Ha, P_ghWpAnti, P_GPlus, P_ghZ, 8888, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghZ, P_G0, 678, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_WPlus, P_WQMinus, 5493, check)
      call createCurrent(P_HQPlus, P_Ha, P_WQMinus, 3587, check)
      call createCurrent(P_HaQ, P_Ha, P_G0, P_HaQ, 2463, check)
      call createCurrent(P_ghZ, P_G0, P_HMinus, P_ghWmAnti, 9521, check)
      call createCurrent(P_WPlus, P_A, P_HMinus, 4405, check)
      call createCurrent(P_ghWp, P_GMinus, P_Ha, P_ghZAnti, 9232, check)
      call createCurrent(P_Hl, P_ghA, P_ghWpAnti, P_HPlus, 4294, check)
      call createCurrent(P_u, P_Hl, P_uAnti, 965, check)
      call createCurrent(P_HlQ, P_ghZ, P_HPlus, P_ghWpAnti, 1467, check)
      call createCurrent(P_Hh, P_HPlus, P_Ha, P_GMinus, 1141, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_ghZ, P_WPlus, 7485, check)
      call createCurrent(P_b, P_bAnti, P_A, 3986, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_AQ, 3713, check)
      call createCurrent(P_GPlus, P_G0, P_A, P_WMinus, 3003, check)
      call createCurrent(P_GMinus, P_GPlus, P_Ha, P_Hh, 9321, check)
      call createCurrent(P_Ha, P_G0, P_HPlus, P_GMinus, 6841, check)
      call createCurrent(P_ghZAnti, P_ghA, P_HMinus, P_HQPlus, 401, check)
      call createCurrent(P_GQPlus, P_G0, P_WQMinus, 6488, check)
      call createCurrent(P_GQPlus, P_Ha, P_GMinus, P_HlQ, 8273, check)
      call createCurrent(P_nu_e, P_A, P_nu_eAnti, 9470, check)
      call createCurrent(P_GPlus, P_HMinus, P_ghWp, P_ghWpAnti, 10191, check)
      call createCurrent(P_ghA, P_ghAAnti, P_HMinus, P_HQPlus, 8488, check)
      call createCurrent(P_WPlus, P_Z, P_WMinus, P_Z, 7402, check)
      call createCurrent(P_WQMinus, P_WPlus, P_ghAAnti, P_ghZ, 5296, check)
      call createCurrent(P_G0, P_HMinus, P_ghZ, P_ghWmAnti, 10285, check)
      call createCurrent(P_Ha, P_tauMinus, P_tauPlus, 1173, check)
      call createCurrent(P_A, P_A, P_Hh, P_Hl, 10676, check)
      call createCurrent(P_HQPlus, P_Ha, P_G0, P_GQMinus, 7277, check)
      call createCurrent(P_GMinus, P_HPlus, P_Z, P_Z, 9677, check)
      call createCurrent(P_muMinus, P_Z, P_muPlus, 7900, check)
      call createCurrent(P_HPlus, P_GMinus, P_Hl, P_G0, 1045, check)
      call createCurrent(P_Ha, P_HMinus, P_ghZAnti, P_ghWp, 1570, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_ZQ, 1581, check)
      call createCurrent(P_GQMinus, P_WPlus, P_Z, P_HlQ, 405, check)
      call createCurrent(P_HaQ, P_G0, P_HhQ, 1638, check)
      call createCurrent(P_ZQ, P_WMinus, P_GPlus, P_HhQ, 8641, check)
      call createCurrent(P_GPlus, P_WMinus, P_HMinus, P_WPlus, 8961, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_Hl, P_HPlus, 8476, check)
      call createCurrent(P_GMinus, P_ghA, P_ghWmAnti, P_Hh, 4828, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghZ, 6130, check)
      call createCurrent(P_HQPlus, P_HMinus, P_G0, P_HhQ, 5830, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghZAnti, P_Hh, 1345, check)
      call createCurrent(P_HQPlus, P_ghWm, P_ghZAnti, 3904, check)
      call createCurrent(P_HlQ, P_u, P_uAnti, 4854, check)
      call createCurrent(P_Z, P_ghWpAnti, P_A, P_ghWp, 3861, check)
      call createCurrent(P_A, P_A, P_ghWpAnti, P_ghWp, 6177, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_GPlus, P_GMinus, 5646, check)
      call createCurrent(P_g, P_g, P_g, P_g, 8377, check)
      call createCurrent(P_ghAAnti, P_ghZ, P_WPlus, P_WMinus, 7606, check)
      call createCurrent(P_Z, P_Z, P_A, P_Z, 10726, check)
      call createCurrent(P_ghWpAnti, P_Z, P_ghA, P_WQPlus, 4950, check)
      call createCurrent(P_nu_eAnti, P_eMinus, P_WPlus, 3709, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Hl, P_Hh, 9214, check)
      call createCurrent(P_Ha, P_GMinus, P_ghWmAnti, P_ghA, 9188, check)
      call createCurrent(P_WPlus, P_ghWm, P_ghWpAnti, P_WPlus, 7587, check)
      call createCurrent(P_GQPlus, P_ghWpAnti, P_G0, P_ghA, 3366, check)
      call createCurrent(P_GQ0, P_G0, P_WPlus, P_WQMinus, 4711, check)
      call createCurrent(P_A, P_Hl, P_WPlus, P_HMinus, 2259, check)
      call createCurrent(P_GMinus, P_ghWp, P_ghAAnti, P_Hh, 6424, check)
      call createCurrent(P_ePlus, P_eMinus, P_GQ0, 2250, check)
      call createCurrent(P_HPlus, P_Hl, P_ghA, P_ghWpAnti, 5507, check)
      call createCurrent(P_bAnti, P_t, P_HQMinus, 5284, check)
      call createCurrent(P_GPlus, P_HMinus, P_A, P_A, 10272, check)
      call createCurrent(P_ghA, P_HMinus, P_ghAAnti, P_HQPlus, 6484, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_HMinus, P_HhQ, 3246, check)
      call createCurrent(P_HQMinus, P_WMinus, P_WPlus, P_HQPlus, 3976, check)
      call createCurrent(P_HhQ, P_muPlus, P_muMinus, 3654, check)
      call createCurrent(P_b, P_bAnti, P_Hl, 4139, check)
      call createCurrent(P_GQMinus, P_WPlus, P_Hl, P_AQ, 4554, check)
      call createCurrent(P_GMinus, P_Hl, P_GPlus, P_G0, 10186, check)
      call createCurrent(P_ghWp, P_GMinus, P_Hl, P_ghAAnti, 4496, check)
      call createCurrent(P_HMinus, P_Hh, P_ghZ, P_ghWmAnti, 3874, check)
      call createCurrent(P_gQ, P_s, P_sAnti, 4365, check)
      call createCurrent(P_GQPlus, P_GMinus, P_ZQ, 161, check)
      call createCurrent(P_Hh, P_GMinus, P_WPlus, P_A, 6714, check)
      call createCurrent(P_HPlus, P_ghWm, P_Hh, P_ghZAnti, 3240, check)
      call createCurrent(P_Z, P_WPlus, P_GMinus, P_G0, 5295, check)
      call createCurrent(P_G0, P_G0, P_ghZ, P_ghZAnti, 1617, check)
      call createCurrent(P_ghAAnti, P_Ha, P_ghWp, P_GMinus, 9384, check)
      call createCurrent(P_ghWp, P_WMinus, P_A, P_ghAAnti, 2500, check)
      call createCurrent(P_Hh, P_HPlus, P_GMinus, P_G0, 8315, check)
      call createCurrent(P_G0, P_ghZAnti, P_GMinus, P_ghWp, 530, check)
      call createCurrent(P_WPlus, P_GMinus, P_GPlus, P_WMinus, 1245, check)
      call createCurrent(P_ghAAnti, P_ghA, P_WMinus, P_WQPlus, 8781, check)
      call createCurrent(P_GMinus, P_ghWp, P_ghZAnti, P_Hl, 822, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_WMinus, P_ZQ, 5653, check)
      call createCurrent(P_WQPlus, P_nu_muAnti, P_muMinus, 330, check)
      call createCurrent(P_GPlus, P_HMinus, P_ghWm, P_ghWmAnti, 9827, check)
      call createCurrent(P_ghZAnti, P_Ha, P_HMinus, P_ghWp, 8335, check)
      call createCurrent(P_WQPlus, P_Z, P_WMinus, P_AQ, 2213, check)
      call createCurrent(P_HhQ, P_HMinus, P_Hh, P_GQPlus, 621, check)
      call createCurrent(P_ghA, P_A, P_ghWpAnti, P_WPlus, 504, check)
      call createCurrent(P_WPlus, P_HMinus, P_Z, P_G0, 10010, check)
      call createCurrent(P_HQPlus, P_G0, P_GMinus, P_GQ0, 6758, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_WPlus, P_WMinus, 8233, check)
      call createCurrent(P_HQMinus, P_WPlus, P_Hl, P_AQ, 3776, check)
      call createCurrent(P_ghZAnti, P_HMinus, P_ghWp, P_Ha, 1259, check)
      call createCurrent(P_Ha, P_Hl, P_G0, P_Hl, 3040, check)
      call createCurrent(P_HlQ, P_GPlus, P_HMinus, P_HaQ, 2298, check)
      call createCurrent(P_ePlus, P_nu_e, P_HQMinus, 2513, check)
      call createCurrent(P_Hh, P_ghWpAnti, P_ghWp, 5113, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghWmAnti, P_Hh, 6441, check)
      call createCurrent(P_GQ0, P_ghWpAnti, P_GPlus, P_ghZ, 4219, check)
      call createCurrent(P_Hh, P_HMinus, P_Ha, P_HPlus, 9667, check)
      call createCurrent(P_WQMinus, P_A, P_Z, P_WQPlus, 6363, check)
      call createCurrent(P_ghWmAnti, P_Hl, P_ghWm, 710, check)
      call createCurrent(P_Ha, P_Z, P_GMinus, P_WPlus, 9452, check)
      call createCurrent(P_GMinus, P_HPlus, P_G0, P_Ha, 3133, check)
      call createCurrent(P_Z, P_ghAAnti, P_WPlus, P_ghWm, 5708, check)
      call createCurrent(P_WQMinus, P_Z, P_HPlus, P_HlQ, 7542, check)
      call createCurrent(P_HPlus, P_Hl, P_GMinus, P_Hl, 564, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghAAnti, P_Z, 2821, check)
      call createCurrent(P_G0, P_Hl, P_A, 10478, check)
      call createCurrent(P_HQPlus, P_HMinus, P_GPlus, P_HQMinus, 6411, check)
      call createCurrent(P_A, P_WMinus, P_GPlus, P_Hl, 677, check)
      call createCurrent(P_HMinus, P_GPlus, P_A, 9499, check)
      call createCurrent(P_HQMinus, P_WPlus, P_Hh, P_ZQ, 4274, check)
      call createCurrent(P_ghA, P_WMinus, P_ghWmAnti, P_Z, 4925, check)
      call createCurrent(P_g, P_GMinus, P_HPlus, P_g, 10575, check)
      call createCurrent(P_GMinus, P_Hh, P_GPlus, P_Hl, 6849, check)
      call createCurrent(P_HMinus, P_ghWmAnti, P_Hh, P_ghZ, 6326, check)
      call createCurrent(P_G0, P_Z, P_GMinus, P_WPlus, 6304, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_WPlus, 206, check)
      call createCurrent(P_HMinus, P_Hh, P_HPlus, P_G0, 9171, check)
      call createCurrent(P_AQ, P_Ha, P_WPlus, P_HQMinus, 3863, check)
      call createCurrent(P_ghZ, P_A, P_ghWmAnti, P_WQMinus, 6815, check)
      call createCurrent(P_ghWmAnti, P_A, P_WMinus, P_ghA, 2719, check)
      call createCurrent(P_AQ, P_ghWpAnti, P_ghWp, 5067, check)
      call createCurrent(P_tAnti, P_GPlus, P_b, 7750, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_GMinus, P_Ha, 10248, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_WMinus, P_Z, 8523, check)
      call createCurrent(P_Ha, P_ghWp, P_ghZAnti, P_GMinus, 10224, check)
      call createCurrent(P_Hh, P_Ha, P_GPlus, P_GMinus, 8848, check)
      call createCurrent(P_HPlus, P_G0, P_Z, P_WMinus, 9315, check)
      call createCurrent(P_HQPlus, P_Ha, P_ghZ, P_ghWpAnti, 6689, check)
      call createCurrent(P_Ha, P_G0, P_WPlus, P_WMinus, 9174, check)
      call createCurrent(P_HPlus, P_HMinus, P_Hl, P_Ha, 9127, check)
      call createCurrent(P_ZQ, P_Ha, P_Z, P_HaQ, 4016, check)
      call createCurrent(P_G0, P_G0, P_Ha, P_Ha, 1933, check)
      call createCurrent(P_Z, P_GMinus, P_Ha, P_WPlus, 10318, check)
      call createCurrent(P_ghWmAnti, P_HMinus, P_ghA, P_Hh, 5387, check)
      call createCurrent(P_d, P_Hh, P_dAnti, 5501, check)
      call createCurrent(P_WQPlus, P_HMinus, P_A, P_HaQ, 5037, check)
      call createCurrent(P_Ha, P_cAnti, P_c, 420, check)
      call createCurrent(P_HQPlus, P_G0, P_G0, P_HQMinus, 3090, check)
      call createCurrent(P_HlQ, P_HPlus, P_ghWpAnti, P_ghZ, 8700, check)
      call createCurrent(P_Ha, P_ghZ, P_ghWmAnti, P_HMinus, 2071, check)
      call createCurrent(P_HPlus, P_Hl, P_WMinus, P_Z, 2433, check)
      call createCurrent(P_HlQ, P_Ha, P_Hl, P_GQ0, 5692, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_HPlus, P_ghZ, 10056, check)
      call createCurrent(P_HMinus, P_Z, P_A, P_HPlus, 4840, check)
      call createCurrent(P_muPlus, P_G0, P_muMinus, 3008, check)
      call createCurrent(P_HPlus, P_G0, P_HMinus, P_Ha, 6229, check)
      call createCurrent(P_nu_eAnti, P_A, P_nu_e, 9409, check)
      call createCurrent(P_Hl, P_Hl, P_WMinus, P_WPlus, 8705, check)
      call createCurrent(P_HQPlus, P_GPlus, P_HMinus, P_GQMinus, 2556, check)
      call createCurrent(P_AQ, P_WMinus, P_ghZAnti, P_ghWp, 6012, check)
      call createCurrent(P_A, P_GPlus, P_Z, P_GMinus, 2713, check)
      call createCurrent(P_HMinus, P_GPlus, P_Hh, P_G0, 6715, check)
      call createCurrent(P_Z, P_ghWmAnti, P_Z, P_ghWm, 2452, check)
      call createCurrent(P_HlQ, P_GPlus, P_A, P_WQMinus, 7956, check)
      call createCurrent(P_Hh, P_GPlus, P_ghA, P_ghWpAnti, 5864, check)
      call createCurrent(P_ghZAnti, P_A, P_WPlus, P_ghWm, 6187, check)
      call createCurrent(P_muMinus, P_HPlus, P_nu_muAnti, 6554, check)
      call createCurrent(P_GMinus, P_Hh, P_HPlus, 5439, check)
      call createCurrent(P_G0, P_HMinus, P_GPlus, P_Ha, 3082, check)
      call createCurrent(P_ghWm, P_WMinus, P_ghWmAnti, P_WPlus, 4552, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_Hh, P_HPlus, 3410, check)
      call createCurrent(P_ghZAnti, P_Hl, P_ghWp, P_HMinus, 1160, check)
      call createCurrent(P_Ha, P_muMinus, P_muPlus, 6667, check)
      call createCurrent(P_Hh, P_GMinus, P_ghWp, P_ghZAnti, 5958, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_ghWp, 787, check)
      call createCurrent(P_s, P_cAnti, P_WQPlus, 3869, check)
      call createCurrent(P_Hh, P_HPlus, P_ghZ, P_ghWpAnti, 3196, check)
      call createCurrent(P_ghA, P_HPlus, P_Ha, P_ghWpAnti, 4795, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_GMinus, P_HhQ, 6060, check)
      call createCurrent(P_Hl, P_Hl, P_HMinus, P_GPlus, 5312, check)
      call createCurrent(P_WQMinus, P_A, P_HPlus, P_HaQ, 4639, check)
      call createCurrent(P_GMinus, P_nu_e, P_ePlus, 5793, check)
      call createCurrent(P_HQMinus, P_HPlus, P_HPlus, P_HQMinus, 7989, check)
      call createCurrent(P_ghZAnti, P_HMinus, P_ghZ, P_HPlus, 4878, check)
      call createCurrent(P_G0, P_A, P_A, P_Ha, 10592, check)
      call createCurrent(P_WMinus, P_ePlus, P_nu_e, 1359, check)
      call createCurrent(P_WPlus, P_G0, P_WMinus, P_G0, 5826, check)
      call createCurrent(P_GQPlus, P_WMinus, P_ZQ, 1495, check)
      call createCurrent(P_GPlus, P_HMinus, P_GPlus, P_GMinus, 768, check)
      call createCurrent(P_HQPlus, P_ghA, P_ghWpAnti, 7588, check)
      call createCurrent(P_HMinus, P_A, P_GPlus, 9146, check)
      call createCurrent(P_G0, P_ghWp, P_ghWpAnti, P_Ha, 9937, check)
      call createCurrent(P_HaQ, P_Hh, P_HMinus, P_HQPlus, 6280, check)
      call createCurrent(P_HaQ, P_Z, P_WMinus, P_HQPlus, 579, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghZ, P_GQ0, 6247, check)
      call createCurrent(P_WMinus, P_Z, P_ghWmAnti, P_ghA, 5495, check)
      call createCurrent(P_GPlus, P_WMinus, P_A, P_Hl, 5385, check)
      call createCurrent(P_HQPlus, P_HMinus, P_Hh, P_GQ0, 8465, check)
      call createCurrent(P_Ha, P_HPlus, P_ghWpAnti, P_ghA, 5138, check)
      call createCurrent(P_cAnti, P_GPlus, P_s, 6466, check)
      call createCurrent(P_HaQ, P_GMinus, P_GPlus, P_GQ0, 1465, check)
      call createCurrent(P_GMinus, P_HPlus, P_ghWp, P_ghWpAnti, 9461, check)
      call createCurrent(P_HlQ, P_WPlus, P_Z, P_GQMinus, 4813, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_WPlus, P_Z, 1251, check)
      call createCurrent(P_Hl, P_ghWp, P_HMinus, P_ghZAnti, 2085, check)
      call createCurrent(P_ghWpAnti, P_A, P_WPlus, P_ghA, 7462, check)
      call createCurrent(P_AQ, P_WMinus, P_WPlus, P_ZQ, 7394, check)
      call createCurrent(P_muPlus, P_nu_mu, P_GMinus, 3909, check)
      call createCurrent(P_AQ, P_WPlus, P_Hh, P_GQMinus, 848, check)
      call createCurrent(P_GPlus, P_ghZ, P_HMinus, P_ghAAnti, 8911, check)
      call createCurrent(P_HQPlus, P_A, P_A, P_HQMinus, 83, check)
      call createCurrent(P_WMinus, P_ghZ, P_ghWmAnti, P_Z, 1415, check)
      call createCurrent(P_Hh, P_Hh, 10242, check)
      call createCurrent(P_ghWp, P_WMinus, P_A, P_ghZAnti, 7624, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_Z, P_WMinus, 3113, check)
      call createCurrent(P_AQ, P_Hl, P_WMinus, P_HQPlus, 7649, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_WMinus, P_Z, 2242, check)
      call createCurrent(P_Ha, P_ghWm, P_ghZAnti, P_HPlus, 2829, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Hh, 4292, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_WMinus, P_ghWp, 107, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_GPlus, P_Hh, 2881, check)
      call createCurrent(P_Z, P_Ha, P_WMinus, P_GPlus, 9063, check)
      call createCurrent(P_GQPlus, P_Hh, P_WMinus, P_AQ, 5599, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_Z, 1728, check)
      call createCurrent(P_b, P_bAnti, P_g, 697, check)
      call createCurrent(P_ghZAnti, P_ghA, P_WMinus, P_WQPlus, 615, check)
      call createCurrent(P_Hl, P_HPlus, P_Hh, P_HMinus, 2169, check)
      call createCurrent(P_ghWpAnti, P_G0, P_ghA, P_HPlus, 10477, check)
      call createCurrent(P_HPlus, P_Ha, P_ghA, P_ghWpAnti, 5300, check)
      call createCurrent(P_nu_mu, P_WMinus, P_muPlus, 7096, check)
      call createCurrent(P_GQMinus, P_HPlus, P_Ha, P_HlQ, 7070, check)
      call createCurrent(P_WQPlus, P_WMinus, P_ghZAnti, P_ghZ, 6360, check)
      call createCurrent(P_G0, P_GMinus, P_ghAAnti, P_ghWp, 7455, check)
      call createCurrent(P_A, P_A, P_WMinus, P_WPlus, 4801, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_Hl, P_ghWm, 6161, check)
      call createCurrent(P_Hh, P_ghWmAnti, P_ghZ, P_HMinus, 5997, check)
      call createCurrent(P_Hh, P_HPlus, P_ghA, P_ghWpAnti, 7414, check)
      call createCurrent(P_HlQ, P_HPlus, P_A, P_WQMinus, 5989, check)
      call createCurrent(P_GMinus, P_G0, P_ghWmAnti, P_ghA, 3030, check)
      call createCurrent(P_A, P_WPlus, P_Hl, P_GMinus, 8043, check)
      call createCurrent(P_HQPlus, P_HMinus, P_ghA, P_ghAAnti, 7408, check)
      call createCurrent(P_HlQ, P_Z, P_WMinus, P_HQPlus, 89, check)
      call createCurrent(P_HQMinus, P_Ha, P_GPlus, P_HhQ, 6519, check)
      call createCurrent(P_ghWm, P_WPlus, P_Z, P_ghZAnti, 2598, check)
      call createCurrent(P_GMinus, P_ghZ, P_ghZAnti, P_HPlus, 9153, check)
      call createCurrent(P_HaQ, P_ghWm, P_HPlus, P_ghAAnti, 3337, check)
      call createCurrent(P_Hh, P_GMinus, P_ghZ, P_ghWmAnti, 8829, check)
      call createCurrent(P_HQPlus, P_WMinus, P_Hh, P_AQ, 7593, check)
      call createCurrent(P_Hl, P_HPlus, P_ghAAnti, P_ghWm, 8126, check)
      call createCurrent(P_HQPlus, P_Hh, P_Z, P_WQMinus, 3384, check)
      call createCurrent(P_HhQ, P_Ha, P_HPlus, P_HQMinus, 3117, check)
      call createCurrent(P_Hh, P_G0, P_Ha, P_Hh, 6128, check)
      call createCurrent(P_ghZAnti, P_HMinus, P_Hh, P_ghWp, 7338, check)
      call createCurrent(P_HlQ, P_G0, P_Hh, P_GQ0, 4053, check)
      call createCurrent(P_Hl, P_GMinus, P_HPlus, P_Hl, 5174, check)
      call createCurrent(P_GQPlus, P_Ha, P_Hl, P_HQMinus, 1243, check)
      call createCurrent(P_HQMinus, P_ghZAnti, P_ghWp, 116, check)
      call createCurrent(P_b, P_tAnti, P_WQPlus, 4664, check)
      call createCurrent(P_ghWmAnti, P_G0, P_GMinus, P_ghZ, 3470, check)
      call createCurrent(P_HQMinus, P_Z, P_A, P_HQPlus, 222, check)
      call createCurrent(P_WPlus, P_Z, P_Hh, P_GMinus, 5051, check)
      call createCurrent(P_HQMinus, P_Hl, P_Hh, P_GQPlus, 1512, check)
      call createCurrent(P_HQMinus, P_nu_tau, P_tauPlus, 7657, check)
      call createCurrent(P_ZQ, P_GPlus, P_GQMinus, 34, check)
      call createCurrent(P_A, P_WMinus, P_Hl, P_HPlus, 7539, check)
      call createCurrent(P_GQ0, P_u, P_uAnti, 1174, check)
      call createCurrent(P_ghA, P_Hl, P_HPlus, P_ghWpAnti, 1980, check)
      call createCurrent(P_ghAAnti, P_ghZ, P_WMinus, P_WQPlus, 8796, check)
      call createCurrent(P_G0, P_ghWmAnti, P_G0, P_ghWm, 3128, check)
      call createCurrent(P_HhQ, P_ghWmAnti, P_ghWm, 5946, check)
      call createCurrent(P_ghZ, P_ghAAnti, P_WMinus, P_WPlus, 4512, check)
      call createCurrent(P_HaQ, P_WPlus, P_WQMinus, 7478, check)
      call createCurrent(P_WPlus, P_Hh, P_GMinus, P_A, 2252, check)
      call createCurrent(P_GPlus, P_WMinus, 9163, check)
      call createCurrent(P_Ha, P_ghWpAnti, P_HPlus, P_ghZ, 8104, check)
      call createCurrent(P_ghZAnti, P_HMinus, P_ghWp, P_HhQ, 8285, check)
      call createCurrent(P_WQMinus, P_WMinus, P_WPlus, P_WQPlus, 5327, check)
      call createCurrent(P_Hh, P_Hl, P_ghWm, P_ghWmAnti, 10175, check)
      call createCurrent(P_GMinus, P_ghZ, P_G0, P_ghWmAnti, 6821, check)
      call createCurrent(P_tauMinus, P_GPlus, P_nu_tauAnti, 1561, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_GPlus, P_HlQ, 2764, check)
      call createCurrent(P_ghZAnti, P_HPlus, P_ghWm, P_HhQ, 6020, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_Hh, P_HPlus, 3902, check)
      call createCurrent(P_A, P_Hl, P_WMinus, P_GPlus, 2311, check)
      call createCurrent(P_GMinus, P_Ha, P_ghZAnti, P_ghWp, 9921, check)
      call createCurrent(P_s, P_sAnti, 9580, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_Hh, P_GPlus, 7146, check)
      call createCurrent(P_ghZ, P_HPlus, P_ghWpAnti, P_Hl, 8264, check)
      call createCurrent(P_GQ0, P_ghWm, P_ghWmAnti, 953, check)
      call createCurrent(P_ghWm, P_GMinus, P_GPlus, P_ghWmAnti, 6414, check)
      call createCurrent(P_HQPlus, P_ghWmAnti, P_HMinus, P_ghWm, 1564, check)
      call createCurrent(P_GMinus, P_GPlus, P_Z, P_Z, 12, check)
      call createCurrent(P_bAnti, P_A, P_b, 7298, check)
      call createCurrent(P_Ha, P_Hh, P_Hh, P_Ha, 680, check)
      call createCurrent(P_Hl, P_Ha, P_Hl, P_G0, 3332, check)
      call createCurrent(P_GMinus, P_Hl, P_HPlus, P_G0, 7128, check)
      call createCurrent(P_Ha, P_ghZ, P_G0, P_ghZAnti, 9867, check)
      call createCurrent(P_Ha, P_ghWp, P_G0, P_ghWpAnti, 9226, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_A, P_ZQ, 6646, check)
      call createCurrent(P_Ha, P_ghZ, P_GMinus, P_ghWmAnti, 9704, check)
      call createCurrent(P_Z, P_G0, P_A, P_Ha, 10588, check)
      call createCurrent(P_Hh, P_ghWm, P_ghWmAnti, 466, check)
      call createCurrent(P_G0, P_ghWm, P_GPlus, P_ghAAnti, 1611, check)
      call createCurrent(P_Z, P_ghZAnti, P_ghWm, P_WPlus, 6357, check)
      call createCurrent(P_GMinus, P_HPlus, 10290, check)
      call createCurrent(P_WPlus, P_Hl, P_Hh, P_WMinus, 9330, check)
      call createCurrent(P_bAnti, P_t, P_GMinus, 3324, check)
      call createCurrent(P_GMinus, P_Ha, P_HPlus, P_Hh, 2876, check)
      call createCurrent(P_WQPlus, P_Z, P_ghWpAnti, P_ghA, 3059, check)
      call createCurrent(P_G0, P_GPlus, P_ghZ, P_ghWpAnti, 928, check)
      call createCurrent(P_GQPlus, P_Hl, P_GMinus, P_HaQ, 6297, check)
      call createCurrent(P_HaQ, P_Ha, P_Hl, P_HhQ, 4158, check)
      call createCurrent(P_G0, P_ghWmAnti, P_Ha, P_ghWm, 9350, check)
      call createCurrent(P_HhQ, P_WPlus, P_Hh, P_WQMinus, 1602, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_WPlus, P_ghA, 6782, check)
      call createCurrent(P_HhQ, P_ghZAnti, P_GMinus, P_ghWp, 1545, check)
      call createCurrent(P_ghA, P_ghZAnti, P_WPlus, P_WQMinus, 2684, check)
      call createCurrent(P_A, P_ghWpAnti, P_ghA, P_WPlus, 8087, check)
      call createCurrent(P_HQPlus, P_Hh, P_Hl, P_HQMinus, 6193, check)
      call createCurrent(P_HaQ, P_Ha, P_GPlus, P_HQMinus, 7851, check)
      call createCurrent(P_HMinus, P_A, P_WPlus, P_Ha, 1117, check)
      call createCurrent(P_G0, P_GMinus, P_WPlus, 7854, check)
      call createCurrent(P_GPlus, P_HMinus, P_Hl, P_G0, 5905, check)
      call createCurrent(P_muMinus, P_nu_muAnti, P_GQPlus, 3764, check)
      call createCurrent(P_A, P_GPlus, P_Hh, P_WMinus, 1265, check)
      call createCurrent(P_GQMinus, P_GPlus, P_Ha, P_HaQ, 5534, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_G0, P_HMinus, 9072, check)
      call createCurrent(P_GMinus, P_WPlus, P_Hh, P_A, 5500, check)
      call createCurrent(P_sAnti, P_GMinus, P_c, 1411, check)
      call createCurrent(P_Hl, P_sAnti, P_s, 6765, check)
      call createCurrent(P_Ha, P_WMinus, P_WPlus, P_G0, 10184, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_WMinus, P_ZQ, 3039, check)
      call createCurrent(P_HMinus, P_ghWp, P_ghZAnti, P_Hl, 2106, check)
      call createCurrent(P_WMinus, P_Hl, P_GPlus, P_A, 3100, check)
      call createCurrent(P_WPlus, P_Z, P_G0, P_HMinus, 9274, check)
      call createCurrent(P_Ha, P_G0, P_Hh, P_Hl, 3522, check)
      call createCurrent(P_WQPlus, P_Hl, P_WMinus, P_HaQ, 7702, check)
      call createCurrent(P_Hl, P_WMinus, P_Hl, P_WPlus, 6717, check)
      call createCurrent(P_ghA, P_HPlus, P_ghWpAnti, P_Ha, 6359, check)
      call createCurrent(P_GPlus, P_Z, P_A, P_HMinus, 9189, check)
      call createCurrent(P_GPlus, P_Hl, P_Ha, P_GMinus, 9054, check)
      call createCurrent(P_Z, P_Z, P_ghWmAnti, P_ghWm, 5642, check)
      call createCurrent(P_GPlus, P_g, P_g, P_GMinus, 10647, check)
      call createCurrent(P_HQPlus, P_muMinus, P_nu_muAnti, 8506, check)
      call createCurrent(P_ghAAnti, P_HMinus, P_Hl, P_ghWp, 4559, check)
      call createCurrent(P_GMinus, P_Hl, P_GPlus, 3441, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_GPlus, P_GMinus, 8195, check)
      call createCurrent(P_HaQ, P_ghWp, P_ghWpAnti, 129, check)
      call createCurrent(P_WQMinus, P_GPlus, P_Z, P_HlQ, 4456, check)
      call createCurrent(P_HPlus, P_Hl, P_ghAAnti, P_ghWm, 5825, check)
      call createCurrent(P_Hh, P_HPlus, P_Hl, P_GMinus, 7308, check)
      call createCurrent(P_GQPlus, P_ghZ, P_GMinus, P_ghZAnti, 8787, check)
      call createCurrent(P_Hl, P_Hl, P_GMinus, P_GPlus, 7133, check)
      call createCurrent(P_HhQ, P_Hl, P_HMinus, P_HQPlus, 95, check)
      call createCurrent(P_GQ0, P_Ha, P_HMinus, P_GQPlus, 734, check)
      call createCurrent(P_Z, P_WMinus, P_Hl, P_HPlus, 2594, check)
      call createCurrent(P_Hl, P_A, P_Z, P_Hh, 10718, check)
      call createCurrent(P_muPlus, P_nu_mu, P_HQMinus, 1957, check)
      call createCurrent(P_HMinus, P_ghWmAnti, P_Hl, P_ghA, 1194, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_G0, P_GPlus, 5657, check)
      call createCurrent(P_Hl, P_GPlus, P_G0, P_HMinus, 1921, check)
      call createCurrent(P_GQMinus, P_WPlus, P_GQ0, 7454, check)
      call createCurrent(P_ghAAnti, P_Ha, P_HPlus, P_ghWm, 947, check)
      call createCurrent(P_Hl, P_HPlus, P_Hl, P_HMinus, 5288, check)
      call createCurrent(P_dAnti, P_d, P_HlQ, 8708, check)
      call createCurrent(P_Hh, P_WPlus, P_WMinus, P_Hh, 3933, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_GPlus, P_Ha, 9774, check)
      call createCurrent(P_GPlus, P_G0, P_ghA, P_ghWpAnti, 1669, check)
      call createCurrent(P_A, P_GPlus, P_G0, P_WMinus, 7889, check)
      call createCurrent(P_Hl, P_HMinus, P_ghA, P_ghWmAnti, 7024, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_WPlus, P_A, 6372, check)
      call createCurrent(P_HaQ, P_GMinus, P_Ha, P_HQPlus, 7708, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_GPlus, 1936, check)
      call createCurrent(P_HPlus, P_ghZAnti, P_ghWm, 5287, check)
      call createCurrent(P_A, P_Ha, P_WPlus, P_GMinus, 10300, check)
      call createCurrent(P_A, P_G0, P_WMinus, P_HPlus, 10000, check)
      call createCurrent(P_d, P_dAnti, P_AQ, 6469, check)
      call createCurrent(P_WQPlus, P_ghAAnti, P_ghWm, 3847, check)
      call createCurrent(P_HlQ, P_Hl, P_GPlus, P_GQMinus, 1711, check)
      call createCurrent(P_GPlus, P_Ha, P_A, P_WMinus, 9078, check)
      call createCurrent(P_WPlus, P_WMinus, P_Hh, P_Hl, 10255, check)
      call createCurrent(P_HQMinus, P_GPlus, P_HhQ, 8279, check)
      call createCurrent(P_HaQ, P_WMinus, P_Hl, P_WQPlus, 6826, check)
      call createCurrent(P_HQPlus, P_HPlus, P_HMinus, P_HQMinus, 4460, check)
      call createCurrent(P_WQMinus, P_A, P_WPlus, P_AQ, 4006, check)
      call createCurrent(P_HhQ, P_Hh, P_ghWm, P_ghWmAnti, 7168, check)
      call createCurrent(P_GMinus, P_HPlus, P_G0, 3163, check)
      call createCurrent(P_GQPlus, P_Ha, P_Hh, P_HQMinus, 1446, check)
      call createCurrent(P_Hh, P_Ha, P_HPlus, P_HMinus, 10423, check)
      call createCurrent(P_HPlus, P_GMinus, P_Hl, P_Hh, 6802, check)
      call createCurrent(P_G0, P_G0, P_ghZAnti, P_ghZ, 984, check)
      call createCurrent(P_HhQ, P_ghWmAnti, P_Ha, P_ghWm, 7665, check)
      call createCurrent(P_HPlus, P_ghA, P_HMinus, P_ghZAnti, 764, check)
      call createCurrent(P_GQ0, P_dAnti, P_d, 4519, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_A, P_ghZ, 8752, check)
      call createCurrent(P_GQ0, P_HPlus, P_GMinus, P_GQ0, 7709, check)
      call createCurrent(P_Ha, P_u, P_uAnti, 6248, check)
      call createCurrent(P_ghZAnti, P_HPlus, P_ghZ, P_GMinus, 8998, check)
      call createCurrent(P_HPlus, P_Ha, P_ghWm, P_ghZAnti, 2817, check)
      call createCurrent(P_ghZ, P_Hh, P_GPlus, P_ghWpAnti, 676, check)
      call createCurrent(P_GQPlus, P_HMinus, P_Ha, P_HhQ, 172, check)
      call createCurrent(P_GQ0, P_Ha, P_HPlus, P_GQMinus, 7463, check)
      call createCurrent(P_ghZAnti, P_ghA, P_HMinus, P_HPlus, 5394, check)
      call createCurrent(P_HMinus, P_Ha, P_WPlus, P_A, 2857, check)
      call createCurrent(P_G0, P_GMinus, P_GPlus, P_Hl, 9956, check)
      call createCurrent(P_G0, P_ghZ, P_G0, P_ghZAnti, 7580, check)
      call createCurrent(P_G0, P_GPlus, P_GMinus, P_Ha, 3481, check)
      call createCurrent(P_Z, P_A, P_HMinus, P_HPlus, 8158, check)
      call createCurrent(P_GMinus, P_HPlus, P_GMinus, P_GPlus, 7703, check)
      call createCurrent(P_WMinus, P_A, P_ghWmAnti, P_ghZ, 1859, check)
      call createCurrent(P_G0, P_ghWp, P_HMinus, P_ghZAnti, 9650, check)
      call createCurrent(P_HhQ, P_ghAAnti, P_GMinus, P_ghWp, 7187, check)
      call createCurrent(P_Z, P_Hh, P_Z, P_Hl, 9403, check)
      call createCurrent(P_HlQ, P_muPlus, P_muMinus, 6800, check)
      call createCurrent(P_ghA, P_Ha, P_HPlus, P_ghWpAnti, 3250, check)
      call createCurrent(P_GQMinus, P_ghA, P_Hh, P_ghWmAnti, 7563, check)
      call createCurrent(P_Z, P_HPlus, P_Z, P_HMinus, 3392, check)
      call createCurrent(P_ghZ, P_G0, P_ghWpAnti, P_HPlus, 10115, check)
      call createCurrent(P_HlQ, P_Z, P_GMinus, P_WQPlus, 1882, check)
      call createCurrent(P_Ha, P_HMinus, P_A, P_WPlus, 4810, check)
      call createCurrent(P_Hl, P_HPlus, P_Hh, P_GMinus, 7259, check)
      call createCurrent(P_tauPlus, P_nu_tau, P_HMinus, 6162, check)
      call createCurrent(P_HPlus, P_Z, P_WMinus, P_Hh, 1087, check)
      call createCurrent(P_HhQ, P_Hl, P_HMinus, P_GQPlus, 8045, check)
      call createCurrent(P_Hh, P_HPlus, P_WMinus, P_A, 6024, check)
      call createCurrent(P_Hh, P_GPlus, P_WMinus, 5658, check)
      call createCurrent(P_A, P_A, P_HPlus, P_GMinus, 9345, check)
      call createCurrent(P_GQ0, P_Hl, P_GPlus, P_HQMinus, 6398, check)
      call createCurrent(P_Hh, P_HMinus, P_G0, P_HPlus, 9446, check)
      call createCurrent(P_WMinus, P_GPlus, 9960, check)
      call createCurrent(P_G0, P_g, P_Ha, P_g, 10733, check)
      call createCurrent(P_Ha, P_WPlus, P_GMinus, P_Z, 9151, check)
      call createCurrent(P_G0, P_HMinus, P_WPlus, 9687, check)
      call createCurrent(P_ghZ, P_Z, P_WMinus, P_ghWmAnti, 4592, check)
      call createCurrent(P_Hl, P_Hh, P_HMinus, P_HPlus, 3108, check)
      call createCurrent(P_ghZ, P_Hh, P_ghZAnti, P_Hh, 0, check)
      call createCurrent(P_WPlus, P_WMinus, P_HMinus, P_GPlus, 9445, check)
      call createCurrent(P_Ha, P_HPlus, P_Ha, P_HMinus, 5450, check)
      call createCurrent(P_GPlus, P_GMinus, P_Ha, P_Hl, 10270, check)
      call createCurrent(P_GMinus, P_ghZ, P_ghZAnti, P_GPlus, 7450, check)
      call createCurrent(P_ZQ, P_Z, P_GMinus, P_GQPlus, 1766, check)
      call createCurrent(P_HlQ, P_G0, P_GPlus, P_HQMinus, 957, check)
      call createCurrent(P_HQPlus, P_HMinus, P_ghA, P_ghZAnti, 2302, check)
      call createCurrent(P_u, P_uAnti, P_gQ, 6535, check)
      call createCurrent(P_G0, P_A, 10074, check)
      call createCurrent(P_HPlus, P_Hh, P_ghZAnti, P_ghWm, 2503, check)
      call createCurrent(P_GPlus, P_HMinus, P_ghZAnti, P_ghA, 10314, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghZ, P_Hl, 3357, check)
      call createCurrent(P_HQPlus, P_G0, P_GQMinus, 2064, check)
      call createCurrent(P_HPlus, P_G0, P_HMinus, 9534, check)
      call createCurrent(P_HaQ, P_GPlus, P_GMinus, P_GQ0, 4960, check)
      call createCurrent(P_HlQ, P_ghWm, P_Hl, P_ghWmAnti, 6259, check)
      call createCurrent(P_HPlus, P_GMinus, P_HPlus, P_GMinus, 4662, check)
      call createCurrent(P_Hl, P_A, P_WMinus, P_HPlus, 3584, check)
      call createCurrent(P_ePlus, P_nu_e, P_WQMinus, 3037, check)
      call createCurrent(P_GMinus, P_ghWp, P_Hl, P_ghZAnti, 4779, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_Z, P_WPlus, 726, check)
      call createCurrent(P_HhQ, P_Hl, P_G0, P_HaQ, 8313, check)
      call createCurrent(P_ghWp, P_Ha, P_ghZAnti, P_HQMinus, 7899, check)
      call createCurrent(P_ghWm, P_Hh, P_ghZAnti, P_HPlus, 751, check)
      call createCurrent(P_GPlus, P_HMinus, P_ghAAnti, P_ghA, 9268, check)
      call createCurrent(P_muMinus, P_muPlus, P_HhQ, 2136, check)
      call createCurrent(P_HMinus, P_ghWp, P_Hl, P_ghZAnti, 8456, check)
      call createCurrent(P_WMinus, P_HMinus, P_WPlus, P_GPlus, 9385, check)
      call createCurrent(P_ghZAnti, P_HPlus, P_ghWm, P_Hl, 1349, check)
      call createCurrent(P_ghWp, P_Ha, P_GMinus, P_ghAAnti, 9218, check)
      call createCurrent(P_A, P_Hh, P_A, P_Hl, 10610, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghWp, P_G0, 8153, check)
      call createCurrent(P_nu_mu, P_muPlus, P_GMinus, 872, check)
      call createCurrent(P_Ha, P_ghZAnti, P_ghZ, P_G0, 9857, check)
      call createCurrent(P_WQPlus, P_GMinus, P_Hl, P_AQ, 7082, check)
      call createCurrent(P_Hh, P_Ha, P_Hh, P_Hh, 10742, check)
      call createCurrent(P_WMinus, P_HPlus, P_Z, P_Ha, 1328, check)
      call createCurrent(P_Hl, P_Z, P_A, 9771, check)
      call createCurrent(P_ZQ, P_A, P_WMinus, P_WQPlus, 3977, check)
      call createCurrent(P_g, P_GMinus, P_g, P_GPlus, 10494, check)
      call createCurrent(P_HaQ, P_Ha, P_Ha, P_GQ0, 1051, check)
      call createCurrent(P_HlQ, P_ghWmAnti, P_GMinus, P_ghZ, 8358, check)
      call createCurrent(P_GMinus, P_Z, P_HPlus, P_A, 9465, check)
      call createCurrent(P_HMinus, P_ghAAnti, P_ghA, P_HPlus, 1877, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_HlQ, 1947, check)
      call createCurrent(P_HQMinus, P_ghWp, P_ghZAnti, 1690, check)
      call createCurrent(P_Hh, P_A, P_A, 10514, check)
      call createCurrent(P_ghAAnti, P_Hl, P_GPlus, P_ghWm, 7224, check)
      call createCurrent(P_bAnti, P_Hh, P_b, 5829, check)
      call createCurrent(P_A, P_A, P_Hh, 10656, check)
      call createCurrent(P_ghAAnti, P_A, P_WPlus, P_ghWm, 5122, check)
      call createCurrent(P_cAnti, P_c, P_Ha, 1279, check)
      call createCurrent(P_HPlus, P_HMinus, P_Ha, P_Hl, 9843, check)
      call createCurrent(P_HaQ, P_WMinus, P_Hh, P_WQPlus, 1876, check)
      call createCurrent(P_WPlus, P_ghWm, P_ghAAnti, P_Z, 7378, check)
      call createCurrent(P_ghWp, P_Hl, P_HMinus, P_ghAAnti, 6147, check)
      call createCurrent(P_ghWpAnti, P_Ha, P_ghWp, P_HlQ, 6071, check)
      call createCurrent(P_HaQ, P_GMinus, P_HPlus, P_GQ0, 3781, check)
      call createCurrent(P_HhQ, P_Ha, P_HMinus, P_GQPlus, 5033, check)
      call createCurrent(P_Hl, P_Hh, P_WPlus, P_WMinus, 9879, check)
      call createCurrent(P_WQPlus, P_G0, P_WMinus, P_GQ0, 5652, check)
      call createCurrent(P_HMinus, P_ghZ, P_G0, P_ghWmAnti, 9185, check)
      call createCurrent(P_G0, P_ghWmAnti, P_ghWm, P_G0, 5246, check)
      call createCurrent(P_A, P_GPlus, P_HMinus, 9250, check)
      call createCurrent(P_Hl, P_ghWmAnti, P_GMinus, P_ghZ, 8038, check)
      call createCurrent(P_ghWmAnti, P_G0, P_Ha, P_ghWm, 10071, check)
      call createCurrent(P_Hl, P_GPlus, P_WMinus, 3223, check)
      call createCurrent(P_ghWm, P_HPlus, P_ghAAnti, P_G0, 9024, check)
      call createCurrent(P_GMinus, P_ghAAnti, P_Hl, P_ghWp, 1960, check)
      call createCurrent(P_d, P_uAnti, P_HQPlus, 566, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Z, P_ZQ, 2479, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_A, P_WPlus, 5475, check)
      call createCurrent(P_A, P_ghAAnti, P_ghWp, P_WMinus, 3951, check)
      call createCurrent(P_ghA, P_Hl, P_ghWmAnti, P_HQMinus, 1318, check)
      call createCurrent(P_ghWp, P_Hh, P_ghWpAnti, P_GQ0, 6605, check)
      call createCurrent(P_ghWm, P_A, P_ghWmAnti, 7578, check)
      call createCurrent(P_WPlus, P_HMinus, P_A, P_G0, 9842, check)
      call createCurrent(P_tAnti, P_t, 9765, check)
      call createCurrent(P_ghWp, P_HMinus, P_ghAAnti, P_HaQ, 6417, check)
      call createCurrent(P_GQMinus, P_G0, P_ghA, P_ghWmAnti, 7491, check)
      call createCurrent(P_A, P_Hl, P_Z, 9059, check)
      call createCurrent(P_Z, P_Ha, P_Ha, P_A, 8879, check)
      call createCurrent(P_WMinus, P_ghZ, P_ghAAnti, P_WPlus, 4829, check)
      call createCurrent(P_ghWm, P_Ha, P_HPlus, P_ghZAnti, 4511, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_Z, P_ghWp, 4385, check)
      call createCurrent(P_ghWp, P_Z, P_WMinus, P_ghAAnti, 1783, check)
      call createCurrent(P_Hh, P_GPlus, P_ghWm, P_ghAAnti, 8817, check)
      call createCurrent(P_A, P_WPlus, P_HMinus, P_Ha, 5623, check)
      call createCurrent(P_HaQ, P_HMinus, P_GPlus, P_HaQ, 3842, check)
      call createCurrent(P_G0, P_ghZ, P_GPlus, P_ghWpAnti, 4276, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghAAnti, 8573, check)
      call createCurrent(P_g, P_sAnti, P_s, 5927, check)
      call createCurrent(P_HQPlus, P_Ha, P_GMinus, P_HhQ, 6952, check)
      call createCurrent(P_Z, P_Hl, P_WPlus, P_HMinus, 4599, check)
      call createCurrent(P_HQMinus, P_WPlus, P_A, P_HlQ, 8068, check)
      call createCurrent(P_Z, P_HMinus, P_HPlus, P_Z, 3106, check)
      call createCurrent(P_WMinus, P_WPlus, P_ghA, P_ghAAnti, 1588, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_ghWm, P_Z, 4838, check)
      call createCurrent(P_GPlus, P_WMinus, P_A, P_Hh, 394, check)
      call createCurrent(P_A, P_GMinus, P_WPlus, P_Hh, 8101, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_Z, P_WPlus, 1180, check)
      call createCurrent(P_WMinus, P_Hh, P_A, P_HPlus, 7437, check)
      call createCurrent(P_ghZAnti, P_Hl, P_ghWp, P_HQMinus, 940, check)
      call createCurrent(P_Hh, P_ghZ, P_ghZAnti, P_Hl, 9340, check)
      call createCurrent(P_WPlus, P_Z, P_WMinus, 2084, check)
      call createCurrent(P_GMinus, P_Hl, P_Hh, P_HPlus, 1105, check)
      call createCurrent(P_HhQ, P_Hh, P_HPlus, P_HQMinus, 5242, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_HMinus, P_Hh, 5100, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_Z, P_ghZ, 1452, check)
      call createCurrent(P_G0, P_Hh, P_GPlus, P_GMinus, 10065, check)
      call createCurrent(P_GQ0, P_Hh, P_WMinus, P_WQPlus, 4029, check)
      call createCurrent(P_HlQ, P_G0, P_ghWpAnti, P_ghWp, 996, check)
      call createCurrent(P_ghZAnti, P_ghA, P_HPlus, P_GMinus, 9002, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_ghWm, 6590, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghAAnti, P_ZQ, 5376, check)
      call createCurrent(P_HMinus, P_ghWm, P_HPlus, P_ghWmAnti, 1900, check)
      call createCurrent(P_uAnti, P_HPlus, P_d, 3419, check)
      call createCurrent(P_d, P_dAnti, P_ZQ, 1599, check)
      call createCurrent(P_HaQ, P_GMinus, P_HPlus, P_HaQ, 1649, check)
      call createCurrent(P_HaQ, P_A, P_HPlus, P_WQMinus, 3317, check)
      call createCurrent(P_HQMinus, P_WPlus, P_Ha, P_ZQ, 1979, check)
      call createCurrent(P_ghWm, P_GPlus, P_Hh, P_ghZAnti, 4625, check)
      call createCurrent(P_ghZAnti, P_HMinus, P_ghWp, P_G0, 9566, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_A, P_WPlus, 934, check)
      call createCurrent(P_A, P_ghZAnti, P_WMinus, P_ghWp, 8135, check)
      call createCurrent(P_ghZ, P_Hh, P_ghWmAnti, P_GQMinus, 8056, check)
      call createCurrent(P_Z, P_Z, P_ghWp, P_ghWpAnti, 2335, check)
      call createCurrent(P_ePlus, P_HMinus, P_nu_e, 4081, check)
      call createCurrent(P_HlQ, P_GMinus, P_HPlus, P_GQ0, 3697, check)
      call createCurrent(P_Z, P_A, P_HPlus, P_HMinus, 5099, check)
      call createCurrent(P_GQMinus, P_HPlus, P_Hh, P_HaQ, 8625, check)
      call createCurrent(P_Z, P_Hl, P_A, P_Hl, 10476, check)
      call createCurrent(P_Z, P_GMinus, P_WPlus, P_Hh, 5240, check)
      call createCurrent(P_ZQ, P_ghWpAnti, P_ghWp, 808, check)
      call createCurrent(P_Ha, P_GMinus, P_Hl, P_GPlus, 9289, check)
      call createCurrent(P_GMinus, P_GPlus, P_Hl, P_G0, 8842, check)
      call createCurrent(P_AQ, P_WPlus, P_HQMinus, 2975, check)
      call createCurrent(P_HaQ, P_HMinus, P_WPlus, P_ZQ, 3056, check)
      call createCurrent(P_GPlus, P_GMinus, P_HMinus, P_GPlus, 4996, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghWp, P_WMinus, 8289, check)
      call createCurrent(P_GMinus, P_ghA, P_ghZAnti, P_HPlus, 9563, check)
      call createCurrent(P_G0, P_HPlus, P_HMinus, P_Hl, 9233, check)
      call createCurrent(P_HQPlus, P_Hh, P_Ha, P_GQMinus, 8115, check)
      call createCurrent(P_WPlus, P_GPlus, P_HMinus, P_WMinus, 9460, check)
      call createCurrent(P_WMinus, P_WMinus, P_ghWp, P_ghWmAnti, 3979, check)
      call createCurrent(P_ghWm, P_Ha, P_Ha, P_ghWmAnti, 5909, check)
      call createCurrent(P_Hh, P_WMinus, P_GPlus, 6785, check)
      call createCurrent(P_HQPlus, P_Ha, P_HMinus, P_HlQ, 6628, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghZAnti, 4523, check)
      call createCurrent(P_GQ0, P_Ha, P_HPlus, P_HQMinus, 5274, check)
      call createCurrent(P_GMinus, P_ghWpAnti, P_GPlus, P_ghWp, 2202, check)
      call createCurrent(P_HPlus, P_A, P_GMinus, P_A, 9668, check)
      call createCurrent(P_GQMinus, P_t, P_bAnti, 5949, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_WMinus, 6943, check)
      call createCurrent(P_ghWm, P_Ha, P_HPlus, P_ghAAnti, 8234, check)
      call createCurrent(P_G0, P_ghWm, P_G0, P_ghWmAnti, 1313, check)
      call createCurrent(P_ghWpAnti, P_Hh, P_ghZ, P_HQPlus, 7441, check)
      call createCurrent(P_A, P_u, P_uAnti, 7585, check)
      call createCurrent(P_GQ0, P_Hl, P_Hl, P_GQ0, 4500, check)
      call createCurrent(P_A, P_Z, P_g, P_g, 10587, check)
      call createCurrent(P_Z, P_A, P_Hh, P_Hh, 9973, check)
      call createCurrent(P_WMinus, P_Z, P_HPlus, P_G0, 9378, check)
      call createCurrent(P_HQPlus, P_Hl, P_HMinus, P_HaQ, 3696, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_HMinus, P_HhQ, 104, check)
      call createCurrent(P_ghWpAnti, P_Z, P_A, P_ghWp, 2342, check)
      call createCurrent(P_GPlus, P_A, P_G0, P_WMinus, 4047, check)
      call createCurrent(P_Z, P_GPlus, P_HMinus, P_A, 9814, check)
      call createCurrent(P_HPlus, P_HMinus, P_ghZAnti, P_ghZ, 331, check)
      call createCurrent(P_HhQ, P_Ha, P_ZQ, 1856, check)
      call createCurrent(P_Z, P_GPlus, P_GMinus, 2792, check)
      call createCurrent(P_HMinus, P_GPlus, 10245, check)
      call createCurrent(P_G0, P_ghAAnti, P_GMinus, P_ghWp, 3, check)
      call createCurrent(P_WQMinus, P_WPlus, P_G0, P_GQ0, 1502, check)
      call createCurrent(P_HPlus, P_ghWm, P_ghWmAnti, P_GMinus, 10153, check)
      call createCurrent(P_ghA, P_HPlus, P_ghZAnti, P_HMinus, 4749, check)
      call createCurrent(P_dAnti, P_GMinus, P_u, 5041, check)
      call createCurrent(P_HaQ, P_HPlus, P_ghWm, P_ghZAnti, 5285, check)
      call createCurrent(P_HQPlus, P_HMinus, P_ghZ, P_ghAAnti, 7183, check)
      call createCurrent(P_HMinus, P_Hh, P_ghWp, P_ghAAnti, 3349, check)
      call createCurrent(P_g, P_HMinus, P_g, P_GPlus, 10662, check)
      call createCurrent(P_WMinus, P_ghWp, P_Z, P_ghAAnti, 3726, check)
      call createCurrent(P_A, P_WPlus, P_WMinus, 8318, check)
      call createCurrent(P_HQMinus, P_GPlus, P_Hl, P_HlQ, 3381, check)
      call createCurrent(P_Ha, P_ghAAnti, P_HPlus, P_ghWm, 2138, check)
      call createCurrent(P_GQMinus, P_bAnti, P_t, 3461, check)
      call createCurrent(P_HMinus, P_Ha, P_ghWmAnti, P_ghZ, 7279, check)
      call createCurrent(P_WPlus, P_HMinus, P_WMinus, P_GPlus, 10364, check)
      call createCurrent(P_HMinus, P_ghZAnti, P_HPlus, P_ghA, 395, check)
      call createCurrent(P_GPlus, P_Ha, P_HMinus, P_G0, 1651, check)
      call createCurrent(P_GQPlus, P_ghWmAnti, P_GMinus, P_ghWm, 8541, check)
      call createCurrent(P_WPlus, P_ghA, P_WMinus, P_ghZAnti, 1453, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_G0, P_HMinus, 10089, check)
      call createCurrent(P_Hh, P_ePlus, P_eMinus, 8355, check)
      call createCurrent(P_HhQ, P_HMinus, P_ghZ, P_ghWmAnti, 8489, check)
      call createCurrent(P_uAnti, P_u, P_HaQ, 2243, check)
      call createCurrent(P_Hh, P_A, P_Hl, P_Z, 10548, check)
      call createCurrent(P_WMinus, P_Ha, P_A, P_HPlus, 361, check)
      call createCurrent(P_WPlus, P_A, P_GMinus, P_Hh, 7594, check)
      call createCurrent(P_WPlus, P_ghWm, P_Z, P_ghAAnti, 2588, check)
      call createCurrent(P_GPlus, P_GPlus, P_HMinus, P_GMinus, 3359, check)
      call createCurrent(P_G0, P_ghWmAnti, P_ghZ, P_GMinus, 6921, check)
      call createCurrent(P_GPlus, P_G0, P_G0, P_GMinus, 3967, check)
      call createCurrent(P_ghA, P_GMinus, P_ghAAnti, P_GPlus, 1724, check)
      call createCurrent(P_HQPlus, P_HMinus, P_Z, P_AQ, 3189, check)
      call createCurrent(P_HQMinus, P_Hh, P_ghWmAnti, P_ghA, 403, check)
      call createCurrent(P_ghA, P_GPlus, P_ghWpAnti, P_G0, 4747, check)
      call createCurrent(P_nu_muAnti, P_muMinus, P_WPlus, 4892, check)
      call createCurrent(P_HQMinus, P_ghA, P_HPlus, P_ghAAnti, 2776, check)
      call createCurrent(P_HhQ, P_WPlus, P_HQMinus, 6577, check)
      call createCurrent(P_ghZ, P_ghAAnti, P_GMinus, P_GQPlus, 1806, check)
      call createCurrent(P_WMinus, P_ghWp, P_ghAAnti, P_A, 4040, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_HMinus, P_ghZ, 9280, check)
      call createCurrent(P_A, P_WMinus, P_ghA, P_ghWmAnti, 3561, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_GMinus, P_Hl, 3227, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghZ, P_HlQ, 3147, check)
      call createCurrent(P_d, P_uAnti, P_GQPlus, 6530, check)
      call createCurrent(P_GQPlus, P_ghZAnti, P_G0, P_ghWm, 2522, check)
      call createCurrent(P_GMinus, P_WPlus, P_Ha, P_A, 9426, check)
      call createCurrent(P_WMinus, P_HPlus, P_Z, P_G0, 9281, check)
      call createCurrent(P_c, P_Hl, P_cAnti, 5678, check)
      call createCurrent(P_G0, P_Ha, P_ghWp, P_ghWpAnti, 9275, check)
      call createCurrent(P_A, P_Ha, P_A, P_G0, 10566, check)
      call createCurrent(P_Hl, P_GPlus, P_Ha, P_HMinus, 949, check)
      call createCurrent(P_WQPlus, P_HMinus, P_Z, P_HaQ, 350, check)
      call createCurrent(P_HMinus, P_ghA, P_HPlus, P_ghZAnti, 8059, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Hh, P_Hl, 9227, check)
      call createCurrent(P_ZQ, P_WPlus, P_ghAAnti, P_ghWm, 5353, check)
      call createCurrent(P_g, P_g, P_Z, P_g, 10549, check)
      call createCurrent(P_WQPlus, P_ghA, P_WMinus, P_ghAAnti, 6428, check)
      call createCurrent(P_WMinus, P_WPlus, P_ghZAnti, P_ghZ, 4064, check)
      call createCurrent(P_Hh, P_HMinus, P_GPlus, P_Ha, 2176, check)
      call createCurrent(P_Ha, P_tauPlus, P_tauMinus, 816, check)
      call createCurrent(P_Hh, P_GMinus, P_ghWp, P_ghAAnti, 901, check)
      call createCurrent(P_muPlus, P_nu_mu, P_HMinus, 182, check)
      call createCurrent(P_HQPlus, P_Hl, P_ghZAnti, P_ghWm, 5596, check)
      call createCurrent(P_HhQ, P_ghZAnti, P_HMinus, P_ghWp, 4254, check)
      call createCurrent(P_GMinus, P_Hh, P_ghZ, P_ghWmAnti, 2855, check)
      call createCurrent(P_g, P_g, P_HMinus, P_GPlus, 10750, check)
      call createCurrent(P_Z, P_GMinus, P_GPlus, 7503, check)
      call createCurrent(P_ghAAnti, P_G0, P_GPlus, P_ghWm, 8800, check)
      call createCurrent(P_WPlus, P_WMinus, P_Z, P_Z, 1729, check)
      call createCurrent(P_HQPlus, P_HMinus, P_Ha, P_HlQ, 8652, check)
      call createCurrent(P_GQ0, P_GMinus, P_G0, P_GQPlus, 6379, check)
      call createCurrent(P_ZQ, P_ghWm, P_WPlus, P_ghAAnti, 3585, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_GMinus, P_Ha, 10426, check)
      call createCurrent(P_HMinus, P_Hl, P_WPlus, P_A, 5893, check)
      call createCurrent(P_ghZAnti, P_G0, P_ghZ, P_G0, 7164, check)
      call createCurrent(P_WMinus, P_WPlus, P_Hh, P_Hl, 9907, check)
      call createCurrent(P_Hh, P_Hl, P_Hl, 6540, check)
      call createCurrent(P_Hh, P_ghZAnti, P_ghWp, P_HMinus, 4865, check)
      call createCurrent(P_AQ, P_bAnti, P_b, 7558, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_G0, P_G0, 5262, check)
      call createCurrent(P_GPlus, P_g, P_GMinus, P_g, 10683, check)
      call createCurrent(P_WQPlus, P_WMinus, P_ghA, P_ghZAnti, 2122, check)
      call createCurrent(P_HPlus, P_Hl, P_GMinus, P_Ha, 7821, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_HPlus, P_Hh, 3608, check)
      call createCurrent(P_ghAAnti, P_G0, P_ghWm, P_GPlus, 1396, check)
      call createCurrent(P_WMinus, P_Hl, P_A, P_HPlus, 1779, check)
      call createCurrent(P_Z, P_Ha, P_G0, P_Z, 9062, check)
      call createCurrent(P_g, P_A, P_Z, P_g, 10526, check)
      call createCurrent(P_Z, P_WMinus, P_G0, P_HPlus, 9600, check)
      call createCurrent(P_ghZAnti, P_G0, P_ghWm, P_HPlus, 9537, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_HMinus, P_ghZ, 10118, check)
      call createCurrent(P_HMinus, P_ghWmAnti, P_ghZ, P_Hl, 2258, check)
      call createCurrent(P_Hl, P_GPlus, P_ghA, P_ghWpAnti, 2625, check)
      call createCurrent(P_Hh, P_HMinus, P_HPlus, P_Ha, 9930, check)
      call createCurrent(P_GQPlus, P_G0, P_HMinus, P_HaQ, 4646, check)
      call createCurrent(P_ghWm, P_Hl, P_Hl, P_ghWmAnti, 2385, check)
      call createCurrent(P_HhQ, P_Z, P_GPlus, P_WQMinus, 7523, check)
      call createCurrent(P_G0, P_Z, P_HPlus, P_WMinus, 10309, check)
      call createCurrent(P_HPlus, P_GMinus, P_G0, 6210, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_HMinus, P_HaQ, 8029, check)
      call createCurrent(P_ghWp, P_Hl, P_ghWpAnti, 1823, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghWm, P_HPlus, 9080, check)
      call createCurrent(P_WPlus, P_A, P_ghA, P_ghWpAnti, 3143, check)
      call createCurrent(P_GQMinus, P_ghWmAnti, P_Hh, P_ghA, 13, check)
      call createCurrent(P_GQPlus, P_Ha, P_HQMinus, 1240, check)
      call createCurrent(P_ghZ, P_G0, P_ghZAnti, P_Ha, 10358, check)
      call createCurrent(P_WQMinus, P_HPlus, P_HaQ, 5313, check)
      call createCurrent(P_HlQ, P_GMinus, P_ghZ, P_ghWmAnti, 480, check)
      call createCurrent(P_HhQ, P_uAnti, P_u, 8557, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_HPlus, P_HhQ, 8324, check)
      call createCurrent(P_HlQ, P_Hh, P_HMinus, P_GQPlus, 6620, check)
      call createCurrent(P_GPlus, P_ghA, P_HMinus, P_ghAAnti, 9247, check)
      call createCurrent(P_WMinus, P_ghZ, P_A, P_ghWmAnti, 6434, check)
      call createCurrent(P_G0, P_GMinus, P_ghZAnti, P_ghWp, 158, check)
      call createCurrent(P_HhQ, P_ghZAnti, P_ghZ, 1197, check)
      call createCurrent(P_GQPlus, P_muMinus, P_nu_muAnti, 4025, check)
      call createCurrent(P_GPlus, P_ghZ, P_ghAAnti, P_HMinus, 9015, check)
      call createCurrent(P_HMinus, P_A, P_Z, P_GPlus, 8918, check)
      call createCurrent(P_GPlus, P_GMinus, P_ghWpAnti, P_ghWp, 3234, check)
      call createCurrent(P_ghWpAnti, P_Hl, P_GPlus, P_ghA, 4934, check)
      call createCurrent(P_GQMinus, P_HMinus, P_HPlus, P_GQPlus, 7369, check)
      call createCurrent(P_ghZAnti, P_G0, P_ghWp, P_GQMinus, 5124, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_HhQ, 4842, check)
      call createCurrent(P_ZQ, P_GMinus, P_Hh, P_WQPlus, 6882, check)
      call createCurrent(P_GQPlus, P_ghA, P_Hl, P_ghWpAnti, 1145, check)
      call createCurrent(P_Hl, P_GPlus, P_ghWm, P_ghZAnti, 2123, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_GPlus, P_GQ0, 3548, check)
      call createCurrent(P_sAnti, P_WMinus, P_c, 7254, check)
      call createCurrent(P_uAnti, P_u, P_G0, 3260, check)
      call createCurrent(P_GPlus, P_tAnti, P_b, 7035, check)
      call createCurrent(P_s, P_HPlus, P_cAnti, 237, check)
      call createCurrent(P_GMinus, P_Hl, P_GPlus, P_Hl, 8798, check)
      call createCurrent(P_HMinus, P_ghZ, P_ghWmAnti, P_Ha, 8759, check)
      call createCurrent(P_WMinus, P_ghAAnti, P_WPlus, P_ghZ, 7565, check)
      call createCurrent(P_AQ, P_WPlus, P_Hh, P_HQMinus, 5114, check)
      call createCurrent(P_HMinus, P_Ha, P_ghWp, P_ghAAnti, 1655, check)
      call createCurrent(P_GMinus, P_ghWp, P_ghWpAnti, P_GPlus, 4428, check)
      call createCurrent(P_Hh, P_GPlus, P_A, P_WMinus, 262, check)
      call createCurrent(P_GPlus, P_G0, P_ghZAnti, P_ghWm, 1639, check)
      call createCurrent(P_HMinus, P_ghAAnti, P_ghZ, P_GPlus, 9170, check)
      call createCurrent(P_GPlus, P_Ha, P_Z, P_WMinus, 9264, check)
      call createCurrent(P_WMinus, P_WPlus, P_ghWp, P_ghWpAnti, 1718, check)
      call createCurrent(P_G0, P_GPlus, P_GMinus, 9270, check)
      call createCurrent(P_Z, P_GPlus, P_G0, P_WMinus, 7908, check)
      call createCurrent(P_ghA, P_Hh, P_GPlus, P_ghWpAnti, 2615, check)
      call createCurrent(P_Hh, P_HMinus, P_ghWp, P_ghAAnti, 5729, check)
      call createCurrent(P_HlQ, P_HMinus, P_Hh, P_HQPlus, 5143, check)
      call createCurrent(P_G0, P_Z, P_WMinus, P_HPlus, 9003, check)
      call createCurrent(P_tAnti, P_t, P_Hl, 6366, check)
      call createCurrent(P_GQMinus, P_A, P_GPlus, P_ZQ, 356, check)
      call createCurrent(P_GMinus, P_HPlus, P_A, P_Z, 8997, check)
      call createCurrent(P_HPlus, P_HMinus, P_ghA, P_ghZAnti, 5058, check)
      call createCurrent(P_GQMinus, P_HPlus, P_G0, P_HlQ, 4692, check)
      call createCurrent(P_GPlus, P_HMinus, P_Z, P_A, 9190, check)
      call createCurrent(P_Hl, P_GMinus, P_G0, P_HPlus, 6275, check)
      call createCurrent(P_Ha, P_Ha, P_Hl, P_Hh, 7078, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_GPlus, P_GQ0, 4645, check)
      call createCurrent(P_GPlus, P_Hh, P_ghWpAnti, P_ghA, 3739, check)
      call createCurrent(P_GPlus, P_Hh, P_Z, P_WMinus, 3177, check)
      call createCurrent(P_GQMinus, P_GPlus, P_G0, P_GQ0, 2254, check)
      call createCurrent(P_A, P_A, 10308, check)
      call createCurrent(P_WPlus, P_Ha, P_Z, P_GMinus, 9007, check)
      call createCurrent(P_GQMinus, P_G0, P_G0, P_GQPlus, 1254, check)
      call createCurrent(P_Hh, P_ghWmAnti, P_Hh, P_ghWm, 4112, check)
      call createCurrent(P_GPlus, P_HMinus, P_ghZAnti, P_ghZ, 10003, check)
      call createCurrent(P_HQPlus, P_ghWpAnti, P_Ha, P_ghZ, 393, check)
      call createCurrent(P_Hl, P_WPlus, P_Z, P_GMinus, 4553, check)
      call createCurrent(P_HPlus, P_A, P_WMinus, P_Hh, 4502, check)
      call createCurrent(P_Z, P_G0, P_Ha, P_Z, 9327, check)
      call createCurrent(P_Hh, P_A, P_Z, P_Hl, 10642, check)
      call createCurrent(P_Z, P_Ha, P_Ha, P_Z, 1198, check)
      call createCurrent(P_uAnti, P_u, P_ZQ, 4252, check)
      call createCurrent(P_WPlus, P_muMinus, P_nu_muAnti, 5320, check)
      call createCurrent(P_ghZAnti, P_HPlus, P_HMinus, P_ghZ, 5935, check)
      call createCurrent(P_ZQ, P_Ha, P_HMinus, P_WQPlus, 2605, check)
      call createCurrent(P_A, P_ghWmAnti, P_A, P_ghWm, 6875, check)
      call createCurrent(P_HMinus, P_Hl, P_Hh, P_HPlus, 7157, check)
      call createCurrent(P_ZQ, P_GPlus, P_WMinus, P_HlQ, 1264, check)
      call createCurrent(P_GPlus, P_ghWm, P_G0, P_ghAAnti, 7114, check)
      call createCurrent(P_Hl, P_Hl, P_ghZ, P_ghZAnti, 6293, check)
      call createCurrent(P_HhQ, P_HPlus, P_GMinus, P_HhQ, 131, check)
      call createCurrent(P_GMinus, P_GPlus, P_A, 1868, check)
      call createCurrent(P_HhQ, P_GMinus, P_HPlus, P_HaQ, 2490, check)
      call createCurrent(P_Hl, P_HMinus, P_Ha, P_GPlus, 3217, check)
      call createCurrent(P_GQPlus, P_Hh, P_ghA, P_ghWpAnti, 190, check)
      call createCurrent(P_HlQ, P_t, P_tAnti, 5277, check)
      call createCurrent(P_GQ0, P_HMinus, P_GQPlus, 4915, check)
      call createCurrent(P_ghWpAnti, P_Ha, P_ghA, P_HPlus, 802, check)
      call createCurrent(P_GPlus, P_ghWm, P_GMinus, P_ghWmAnti, 2057, check)
      call createCurrent(P_GQMinus, P_Hh, P_GPlus, P_GQ0, 7595, check)
      call createCurrent(P_Hh, P_HMinus, P_Z, P_WPlus, 8724, check)
      call createCurrent(P_Hl, P_tAnti, P_t, 7, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_G0, P_HPlus, 10120, check)
      call createCurrent(P_g, P_g, P_Z, P_Z, 10760, check)
      call createCurrent(P_GQ0, P_Hl, P_GQ0, 7912, check)
      call createCurrent(P_Ha, P_ghZ, P_HMinus, P_ghWmAnti, 6626, check)
      call createCurrent(P_GQMinus, P_Hl, P_ghWmAnti, P_ghZ, 7697, check)
      call createCurrent(P_HhQ, P_HPlus, P_Ha, P_GQMinus, 3577, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_HPlus, 7234, check)
      call createCurrent(P_HMinus, P_HPlus, P_HPlus, P_GMinus, 6096, check)
      call createCurrent(P_GQ0, P_Hh, P_GMinus, P_GQPlus, 2744, check)
      call createCurrent(P_WPlus, P_GMinus, P_Hl, P_A, 3512, check)
      call createCurrent(P_GMinus, P_g, P_g, P_HPlus, 10550, check)
      call createCurrent(P_Z, P_sAnti, P_s, 2370, check)
      call createCurrent(P_GPlus, P_G0, P_GMinus, P_Hh, 10011, check)
      call createCurrent(P_HPlus, P_GMinus, P_HPlus, P_HMinus, 2567, check)
      call createCurrent(P_eMinus, P_nu_eAnti, P_WQPlus, 6269, check)
      call createCurrent(P_WQMinus, P_WMinus, P_ghWmAnti, P_ghWp, 2916, check)
      call createCurrent(P_GMinus, P_ghA, P_ghAAnti, P_GPlus, 6694, check)
      call createCurrent(P_ghWp, P_Ha, P_G0, P_ghWpAnti, 9055, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_GPlus, P_GQMinus, 633, check)
      call createCurrent(P_GMinus, P_ghWp, P_GPlus, P_ghWpAnti, 5322, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_GMinus, P_HPlus, 9570, check)
      call createCurrent(P_ghWp, P_Ha, P_ghZAnti, P_HMinus, 2714, check)
      call createCurrent(P_G0, P_HMinus, P_HPlus, P_Ha, 1121, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_WPlus, P_AQ, 2000, check)
      call createCurrent(P_HQPlus, P_HMinus, P_HPlus, P_HQMinus, 910, check)
      call createCurrent(P_WQMinus, P_G0, P_Z, P_GQPlus, 6316, check)
      call createCurrent(P_Hl, P_Z, P_WMinus, P_HPlus, 3595, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_HPlus, 4528, check)
      call createCurrent(P_Hl, P_Hh, P_HMinus, P_GPlus, 2413, check)
      call createCurrent(P_WPlus, P_Hh, P_Z, P_HMinus, 4808, check)
      call createCurrent(P_ghWm, P_HPlus, P_Hl, P_ghZAnti, 5027, check)
      call createCurrent(P_nu_muAnti, P_Z, P_nu_mu, 7161, check)
      call createCurrent(P_ghWm, P_A, P_ghWmAnti, P_ZQ, 630, check)
      call createCurrent(P_HPlus, P_ghZAnti, P_HMinus, P_ghZ, 720, check)
      call createCurrent(P_WMinus, P_Z, P_GPlus, P_Hl, 1406, check)
      call createCurrent(P_GPlus, P_nu_eAnti, P_eMinus, 5787, check)
      call createCurrent(P_WQPlus, P_WPlus, P_ghWm, P_ghWpAnti, 4988, check)
      call createCurrent(P_HQMinus, P_HPlus, P_ghWpAnti, P_ghWp, 8290, check)
      call createCurrent(P_HhQ, P_t, P_tAnti, 8594, check)
      call createCurrent(P_WMinus, P_G0, P_GPlus, P_A, 3712, check)
      call createCurrent(P_Ha, P_HPlus, P_ghZ, P_ghWpAnti, 5141, check)
      call createCurrent(P_A, P_Z, P_G0, P_G0, 10435, check)
      call createCurrent(P_GQ0, P_GPlus, P_Ha, P_HQMinus, 1206, check)
      call createCurrent(P_Ha, P_GMinus, P_GPlus, P_G0, 3681, check)
      call createCurrent(P_Ha, P_Hl, P_Hl, P_G0, 7477, check)
      call createCurrent(P_WMinus, P_Z, P_G0, P_GPlus, 6897, check)
      call createCurrent(P_GQPlus, P_Hl, P_Hh, P_HQMinus, 5293, check)
      call createCurrent(P_HhQ, P_HMinus, P_A, P_WQPlus, 2974, check)
      call createCurrent(P_ghWmAnti, P_Ha, P_ghA, P_HQMinus, 6987, check)
      call createCurrent(P_GMinus, P_A, P_HPlus, 8885, check)
      call createCurrent(P_ghWmAnti, P_Ha, P_ghWm, P_HhQ, 1706, check)
      call createCurrent(P_A, P_HPlus, P_WMinus, P_Ha, 1986, check)
      call createCurrent(P_WMinus, P_GPlus, P_WPlus, P_HMinus, 9998, check)
      call createCurrent(P_ghWp, P_Ha, P_GMinus, P_ghZAnti, 9500, check)
      call createCurrent(P_sAnti, P_Hl, P_s, 5526, check)
      call createCurrent(P_ghAAnti, P_Ha, P_GMinus, P_ghWp, 9361, check)
      call createCurrent(P_HaQ, P_HMinus, P_ghZAnti, P_ghWp, 7626, check)
      call createCurrent(P_ghWm, P_Hl, P_ghAAnti, P_HPlus, 818, check)
      call createCurrent(P_WQMinus, P_HPlus, P_Z, P_HhQ, 2283, check)
      call createCurrent(P_HaQ, P_WPlus, P_Hh, P_WQMinus, 8067, check)
      call createCurrent(P_A, P_HMinus, P_GPlus, P_A, 9853, check)
      call createCurrent(P_WMinus, P_WPlus, 10433, check)
      call createCurrent(P_HPlus, P_WMinus, P_GMinus, P_WPlus, 10165, check)
      call createCurrent(P_GMinus, P_Hh, P_ghA, P_ghWmAnti, 7431, check)
      call createCurrent(P_Ha, P_GMinus, P_WPlus, 8917, check)
      call createCurrent(P_HhQ, P_ghWm, P_Hh, P_ghWmAnti, 317, check)
      call createCurrent(P_A, P_WMinus, P_Ha, P_HPlus, 667, check)
      call createCurrent(P_Hh, P_GMinus, P_G0, P_GPlus, 9164, check)
      call createCurrent(P_WPlus, P_Hh, P_Hl, P_WMinus, 9913, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_Hh, P_GQPlus, 5342, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_G0, P_GMinus, 5566, check)
      call createCurrent(P_HPlus, P_Hh, P_GMinus, P_Ha, 5881, check)
      call createCurrent(P_Hh, P_Hl, P_ghWpAnti, P_ghWp, 10038, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_WPlus, P_ZQ, 2864, check)
      call createCurrent(P_HhQ, P_Ha, P_Hh, P_GQ0, 4441, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_Ha, P_HMinus, 5339, check)
      call createCurrent(P_d, P_dAnti, P_Hh, 1003, check)
      call createCurrent(P_Hl, P_WPlus, P_GMinus, P_A, 7744, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_WQPlus, 1712, check)
      call createCurrent(P_HMinus, P_tauPlus, P_nu_tau, 7598, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghA, P_Hh, 6438, check)
      call createCurrent(P_ghWm, P_Hh, P_ghZAnti, P_GQPlus, 2188, check)
      call createCurrent(P_eMinus, P_G0, P_ePlus, 3400, check)
      call createCurrent(P_WPlus, P_HMinus, P_WMinus, P_HPlus, 5672, check)
      call createCurrent(P_HhQ, P_GMinus, P_Z, P_WQPlus, 7620, check)
      call createCurrent(P_WQPlus, P_Hl, P_HQMinus, 2933, check)
      call createCurrent(P_HlQ, P_Hl, P_WPlus, P_WQMinus, 2657, check)
      call createCurrent(P_ghWpAnti, P_ghWm, P_WPlus, P_WQPlus, 336, check)
      call createCurrent(P_HhQ, P_Hh, P_Ha, P_GQ0, 1911, check)
      call createCurrent(P_GQPlus, P_Z, P_Hl, P_WQMinus, 4232, check)
      call createCurrent(P_c, P_A, P_cAnti, 4529, check)
      call createCurrent(P_sAnti, P_s, P_HaQ, 2953, check)
      call createCurrent(P_GMinus, P_G0, P_ghZ, P_ghWmAnti, 3716, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_HPlus, 4874, check)
      call createCurrent(P_tauPlus, P_Z, P_tauMinus, 806, check)
      call createCurrent(P_GQMinus, P_ghWp, P_Hh, P_ghZAnti, 456, check)
      call createCurrent(P_Ha, P_G0, P_Hl, 3660, check)
      call createCurrent(P_GPlus, P_GMinus, P_G0, P_G0, 90, check)
      call createCurrent(P_A, P_GMinus, P_Hl, P_WPlus, 623, check)
      call createCurrent(P_c, P_Hh, P_cAnti, 4324, check)
      call createCurrent(P_GQPlus, P_Z, P_Z, P_GQMinus, 6977, check)
      call createCurrent(P_Hh, P_ghWmAnti, P_HMinus, P_ghA, 3489, check)
      call createCurrent(P_A, P_WPlus, P_ghZ, P_ghWpAnti, 962, check)
      call createCurrent(P_GQPlus, P_ghAAnti, P_GMinus, P_ghZ, 1055, check)
      call createCurrent(P_HQMinus, P_Hl, P_GPlus, P_HlQ, 7483, check)
      call createCurrent(P_Ha, P_Hl, P_HPlus, P_GMinus, 1910, check)
      call createCurrent(P_GQPlus, P_s, P_cAnti, 6309, check)
      call createCurrent(P_ghWp, P_Z, P_ghWpAnti, P_Z, 4369, check)
      call createCurrent(P_ghWm, P_HMinus, P_ghWmAnti, P_HPlus, 4683, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_HlQ, 2334, check)
      call createCurrent(P_A, P_WMinus, P_ghWmAnti, P_ghZ, 308, check)
      call createCurrent(P_G0, P_GPlus, P_ghA, P_ghWpAnti, 6555, check)
      call createCurrent(P_ghZ, P_G0, P_HPlus, P_ghWpAnti, 9616, check)
      call createCurrent(P_nu_tau, P_tauPlus, P_WMinus, 1646, check)
      call createCurrent(P_ghA, P_GMinus, P_GPlus, P_ghZAnti, 2698, check)
      call createCurrent(P_Hl, P_Hl, P_HPlus, P_HMinus, 7088, check)
      call createCurrent(P_ZQ, P_WPlus, P_WMinus, P_AQ, 3395, check)
      call createCurrent(P_GQPlus, P_G0, P_Ha, P_GQMinus, 6207, check)
      call createCurrent(P_ghAAnti, P_HMinus, P_ghZ, P_HQPlus, 1867, check)
      call createCurrent(P_HaQ, P_Hl, P_ghWm, P_ghWmAnti, 2677, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_G0, P_HPlus, 10332, check)
      call createCurrent(P_WMinus, P_GPlus, P_G0, P_Z, 3256, check)
      call createCurrent(P_GQ0, P_Hh, P_GQ0, 1656, check)
      call createCurrent(P_WQMinus, P_HPlus, P_Hl, P_ZQ, 8688, check)
      call createCurrent(P_GQPlus, P_Hh, P_HMinus, P_HhQ, 7453, check)
      call createCurrent(P_Z, P_Hh, P_A, 9248, check)
      call createCurrent(P_A, P_muMinus, P_muPlus, 1985, check)
      call createCurrent(P_HQMinus, P_GPlus, P_Ha, P_HaQ, 3744, check)
      call createCurrent(P_WMinus, P_A, P_HPlus, P_G0, 9278, check)
      call createCurrent(P_HMinus, P_Hh, P_ghZAnti, P_ghWp, 4669, check)
      call createCurrent(P_WMinus, P_Z, P_WPlus, 8768, check)
      call createCurrent(P_AQ, P_HPlus, P_Ha, P_WQMinus, 5412, check)
      call createCurrent(P_ghA, P_WMinus, P_ghAAnti, P_WPlus, 6301, check)
      call createCurrent(P_Hl, P_ghAAnti, P_ghWp, P_GMinus, 4241, check)
      call createCurrent(P_GPlus, P_Hh, P_ghZ, P_ghWpAnti, 4381, check)
      call createCurrent(P_HhQ, P_Ha, P_WMinus, P_WQPlus, 1476, check)
      call createCurrent(P_G0, P_WMinus, P_HPlus, P_A, 10030, check)
      call createCurrent(P_Hh, P_Hh, P_Hh, 5229, check)
      call createCurrent(P_HPlus, P_HMinus, P_Ha, 9674, check)
      call createCurrent(P_HMinus, P_ghWmAnti, P_ghZ, P_G0, 9750, check)
      call createCurrent(P_WPlus, P_ghZ, P_WMinus, P_ghAAnti, 8439, check)
      call createCurrent(P_ghA, P_G0, P_GMinus, P_ghWmAnti, 4079, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_Ha, P_HQMinus, 624, check)
      call createCurrent(P_HMinus, P_A, P_WPlus, P_G0, 9833, check)
      call createCurrent(P_ghGAnti, P_ghG, P_g, P_g, 4008, check)
      call createCurrent(P_ghZ, P_Ha, P_ghZAnti, P_HaQ, 4643, check)
      call createCurrent(P_ZQ, P_WMinus, P_GPlus, P_GQ0, 8590, check)
      call createCurrent(P_HaQ, P_GMinus, P_Hl, P_GQPlus, 110, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_Hl, P_GPlus, 3385, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_GPlus, P_GMinus, 6195, check)
      call createCurrent(P_WQPlus, P_WMinus, P_G0, P_GQ0, 2343, check)
      call createCurrent(P_G0, P_GPlus, P_HMinus, P_Hl, 1109, check)
      call createCurrent(P_gQ, P_cAnti, P_c, 6727, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_HMinus, P_Hh, 3244, check)
      call createCurrent(P_GQ0, P_Hh, P_HPlus, P_HQMinus, 1330, check)
      call createCurrent(P_HlQ, P_WPlus, P_Hl, P_WQMinus, 3575, check)
      call createCurrent(P_HMinus, P_ghA, P_ghAAnti, P_HPlus, 893, check)
      call createCurrent(P_ghG, P_ghGAnti, P_g, 5120, check)
      call createCurrent(P_Ha, P_ghAAnti, P_ghWp, P_HMinus, 6014, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_HMinus, 6403, check)
      call createCurrent(P_s, P_sAnti, P_G0, 3251, check)
      call createCurrent(P_ghZAnti, P_Ha, P_Ha, P_ghZ, 3628, check)
      call createCurrent(P_ghZ, P_ghAAnti, P_WMinus, P_WQPlus, 7245, check)
      call createCurrent(P_HMinus, P_Hl, P_Hh, P_GPlus, 465, check)
      call createCurrent(P_HlQ, P_GMinus, P_G0, P_GQPlus, 8726, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghWm, 1597, check)
      call createCurrent(P_Hl, P_HMinus, P_Hl, P_GPlus, 6288, check)
      call createCurrent(P_tAnti, P_t, P_GQ0, 5581, check)
      call createCurrent(P_Hh, P_A, P_Ha, 9262, check)
      call createCurrent(P_nu_muAnti, P_WPlus, P_muMinus, 4604, check)
      call createCurrent(P_ZQ, P_G0, P_GMinus, P_WQPlus, 6960, check)
      call createCurrent(P_WPlus, P_A, P_WMinus, P_Z, 3882, check)
      call createCurrent(P_HhQ, P_Hl, P_GMinus, P_GQPlus, 3034, check)
      call createCurrent(P_G0, P_ghWmAnti, P_GMinus, P_ghZ, 3525, check)
      call createCurrent(P_Hl, P_HMinus, P_GPlus, P_Hh, 7605, check)
      call createCurrent(P_HaQ, P_WPlus, P_Ha, P_WQMinus, 5586, check)
      call createCurrent(P_HMinus, P_Hh, P_G0, P_GPlus, 4648, check)
      call createCurrent(P_HPlus, P_ghWpAnti, P_ghA, 5789, check)
      call createCurrent(P_HPlus, P_ghAAnti, P_ghWm, P_Ha, 1633, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Hl, P_HaQ, 8263, check)
      call createCurrent(P_HhQ, P_GPlus, P_HMinus, P_GQ0, 3329, check)
      call createCurrent(P_Hh, P_ghWpAnti, P_ghA, P_GPlus, 5610, check)
      call createCurrent(P_WMinus, P_ghA, P_ghAAnti, P_WPlus, 8789, check)
      call createCurrent(P_GQPlus, P_Hh, P_ghZAnti, P_ghWm, 3626, check)
      call createCurrent(P_WPlus, P_ghZAnti, P_Z, P_ghWm, 5696, check)
      call createCurrent(P_HQPlus, P_HPlus, P_GMinus, P_HQMinus, 4896, check)
      call createCurrent(P_HhQ, P_HMinus, P_GPlus, P_GQ0, 7813, check)
      call createCurrent(P_WQPlus, P_GMinus, P_Z, P_HhQ, 8699, check)
      call createCurrent(P_GMinus, P_Ha, P_Ha, P_GPlus, 7887, check)
      call createCurrent(P_HQPlus, P_GMinus, P_Ha, P_HlQ, 2324, check)
      call createCurrent(P_A, P_HMinus, P_Hh, P_WPlus, 7534, check)
      call createCurrent(P_A, P_WPlus, P_WMinus, P_A, 2940, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_WPlus, P_AQ, 5046, check)
      call createCurrent(P_HQMinus, P_Ha, P_Ha, P_HQPlus, 2068, check)
      call createCurrent(P_GMinus, P_Hh, P_G0, P_GPlus, 10469, check)
      call createCurrent(P_HPlus, P_HMinus, P_ghZ, P_ghAAnti, 8093, check)
      call createCurrent(P_WQPlus, P_ghZ, P_A, P_ghWpAnti, 4098, check)
      call createCurrent(P_d, P_dAnti, P_Ha, 4703, check)
      call createCurrent(P_Ha, P_GPlus, P_Ha, P_GMinus, 555, check)
      call createCurrent(P_HMinus, P_GPlus, P_Hh, 1998, check)
      call createCurrent(P_Ha, P_A, P_GMinus, P_WPlus, 8942, check)
      call createCurrent(P_HQMinus, P_Z, P_HPlus, P_ZQ, 5153, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_Hl, P_HPlus, 5805, check)
      call createCurrent(P_Ha, P_HMinus, P_Hh, P_GPlus, 7833, check)
      call createCurrent(P_ghA, P_GMinus, P_ghWmAnti, 3123, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_GMinus, P_HlQ, 3782, check)
      call createCurrent(P_HQPlus, P_ghWm, P_HMinus, P_ghWmAnti, 5398, check)
      call createCurrent(P_WQMinus, P_GPlus, P_A, P_HlQ, 794, check)
      call createCurrent(P_WPlus, P_A, P_HMinus, P_Hl, 2800, check)
      call createCurrent(P_GQ0, P_WMinus, P_Z, P_GQPlus, 7531, check)
      call createCurrent(P_Z, P_G0, P_G0, P_Z, 8511, check)
      call createCurrent(P_AQ, P_ghWp, P_WMinus, P_ghZAnti, 4642, check)
      call createCurrent(P_Hl, P_ghWm, P_ghZAnti, P_GPlus, 1901, check)
      call createCurrent(P_GQPlus, P_Hl, P_GQMinus, 7919, check)
      call createCurrent(P_ghWm, P_HMinus, P_GPlus, P_ghWmAnti, 9111, check)
      call createCurrent(P_HQMinus, P_GMinus, P_GPlus, P_GQPlus, 7781, check)
      call createCurrent(P_Ha, P_ghWpAnti, P_ghA, P_GPlus, 9688, check)
      call createCurrent(P_HhQ, P_G0, P_WMinus, P_WQPlus, 6720, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_HPlus, P_ghZ, 9323, check)
      call createCurrent(P_AQ, P_cAnti, P_c, 958, check)
      call createCurrent(P_HhQ, P_HPlus, P_ghWm, P_ghAAnti, 3719, check)
      call createCurrent(P_ePlus, P_GMinus, P_nu_e, 5416, check)
      call createCurrent(P_Hl, P_ghWm, P_GPlus, P_ghZAnti, 6279, check)
      call createCurrent(P_GQ0, P_ghWp, P_G0, P_ghWpAnti, 4627, check)
      call createCurrent(P_HhQ, P_Hl, P_Hh, P_HlQ, 6184, check)
      call createCurrent(P_AQ, P_dAnti, P_d, 1954, check)
      call createCurrent(P_GMinus, P_ghA, P_Hh, P_ghWmAnti, 7874, check)
      call createCurrent(P_WQMinus, P_Hh, P_WQPlus, 1623, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_Ha, P_GPlus, 9782, check)
      call createCurrent(P_GQPlus, P_WMinus, P_GQ0, 8416, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_GMinus, P_G0, 3105, check)
      call createCurrent(P_GMinus, P_Z, P_Z, P_HPlus, 10356, check)
      call createCurrent(P_ZQ, P_Z, P_Hl, P_HlQ, 4917, check)
      call createCurrent(P_HMinus, P_ghWp, P_Ha, P_ghAAnti, 3338, check)
      call createCurrent(P_GMinus, P_Hl, P_WPlus, P_Z, 979, check)
      call createCurrent(P_HlQ, P_ghWm, P_Ha, P_ghWmAnti, 1527, check)
      call createCurrent(P_GPlus, P_Hh, P_HMinus, P_Hl, 6956, check)
      call createCurrent(P_Ha, P_GMinus, P_HPlus, P_Ha, 2226, check)
      call createCurrent(P_HlQ, P_Z, P_GQ0, 5685, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_GQPlus, 6118, check)
      call createCurrent(P_G0, P_ghZ, P_GMinus, P_ghWmAnti, 6642, check)
      call createCurrent(P_HMinus, P_ghZ, P_Hl, P_ghWmAnti, 6294, check)
      call createCurrent(P_Z, P_G0, P_WPlus, P_HMinus, 10127, check)
      call createCurrent(P_HlQ, P_Z, P_HMinus, P_WQPlus, 5371, check)
      call createCurrent(P_HaQ, P_s, P_sAnti, 8151, check)
      call createCurrent(P_WMinus, P_GPlus, P_HMinus, P_WPlus, 9794, check)
      call createCurrent(P_Hl, P_GPlus, P_Z, P_WMinus, 122, check)
      call createCurrent(P_Hh, P_ghWpAnti, P_HPlus, P_ghA, 7373, check)
      call createCurrent(P_HPlus, P_WMinus, P_A, P_Ha, 3488, check)
      call createCurrent(P_ghZAnti, P_HPlus, P_ghWm, P_Ha, 2790, check)
      call createCurrent(P_ghWpAnti, P_HPlus, P_ghZ, P_Ha, 3907, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_Ha, P_HMinus, 8449, check)
      call createCurrent(P_HQPlus, P_A, P_WMinus, P_HlQ, 388, check)
      call createCurrent(P_Hh, P_Z, P_Ha, 8386, check)
      call createCurrent(P_HlQ, P_HMinus, P_Hl, P_GQPlus, 5664, check)
      call createCurrent(P_HPlus, P_HMinus, P_Hh, 2854, check)
      call createCurrent(P_ghZAnti, P_Ha, P_GPlus, P_ghWm, 9183, check)
      call createCurrent(P_Ha, P_GPlus, P_ghWpAnti, P_ghZ, 10180, check)
      call createCurrent(P_HPlus, P_GMinus, P_Hh, P_G0, 3743, check)
      call createCurrent(P_GMinus, P_ghA, P_HPlus, P_ghZAnti, 10465, check)
      call createCurrent(P_GQMinus, P_G0, P_Ha, P_GQPlus, 7967, check)
      call createCurrent(P_HaQ, P_ePlus, P_eMinus, 1740, check)
      call createCurrent(P_bAnti, P_GMinus, P_t, 2416, check)
      call createCurrent(P_ghZ, P_Hl, P_ghWmAnti, P_HQMinus, 5705, check)
      call createCurrent(P_HQMinus, P_WPlus, P_A, P_HaQ, 7415, check)
      call createCurrent(P_HlQ, P_G0, P_Hl, P_HaQ, 8623, check)
      call createCurrent(P_ghZAnti, P_Hl, P_HPlus, P_ghWm, 1389, check)
      call createCurrent(P_WQMinus, P_HPlus, P_Z, P_HaQ, 3061, check)
      call createCurrent(P_A, P_Hl, P_G0, 9822, check)
      call createCurrent(P_ghWm, P_HPlus, P_ghAAnti, P_Hh, 6604, check)
      call createCurrent(P_WQMinus, P_WPlus, P_Hh, P_HaQ, 7290, check)
      call createCurrent(P_ghWpAnti, P_HPlus, P_G0, P_ghA, 9482, check)
      call createCurrent(P_HQPlus, P_GMinus, P_Ha, P_HhQ, 189, check)
      call createCurrent(P_HMinus, P_Hl, P_HPlus, P_Hh, 6771, check)
      call createCurrent(P_Hl, P_ePlus, P_eMinus, 3849, check)
      call createCurrent(P_WQPlus, P_Hh, P_WMinus, P_GQ0, 3405, check)
      call createCurrent(P_HlQ, P_ghWmAnti, P_Hl, P_ghWm, 1469, check)
      call createCurrent(P_HMinus, P_GPlus, P_G0, P_Hl, 5436, check)
      call createCurrent(P_WPlus, P_Hl, P_WMinus, P_Hl, 204, check)
      call createCurrent(P_HPlus, P_HMinus, 8843, check)
      call createCurrent(P_HPlus, P_HMinus, P_Ha, P_Ha, 7063, check)
      call createCurrent(P_HPlus, P_ghZ, P_HMinus, P_ghZAnti, 4195, check)
      call createCurrent(P_Hl, P_WPlus, P_WMinus, P_Hh, 10174, check)
      call createCurrent(P_ghZ, P_ghAAnti, P_GMinus, P_GPlus, 6861, check)
      call createCurrent(P_ghWm, P_HPlus, P_ghZAnti, P_Hh, 4853, check)
      call createCurrent(P_WQPlus, P_WMinus, P_Ha, P_HaQ, 1432, check)
      call createCurrent(P_A, P_G0, P_GMinus, P_WPlus, 5338, check)
      call createCurrent(P_Ha, P_GMinus, P_ghZAnti, P_ghWp, 9036, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_AQ, 2116, check)
      call createCurrent(P_HPlus, P_HMinus, P_ghWpAnti, P_ghWp, 3870, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_Hl, P_HlQ, 1841, check)
      call createCurrent(P_HhQ, P_WMinus, P_WPlus, P_HhQ, 6939, check)
      call createCurrent(P_Ha, P_WMinus, P_HPlus, 3890, check)
      call createCurrent(P_G0, P_WPlus, P_GMinus, 8644, check)
      call createCurrent(P_ghZAnti, P_HMinus, P_ghZ, P_GPlus, 10053, check)
      call createCurrent(P_Ha, P_GMinus, P_Hh, P_HPlus, 7303, check)
      call createCurrent(P_g, P_WPlus, P_g, P_WMinus, 10611, check)
      call createCurrent(P_HPlus, P_Hh, P_HMinus, P_G0, 10315, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_Ha, P_HQMinus, 3249, check)
      call createCurrent(P_Hl, P_Z, P_Hl, P_A, 10114, check)
      call createCurrent(P_HQPlus, P_WMinus, P_Ha, P_AQ, 4916, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_WPlus, P_WQMinus, 3927, check)
      call createCurrent(P_HMinus, P_ghAAnti, P_ghA, P_GPlus, 9791, check)
      call createCurrent(P_Hl, P_HMinus, P_HPlus, P_Hl, 3229, check)
      call createCurrent(P_A, P_GPlus, P_Hl, P_WMinus, 8458, check)
      call createCurrent(P_ghWmAnti, P_G0, P_ghWm, P_HlQ, 7904, check)
      call createCurrent(P_cAnti, P_c, P_HlQ, 5349, check)
      call createCurrent(P_HhQ, P_HMinus, P_ghAAnti, P_ghWp, 906, check)
      call createCurrent(P_ghZ, P_A, P_ghWmAnti, P_WMinus, 1972, check)
      call createCurrent(P_GQPlus, P_WPlus, P_GMinus, P_WQMinus, 6748, check)
      call createCurrent(P_ghWmAnti, P_Z, P_ghWm, P_AQ, 3579, check)
      call createCurrent(P_GPlus, P_WMinus, P_Z, P_Ha, 10125, check)
      call createCurrent(P_HlQ, P_ghWpAnti, P_G0, P_ghWp, 7914, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_Ha, P_GPlus, 9391, check)
      call createCurrent(P_HhQ, P_ghWp, P_Hh, P_ghWpAnti, 3768, check)
      call createCurrent(P_tAnti, P_g, P_t, 7662, check)
      call createCurrent(P_GMinus, P_Z, P_G0, P_WPlus, 507, check)
      call createCurrent(P_WMinus, P_ghZAnti, P_WPlus, P_ghZ, 8374, check)
      call createCurrent(P_Hl, P_GPlus, P_ghZ, P_ghWpAnti, 2785, check)
      call createCurrent(P_Ha, P_HPlus, P_Hl, P_HMinus, 10196, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_ghA, P_WQPlus, 5009, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_Hh, P_HMinus, 5291, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghWpAnti, 4898, check)
      call createCurrent(P_HQMinus, P_G0, P_GPlus, P_HhQ, 6267, check)
      call createCurrent(P_WQMinus, P_Ha, P_WPlus, P_HaQ, 2310, check)
      call createCurrent(P_ZQ, P_HPlus, P_Ha, P_WQMinus, 7614, check)
      call createCurrent(P_HPlus, P_ghWpAnti, P_ghA, P_Ha, 7034, check)
      call createCurrent(P_cAnti, P_s, P_HPlus, 7730, check)
      call createCurrent(P_G0, P_HMinus, P_Hh, P_HPlus, 8992, check)
      call createCurrent(P_c, P_cAnti, P_ZQ, 2133, check)
      call createCurrent(P_HMinus, P_ghWp, P_ghWpAnti, P_GPlus, 9882, check)
      call createCurrent(P_HQMinus, P_Ha, P_ghWmAnti, P_ghZ, 7646, check)
      call createCurrent(P_tAnti, P_HPlus, P_b, 6074, check)
      call createCurrent(P_HMinus, P_HPlus, P_ghWp, P_ghWpAnti, 282, check)
      call createCurrent(P_Ha, P_GPlus, P_WMinus, P_Z, 8996, check)
      call createCurrent(P_GQ0, P_Hl, P_Hl, P_HaQ, 5233, check)
      call createCurrent(P_HQPlus, P_ghWpAnti, P_ghA, 8822, check)
      call createCurrent(P_A, P_WPlus, P_A, P_WMinus, 7494, check)
      call createCurrent(P_GPlus, P_ghZ, P_G0, P_ghWpAnti, 2086, check)
      call createCurrent(P_WPlus, P_Hh, P_A, P_HMinus, 8574, check)
      call createCurrent(P_Hl, P_Hl, P_ghWpAnti, P_ghWp, 457, check)
      call createCurrent(P_nu_eAnti, P_eMinus, P_HPlus, 7976, check)
      call createCurrent(P_HMinus, P_ghWm, P_GPlus, P_ghWmAnti, 9306, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_HMinus, P_GPlus, 10382, check)
      call createCurrent(P_GQ0, P_HPlus, P_Hh, P_GQMinus, 1074, check)
      call createCurrent(P_Ha, P_Ha, P_A, P_A, 10502, check)
      call createCurrent(P_HhQ, P_GMinus, P_G0, P_HQPlus, 7770, check)
      call createCurrent(P_HQPlus, P_Ha, P_HMinus, P_HhQ, 130, check)
      call createCurrent(P_HQPlus, P_Hh, P_HMinus, P_GQ0, 932, check)
      call createCurrent(P_Ha, P_Ha, P_ghWpAnti, P_ghWp, 2947, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_WMinus, P_ghZ, 1604, check)
      call createCurrent(P_AQ, P_HMinus, P_A, P_HQPlus, 7375, check)
      call createCurrent(P_t, P_bAnti, P_WQMinus, 1227, check)
      call createCurrent(P_Ha, P_HPlus, P_HMinus, P_G0, 8727, check)
      call createCurrent(P_AQ, P_WPlus, P_WMinus, P_ZQ, 1084, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_HMinus, P_Ha, 8721, check)
      call createCurrent(P_G0, P_ghZ, P_ghWmAnti, P_GMinus, 2240, check)
      call createCurrent(P_G0, P_WMinus, P_Ha, P_WPlus, 9517, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Ha, P_Ha, 1275, check)
      call createCurrent(P_Hl, P_muPlus, P_muMinus, 309, check)
      call createCurrent(P_HhQ, P_HPlus, P_WQMinus, 1758, check)
      call createCurrent(P_GPlus, P_WMinus, P_Hl, P_Z, 3007, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_Ha, P_HQPlus, 1029, check)
      call createCurrent(P_A, P_WPlus, P_ghZAnti, P_ghWm, 4066, check)
      call createCurrent(P_ghWmAnti, P_Z, P_WMinus, P_ghZ, 6315, check)
      call createCurrent(P_HQPlus, P_ghA, P_HMinus, P_ghZAnti, 7134, check)
      call createCurrent(P_Hh, P_Hl, P_GMinus, P_GPlus, 4961, check)
    end subroutine createCurrents

    subroutine check_vertices_mdl()
      call createCurrents(.true.)
    end subroutine check_vertices_mdl

    subroutine get_vertex_lorentz_rank_mdl(ty,cc,mr)
      integer, intent(in) :: ty
      logical, intent(in) :: cc(0:)
      integer, intent(out) :: mr
      select case(ty)
      case(5)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(6)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(12)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(13)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(24)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(25)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(26)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(27)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(28)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(31)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(32)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(34)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(39)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(40)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(42)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(43)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(68)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(69)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(70)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(71)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(72)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(73)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(74)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(75)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(78)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(79)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(80)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(81)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(85)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(86)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(95)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(96)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(99)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(105)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(106)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(109)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(110)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case default
        mr = 0
      end select 
    end subroutine get_vertex_lorentz_rank_mdl
end module class_vertices
